/* Copyright (C) 2007-2022 Free Software Foundation, Inc.

This file is part of GCC.

GCC is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 3, or (at your option) any later
version.

GCC is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

Under Section 7 of GPL version 3, you are granted additional
permissions described in the GCC Runtime Library Exception, version
3.1, as published by the Free Software Foundation.

You should have received a copy of the GNU General Public License and
a copy of the GCC Runtime Library Exception along with this program;
see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
<http://www.gnu.org/licenses/>.  */

#include "bid_internal.h"

// Counting leading zeros in an unsigned 32-bit word
// The "_nz" version will return the wrong answer (31) for zero inputs

#define CLZ32_MASK16 0xFFFF0000ul
#define CLZ32_MASK8  0xFF00FF00ul
#define CLZ32_MASK4  0xF0F0F0F0ul
#define CLZ32_MASK2  0xCCCCCCCCul
#define CLZ32_MASK1  0xAAAAAAAAul

#define clz32_nz(n)                                             \
 (((((n) & CLZ32_MASK16) <= ((n) & ~CLZ32_MASK16)) ? 16 : 0) +  \
  ((((n) & CLZ32_MASK8) <= ((n) & ~CLZ32_MASK8)) ? 8 : 0) +     \
  ((((n) & CLZ32_MASK4) <= ((n) & ~CLZ32_MASK4)) ? 4 : 0) +     \
  ((((n) & CLZ32_MASK2) <= ((n) & ~CLZ32_MASK2)) ? 2 : 0) +     \
  ((((n) & CLZ32_MASK1) <= ((n) & ~CLZ32_MASK1)) ? 1 : 0))

#define clz32(n) (((n)==0) ? 32 : clz32_nz(n))

// Counting trailing zeros in an unsigned 32-bit word
// The ctz32_1bit version is for a single bit

#define ctz32_1bit(n)                                           \
 ((((n) & ~CLZ32_MASK16) ? 0 : 16) +                            \
  (((n) & ~CLZ32_MASK8) ? 0 : 8) +                              \
  (((n) & ~CLZ32_MASK4) ? 0 : 4) +                              \
  (((n) & ~CLZ32_MASK2) ? 0 : 2) +                              \
  (((n) & ~CLZ32_MASK1) ? 0 : 1))

#define ctz32(n) (((n) == 0) ? 32 : ctz32_1bit((n) & -(n)))

// Counting leading zeros in an unsigned 64-bit word
// The "_nz" version will return the wrong answer (63) for zero inputs

#define CLZ64_MASK32 0xFFFFFFFF00000000ull
#define CLZ64_MASK16 0xFFFF0000FFFF0000ull
#define CLZ64_MASK8  0xFF00FF00FF00FF00ull
#define CLZ64_MASK4  0xF0F0F0F0F0F0F0F0ull
#define CLZ64_MASK2  0xCCCCCCCCCCCCCCCCull
#define CLZ64_MASK1  0xAAAAAAAAAAAAAAAAull

#define clz64_nz(n)                                             \
 (((((n) & CLZ64_MASK32) <= ((n) & ~CLZ64_MASK32)) ? 32 : 0) +  \
  ((((n) & CLZ64_MASK16) <= ((n) & ~CLZ64_MASK16)) ? 16 : 0) +  \
  ((((n) & CLZ64_MASK8) <= ((n) & ~CLZ64_MASK8)) ? 8 : 0) +     \
  ((((n) & CLZ64_MASK4) <= ((n) & ~CLZ64_MASK4)) ? 4 : 0) +     \
  ((((n) & CLZ64_MASK2) <= ((n) & ~CLZ64_MASK2)) ? 2 : 0) +     \
  ((((n) & CLZ64_MASK1) <= ((n) & ~CLZ64_MASK1)) ? 1 : 0))      \

#define clz64(n) (((n)==0) ? 64 : clz64_nz(n))

// Counting trailing zeros in an unsigned 64-bit word
// The ctz64_1bit version is for a single bit

#define ctz64_1bit(n)                                           \
 ((((n) & ~CLZ64_MASK32) ? 0 : 32) +                            \
  (((n) & ~CLZ64_MASK16) ? 0 : 16) +                            \
  (((n) & ~CLZ64_MASK8) ? 0 : 8) +                              \
  (((n) & ~CLZ64_MASK4) ? 0 : 4) +                              \
  (((n) & ~CLZ64_MASK2) ? 0 : 2) +                              \
  (((n) & ~CLZ64_MASK1) ? 0 : 1))

#define ctz64(n) (((n) == 0) ? 64 : ctz64_1bit((n) & -(n)))

// Counting leading zeros in an unsigned 2-part 128-bit word

#define clz128(n_hi,n_lo) (((n_hi) == 0) ? 64 + clz64(n_lo) : clz64_nz(n_hi))

// Counting trailing zeros in a 2-part 128-bit word

#define ctz128(hi,lo) (((lo) == 0) ? 64 + ctz64(hi) : ctz64(lo))

// Shift 2-part 2^64 * hi + lo left by "c" bits
// The "short" form requires a shift 0 < c < 64 and will be faster
// Note that shifts of 64 can't be relied on as ANSI

#define sll128_short(hi,lo,c)                                   \
  ((hi) = ((hi) << (c)) + ((lo)>>(64-(c))),                     \
   (lo) = (lo) << (c)                                           \
  )

#define sll128(hi,lo,c)                                         \
  (((c) == 0) ? hi = hi, lo = lo :                              \
  (((c) >= 64) ? hi = lo << ((c) - 64), lo = 0 : sll128_short(hi,lo,c)))

// Shift 2-part 2^64 * hi + lo right by "c" bits
// The "short" form requires a shift 0 < c < 64 and will be faster
// Note that shifts of 64 can't be relied on as ANSI

#define srl128_short(hi,lo,c)                                   \
  ((lo) = ((hi) << (64 - (c))) + ((lo) >> (c)),                 \
   (hi) = (hi) >> (c)                                           \
  )

#define srl128(hi,lo,c)                                         \
  (((c) == 0) ? hi = hi, lo = lo :                              \
  (((c) >= 64) ? lo = hi >> ((c) - 64), hi = 0 : srl128_short(hi,lo,c)))

// Shift 4-part 2^196 * x3 + 2^128 * x2 + 2^64 * x1 + x0
// right by "c" bits (must have c < 64)

#define srl256(x3,x2,x1,x0,c)                                   \
  ((x0) = ((x1) << (64 - (c))) + ((x0) >> (c)),                 \
   (x1) = ((x2) << (64 - (c))) + ((x1) >> (c)),                 \
   (x2) = ((x3) << (64 - (c))) + ((x2) >> (c)),                 \
   (x3) = (x3) >> (c)                                           \
  )

// Compare "<" two 2-part unsigned integers

#define lt128(x_hi,x_lo,y_hi,y_lo)                              \
  (((x_hi) < (y_hi)) || (((x_hi) == (y_hi)) && ((x_lo) < (y_lo))))

// Likewise "<="

#define le128(x_hi,x_lo,y_hi,y_lo)                              \
  (((x_hi) < (y_hi)) || (((x_hi) == (y_hi)) && ((x_lo) <= (y_lo))))

// 128x256->384 bit multiplication (missing from existing macros)
// I derived this by propagating (A).w[2] = 0 in __mul_192x256_to_448

#define __mul_128x256_to_384(P, A, B)                           \
{                                                               \
UINT512 P0,P1;                                                  \
UINT64 CY;                                                      \
        __mul_64x256_to_320(P0, (A).w[0], B);                   \
        __mul_64x256_to_320(P1, (A).w[1], B);                   \
        (P).w[0] = P0.w[0];                                     \
        __add_carry_out((P).w[1],CY,P1.w[0],P0.w[1]);           \
        __add_carry_in_out((P).w[2],CY,P1.w[1],P0.w[2],CY);     \
        __add_carry_in_out((P).w[3],CY,P1.w[2],P0.w[3],CY);     \
        __add_carry_in_out((P).w[4],CY,P1.w[3],P0.w[4],CY);     \
        (P).w[5] = P1.w[4] + CY;                                \
}

// Multiply a 64-bit number by 10, getting "carry" and "sum"

#define __mul_10x64(sum,carryout,input,carryin)                         \
{ unsigned long long s3 = (input) + ((input) >> 2);                     \
  (carryout) = ((s3 < (unsigned long long)(input))<<3) + (s3>>61);      \
  s3 = (s3<<3) + ((input&3)<<1);                                        \
  (sum) = s3 + (carryin);                                               \
  if ((unsigned long long)(sum) < s3) ++(carryout);                     \
}

// Multiply a 256-bit number by 10, assuming no overflow

#define __mul_10x256_to_256(p3,p2,p1,p0,a3,a2,a1,a0)            \
{ unsigned long long c0,c1,c2,c3;                               \
  __mul_10x64(p0,c0,a0,0ull);                                   \
  __mul_10x64(p1,c1,a1,c0);                                     \
  __mul_10x64(p2,c2,a2,c1);                                     \
  __mul_10x64(p3,c3,a3,c2);                                     \
}

// Set up indices for low and high parts, depending on the endian-ness.
// Note that this only affects 128-bit input and output operands, not any
// of the internal workings, where w[0] is always the low-order part.

#if BID_BIG_ENDIAN
typedef union {
  struct {
    unsigned short hi;
    unsigned short lo1;
    unsigned short lo2;
    unsigned short lo3;
    unsigned short lo4;
    unsigned short pad;
    unsigned pad128;
  } i;
  BINARY80 f;
}
BID_BINARY80LDOUBLE;
#else
typedef union {
  struct {
    unsigned short lo4;
    unsigned short lo3;
    unsigned short lo2;
    unsigned short lo1;
    unsigned short hi;
    unsigned short pad;
    unsigned pad128;
  } i;
  BINARY80 f;
}
BID_BINARY80LDOUBLE;
#endif

// Pack and return binary floating-point numbers from raw fields

#if !DECIMAL_CALL_BY_REFERENCE
#define return_binary32(s,e,c)                  \
 { union {UINT32 i; float f; } x_out;           \
   x_out.i = (((UINT32)(s)) << 31) +            \
           (((UINT32)(e)) << 23) +              \
           (c);                                 \
   return x_out.f;                              \
}
#else
#define return_binary32(s,e,c)                  \
 { union {UINT32 i; float f; } x_out;           \
   x_out.i = (((UINT32)(s)) << 31) +            \
           (((UINT32)(e)) << 23) +              \
           (c);                                 \
   *pres = x_out.f;                             \
   return;                                      \
}
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_binary64(s,e,c)                  \
 { union {UINT64 i; double f; } x_out;          \
   x_out.i = (((UINT64)(s)) << 63) +            \
           (((UINT64)(e)) << 52) +              \
           (c);                                 \
   return x_out.f;                              \
 }
#else
#define return_binary64(s,e,c)                  \
 { union {UINT64 i; double f; } x_out;          \
   x_out.i = (((UINT64)(s)) << 63) +            \
           (((UINT64)(e)) << 52) +              \
           (c);                                 \
   *pres = x_out.f;                             \
   return;                                      \
 }
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_binary80(s,e,c)                      \
 { BID_BINARY80LDOUBLE x_out;                       \
   x_out.i.pad128 = 0;                              \
   x_out.i.pad = 0;                                 \
   x_out.i.lo4 =  (c)&0xffff;                       \
   x_out.i.lo3 = ((c)&0xffff0000) >> 16;            \
   x_out.i.lo2 = ((c)&0xffff00000000ull) >> 32;     \
   x_out.i.lo1 = ((c)&0xffff000000000000ull) >> 48; \
   x_out.i.hi = (((UINT64)(s)) << 15) +             \
                (e);                                \
   return x_out.f;                                  \
 }
#else
#define return_binary80(s,e,c)                      \
 { BID_BINARY80LDOUBLE x_out;                       \
   x_out.i.pad128 = 0;                              \
   x_out.i.pad = 0;                                 \
   x_out.i.lo4 =  (c)&0xffff;                       \
   x_out.i.lo3 = ((c)&0xffff0000) >> 16;            \
   x_out.i.lo2 = ((c)&0xffff00000000ull) >> 32;     \
   x_out.i.lo1 = ((c)&0xffff000000000000ull) >> 48; \
   x_out.i.hi = ((s) << 15) +                       \
                (e);                                \
   *pres = x_out.f;                                 \
   return;                                          \
 }
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_binary128(s,e,c_hi,c_lo)                 \
 { union {UINT128 i; BINARY128 f; } x_out;             \
   x_out.i.w[LOW_128W] = (c_lo);                   \
   x_out.i.w[HIGH_128W] = (((UINT64)(s)) << 63) +   \
                (((UINT64)(e)) << 48) +                 \
                (c_hi);                                 \
   return x_out.f;                                      \
 }
#else
#define return_binary128(s,e,c_hi,c_lo)                 \
 { union {UINT128 i; BINARY128 f; } x_out;             \
   x_out.i.w[LOW_128W] = (c_lo);                   \
   x_out.i.w[HIGH_128W] = (((UINT64)(s)) << 63) +   \
                (((UINT64)(e)) << 48) +                 \
                (c_hi);                                 \
   *pres = x_out.f;                                     \
   return;                                              \
 }
#endif

// Special cases of returning zero, infinity, NaN as binary FP
// Take parameters for the sign, and for NaN the significand

#define return_binary32_zero(s) return_binary32(s,0,0)
#define return_binary32_inf(s) return_binary32(s,255,0)
#define return_binary32_nan(s,c_hi,c_lo) \
  return_binary32(s,255,(c_hi>>42)+(1ul<<22))

#define return_binary64_zero(s) return_binary64(s,0,0)
#define return_binary64_inf(s) return_binary64(s,2047,0)
#define return_binary64_nan(s,c_hi,c_lo) \
  return_binary64(s,2047,(c_hi>>13)+(1ull<<51))

#define return_binary80_zero(s) return_binary80(s,0,0)
#define return_binary80_inf(s) return_binary80(s,32767,(1ull<<63))
#define return_binary80_nan(s,c_hi,c_lo) \
  return_binary80(s,32767,(c_hi>>2)+(3ull<<62))

#define return_binary128_zero(s) return_binary128(s,0,0,0)
#define return_binary128_inf(s) return_binary128(s,32767,0,0)
#define return_binary128_nan(s,c_hi,c_lo) \
  return_binary128(s,32767,(c_hi>>17)+(1ull<<47),((c_lo>>17)+(c_hi<<47)))

// Return finite values of maximal magnitude in the various formats

#define return_binary32_max(s) return_binary32(s,254,((1ul<<23)-1ul))
#define return_binary64_max(s) return_binary64(s,2046,((1ull<<52)-1ull))
#define return_binary80_max(s) return_binary80(s,32766,0xFFFFFFFFFFFFFFFFull)
#define return_binary128_max(s) \
  return_binary128(s,32766,((1ull<<48)-1ull),0xFFFFFFFFFFFFFFFFull)

#define return_bid32_max(s) return_bid32(s,191,9999999ul)
#define return_bid64_max(s) return_bid64(s,767,9999999999999999ull)
#define return_bid128_max(s)    \
  return_bid128(s,12287,542101086242752ull,4003012203950112767ull)

// Handle overflow by either infinity or maximal value as appropriate

#define return_binary32_ovf(s)                                               \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_binary32_max(s)                                                   \
  else return_binary32_inf(s)                                                \
}

#define return_binary64_ovf(s)                                               \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_binary64_max(s)                                                   \
  else return_binary64_inf(s)                                                \
}

#define return_binary80_ovf(s)                                               \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_binary80_max(s)                                                   \
  else return_binary80_inf(s)                                                \
}

#define return_binary128_ovf(s)                                              \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_binary128_max(s)                                                  \
  else return_binary128_inf(s)                                               \
}

#define return_bid32_ovf(s)                                                  \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_bid32_max(s)                                                      \
  else return_bid32_inf(s)                                                   \
}

#define return_bid64_ovf(s)                                                  \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_bid64_max(s)                                                      \
  else return_bid64_inf(s)                                                   \
}

#define return_bid128_ovf(s)                                                 \
{ if ((rnd_mode==ROUNDING_TO_ZERO) ||                                        \
      (rnd_mode==((s!=0) ? ROUNDING_UP : ROUNDING_DOWN)))                    \
    return_bid128_max(s)                                                     \
  else return_bid128_inf(s)                                                  \
}

// Unpack binary floating-point number x into
//
// int    s (sign in the LSB)
// int    e (true "integer" exponent)
//        c (normalized coefficient with explicit 1 bit)
//        t (trailing zero count, valid in normalized case only)
//        [c_hi,c_lo in the case of quad]
//
// Call the given zero, infinity or nan macros if appropriate

#define unpack_binary32(x,s,e,c,t,zero,inf,nan)                             \
{ union { UINT32 i; float f; } x_in;                                        \
  x_in.f = x;                                                               \
  c = x_in.i;                                                               \
  e = (c >> 23) & ((1ull<<8)-1);                                            \
  s = c >> 31;                                                              \
  c = c & ((1ull<<23)-1);                                                   \
  if (e == 0)                                                               \
   { int l;                                                                 \
     if (c == 0) zero;                                                      \
     l = clz32(c) - (32 - 24);                                              \
     c = c << l;                                                            \
     e = -(l + 149);                                                        \
     t = 0;                                                                 \
     *pfpsf |= DENORMAL_EXCEPTION;                                          \
   }                                                                        \
  else if (e == ((1ull<<8)-1))                                              \
   { if (c == 0) inf;                                                       \
     if ((c&(1ul<<22))==0) *pfpsf |= INVALID_EXCEPTION;                     \
     nan(s,(((unsigned long long) c)) << 42,0ull)                           \
   }                                                                        \
  else                                                                      \
   { c += 1ull<<23;                                                         \
     t = ctz32(c);                                                          \
     e -= 150;                                                              \
   }                                                                        \
}

#define unpack_binary64(x,s,e,c,t,zero,inf,nan)                             \
{ union { UINT64 i; double f; } x_in;                                       \
  x_in.f = x;                                                               \
  c = x_in.i;                                                               \
  e = (c >> 52) & ((1ull<<11)-1);                                           \
  s = c >> 63;                                                              \
  c = c & ((1ull<<52)-1);                                                   \
  if (e == 0)                                                               \
   { int l;                                                                 \
     if (c == 0) zero;                                                      \
     l = clz64(c) - (64 - 53);                                              \
     c = c << l;                                                            \
     e = -(l + 1074);                                                       \
     t = 0;                                                                 \
     *pfpsf |= DENORMAL_EXCEPTION;                                          \
   }                                                                        \
  else if (e == ((1ull<<11)-1))                                             \
   { if (c == 0) inf;                                                       \
     if ((c&(1ull<<51))==0) *pfpsf |= INVALID_EXCEPTION;                    \
     nan(s,(((unsigned long long) c) << 13),0ull)                           \
   }                                                                        \
  else                                                                      \
   { c += 1ull<<52;                                                         \
     t = ctz64(c);                                                          \
     e -= 1075;                                                             \
   }                                                                        \
}

#define unpack_binary80(x,s,e,c,t,zero,inf,nan)                             \
{ BID_BINARY80LDOUBLE x_in;                                                 \
  x_in.f = x;                                                               \
  c = x_in.i.lo4 + ((UINT64)x_in.i.lo3 << 16) +                             \
      ((UINT64)x_in.i.lo2 << 32) + ((UINT64)x_in.i.lo1 << 48);              \
  e = x_in.i.hi;                                                            \
  s = e >> 15;                                                              \
  e = (e & ((1<<15)-1));                                                    \
  if (e == 0)                                                               \
   { int l;                                                                 \
     if (c == 0) zero;                                                      \
     l = clz64(c);                                                          \
     c = c << l;                                                            \
     e -= (l + 16445);                                                      \
     t = 0;                                                                 \
     *pfpsf |= DENORMAL_EXCEPTION;                                          \
    }                                                                       \
  else if (e == ((1ull<<15)-1))                                             \
   { if ((c & ((1ull<<63)-1)) == 0) inf;                                    \
     if ((c&(1ull<<62))==0) *pfpsf |= INVALID_EXCEPTION;                    \
     nan(s,(((unsigned long long) c) << 2),0ull)                            \
   }                                                                        \
  else                                                                      \
   { t = ctz64(c);                                                          \
     e -= 16446;                                                            \
   }                                                                        \
}

#define unpack_binary128(x,s,e,c_hi,c_lo,t,zero,inf,nan)                    \
{ union { UINT128 i; BINARY128 f; } x_in;                                  \
  x_in.f = x;                                                               \
  c_lo = x_in.i.w[LOW_128W];                                           \
  c_hi = x_in.i.w[HIGH_128W];                                           \
  e = (c_hi >> 48) & ((1ull<<15)-1);                                        \
  s = c_hi >> 63;                                                           \
  c_hi = c_hi & ((1ull<<48)-1);                                             \
  if (e == 0)                                                               \
   { int l;                                                                 \
     if ((c_hi == 0) && (c_lo == 0)) zero;                                  \
     l = clz128(c_hi,c_lo) - (128 - 113);                                   \
     sll128(c_hi,c_lo,l);                                                   \
     e = -(l + 16494);                                                      \
     t = 0;                                                                 \
     *pfpsf |= DENORMAL_EXCEPTION;                                          \
   }                                                                        \
  else if (e == ((1ull<<15)-1))                                             \
   { if ((c_hi == 0) && (c_lo == 0)) inf;                                   \
     if ((c_hi&(1ull<<47))==0) *pfpsf |= INVALID_EXCEPTION;                 \
     nan(s,((((unsigned long long) c_hi) << 17) +                           \
            (((unsigned long long) c_lo) >> 47)),                           \
           (((unsigned long long) c_lo) << 17))                             \
   }                                                                        \
  else                                                                      \
   { c_hi += 1ull<<48;                                                      \
     t = ctz128(c_hi,c_lo);                                                 \
     e -= 16495;                                                            \
   }                                                                        \
}

// Pack and return decimal number from raw fields

#if !DECIMAL_CALL_BY_REFERENCE
#define return_bid32(s,e,c)                                                 \
  { if ((UINT32) (c) < (1ul<<23))                                           \
      return (((UINT32) (s) << 31) + ((UINT32) (e) << 23) + (UINT32) (c));  \
    else                                                                    \
      return (((UINT32) (s) << 31) + ((0x3ull<<29) - (1ull<<23)) +          \
             ((UINT32) (e) << 21) + (UINT32) (c));                          \
  }
#else
#define return_bid32(s,e,c)                                                 \
  { if ((UINT32) (c) < (1ul<<23))                                           \
      *pres = (((UINT32) (s) << 31) + ((UINT32) (e) << 23) + (UINT32) (c)); \
    else                                                                    \
      *pres = (((UINT32) (s) << 31) + ((0x3ull<<29) - (1ull<<23)) +         \
             ((UINT32) (e) << 21) + (UINT32) (c));                          \
    return;                                                                 \
  }
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_bid64(s,e,c)                                                 \
  { if ((c) < (1ull<<53))                                                   \
      return (((UINT64) (s) << 63) + ((UINT64) (e) << 53) + (c));           \
    else                                                                    \
      return (((UINT64) (s) << 63) + ((0x3ull<<61) - (1ull<<53)) +          \
             ((UINT64) (e) << 51) + (c));                                   \
  }
#else
#define return_bid64(s,e,c)                                                 \
  { if ((c) < (1ull<<53))                                                   \
      *pres = (((UINT64) (s) << 63) + ((UINT64) (e) << 53) + (c));          \
    else                                                                    \
      *pres = (((UINT64) (s) << 63) + ((0x3ull<<61) - (1ull<<53)) +         \
             ((UINT64) (e) << 51) + (c));                                   \
    return;                                                                 \
  }
#endif

#if !DECIMAL_CALL_BY_REFERENCE
#define return_bid128(s,e,c_hi,c_lo)                                        \
  { UINT128 x_out;                                                          \
    x_out.w[LOW_128W] = c_lo;                                          \
    x_out.w[HIGH_128W] = ((UINT64) (s) << 63) + ((UINT64) (e) << 49) +  \
                             (c_hi);                                        \
    return x_out;                                                           \
  }
#else
#define return_bid128(s,e,c_hi,c_lo)                                                    \
  { UINT128 x_out;                                                                      \
    x_out.w[LOW_128W] = c_lo;                                                      \
    x_out.w[HIGH_128W] = ((UINT64) (s) << 63) + ((UINT64) (e) << 49) + (c_hi);      \
    *pres = x_out;                                                                      \
    return;                                                                             \
  }
#endif

// Special cases of returning zero, infinity, NaN as decimal FP
// Take parameters for the sign, and for NaN the significand

#define return_bid32_zero(s) return_bid32(s,101,0)
#define return_bid32_inf(s) return_bid32(s,(0xF<<4),0)
#define return_bid32_nan(s,c_hi,c_lo)                                       \
  return_bid32(s,(0x1F<<3),(((c_hi>>44) > 999999ul) ? 0 : (c_hi>>44)));

#define return_bid64_zero(s) return_bid64(s,398,0)
#define return_bid64_inf(s) return_bid64(s,(0xF<<6),0)
#define return_bid64_nan(s,c_hi,c_lo)                                       \
  return_bid64(s,(0x1F<<5),                                                 \
               (((c_hi>>14) > 999999999999999ull) ? 0 : (c_hi>>14)));

#define return_bid128_zero(s) return_bid128(s,6176,0,0)
#define return_bid128_inf(s) return_bid128(s,(0xF<<10),0,0)
#define return_bid128_nan(s,c_hi,c_lo)                                      \
 { if (lt128(54210108624275ull,4089650035136921599ull,                      \
             (c_hi>>18),((c_lo>>18)+(c_hi<<46))))                           \
   return_bid128(s,(0x1F<<9),0ull,0ull)                                     \
   else return_bid128(s,(0x1F<<9),(c_hi>>18),((c_lo>>18)+(c_hi<<46)))       \
 }

// Unpack decimal floating-point number x into sign,exponent,coefficient
// In special cases, call the macros provided
// Coefficient is normalized in the binary sense with postcorrection k,
// so that x = 10^e * c / 2^k and the range of c is:
//
// 2^23 <= c < 2^24   (decimal32)
// 2^53 <= c < 2^54   (decimal64)
// 2^112 <= c < 2^113 (decimal128)

#define unpack_bid32(x,s,e,k,c,zero,inf,nan)                                \
{ s = x >> 31;                                                              \
  if ((x & (3ull<<29)) == (3ull<<29))                                       \
   { if ((x & (0xFull<<27)) == (0xFull<<27))                                \
      { if ((x & (0x1Full<<26)) != (0x1Full<<26)) inf;                      \
        if ((x & (1ul<<25))!=0) *pfpsf |= INVALID_EXCEPTION;                \
        nan(s,((((x) & 0xFFFFul) > 999999ul) ? 0 :                          \
               (((unsigned long long) x) << 44)),0ull);                     \
      }                                                                     \
     e = ((x >> 21) & ((1ull<<8)-1)) - 101;                                 \
     c = (1ull<<23) + (x & ((1ull<<21)-1));                                 \
     if ((unsigned long)(c) > 9999999ul) c = 0;                             \
     k = 0;                                                                 \
   }                                                                        \
  else                                                                      \
   { e = ((x >> 23) & ((1ull<<8)-1)) - 101;                                 \
     c = x & ((1ull<<23)-1);                                                \
     if (c == 0) zero;                                                      \
     k = clz32(c) - 8;                                                      \
     c = c << k;                                                            \
   }                                                                        \
}

#define unpack_bid64(x,s,e,k,c,zero,inf,nan)                                \
{ s = x >> 63;                                                              \
  if ((x & (3ull<<61)) == (3ull<<61))                                       \
   { if ((x & (0xFull<<59)) == (0xFull<<59))                                \
      { if ((x & (0x1Full<<58)) != (0x1Full<<58)) inf;                      \
        if ((x & (1ull<<57))!=0) *pfpsf |= INVALID_EXCEPTION;               \
        nan(s,((((x) & 0x3FFFFFFFFFFFFull) > 999999999999999ull) ? 0 :      \
               (((unsigned long long) x) << 14)),0ull);                     \
      }                                                                     \
     e = ((x >> 51) & ((1ull<<10)-1)) - 398;                                \
     c = (1ull<<53) + (x & ((1ull<<51)-1));                                 \
     if ((unsigned long long)(c) > 9999999999999999ull) c = 0;              \
     k = 0;                                                                 \
   }                                                                        \
  else                                                                      \
   { e = ((x >> 53) & ((1ull<<10)-1)) - 398;                                \
     c = x & ((1ull<<53)-1);                                                \
     if (c == 0) zero;                                                      \
     k = clz64(c) - 10;                                                     \
     c = c << k;                                                            \
   }                                                                        \
}

#define unpack_bid128(x,s,e,k,c,zero,inf,nan)                               \
{ s = x.w[HIGH_128W] >> 63;                                             \
  if ((x.w[HIGH_128W] & (3ull<<61)) == (3ull<<61))                      \
   { if ((x.w[HIGH_128W] & (0xFull<<59)) == (0xFull<<59))               \
      { if ((x.w[HIGH_128W] & (0x1Full<<58)) != (0x1Full<<58)) inf;     \
        if ((x.w[HIGH_128W] & (1ull<<57))!=0)                           \
           *pfpsf |= INVALID_EXCEPTION;                                     \
        if (lt128(54210108624275ull,4089650035136921599ull,                 \
            (x.w[HIGH_128W] & 0x3FFFFFFFFFFFull),x.w[LOW_128W]))   \
          nan(s,0ull,0ull);                                                 \
        nan(s,((((unsigned long long) x.w[HIGH_128W]) << 18) +          \
               (((unsigned long long) x.w[LOW_128W]) >> 46)),          \
              (((unsigned long long) x.w[LOW_128W]) << 18));           \
      }                                                                     \
     zero;                                                                  \
   }                                                                        \
  else                                                                      \
   { e = ((x.w[HIGH_128W] >> 49) & ((1ull<<14)-1)) - 6176;              \
     c.w[1] = x.w[HIGH_128W] & ((1ull<<49)-1);                          \
     c.w[0] = x.w[LOW_128W];                                           \
     if (lt128(542101086242752ull,4003012203950112767ull,                   \
               c.w[1],c.w[0]))                                              \
      { c.w[1] = 0ull; c.w[0] = 0ull; }                                     \
     if ((c.w[1] == 0) && (c.w[0] == 0)) zero;                              \
     k = clz128(c.w[1],c.w[0]) - 15;                                        \
     sll128(c.w[1],c.w[0],k);                                               \
   }                                                                        \
}

// Rounding boundaries table, indexed by
// 4 * rounding_mode + 2 * sign + lsb of truncation
// We round up if the round/sticky data is strictly > this boundary
//
// NB: This depends on the particular values of the rounding mode
// numbers, which are supposed to be defined as here:
//
// #define ROUNDING_TO_NEAREST     0x00000
// #define ROUNDING_DOWN           0x00001
// #define ROUNDING_UP             0x00002
// #define ROUNDING_TO_ZERO        0x00003
// #define ROUNDING_TIES_AWAY      0x00004
//
// Some of the shortcuts below in "underflow after rounding" also use
// the concrete values.
//
// So we add a directive here to double-check that this is the case

#if ((ROUNDING_TO_NEAREST!=0) || (ROUNDING_DOWN!=1) ||          \
     (ROUNDING_UP!=2) || (ROUNDING_TO_ZERO!=3) ||               \
     (ROUNDING_TIES_AWAY!=4))
#error "Rounding mode numbers don't match tables for binary/decimal conversion"
#endif

static const UINT128 roundbound_128[] = { {{0ull, (1ull << 63)}},       // ROUNDING_TO_NEAREST | positive | even
{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TO_NEAREST | positive | odd
{{0ull, (1ull << 63)}}, // ROUNDING_TO_NEAREST | negative | even
{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TO_NEAREST | negative | odd

{{~0ull, ~0ull}},       // ROUNDING_DOWN       | positive | even
{{~0ull, ~0ull}},       // ROUNDING_DOWN       | positive | odd
{{0ull, 0ull}}, // ROUNDING_DOWN       | negative | even
{{0ull, 0ull}}, // ROUNDING_DOWN       | negative | odd

{{0ull, 0ull}}, // ROUNDING_UP         | positive | even
{{0ull, 0ull}}, // ROUNDING_UP         | positive | odd
{{~0ull, ~0ull}},       // ROUNDING_UP         | negative | even
{{~0ull, ~0ull}},       // ROUNDING_UP         | negative | odd

{{~0ull, ~0ull}},       // ROUNDING_TO_ZERO    | positive | even
{{~0ull, ~0ull}},       // ROUNDING_TO_ZERO    | positive | odd
{{~0ull, ~0ull}},       // ROUNDING_TO_ZERO    | negative | even
{{~0ull, ~0ull}},       // ROUNDING_TO_ZERO    | negative | odd

{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TIES_AWAY  | positive | even
{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TIES_AWAY  | positive | odd
{{~0ull, (1ull << 63) - 1}},    // ROUNDING_TIES_AWAY  | negative | even
{{~0ull, (1ull << 63) - 1}}     // ROUNDING_TIES_AWAY  | negative | odd
};

// Table of powers of 5

static const UINT128 power_five[] = { {{1ull, 0ull}},
{{5ull, 0ull}},
{{25ull, 0ull}},
{{125ull, 0ull}},
{{625ull, 0ull}},
{{3125ull, 0ull}},
{{15625ull, 0ull}},
{{78125ull, 0ull}},
{{390625ull, 0ull}},
{{1953125ull, 0ull}},
{{9765625ull, 0ull}},
{{48828125ull, 0ull}},
{{244140625ull, 0ull}},
{{1220703125ull, 0ull}},
{{6103515625ull, 0ull}},
{{30517578125ull, 0ull}},
{{152587890625ull, 0ull}},
{{762939453125ull, 0ull}},
{{3814697265625ull, 0ull}},
{{19073486328125ull, 0ull}},
{{95367431640625ull, 0ull}},
{{476837158203125ull, 0ull}},
{{2384185791015625ull, 0ull}},
{{11920928955078125ull, 0ull}},
{{59604644775390625ull, 0ull}},
{{298023223876953125ull, 0ull}},
{{1490116119384765625ull, 0ull}},
{{7450580596923828125ull, 0ull}},
{{359414837200037393ull, 2ull}},
{{1797074186000186965ull, 10ull}},
{{8985370930000934825ull, 50ull}},
{{8033366502585570893ull, 252ull}},
{{3273344365508751233ull, 1262ull}},
{{16366721827543756165ull, 6310ull}},
{{8046632842880574361ull, 31554ull}},
{{3339676066983768573ull, 157772ull}},
{{16698380334918842865ull, 788860ull}},
{{9704925379756007861ull, 3944304ull}},
{{11631138751360936073ull, 19721522ull}},
{{2815461535676025517ull, 98607613ull}},
{{14077307678380127585ull, 493038065ull}},
{{15046306170771983077ull, 2465190328ull}},
{{1444554559021708921ull, 12325951644ull}},
{{7222772795108544605ull, 61629758220ull}},
{{17667119901833171409ull, 308148791101ull}},
{{14548623214327650581ull, 1540743955509ull}},
{{17402883850509598057ull, 7703719777548ull}},
{{13227442957709783821ull, 38518598887744ull}},
{{10796982567420264257ull, 192592994438723ull}}
};


// Tables of values for the various conversions:
//
// exponents: table of output exponents
// breakpoints: test values to decide between two possible exponents
// multipliers1/multipliers2: corresponding reciprocal multipliers
// coefflimits: used in exactness checks
//

static const UINT128 breakpoints_binary32[] =
  { {{17291492046443221751ull, 474778387287989ull}},
{{17522542451896487724ull, 379822709830391ull}},
{{10328685146775279856ull, 303858167864313ull}},
{{12836547420098537447ull, 486173068582901ull}},
{{6579889121336919634ull, 388938454866321ull}},
{{1574562482327625384ull, 311150763893057ull}},
{{6208648786466110938ull, 497841222228891ull}},
{{1277570214430978427ull, 398272977783113ull}},
{{8400753801028603388ull, 318618382226490ull}},
{{13441206081645765421ull, 509789411562384ull}},
{{14442313680058522660ull, 407831529249907ull}},
{{4175153314562997481ull, 326265223399926ull}},
{{17748291747526526940ull, 522024357439881ull}},
{{10509284583279311229ull, 417619485951905ull}},
{{8407427666623448983ull, 334095588761524ull}},
{{2383837822371787403ull, 534552942018439ull}},
{{5596419072639340246ull, 427642353614751ull}},
{{787786443369561873ull, 342113882891801ull}},
{{12328504753617029967ull, 547382212626881ull}},
{{6173454988151713650ull, 437905770101505ull}},
{{4938763990521370920ull, 350324616081204ull}},
{{15280720014318014119ull, 560519385729926ull}},
{{8535227196712500972ull, 448415508583941ull}},
{{3138832942628090454ull, 358732406867153ull}},
{{9889763983586293010ull, 286985925493722ull}},
{{1066227114770427523ull, 459177480789956ull}},
{{15610376950783983311ull, 367341984631964ull}},
{{16177650375369096972ull, 293873587705571ull}},
{{58798897397182893ull, 470197740328915ull}},
{{47039117917746314ull, 376158192263132ull}},
{{11105677738559928021ull, 300926553810505ull}},
{{17769084381695884834ull, 481482486096808ull}},
{{3147221061130976897ull, 385185988877447ull}},
{{13585823293130512487ull, 308148791101957ull}},
{{6979922010041178687ull, 493038065763132ull}},
{{16651984052258673919ull, 394430452610505ull}},
{{13321587241806939135ull, 315544362088404ull}},
{{10246493142665371647ull, 504870979341447ull}},
{{818496884648476671ull, 403896783473158ull}},
{{8033495137202601983ull, 323117426778526ull}},
{{5474894590040342527ull, 516987882845642ull}},
{{15447962116258004991ull, 413590306276513ull}},
{{1290323248780673023ull, 330872245021211ull}},
{{13132563642274807807ull, 529395592033937ull}},
{{3127353284336025599ull, 423516473627150ull}},
{{2501882627468820479ull, 338813178901720ull}},
{{4003012203950112767ull, 542101086242752ull}},
{{14270456207385821183ull, 433680868994201ull}},
{{7727016151166746623ull, 346944695195361ull}},
{{4984528212382973951ull, 555111512312578ull}},
{{11366320199390199807ull, 444089209850062ull}},
{{1714358530028339199ull, 355271367880050ull}},
{{1371486824022671359ull, 284217094304040ull}},
{{2194378918436274175ull, 454747350886464ull}},
{{5444851949490929663ull, 363797880709171ull}},
{{666532744850833407ull, 291038304567337ull}},
{{4755801206503243775ull, 465661287307739ull}},
{{7493989779944505343ull, 372529029846191ull}},
{{2305843009213693951ull, 298023223876953ull}},
{{18446744073709551615ull, 476837158203124ull}},
{{18446744073709551615ull, 381469726562499ull}},
{{18446744073709551615ull, 305175781249999ull}},
{{18446744073709551615ull, 488281249999999ull}},
{{18446744073709551615ull, 390624999999999ull}},
{{18446744073709551615ull, 312499999999999ull}},
{{18446744073709551615ull, 499999999999999ull}},
{{18446744073709551615ull, 399999999999999ull}},
{{18446744073709551615ull, 319999999999999ull}},
{{18446744073709551615ull, 511999999999999ull}},
{{18446744073709551615ull, 409599999999999ull}},
{{18446744073709551615ull, 327679999999999ull}},
{{18446744073709551615ull, 524287999999999ull}},
{{18446744073709551615ull, 419430399999999ull}},
{{18446744073709551615ull, 335544319999999ull}},
{{18446744073709551615ull, 536870911999999ull}},
{{18446744073709551615ull, 429496729599999ull}},
{{18446744073709551615ull, 343597383679999ull}},
{{18446744073709551615ull, 549755813887999ull}},
{{18446744073709551615ull, 439804651110399ull}},
{{18446744073709551615ull, 351843720888319ull}},
{{18446744073709551615ull, 281474976710655ull}},
{{11068046444225730969ull, 450359962737049ull}},
{{12543785970122495098ull, 360287970189639ull}},
{{13724377590839906402ull, 288230376151711ull}},
{{14580306515860029597ull, 461168601842738ull}},
{{596198768462292708ull, 368934881474191ull}},
{{15234354273737475459ull, 295147905179352ull}},
{{9617571579012319442ull, 472236648286964ull}},
{{11383406077951765876ull, 377789318629571ull}},
{{5417376047619502378ull, 302231454903657ull}},
{{12357150490933114128ull, 483570327845851ull}},
{{6196371578004580979ull, 386856262276681ull}},
{{1267748447661754460ull, 309485009821345ull}},
{{2028397516258807136ull, 495176015714152ull}},
{{12690764457232776679ull, 396140812571321ull}},
{{6463262751044311020ull, 316912650057057ull}},
{{14030569216412807955ull, 507060240091291ull}},
{{7535106558388336041ull, 405648192073033ull}},
{{13406782876194489479ull, 324518553658426ull}},
{{14072154972427362520ull, 519229685853482ull}},
{{3879026348458069369ull, 415383748682786ull}},
{{17860616337734096788ull, 332306998946228ull}},
{{6440893251923092922ull, 531691198313966ull}},
{{1463365786796564015ull, 425352958651173ull}},
{{8549390258921071858ull, 340282366920938ull}},
{{9989675599531804650ull, 544451787073501ull}},
{{4302391664883533397ull, 435561429658801ull}},
{{18199308590874468010ull, 348449143727040ull}},
{{10672149671689597200ull, 557518629963265ull}},
{{8537719737351677760ull, 446014903970612ull}},
{{17898222234107073178ull, 356811923176489ull}},
{{18007926602027568865ull, 285449538541191ull}},
{{2987240860050737922ull, 456719261665907ull}},
{{13457839132266321307ull, 365375409332725ull}},
{{10766271305813057046ull, 292300327466180ull}},
{{17226034089300891273ull, 467680523945888ull}},
{{2712780827214982049ull, 374144419156711ull}},
{{16927619920739626932ull, 299315535325368ull}},
{{4948098984731941152ull, 478904856520590ull}},
{{3958479187785552922ull, 383123885216472ull}}
};

static const int exponents_binary32[] = { -27,
  -24,
  -21,
  -17,
  -14,
  -11,
  -7,
  -4,
  -1,
  3,
  6,
  9,
  13,
  16,
  19,
  23,
  26,
  29,
  33,
  36,
  39,
  43,
  46,
  49,
  52,
  56,
  59,
  62,
  66,
  69,
  72,
  76,
  79,
  82,
  86,
  89,
  92,
  96,
  99,
  102,
  106,
  109,
  112,
  116,
  119,
  122,
  126,
  129,
  132,
  136,
  139,
  142,
  145,
  149,
  152,
  155,
  159,
  162,
  165,
  169,
  172,
  175,
  179,
  182,
  185,
  189,
  192,
  195,
  199,
  202,
  205,
  209,
  212,
  215,
  219,
  222,
  225,
  229,
  232,
  235,
  238,
  242,
  245,
  248,
  252,
  255,
  258,
  262,
  265,
  268,
  272,
  275,
  278,
  282,
  285,
  288,
  292,
  295,
  298,
  302,
  305,
  308,
  312,
  315,
  318,
  322,
  325,
  328,
  332,
  335,
  338,
  341,
  345,
  348,
  351,
  355,
  358,
  361,
  365,
  368,
};

static const UINT256 multipliers1_binary32[] =
  { {{6013890151484785128ull, 7481633477359093489ull,
      655737588518723529ull, 651851512427ull}},
{{12129048707783369314ull, 13963727865126254765ull,
  14654730040930568123ull, 814814390533ull}},
{{1326252829447047930ull, 12842973812980430553ull,
  4483354495881046442ull, 1018517988167ull}},
{{12358123064472874716ull, 12638544651540156999ull,
  9719625587566735882ull, 636573742604ull}},
{{10835967812163705491ull, 6574808777570420441ull,
  12149531984458419853ull, 795717178255ull}},
{{18156645783632019768ull, 12830196990390413455ull,
  10575228962145636912ull, 994646472819ull}},
{{18265432642411094211ull, 8018873118994008409ull,
  4303675092127329118ull, 621654045512ull}},
{{8996732747731704052ull, 800219361887734704ull, 5379593865159161398ull,
  777067556890ull}},
{{11245915934664630065ull, 10223646239214444188ull,
  15947864368303727555ull, 971334446112ull}},
{{16252069496020169599ull, 4083935890295333665ull,
  9967415230189829722ull, 607084028820ull}},
{{6480028814743048286ull, 14328291899723942890ull,
  12459269037737287152ull, 758855036025ull}},
{{17323408055283586166ull, 17910364874654928612ull,
  1739028241889445228ull, 948568795032ull}},
{{1603757997697465546ull, 1970606009804554575ull,
  1086892651180903268ull, 592855496895ull}},
{{15839755552403995644ull, 2463257512255693218ull,
  15193673869258292797ull, 741069371118ull}},
{{10576322403650218747ull, 7690757908747004427ull,
  9768720299718090188ull, 926336713898ull}},
{{4304358493067692765ull, 14030095729821653575ull,
  10717136205751194271ull, 578960446186ull}},
{{768762097907228052ull, 12925933643849679065ull,
  4173048220334217031ull, 723700557733ull}},
{{5572638640811422969ull, 11545731036384710927ull,
  9827996293845159193ull, 904625697166ull}},
{{10400428178148221212ull, 298552870099362473ull,
  1530811665225836592ull, 565391060729ull}},
{{17612221241112664419ull, 373191087624203091ull,
  6525200599959683644ull, 706738825911ull}},
{{17403590532963442619ull, 466488859530253864ull,
  3544814731522216651ull, 883423532389ull}},
{{10877244083102151637ull, 16432456601702266329ull,
  4521352216415079358ull, 552139707743ull}},
{{18208241122305077450ull, 11317198715273057103ull,
  1040004252091461294ull, 690174634679ull}},
{{18148615384453958909ull, 4923126357236545571ull,
  15135063370396490330ull, 862718293348ull}},
{{18074083212140060732ull, 15377279983400457772ull,
  472085139286061296ull, 1078397866686ull}},
{{2072929970732762150ull, 9610799989625286108ull,
  14130111267335952022ull, 673998666678ull}},
{{2591162463415952687ull, 2790127950176831827ull,
  8439267047315164220ull, 842498333348ull}},
{{17074011134552104570ull, 3487659937721039783ull,
  10549083809143955275ull, 1053122916685ull}},
{{17588785986736147213ull, 18320688525571507528ull,
  8899020389928665998ull, 658201822928ull}},
{{3539238409710632400ull, 13677488620109608603ull,
  11123775487410832498ull, 822752278660ull}},
{{18259106067420454212ull, 7873488738282234945ull,
  13904719359263540623ull, 1028440348325ull}},
{{4494412264496702026ull, 11838459489067478697ull,
  10996292608753406841ull, 642775217703ull}},
{{10229701349048265437ull, 963016306052184659ull,
  9133679742514370648ull, 803469022129ull}},
{{8175440667882943892ull, 1203770382565230824ull,
  16028785696570351214ull, 1004336277661ull}},
{{5109650417426839933ull, 14587414544385432977ull,
  12323834069570163460ull, 627710173538ull}},
{{10998749040210937820ull, 18234268180481791221ull,
  6181420550107928517ull, 784637716923ull}},
{{18360122318691060179ull, 8957777170320075314ull,
  3115089669207522743ull, 980797146154ull}},
{{16086762467609300516ull, 12516139759091128927ull,
  6558617061682089618ull, 612998216346ull}},
{{15496767066084237741ull, 6421802662009135351ull,
  17421643363957387831ull, 766247770432ull}},
{{14759272814177909272ull, 3415567309084031285ull,
  3330310131237183173ull, 957809713041ull}},
{{11530388518074887247ull, 4440572577391213505ull,
  13610658878091709243ull, 598631070650ull}},
{{577927592311445347ull, 939029703311628978ull, 7789951560759860746ull,
  748288838313ull}},
{{9945781527244082491ull, 10397159165994312030ull,
  14349125469377213836ull, 935361047891ull}},
{{1604427436100163653ull, 15721596515601220827ull,
  6662360409147064695ull, 584600654932ull}},
{{15840592350407368278ull, 15040309626074138129ull,
  8327950511433830869ull, 730750818665ull}},
{{5965682382727046636ull, 4965328977310508950ull,
  15021624157719676491ull, 913438523331ull}},
{{17563609544486567859ull, 797487601605374141ull,
  7082672089361103855ull, 570899077082ull}},
{{8119453875326046112ull, 14831917557288881389ull,
  18076712148556155626ull, 713623846352ull}},
{{14761003362584945544ull, 9316524909756325928ull,
  4149146111985642917ull, 892029807941ull}},
{{9225627101615590965ull, 8128671077811397657ull,
  4899059329204720775ull, 557518629963ull}},
{{16143719895446876610ull, 5549152828836859167ull,
  1512138143078513065ull, 696898287454ull}},
{{15567963850881207859ull, 11548127054473461863ull,
  11113544715702917139ull, 871122859317ull}},
{{14848268795174121920ull, 9823472799664439425ull, 56872839346482712ull,
  1088903574147ull}},
{{2362638969342744344ull, 6139670499790274641ull,
  16176446589087409359ull, 680564733841ull}},
{{7564984730105818334ull, 3062902106310455397ull,
  6385500181077097987ull, 850705917302ull}},
{{14067916931059660821ull, 17663685688170232958ull,
  17205247263201148291ull, 1063382396627ull}},
{{4180762063484900109ull, 8733960545892701647ull,
  8447436530287023730ull, 664613997892ull}},
{{614266560928737233ull, 1694078645511101251ull,
  10559295662858779663ull, 830767497365ull}},
{{14602891256443085253ull, 15952656362171040275ull,
  17810805597000862482ull, 1038459371706ull}},
{{6820964026063234331ull, 14582096244784288076ull,
  15743439516552926955ull, 649037107316ull}},
{{8526205032579042914ull, 13615934287552972191ull,
  1232555321981607078ull, 811296384146ull}},
{{6046070272296415738ull, 7796545822586439431ull,
  10764066189331784656ull, 1014120480182ull}},
{{10696322947826341692ull, 4872841139116524644ull,
  2115855349904977506ull, 633825300114ull}},
{{13370403684782927115ull, 15314423460750431613ull,
  11868191224235997690ull, 792281625142ull}},
{{2877946550696495182ull, 9919657289083263709ull,
  5611866993440221305ull, 990352031428ull}},
{{4104559603399003441ull, 17729000851745509578ull,
  12730788907754914123ull, 618970019642ull}},
{{14354071541103530109ull, 17549565046254499068ull,
  6690114097838866846ull, 773712524553ull}},
{{17942589426379412636ull, 12713584270963348027ull,
  12974328640725971462ull, 967140655691ull}},
{{8908275382273438946ull, 3334304150924704613ull,
  5803112391240038212ull, 604462909807ull}},
{{15747030246269186586ull, 4167880188655880766ull,
  2642204470622659861ull, 755578637259ull}},
{{10460415770981707425ull, 9821536254247238862ull,
  17137813643560488538ull, 944473296573ull}},
{{1926073838436179237ull, 10750146177331912193ull,
  13016976536438999288ull, 590295810358ull}},
{{7019278316472611950ull, 13437682721664890241ull,
  7047848633693973302ull, 737869762948ull}},
{{13385783914018152841ull, 7573731365226336993ull,
  8809810792117466628ull, 922337203685ull}},
{{1448585918620263670ull, 13956954140121236429ull,
  7811974754287110594ull, 576460752303ull}},
{{6422418416702717491ull, 8222820638296769728ull,
  5153282424431500339ull, 720575940379ull}},
{{8028023020878396864ull, 5666839779443574256ull,
  1829917012111987520ull, 900719925474ull}},
{{5017514388048998040ull, 3541774862152233910ull,
  5755384150997380104ull, 562949953421ull}},
{{15495265021916023358ull, 4427218577690292387ull,
  11805916207174113034ull, 703687441776ull}},
{{14757395258967641293ull, 14757395258967641292ull,
  14757395258967641292ull, 879609302220ull}},
{{0ull, 0ull, 0ull, 1099511627776ull}},
{{0ull, 0ull, 0ull, 687194767360ull}},
{{0ull, 0ull, 0ull, 858993459200ull}},
{{0ull, 0ull, 0ull, 1073741824000ull}},
{{0ull, 0ull, 0ull, 671088640000ull}},
{{0ull, 0ull, 0ull, 838860800000ull}},
{{0ull, 0ull, 0ull, 1048576000000ull}},
{{0ull, 0ull, 0ull, 655360000000ull}},
{{0ull, 0ull, 0ull, 819200000000ull}},
{{0ull, 0ull, 0ull, 1024000000000ull}},
{{0ull, 0ull, 0ull, 640000000000ull}},
{{0ull, 0ull, 0ull, 800000000000ull}},
{{0ull, 0ull, 0ull, 1000000000000ull}},
{{0ull, 0ull, 0ull, 625000000000ull}},
{{0ull, 0ull, 0ull, 781250000000ull}},
{{0ull, 0ull, 0ull, 976562500000ull}},
{{0ull, 0ull, 0ull, 610351562500ull}},
{{0ull, 0ull, 0ull, 762939453125ull}},
{{0ull, 0ull, 4611686018427387904ull, 953674316406ull}},
{{0ull, 0ull, 16717361816799281152ull, 596046447753ull}},
{{0ull, 0ull, 7061644215716937728ull, 745058059692ull}},
{{0ull, 0ull, 8827055269646172160ull, 931322574615ull}},
{{0ull, 0ull, 12434438571169939456ull, 582076609134ull}},
{{0ull, 0ull, 6319676177107648512ull, 727595761418ull}},
{{0ull, 0ull, 17122967258239336448ull, 909494701772ull}},
{{0ull, 0ull, 1478482499544809472ull, 568434188608ull}},
{{0ull, 0ull, 1848103124431011840ull, 710542735760ull}},
{{0ull, 0ull, 2310128905538764800ull, 888178419700ull}},
{{0ull, 0ull, 10667202602816503808ull, 555111512312ull}},
{{0ull, 0ull, 13334003253520629760ull, 693889390390ull}},
{{0ull, 0ull, 7444132030046011392ull, 867361737988ull}},
{{0ull, 0ull, 9305165037557514240ull, 1084202172485ull}},
{{0ull, 0ull, 8121571157687140352ull, 677626357803ull}},
{{0ull, 0ull, 5540277928681537536ull, 847032947254ull}},
{{0ull, 0ull, 16148719447706697728ull, 1058791184067ull}},
{{0ull, 0ull, 7787106645602992128ull, 661744490042ull}},
{{0ull, 0ull, 510511270148964352ull, 827180612553ull}},
{{0ull, 0ull, 5249825106113593344ull, 1033975765691ull}},
{{0ull, 0ull, 975297682107301888ull, 646234853557ull}},
{{0ull, 0ull, 5830808121061515264ull, 807793566946ull}}
};

static const UINT256 multipliers2_binary32[] =
  { {{12230317112597168372ull, 12964188775534322552ull,
      9551240831114137572ull, 325925756213ull}},
{{15287896390746460465ull, 16205235969417903190ull,
  16550737057320059869ull, 407407195266ull}},
{{9886498451578299773ull, 6421486906490215276ull,
  11465049284795299029ull, 509258994083ull}},
{{15402433569091213166ull, 6319272325770078499ull,
  4859812793783367941ull, 318286871302ull}},
{{14641355942936628554ull, 12510776425639986028ull,
  15298138029083985734ull, 397858589127ull}},
{{18301694928670785692ull, 6415098495195206727ull,
  14510986517927594264ull, 497323236409ull}},
{{18356088358060322914ull, 4009436559497004204ull,
  2151837546063664559ull, 310827022756ull}},
{{4498366373865852026ull, 400109680943867352ull, 2689796932579580699ull,
  388533778445ull}},
{{5622957967332315033ull, 14335195156461997902ull,
  7973932184151863777ull, 485667223056ull}},
{{17349406784864860608ull, 2041967945147666832ull,
  4983707615094914861ull, 303542014410ull}},
{{3240014407371524143ull, 7164145949861971445ull,
  15453006555723419384ull, 379427518012ull}},
{{8661704027641793083ull, 8955182437327464306ull, 869514120944722614ull,
  474284397516ull}},
{{10025251035703508581ull, 985303004902277287ull,
  9766818362445227442ull, 296427748447ull}},
{{7919877776201997822ull, 10455000792982622417ull,
  7596836934629146398ull, 370534685559ull}},
{{14511533238679885182ull, 3845378954373502213ull,
  4884360149859045094ull, 463168356949ull}},
{{11375551283388622191ull, 16238419901765602595ull,
  5358568102875597135ull, 289480223093ull}},
{{9607753085808389834ull, 15686338858779615340ull,
  11309896147021884323ull, 361850278866ull}},
{{12009691357260487293ull, 14996237555047131271ull,
  4913998146922579596ull, 452312848583ull}},
{{14423586125928886414ull, 149276435049681236ull,
  9988777869467694104ull, 282695530364ull}},
{{18029482657411108018ull, 186595543812101545ull,
  12485972336834617630ull, 353369412955ull}},
{{8701795266481721310ull, 9456616466619902740ull,
  10995779402615884133ull, 441711766194ull}},
{{14661994078405851627ull, 8216228300851133164ull,
  11484048145062315487ull, 276069853871ull}},
{{18327492598007314533ull, 5658599357636528551ull,
  9743374162900506455ull, 345087317339ull}},
{{18297679729081755263ull, 2461563178618272785ull,
  7567531685198245165ull, 431359146674ull}},
{{9037041606070030366ull, 7688639991700228886ull, 236042569643030648ull,
  539198933343ull}},
{{1036464985366381075ull, 4805399994812643054ull,
  7065055633667976011ull, 336999333339ull}},
{{10518953268562752152ull, 1395063975088415913ull,
  4219633523657582110ull, 421249166674ull}},
{{17760377604130828093ull, 10967202005715295699ull,
  14497913941426753445ull, 526561458342ull}},
{{8794392993368073607ull, 9160344262785753764ull,
  4449510194964332999ull, 329100911464ull}},
{{10992991241710092008ull, 6838744310054804301ull,
  5561887743705416249ull, 411376139330ull}},
{{18352925070565002914ull, 13160116405995893280ull,
  16175731716486546119ull, 514220174162ull}},
{{11470578169103126821ull, 15142601781388515156ull,
  14721518341231479228ull, 321387608851ull}},
{{14338222711378908527ull, 481508153026092329ull,
  13790211908111961132ull, 401734511064ull}},
{{4087720333941471946ull, 601885191282615412ull,
  17237764885139951415ull, 502168138830ull}},
{{11778197245568195775ull, 7293707272192716488ull,
  6161917034785081730ull, 313855086769ull}},
{{14722746556960244718ull, 18340506127095671418ull,
  12314082311908740066ull, 392318858461ull}},
{{9180061159345530090ull, 13702260622014813465ull,
  1557544834603761371ull, 490398573077ull}},
{{17266753270659426066ull, 6258069879545564463ull,
  3279308530841044809ull, 306499108173ull}},
{{16971755569896894679ull, 12434273367859343483ull,
  8710821681978693915ull, 383123885216ull}},
{{16603008443943730444ull, 10931155691396791450ull,
  10888527102473367394ull, 478904856520ull}},
{{14988566295892219432ull, 11443658325550382560ull,
  6805329439045854621ull, 299315535325ull}},
{{288963796155722674ull, 469514851655814489ull, 13118347817234706181ull,
  374144419156ull}},
{{4972890763622041246ull, 5198579582997156015ull,
  16397934771543382726ull, 467680523945ull}},
{{10025585754904857635ull, 17084170294655386221ull,
  3331180204573532347ull, 292300327466ull}},
{{17143668212058459947ull, 16743526849891844872ull,
  13387347292571691242ull, 365375409332ull}},
{{2982841191363523318ull, 11706036525510030283ull,
  16734184115714614053ull, 456719261665ull}},
{{18005176809098059738ull, 9622115837657462878ull,
  3541336044680551927ull, 285449538541ull}},
{{13283098974517798864ull, 7415958778644440694ull,
  9038356074278077813ull, 356811923176ull}},
{{7380501681292472772ull, 13881634491732938772ull,
  11297945092847597266ull, 446014903970ull}},
{{13836185587662571291ull, 13287707575760474636ull,
  11672901701457136195ull, 278759314981ull}},
{{17295231984578214113ull, 11997948451273205391ull,
  756069071539256532ull, 348449143727ull}},
{{17007353962295379738ull, 14997435564091506739ull,
  14780144394706234377ull, 435561429658ull}},
{{16647506434441836768ull, 4911736399832219712ull,
  9251808456528017164ull, 544451787073ull}},
{{10404691521526147980ull, 12293207286749913128ull,
  17311595331398480487ull, 340282366920ull}},
{{13005864401907684975ull, 10754823090010003506ull,
  3192750090538548993ull, 425352958651ull}},
{{7033958465529830411ull, 18055214880939892287ull,
  17825995668455349953ull, 531691198313ull}},
{{11313753068597225863ull, 4366980272946350823ull,
  4223718265143511865ull, 332306998946ull}},
{{9530505317319144425ull, 10070411359610326433ull,
  14503019868284165639ull, 415383748682ull}},
{{16524817665076318435ull, 7976328181085520137ull,
  8905402798500431241ull, 519229685853ull}},
{{3410482013031617166ull, 16514420159246919846ull,
  7871719758276463477ull, 324518553658ull}},
{{13486474553144297265ull, 6807967143776486095ull,
  616277660990803539ull, 405648192073ull}},
{{12246407173002983677ull, 3898272911293219715ull,
  5382033094665892328ull, 507060240091ull}},
{{5348161473913170846ull, 2436420569558262322ull,
  1057927674952488753ull, 316912650057ull}},
{{15908573879246239366ull, 7657211730375215806ull,
  5934095612117998845ull, 396140812571ull}},
{{10662345312203023399ull, 14183200681396407662ull,
  2805933496720110652ull, 495176015714ull}},
{{2052279801699501721ull, 18087872462727530597ull,
  6365394453877457061ull, 309485009821ull}},
{{7177035770551765055ull, 8774782523127249534ull,
  12568429085774209231ull, 386856262276ull}},
{{18194666750044482126ull, 6356792135481674013ull,
  15710536357217761539ull, 483570327845ull}},
{{13677509727991495281ull, 1667152075462352306ull,
  12124928232474794914ull, 302231454903ull}},
{{7873515123134593293ull, 11307312131182716191ull,
  10544474272166105738ull, 377789318629ull}},
{{5230207885490853713ull, 4910768127123619431ull,
  17792278858635020077ull, 472236648286ull}},
{{10186408956072865427ull, 5375073088665956096ull,
  6508488268219499644ull, 295147905179ull}},
{{12733011195091081783ull, 6718841360832445120ull,
  3523924316846986651ull, 368934881474ull}},
{{15916263993863852229ull, 3786865682613168496ull,
  13628277432913509122ull, 461168601842ull}},
{{9947664996164907643ull, 6978477070060618214ull,
  13129359413998331105ull, 288230376151ull}},
{{3211209208351358746ull, 13334782356003160672ull,
  11800013249070525977ull, 360287970189ull}},
{{4014011510439198432ull, 2833419889721787128ull, 914958506055993760ull,
  450359962737ull}},
{{2508757194024499020ull, 1770887431076116955ull,
  12101064112353465860ull, 281474976710ull}},
{{16971004547812787487ull, 2213609288845146193ull,
  5902958103587056517ull, 351843720888ull}},
{{7378697629483820647ull, 7378697629483820646ull,
  7378697629483820646ull, 439804651110ull}},
{{0ull, 0ull, 0ull, 549755813888ull}},
{{0ull, 0ull, 0ull, 343597383680ull}},
{{0ull, 0ull, 0ull, 429496729600ull}},
{{0ull, 0ull, 0ull, 536870912000ull}},
{{0ull, 0ull, 0ull, 335544320000ull}},
{{0ull, 0ull, 0ull, 419430400000ull}},
{{0ull, 0ull, 0ull, 524288000000ull}},
{{0ull, 0ull, 0ull, 327680000000ull}},
{{0ull, 0ull, 0ull, 409600000000ull}},
{{0ull, 0ull, 0ull, 512000000000ull}},
{{0ull, 0ull, 0ull, 320000000000ull}},
{{0ull, 0ull, 0ull, 400000000000ull}},
{{0ull, 0ull, 0ull, 500000000000ull}},
{{0ull, 0ull, 0ull, 312500000000ull}},
{{0ull, 0ull, 0ull, 390625000000ull}},
{{0ull, 0ull, 0ull, 488281250000ull}},
{{0ull, 0ull, 0ull, 305175781250ull}},
{{0ull, 0ull, 9223372036854775808ull, 381469726562ull}},
{{0ull, 0ull, 2305843009213693952ull, 476837158203ull}},
{{0ull, 0ull, 17582052945254416384ull, 298023223876ull}},
{{0ull, 0ull, 3530822107858468864ull, 372529029846ull}},
{{0ull, 0ull, 13636899671677861888ull, 465661287307ull}},
{{0ull, 0ull, 6217219285584969728ull, 291038304567ull}},
{{0ull, 0ull, 3159838088553824256ull, 363797880709ull}},
{{0ull, 0ull, 8561483629119668224ull, 454747350886ull}},
{{0ull, 0ull, 739241249772404736ull, 284217094304ull}},
{{0ull, 0ull, 924051562215505920ull, 355271367880ull}},
{{0ull, 0ull, 1155064452769382400ull, 444089209850ull}},
{{0ull, 0ull, 5333601301408251904ull, 277555756156ull}},
{{0ull, 0ull, 6667001626760314880ull, 346944695195ull}},
{{0ull, 0ull, 3722066015023005696ull, 433680868994ull}},
{{0ull, 0ull, 13875954555633532928ull, 542101086242ull}},
{{0ull, 0ull, 13284157615698345984ull, 338813178901ull}},
{{0ull, 0ull, 2770138964340768768ull, 423516473627ull}},
{{0ull, 0ull, 17297731760708124672ull, 529395592033ull}},
{{0ull, 0ull, 3893553322801496064ull, 330872245021ull}},
{{0ull, 0ull, 9478627671929257984ull, 413590306276ull}},
{{0ull, 0ull, 11848284589911572480ull, 516987882845ull}},
{{0ull, 0ull, 9711020877908426752ull, 323117426778ull}},
{{0ull, 0ull, 2915404060530757632ull, 403896783473ull}}
};

// **********************************************************************

static const UINT128 breakpoints_binary64[] =
  { {{5261314576080512960ull, 21426681862861333ull}},
{{4728754506986910400ull, 34282690980578133ull}},
{{11161701235073348928ull, 27426152784462506ull}},
{{5240012173316768832ull, 21940922227570005ull}},
{{8384019477306830144ull, 35105475564112008ull}},
{{14085913211329284736ull, 28084380451289606ull}},
{{7579381754321517504ull, 22467504361031685ull}},
{{12127010806914427968ull, 35948006977650696ull}},
{{6012259830789632064ull, 28758405582120557ull}},
{{15877854308857436608ull, 23006724465696445ull}},
{{12702283447085949312ull, 18405379572557156ull}},
{{12944955885853698240ull, 29448607316091450ull}},
{{10355964708682958592ull, 23558885852873160ull}},
{{8284771766946366848ull, 18847108682298528ull}},
{{9566286012372276672ull, 30155373891677645ull}},
{{7653028809897821312ull, 24124299113342116ull}},
{{2433074233176346752ull, 19299439290673693ull}},
{{203569958340244480ull, 30879102865077909ull}},
{{3852204781414105920ull, 24703282292062327ull}},
{{14149810269357015680ull, 19762625833649861ull}},
{{15260998801487404480ull, 31620201333839778ull}},
{{1140752596964192576ull, 25296161067071823ull}},
{{8291299707055174720ull, 20236928853657458ull}},
{{9576730716546369216ull, 32379086165851933ull}},
{{15040082202720916032ull, 25903268932681546ull}},
{{8342716947434822464ull, 20722615146145237ull}},
{{17037695930637626304ull, 33156184233832379ull}},
{{17319505559252011392ull, 26524947387065903ull}},
{{2787558003175878144ull, 21219957909652723ull}},
{{770743990339494720ull, 33951932655444357ull}},
{{11684641636497326720ull, 27161546124355485ull}},
{{9347713309197861376ull, 21729236899484388ull}},
{{11266992479974667904ull, 34766779039175021ull}},
{{5324245169237824000ull, 27813423231340017ull}},
{{15327442579615990144ull, 22250738585072013ull}},
{{2387815238934122304ull, 35601181736115222ull}},
{{12978298635373028800ull, 28480945388892177ull}},
{{3003941278814602368ull, 22784756311113742ull}},
{{13471199467277412864ull, 18227805048890993ull}},
{{17864570332901950336ull, 29164488078225589ull}},
{{17981005081063470592ull, 23331590462580471ull}},
{{10695455250108866112ull, 18665272370064377ull}},
{{2355333141206544512ull, 29864435792103004ull}},
{{5573615327707145920ull, 23891548633682403ull}},
{{11837589891649537408ull, 19113238906945922ull}},
{{4182748567671618560ull, 30581182251113476ull}},
{{18103594113104936128ull, 24464945800890780ull}},
{{14482875290483948864ull, 19571956640712624ull}},
{{12104554020548587264ull, 31315130625140199ull}},
{{13372992031180780160ull, 25052104500112159ull}},
{{14387742439686534400ull, 20041683600089727ull}},
{{8262992644530813824ull, 32066693760143564ull}},
{{10299742930366561344ull, 25653355008114851ull}},
{{4550445529551338752ull, 20522684006491881ull}},
{{18348759291507873024ull, 32836294410387009ull}},
{{18368356247948208704ull, 26269035528309607ull}},
{{7315987368874746304ull, 21015228422647686ull}},
{{4326882160715773504ull, 33624365476236298ull}},
{{10840203358056439424ull, 26899492380989038ull}},
{{16050860315928972160ull, 21519593904791230ull}},
{{7234632431776803904ull, 34431350247665969ull}},
{{9477054760163353472ull, 27545080198132775ull}},
{{7581643808130682752ull, 22036064158506220ull}},
{{12130630093009092416ull, 35257702653609952ull}},
{{2325806444923453248ull, 28206162122887962ull}},
{{12928691600164493568ull, 22564929698310369ull}},
{{14032302094873505216ull, 18051943758648295ull}},
{{4004939278088056704ull, 28883110013837273ull}},
{{10582649051954265984ull, 23106488011069818ull}},
{{15844816871047233408ull, 18485190408855854ull}},
{{14283660549449842560ull, 29576304654169367ull}},
{{4048230810076053376ull, 23661043723335494ull}},
{{6927933462802753024ull, 18928834978668395ull}},
{{11084693540484404864ull, 30286135965869432ull}},
{{1489057202903703232ull, 24228908772695546ull}},
{{15948641021290603904ull, 19383127018156436ull}},
{{18139128004581145600ull, 31013003229050298ull}},
{{3443255959439185472ull, 24810402583240239ull}},
{{6443953582293258688ull, 19848322066592191ull}},
{{2931628102185393280ull, 31757315306547506ull}},
{{17102697740715955904ull, 25405852245238004ull}},
{{17371507007314675072ull, 20324681796190403ull}},
{{5658318323252018176ull, 32519490873904646ull}},
{{837305843859704192ull, 26015592699123717ull}},
{{11737891119313494336ull, 20812474159298973ull}},
{{15091276976159680640ull, 33299958654878357ull}},
{{4694323951443923840ull, 26639966923902686ull}},
{{66110346413228736ull, 21311973539122149ull}},
{{7484474183744986688ull, 34099157662595438ull}},
{{13366276976479809984ull, 27279326130076350ull}},
{{10693021581183848000ull, 21823460904061080ull}},
{{17108834529894156800ull, 34917537446497728ull}},
{{2619021179689594432ull, 27934029957198183ull}},
{{9473914573235496192ull, 22347223965758546ull}},
{{7779565687692973312ull, 35755558345213674ull}},
{{9913001364896288960ull, 28604446676170939ull}},
{{11619749906658941440ull, 22883557340936751ull}},
{{5606451110585242816ull, 18306845872749401ull}},
{{1591624147452567936ull, 29290953396399042ull}},
{{12341345762187785280ull, 23432762717119233ull}},
{{17251774239234048896ull, 18746210173695386ull}},
{{1777397079581105984ull, 29993936277912619ull}},
{{5111266478406795072ull, 23995149022330095ull}},
{{4089013182725436096ull, 19196119217864076ull}},
{{17610467536586428672ull, 30713790748582521ull}},
{{10399025214527232640ull, 24571032598866017ull}},
{{940522542137965440ull, 19656826079092814ull}},
{{8883533696904565376ull, 31450921726548502ull}},
{{18174873401749383296ull, 25160737381238801ull}},
{{10850549906657596288ull, 20128589904991041ull}},
{{9982182221168333440ull, 32205743847985666ull}},
{{4296396962192756416ull, 25764595078388533ull}},
{{10815815199238025792ull, 20611676062710826ull}},
{{9926606689297020608ull, 32978681700337322ull}},
{{562587721953795840ull, 26382945360269858ull}},
{{7828767807046857280ull, 21106356288215886ull}},
{{5147330861791151040ull, 33770170061145418ull}},
{{11496562318916741504ull, 27016136048916334ull}},
{{12886598669875303488ull, 21612908839133067ull}},
{{5861162612832844352ull, 34580654142612908ull}},
{{12067627719750096128ull, 27664523314090326ull}},
{{5964753361058166592ull, 22131618651272261ull}},
{{2164907748209245888ull, 35410589842035618ull}},
{{9110623828051217344ull, 28328471873628494ull}},
{{10977847877182884160ull, 22662777498902795ull}},
{{8782278301746307328ull, 18130221999122236ull}},
{{6672947653310271104ull, 29008355198595578ull}},
{{12717055752132037568ull, 23206684158876462ull}},
{{2794946972221809408ull, 18565347327101170ull}},
{{4471915155554895040ull, 29704555723361872ull}},
{{14645578568669646976ull, 23763644578689497ull}},
{{4337765225451896960ull, 19010915662951598ull}},
{{3251075545981124800ull, 30417465060722557ull}},
{{13668906881010630784ull, 24333972048578045ull}},
{{10935125504808504640ull, 19467177638862436ull}},
{{10117503178209786752ull, 31147484222179898ull}},
{{15472700172051650048ull, 24917987377743918ull}},
{{1310113693415589056ull, 19934389902195135ull}},
{{2096181909464942528ull, 31895023843512216ull}},
{{16434340786539595328ull, 25516019074809772ull}},
{{5768774999747855616ull, 20412815259847818ull}},
{{5540691184854658688ull, 32660504415756509ull}},
{{8121901762625637248ull, 26128403532605207ull}},
{{17565567854326240768ull, 20902722826084165ull}},
{{9658164493212433600ull, 33444356521734665ull}},
{{7726531594569946880ull, 26755485217387732ull}},
{{17249271719881688448ull, 21404388173910185ull}},
{{9152090678101149952ull, 34247021078256297ull}},
{{18389718986706650944ull, 27397616862605037ull}},
{{7333077559881500096ull, 21918093490084030ull}},
{{11732924095810400192ull, 35068949584134448ull}},
{{16765036906132140800ull, 28055159667307558ull}},
{{2343983080679981632ull, 22444127733846047ull}},
{{7439721743829880960ull, 35910604374153675ull}},
{{5951777395063904768ull, 28728483499322940ull}},
{{4761421916051123840ull, 22982786799458352ull}},
{{14877183977066630016ull, 18386229439566681ull}},
{{16424796733822787392ull, 29417967103306690ull}},
{{13139837387058229888ull, 23534373682645352ull}},
{{3133172280162763264ull, 18827498946116282ull}},
{{8702424463002331584ull, 30123998313786051ull}},
{{3272590755659954944ull, 24099198651028841ull}},
{{17375467863495605248ull, 19279358920823072ull}},
{{13043353322625327104ull, 30846974273316916ull}},
{{6745333843358351360ull, 24677579418653533ull}},
{{12774964704170501696ull, 19742063534922826ull}},
{{13061245897188982144ull, 31587301655876522ull}},
{{3070299088267365056ull, 25269841324701218ull}},
{{9834936900097712704ull, 20215873059760974ull}},
{{4667852595930609344ull, 32345396895617559ull}},
{{7423630891486397760ull, 25876317516494047ull}},
{{17006951157414849216ull, 20701054013195237ull}},
{{12453726592896117440ull, 33121686421112380ull}},
{{9962981274316893952ull, 26497349136889904ull}},
{{11659733834195425472ull, 21197879309511923ull}},
{{14966225319970770432ull, 33916606895219077ull}},
{{4594282626492795712ull, 27133285516175262ull}},
{{14743472545419967552ull, 21706628412940209ull}},
{{12521509628446217088ull, 34730605460704335ull}},
{{10017207702756973632ull, 27784484368563468ull}},
{{15392463791689399552ull, 22227587494850774ull}},
{{13559895622477308352ull, 35564139991761239ull}},
{{14537265312723756992ull, 28451311993408991ull}},
{{7940463435437095296ull, 22761049594727193ull}},
{{13731068377833496832ull, 18208839675781754ull}},
{{10901662960307864000ull, 29134143481250807ull}},
{{1342632738762470592ull, 23307314785000646ull}},
{{15831501449977617728ull, 18645851828000516ull}},
{{17951704690480367744ull, 29833362924800826ull}},
{{10672014937642383872ull, 23866690339840661ull}},
{{4848263135371996800ull, 19093352271872529ull}},
{{15135918646079015488ull, 30549363634996046ull}},
{{8419386102121302080ull, 24439490907996837ull}},
{{17803555325922772608ull, 19551592726397469ull}},
{{17417642077250705216ull, 31282548362235951ull}},
{{10244764847058653888ull, 25026038689788761ull}},
{{4506463062905012736ull, 20020830951831009ull}},
{{14589038530131841088ull, 32033329522929614ull}},
{{15360579638847383168ull, 25626663618343691ull}},
{{8599114896335996224ull, 20501330894674953ull}},
{{10069235019395683648ull, 32802129431479925ull}},
{{8055388015516546880ull, 26241703545183940ull}},
{{6444310412413237504ull, 20993362836147152ull}},
{{14000245474603090368ull, 33589380537835443ull}},
{{132149935456741312ull, 26871504430268355ull}},
{{105719948365393024ull, 21497203544214684ull}},
{{7547849546868449536ull, 34395525670743494ull}},
{{9727628452236669952ull, 27516420536594795ull}},
{{7782102761789335936ull, 22013136429275836ull}},
{{5072666789379116928ull, 35221018286841338ull}},
{{11436831060987114176ull, 28176814629473070ull}},
{{9149464848789691328ull, 22541451703578456ull}},
{{3630223064289842752ull, 18033161362862765ull}},
{{5808356902863748416ull, 28853058180580424ull}},
{{8336034337032909056ull, 23082446544464339ull}},
{{10358176284368237568ull, 18465957235571471ull}},
{{9194384425505359424ull, 29545531576914354ull}},
{{11044856355146197888ull, 23636425261531483ull}},
{{16214582713600778944ull, 18909140209225186ull}},
{{117890638567874048ull, 30254624334760299ull}},
{{3783661325596209536ull, 24203699467808239ull}},
{{6716277875218877952ull, 19362959574246591ull}},
{{3367346970866384128ull, 30980735318794546ull}},
{{17451272835660748544ull, 24784588255035636ull}},
{{10271669453786688512ull, 19827670604028509ull}},
{{5366624681832970688ull, 31724272966445615ull}},
{{4293299745466376576ull, 25379418373156492ull}},
{{14502686240598832192ull, 20303534698525193ull}},
{{1068205096506669632ull, 32485655517640310ull}},
{{854564077205335680ull, 25988524414112248ull}},
{{8062348891248089216ull, 20790819531289798ull}},
{{9210409411255032384ull, 33265311250063677ull}},
{{18436373973229756864ull, 26612249000050941ull}},
{{11059750363841895168ull, 21289799200040753ull}},
{{14006251767405121984ull, 34063678720065205ull}},
{{11205001413924097600ull, 27250942976052164ull}},
{{12653349945881188352ull, 21800754380841731ull}},
{{12866662283926080768ull, 34881207009346770ull}},
{{10293329827140864640ull, 27904965607477416ull}},
{{4545315046970781376ull, 22323972485981933ull}},
{{3583155260411339840ull, 35718355977571093ull}},
{{10245221837812892544ull, 28574684782056874ull}},
{{11885526284992224320ull, 22859747825645499ull}},
{{13197769842735689792ull, 18287798260516399ull}},
{{10048385304151372736ull, 29260477216826239ull}},
{{11728057058063008512ull, 23408381773460991ull}},
{{5693096831708496448ull, 18726705418768793ull}},
{{5419606115991684032ull, 29962728670030069ull}},
{{8025033707535257536ull, 23970182936024055ull}},
{{6420026966028206016ull, 19176146348819244ull}},
{{17650740775128950336ull, 30681834158110790ull}},
{{14120592620103160256ull, 24545467326488632ull}},
{{3917776466598707520ull, 19636373861190906ull}},
{{17336488790783663040ull, 31418198177905449ull}},
{{17558539847368840768ull, 25134558542324359ull}},
{{17736180692636982912ull, 20107646833859487ull}},
{{13620493849251531392ull, 32172234934175180ull}},
{{10896395079401225152ull, 25737787947340144ull}},
{{12406464878262890432ull, 20590230357872115ull}},
{{1403599731511073088ull, 32944368572595385ull}},
{{1122879785208858432ull, 26355494858076308ull}},
{{8277001457650907392ull, 21084395886461046ull}},
{{5864504702757631232ull, 33735033418337674ull}},
{{8380952576948015296ull, 26988026734670139ull}},
{{10394110876300322560ull, 21590421387736111ull}},
{{9251879772596695424ull, 34544674220377778ull}},
{{14780201447561177024ull, 27635739376302222ull}},
{{4445463528565120960ull, 22108591501041778ull}},
{{3423392830962283200ull, 35373746401666845ull}},
{{2738714264769826560ull, 28298997121333476ull}},
{{16948366670783502528ull, 22639197697066780ull}},
{{13558693336626802048ull, 18111358157653424ull}},
{{10625862894377152256ull, 28978173052245479ull}},
{{12190039130243632128ull, 23182538441796383ull}},
{{17130728933678726336ull, 18546030753437106ull}},
{{1583724590692589952ull, 29673649205499371ull}},
{{16024374931521713216ull, 23738919364399496ull}},
{{9130151130475460224ull, 18991135491519597ull}},
{{18297590623502646720ull, 30385816786431355ull}},
{{14638072498802117376ull, 24308653429145084ull}},
{{15399806813783604224ull, 19446922743316067ull}},
{{9882295643086125504ull, 31115076389305708ull}},
{{15284534143952721024ull, 24892061111444566ull}},
{{8538278500420266496ull, 19913648889155653ull}},
{{9971896785930516096ull, 31861838222649045ull}},
{{7977517428744412864ull, 25489470578119236ull}},
{{2692665128253619968ull, 20391576462495389ull}},
{{11686961834689612608ull, 32626522339992622ull}},
{{1970871838267869440ull, 26101217871994098ull}},
{{8955395100098116160ull, 20880974297595278ull}},
{{10639283345415075584ull, 33409558876152445ull}},
{{8511426676332060480ull, 26727647100921956ull}},
{{3119792526323738048ull, 21382117680737565ull}},
{{4991668042117980864ull, 34211388289180104ull}},
{{7682683248436295040ull, 27369110631344083ull}},
{{13524844228232856640ull, 21895288505075266ull}},
{{14261053135688750016ull, 35032461608120426ull}},
{{7719493693809089664ull, 28025969286496341ull}},
{{2486246140305361408ull, 22420775429197073ull}},
{{288645009746667968ull, 35873240686715317ull}},
{{11298962452023065344ull, 28698592549372253ull}},
{{16417867591102272896ull, 22958874039497802ull}},
{{5755596443397997696ull, 18367099231598242ull}},
{{12898303124178706624ull, 29387358770557187ull}},
{{2939944869859144640ull, 23509887016445750ull}},
{{2351955895887315712ull, 18807909613156600ull}},
{{3763129433419705152ull, 30092655381050560ull}},
{{3010503546735764096ull, 24074124304840448ull}},
{{9787100466872431936ull, 19259299443872358ull}},
{{11970011932253980800ull, 30814879110195773ull}},
{{16954707175287005248ull, 24651903288156618ull}},
{{2495719296003873216ull, 19721522630525295ull}},
{{3993150873606197184ull, 31554436208840472ull}},
{{14262567143110688704ull, 25243548967072377ull}},
{{4031356085004730304ull, 20194839173657902ull}},
{{10139518550749478848ull, 32311742677852643ull}},
{{15490312470083403712ull, 25849394142282114ull}},
{{16081598790808633280ull, 20679515313825691ull}},
{{18351860435809992640ull, 33087224502121106ull}},
{{10992139533906083776ull, 26469779601696885ull}},
{{8793711627124867008ull, 21175823681357508ull}},
{{10380589788657876928ull, 33881317890172013ull}},
{{15683169460410122176ull, 27105054312137610ull}},
{{12546535568328097728ull, 21684043449710088ull}},
{{16385108094583046080ull, 34694469519536141ull}},
{{9418737660924526528ull, 27755575615628913ull}},
{{14913687758223441856ull, 22204460492503130ull}},
{{5415156339447955392ull, 35527136788005009ull}},
{{8021473886300274624ull, 28421709430404007ull}},
{{17485225553265950656ull, 22737367544323205ull}},
{{13988180442612760512ull, 18189894035458564ull}},
{{11313042263954685888ull, 29103830456733703ull}},
{{16429131440647569344ull, 23283064365386962ull}},
{{5764607523034234816ull, 18626451492309570ull}},
{{9223372036854775744ull, 29802322387695312ull}},
{{18446744073709551552ull, 23841857910156249ull}},
{{18446744073709551552ull, 19073486328124999ull}},
{{18446744073709551552ull, 30517578124999999ull}},
{{18446744073709551552ull, 24414062499999999ull}},
{{18446744073709551552ull, 19531249999999999ull}},
{{18446744073709551552ull, 31249999999999999ull}},
{{18446744073709551552ull, 24999999999999999ull}},
{{18446744073709551552ull, 19999999999999999ull}},
{{18446744073709551552ull, 31999999999999999ull}},
{{18446744073709551552ull, 25599999999999999ull}},
{{18446744073709551552ull, 20479999999999999ull}},
{{18446744073709551552ull, 32767999999999999ull}},
{{18446744073709551552ull, 26214399999999999ull}},
{{18446744073709551552ull, 20971519999999999ull}},
{{18446744073709551552ull, 33554431999999999ull}},
{{18446744073709551552ull, 26843545599999999ull}},
{{18446744073709551552ull, 21474836479999999ull}},
{{18446744073709551552ull, 34359738367999999ull}},
{{18446744073709551552ull, 27487790694399999ull}},
{{18446744073709551552ull, 21990232555519999ull}},
{{18446744073709551552ull, 35184372088831999ull}},
{{18446744073709551552ull, 28147497671065599ull}},
{{18446744073709551552ull, 22517998136852479ull}},
{{18446744073709551552ull, 18014398509481983ull}},
{{7378697629483820608ull, 28823037615171174ull}},
{{9592306918328966784ull, 23058430092136939ull}},
{{11363194349405083776ull, 18446744073709551ull}},
{{10802413329564313408ull, 29514790517935282ull}},
{{1263233034167630080ull, 23611832414348226ull}},
{{15767981686301745344ull, 18889465931478580ull}},
{{6782026624373240960ull, 30223145490365729ull}},
{{9114970114240503040ull, 24178516392292583ull}},
{{14670673720876223104ull, 19342813113834066ull}},
{{16094380323918136320ull, 30948500982134506ull}},
{{9186155444392598720ull, 24758800785707605ull}},
{{7348924355514078976ull, 19807040628566084ull}},
{{690232524596795392ull, 31691265005705735ull}},
{{552186019677436352ull, 25353012004564588ull}},
{{7820446445225769728ull, 20282409603651670ull}},
{{12512714312361231552ull, 32451855365842672ull}},
{{2631473820405164608ull, 25961484292674138ull}},
{{9483876685807952320ull, 20769187434139310ull}},
{{15174202697292723712ull, 33230699894622896ull}},
{{8450013343092268608ull, 26584559915698317ull}},
{{17828057118699545856ull, 21267647932558653ull}},
{{6388798501467811456ull, 34028236692093846ull}},
{{1421689986432338880ull, 27222589353675077ull}},
{{12205398433371602048ull, 21778071482940061ull}},
{{12149939863910742656ull, 34844914372704098ull}},
{{17098649520612414784ull, 27875931498163278ull}},
{{2610873172264200832ull, 22300745198530623ull}},
{{488048260880811008ull, 35681192317648997ull}},
{{11458485052930379776ull, 28544953854119197ull}},
{{1788090412860483200ull, 22835963083295358ull}},
{{8809169959772207168ull, 18268770466636286ull}},
{{6715974306151710848ull, 29230032746618058ull}},
{{12751477074405189312ull, 23384026197294446ull}},
{{6511832844782241152ull, 18707220957835557ull}},
{{14108281366393496128ull, 29931553532536891ull}},
{{7597276278372886592ull, 23945242826029513ull}},
{{13456518652182129920ull, 19156194260823610ull}},
{{3083685769781856256ull, 30649910817317777ull}},
{{13534995060051216000ull, 24519928653854221ull}},
{{7138647233299062464ull, 19615942923083377ull}},
{{15111184388020410240ull, 31385508676933403ull}},
{{1020901066190597248ull, 25108406941546723ull}},
{{8195418482436298432ull, 20086725553237378ull}},
{{9423320757156167168ull, 32138760885179805ull}},
{{7538656605724933760ull, 25711008708143844ull}},
{{9720274099321857280ull, 20568806966515075ull}},
{{15552438558914971712ull, 32910091146424120ull}},
{{12441950847131977344ull, 26328072917139296ull}},
{{6264211862963671552ull, 21062458333711437ull}},
{{13712087795483784832ull, 33699933333938299ull}},
{{14659019051128938176ull, 26959946667150639ull}},
{{15416564055645060864ull, 21567957333720511ull}},
{{17287804859548276736ull, 34508731733952818ull}},
{{2762197443412890432ull, 27606985387162255ull}},
{{2209757954730312320ull, 22085588309729804ull}},
{{10914310357052320384ull, 35336941295567686ull}},
{{5042099470899945984ull, 28269553036454149ull}},
{{7723028391461867136ull, 22615642429163319ull}},
{{9867771527911404032ull, 18092513943330655ull}},
{{15788434444658246400ull, 28948022309329048ull}},
{{1562701111500866176ull, 23158417847463239ull}},
{{4939509703942603264ull, 18526734277970591ull}},
{{524517896824344576ull, 29642774844752946ull}},
{{15177009576427116928ull, 23714219875802356ull}},
{{8452258846399783232ull, 18971375900641885ull}},
{{13523614154239653184ull, 30354201441027016ull}},
{{7129542508649812224ull, 24283361152821613ull}},
{{13082331636403670400ull, 19426688922257290ull}},
{{2484986544536321088ull, 31082702275611665ull}},
{{1987989235629056832ull, 24866161820489332ull}},
{{12658437832728976448ull, 19892929456391465ull}},
{{1806756458656810688ull, 31828687130226345ull}},
{{1445405166925448576ull, 25462949704181076ull}},
{{15913719392508000128ull, 20370359763344860ull}},
{{7015206954303248640ull, 32592575621351777ull}},
{{16680212007668329856ull, 26074060497081421ull}},
{{9654820791392753536ull, 20859248397665137ull}},
{{690318007260764416ull, 33374797436264220ull}},
{{552254405808611520ull, 26699837949011376ull}},
{{15199198783614530496ull, 21359870359209100ull}},
{{5871973980073697216ull, 34175792574734561ull}},
{{1008230369317047424ull, 27340634059787649ull}},
{{4495933110195548288ull, 21872507247830119ull}},
{{14572190605796697920ull, 34996011596528190ull}},
{{11657752484637358336ull, 27996809277222552ull}},
{{1947504358226065984ull, 22397447421778042ull}},
{{6805355787903615936ull, 35835915874844867ull}},
{{16512331074548623680ull, 28668732699875893ull}},
{{2141818415413168000ull, 22934986159900715ull}},
{{1713454732330534400ull, 18347988927920572ull}},
{{6430876386470765376ull, 29356782284672915ull}},
{{5144701109176612288ull, 23485425827738332ull}},
{{15183807331567020800ull, 18788340662190665ull}},
{{5847347656797681664ull, 30061345059505065ull}},
{{4677878125438145344ull, 24049076047604052ull}},
{{14810348944576247232ull, 19239260838083241ull}},
{{16317860681838174912ull, 30782817340933186ull}},
{{9364939730728629632ull, 24626253872746549ull}},
{{11181300599324814016ull, 19701003098197239ull}},
{{6822034514693971456ull, 31521604957115583ull}},
{{12836325241238997824ull, 25217283965692466ull}},
{{6579711378249287936ull, 20173827172553973ull}},
{{6838189390456950400ull, 32278123476086357ull}},
{{16538597956591291264ull, 25822498780869085ull}},
{{13230878365273033024ull, 20657999024695268ull}},
{{17480056569694942528ull, 33052798439512429ull}},
{{17673394070497864320ull, 26442238751609943ull}},
{{3070668812172560448ull, 21153791001287955ull}},
{{4913070099476096768ull, 33846065602060728ull}},
{{11309153709064698048ull, 27076852481648582ull}},
{{1668625337767937792ull, 21661481985318866ull}},
{{13737846984654431488ull, 34658371176510185ull}},
{{10990277587723545152ull, 27726696941208148ull}},
{{16170919699662656768ull, 22181357552966518ull}},
{{3737378631008788928ull, 35490172084746430ull}},
{{2989902904807031104ull, 28392137667797144ull}},
{{6081271138587535232ull, 22713710134237715ull}},
{{4865016910870028160ull, 18170968107390172ull}},
{{11473375872133955392ull, 29073548971824275ull}},
{{9178700697707164352ull, 23258839177459420ull}},
{{7342960558165731456ull, 18607071341967536ull}},
{{4370039263581349696ull, 29771314147148058ull}},
{{10874729040348900416ull, 23817051317718446ull}},
{{5010434417537209984ull, 19053641054174757ull}},
{{11706043882801446336ull, 30485825686679611ull}},
{{5675486291499246720ull, 24388660549343689ull}},
{{8229737847941307712ull, 19510928439474951ull}},
{{5788882927222271680ull, 31217485503159922ull}},
{{15699152786003548288ull, 24973988402527937ull}},
{{5180624599319017984ull, 19979190722022350ull}},
{{8288999358910428800ull, 31966705155235760ull}},
{{6631199487128343040ull, 25573364124188608ull}},
{{12683657219186495104ull, 20458691299350886ull}},
{{12915153921214571520ull, 32733906078961418ull}},
{{17710820766455477824ull, 26187124863169134ull}},
{{17858005427906292608ull, 20949699890535307ull}},
{{13815413425682426880ull, 33519519824856492ull}},
{{3673633111062120832ull, 26815615859885194ull}},
{{6628255303591606976ull, 21452492687908155ull}},
{{10605208485746571200ull, 34323988300653048ull}},
{{15862864418081077632ull, 27459190640522438ull}},
{{1622245090239131136ull, 21967352512417951ull}},
{{13663638588608340736ull, 35147764019868721ull}},
{{7241562056144762304ull, 28118211215894977ull}},
{{16861296089141540800ull, 22494568972715981ull}},
{{1152632039433092992ull, 35991310356345571ull}},
{{15679500890514115712ull, 28793048285076456ull}},
{{8854251897669382208ull, 23034438628061165ull}},
{{7083401518135505792ull, 18427550902448932ull}},
{{15022791243758719616ull, 29484081443918291ull}},
{{8328884180265065344ull, 23587265155134633ull}},
{{14041804973695872896ull, 18869812124107706ull}},
{{15088190328429576000ull, 30191699398572330ull}},
{{12070552262743660800ull, 24153359518857864ull}},
{{13345790624936838976ull, 19322687615086291ull}},
{{13974567370415121728ull, 30916300184138066ull}},
{{7490305081590187072ull, 24733040147310453ull}},
{{13370941694755970304ull, 19786432117848362ull}},
{{6636111452641911168ull, 31658291388557380ull}},
{{5308889162113528960ull, 25326633110845904ull}},
{{7936460144432733440ull, 20261306488676723ull}},
{{9008987416350463232ull, 32418090381882757ull}},
{{18275236377306101568ull, 25934472305506205ull}},
{{14620189101844881216ull, 20747577844404964ull}},
{{12324256118726079040ull, 33196124551047943ull}},
{{17238102524464683840ull, 26556899640838354ull}},
{{17479830834313657408ull, 21245519712670683ull}},
{{5831636446450389952ull, 33992831540273094ull}},
{{8354657971902222272ull, 27194265232218475ull}},
{{6683726377521777792ull, 21755412185774780ull}},
{{10693962204034844480ull, 34808659497239648ull}},
{{15933867392711696256ull, 27846927597791718ull}},
{{1679047469943626048ull, 22277542078233375ull}},
{{2686475951909801664ull, 35644067325173400ull}},
{{2149180761527841344ull, 28515253860138720ull}},
{{1719344609222273024ull, 22812203088110976ull}},
{{16132870946345459712ull, 18249762470488780ull}},
{{7365849440443183936ull, 29199619952782049ull}},
{{9582028367096457472ull, 23359695962225639ull}},
{{11354971508419076288ull, 18687756769780511ull}},
{{10789256783986701440ull, 29900410831648818ull}},
{{16010103056673181824ull, 23920328665319054ull}},
{{16497431260080455744ull, 19136262932255243ull}},
{{4259797127677267328ull, 30618020691608390ull}},
{{3407837702141813824ull, 24494416553286712ull}},
{{13794316605939182016ull, 19595533242629369ull}},
{{11002860125276960320ull, 31352853188206991ull}},
{{5112939285479657920ull, 25082282550565593ull}},
{{11469049057867546944ull, 20065826040452474ull}},
{{7282432048362344192ull, 32105321664723959ull}},
{{9515294453431785664ull, 25684257331779167ull}},
{{233537933261607872ull, 20547405865423334ull}},
{{7752358322702393280ull, 32875849384677334ull}},
{{9891235472903824960ull, 26300679507741867ull}},
{{534290748839239296ull, 21040543606193494ull}},
{{8233562827626603520ull, 33664869769909590ull}},
{{6586850262101282816ull, 26931895815927672ull}},
{{16337526653906757248ull, 21545516652742137ull}},
{{11382647387283170304ull, 34472826644387420ull}},
{{9106117909826536256ull, 27578261315509936ull}},
{{3595545513119318656ull, 22062609052407949ull}},
{{13131570450474730496ull, 35300174483852718ull}},
{{17883953989863605056ull, 28240139587082174ull}},
{{17996512006632794368ull, 22592111669665739ull}},
{{18086558420048145792ull, 18073689335732591ull}},
{{3113051768883661056ull, 28917902937172147ull}},
{{13558487859332659776ull, 23134322349737717ull}},
{{3468092657982307200ull, 18507457879790174ull}},
{{12927645882255512128ull, 29611932607664278ull}},
{{17720814335288230336ull, 23689546086131422ull}},
{{6797953838746763648ull, 18951636868905138ull}},
{{7187377327252911552ull, 30322618990248221ull}},
{{2060553047060418880ull, 24258095192198577ull}},
{{12716488881874066048ull, 19406476153758861ull}},
{{12967684581514685120ull, 31050361846014178ull}},
{{17752845294695568704ull, 24840289476811342ull}},
{{6823578606272634304ull, 19872231581449074ull}},
{{18296423399520035584ull, 31795570530318518ull}},
{{3569092275390297472ull, 25436456424254815ull}},
{{2855273820312237952ull, 20349165139403852ull}},
{{8257786927241491136ull, 32558664223046163ull}},
{{13984927171277013504ull, 26046931378436930ull}},
{{11187941737021610816ull, 20837545102749544ull}},
{{6832660335008846336ull, 33340072164399271ull}},
{{1776779453265166784ull, 26672057731519417ull}},
{{12489470006837864384ull, 21337646185215533ull}},
{{16293803196198672704ull, 34140233896344853ull}},
{{1966996112733207168ull, 27312187117075883ull}},
{{8952294519670386368ull, 21849749693660706ull}},
{{6944973601988797568ull, 34959599509857130ull}},
{{5555978881591038080ull, 27967679607885704ull}},
{{8134131920014740736ull, 22374143686308563ull}},
{{9325262257281674880ull, 35798629898093701ull}},
{{3770860991083429568ull, 28638903918474961ull}},
{{17774084051834384960ull, 22911123134779968ull}},
{{3151220797241777024ull, 18328898507823975ull}},
{{5041953275586843200ull, 29326237612518360ull}},
{{4033562620469474560ull, 23460990090014688ull}},
{{10605547725859400320ull, 18768792072011750ull}},
{{16968876361375040512ull, 30030067315218800ull}},
{{13575101089100032384ull, 24024053852175040ull}},
{{10860080871280025920ull, 19219243081740032ull}},
{{2618734135080400192ull, 30750788930784052ull}},
{{13163033752290051072ull, 24600631144627241ull}},
{{6841078187090130560ull, 19680504915701793ull}},
{{7256376284602298560ull, 31488807865122869ull}},
{{9494449842423749184ull, 25191046292098295ull}},
{{7595559873938999360ull, 20152837033678636ull}},
{{4774198168818578304ull, 32244539253885818ull}},
{{11198056164538683264ull, 25795631403108654ull}},
{{12647793746372856960ull, 20636505122486923ull}},
{{16547121179454660800ull, 33018408195979077ull}},
{{5858999314079907968ull, 26414726556783262ull}},
{{15755245895489657344ull, 21131781245426609ull}},
{{14140346988557720832ull, 33810849992682575ull}},
{{11312277590846176640ull, 27048679994146060ull}},
{{9049822072676941312ull, 21638943995316848ull}},
{{10790366501541195776ull, 34622310392506957ull}},
{{1253595571749136000ull, 27697848314005566ull}},
{{15760271716366950080ull, 22158278651204452ull}},
{{10459039487219478848ull, 35453245841927124ull}},
{{12056580404517493376ull, 28362596673541699ull}},
{{13334613138355905024ull, 22690077338833359ull}},
{{14357039325426634368ull, 18152061871066687ull}},
{{8213867661714973696ull, 29043298993706700ull}},
{{6571094129371978944ull, 23234639194965360ull}},
{{5256875303497583168ull, 18587711355972288ull}},
{{4721651670854222720ull, 29740338169555661ull}},
{{87972521941467840ull, 23792270535644529ull}},
{{3759726832295084608ull, 19033816428515623ull}},
{{2326214116930225024ull, 30454106285624997ull}},
{{12929017737769910976ull, 24363285028499997ull}},
{{2964516560732108160ull, 19490628022799998ull}},
{{1053877682429462720ull, 31185004836479997ull}},
{{11911148590169301120ull, 24948003869183997ull}},
{{2150221242651620288ull, 19958403095347198ull}},
{{18197749247210233728ull, 31933444952555516ull}},
{{10868850583026276672ull, 25546755962044413ull}},
{{16073778095904841984ull, 20437404769635530ull}},
{{7271300879738195520ull, 32699847631416849ull}},
{{9506389518532466752ull, 26159878105133479ull}},
{{11294460429567883712ull, 20927902484106783ull}},
{{14381787872566703680ull, 33484643974570853ull}},
{{437383853827631936ull, 26787715179656683ull}},
{{7728604712545926208ull, 21430172143725346ull}},
{{4987069910589661312ull, 34288275429960554ull}},
{{7679004743213639360ull, 27430620343968443ull}},
{{13521901424054732096ull, 21944496275174754ull}},
{{10566995834261840448ull, 35111194040279607ull}},
{{1074899037925651712ull, 28088955232223686ull}},
{{15617314489308162624ull, 22471164185778948ull}},
{{2851610294441598336ull, 35953862697246318ull}},
{{9659985865037099264ull, 28763090157797054ull}},
{{11417337506771589760ull, 23010472126237643ull}},
{{16512567634901092416ull, 18408377700990114ull}},
{{15352061771616016960ull, 29453404321584183ull}},
{{1213602973067082560ull, 23562723457267347ull}},
{{12038928822679397056ull, 18850178765813877ull}},
{{4504890857319393984ull, 30160286025302204ull}},
{{7293261500597425472ull, 24128228820241763ull}},
{{13213306829961761024ull, 19302583056193410ull}},
{{2694546854229266048ull, 30884132889909457ull}},
{{13223683927609143808ull, 24707306311927565ull}},
{{10578947142087315072ull, 19765845049542052ull}},
{{2168920168372062784ull, 31625352079267284ull}},
{{5424484949439560576ull, 25300281663413827ull}},
{{15407634403777379392ull, 20240225330731061ull}},
{{17273517416559986432ull, 32384360529169698ull}},
{{2750767489022258176ull, 25907488423335759ull}}
};

static const int exponents_binary64[] = { -55,
  -51,
  -48,
  -45,
  -41,
  -38,
  -35,
  -31,
  -28,
  -25,
  -22,
  -18,
  -15,
  -12,
  -8,
  -5,
  -2,
  2,
  5,
  8,
  12,
  15,
  18,
  22,
  25,
  28,
  32,
  35,
  38,
  42,
  45,
  48,
  52,
  55,
  58,
  62,
  65,
  68,
  71,
  75,
  78,
  81,
  85,
  88,
  91,
  95,
  98,
  101,
  105,
  108,
  111,
  115,
  118,
  121,
  125,
  128,
  131,
  135,
  138,
  141,
  145,
  148,
  151,
  155,
  158,
  161,
  164,
  168,
  171,
  174,
  178,
  181,
  184,
  188,
  191,
  194,
  198,
  201,
  204,
  208,
  211,
  214,
  218,
  221,
  224,
  228,
  231,
  234,
  238,
  241,
  244,
  248,
  251,
  254,
  258,
  261,
  264,
  267,
  271,
  274,
  277,
  281,
  284,
  287,
  291,
  294,
  297,
  301,
  304,
  307,
  311,
  314,
  317,
  321,
  324,
  327,
  331,
  334,
  337,
  341,
  344,
  347,
  351,
  354,
  357,
  360,
  364,
  367,
  370,
  374,
  377,
  380,
  384,
  387,
  390,
  394,
  397,
  400,
  404,
  407,
  410,
  414,
  417,
  420,
  424,
  427,
  430,
  434,
  437,
  440,
  444,
  447,
  450,
  454,
  457,
  460,
  463,
  467,
  470,
  473,
  477,
  480,
  483,
  487,
  490,
  493,
  497,
  500,
  503,
  507,
  510,
  513,
  517,
  520,
  523,
  527,
  530,
  533,
  537,
  540,
  543,
  547,
  550,
  553,
  556,
  560,
  563,
  566,
  570,
  573,
  576,
  580,
  583,
  586,
  590,
  593,
  596,
  600,
  603,
  606,
  610,
  613,
  616,
  620,
  623,
  626,
  630,
  633,
  636,
  640,
  643,
  646,
  649,
  653,
  656,
  659,
  663,
  666,
  669,
  673,
  676,
  679,
  683,
  686,
  689,
  693,
  696,
  699,
  703,
  706,
  709,
  713,
  716,
  719,
  723,
  726,
  729,
  733,
  736,
  739,
  743,
  746,
  749,
  752,
  756,
  759,
  762,
  766,
  769,
  772,
  776,
  779,
  782,
  786,
  789,
  792,
  796,
  799,
  802,
  806,
  809,
  812,
  816,
  819,
  822,
  826,
  829,
  832,
  836,
  839,
  842,
  845,
  849,
  852,
  855,
  859,
  862,
  865,
  869,
  872,
  875,
  879,
  882,
  885,
  889,
  892,
  895,
  899,
  902,
  905,
  909,
  912,
  915,
  919,
  922,
  925,
  929,
  932,
  935,
  939,
  942,
  945,
  948,
  952,
  955,
  958,
  962,
  965,
  968,
  972,
  975,
  978,
  982,
  985,
  988,
  992,
  995,
  998,
  1002,
  1005,
  1008,
  1012,
  1015,
  1018,
  1022,
  1025,
  1028,
  1032,
  1035,
  1038,
  1041,
  1045,
  1048,
  1051,
  1055,
  1058,
  1061,
  1065,
  1068,
  1071,
  1075,
  1078,
  1081,
  1085,
  1088,
  1091,
  1095,
  1098,
  1101,
  1105,
  1108,
  1111,
  1115,
  1118,
  1121,
  1125,
  1128,
  1131,
  1134,
  1138,
  1141,
  1144,
  1148,
  1151,
  1154,
  1158,
  1161,
  1164,
  1168,
  1171,
  1174,
  1178,
  1181,
  1184,
  1188,
  1191,
  1194,
  1198,
  1201,
  1204,
  1208,
  1211,
  1214,
  1218,
  1221,
  1224,
  1228,
  1231,
  1234,
  1237,
  1241,
  1244,
  1247,
  1251,
  1254,
  1257,
  1261,
  1264,
  1267,
  1271,
  1274,
  1277,
  1281,
  1284,
  1287,
  1291,
  1294,
  1297,
  1301,
  1304,
  1307,
  1311,
  1314,
  1317,
  1321,
  1324,
  1327,
  1330,
  1334,
  1337,
  1340,
  1344,
  1347,
  1350,
  1354,
  1357,
  1360,
  1364,
  1367,
  1370,
  1374,
  1377,
  1380,
  1384,
  1387,
  1390,
  1394,
  1397,
  1400,
  1404,
  1407,
  1410,
  1414,
  1417,
  1420,
  1424,
  1427,
  1430,
  1433,
  1437,
  1440,
  1443,
  1447,
  1450,
  1453,
  1457,
  1460,
  1463,
  1467,
  1470,
  1473,
  1477,
  1480,
  1483,
  1487,
  1490,
  1493,
  1497,
  1500,
  1503,
  1507,
  1510,
  1513,
  1517,
  1520,
  1523,
  1526,
  1530,
  1533,
  1536,
  1540,
  1543,
  1546,
  1550,
  1553,
  1556,
  1560,
  1563,
  1566,
  1570,
  1573,
  1576,
  1580,
  1583,
  1586,
  1590,
  1593,
  1596,
  1600,
  1603,
  1606,
  1610,
  1613,
  1616,
  1620,
  1623,
  1626,
  1629,
  1633,
  1636,
  1639,
  1643,
  1646,
  1649,
  1653,
  1656,
  1659,
  1663,
  1666,
  1669,
  1673,
  1676,
  1679,
  1683,
  1686,
  1689,
  1693,
  1696,
  1699,
  1703,
  1706,
  1709,
  1713,
  1716,
  1719,
  1722,
  1726,
  1729,
  1732,
  1736,
  1739,
  1742,
  1746,
  1749,
  1752,
  1756,
  1759,
  1762,
  1766,
  1769,
  1772,
  1776,
  1779,
  1782,
  1786,
  1789,
  1792,
  1796,
  1799,
  1802,
  1806,
  1809,
  1812,
  1815,
  1819,
  1822,
  1825,
  1829,
  1832,
  1835,
  1839,
  1842,
  1845,
  1849,
  1852,
  1855,
  1859,
  1862,
  1865,
  1869,
  1872,
  1875,
  1879,
  1882,
  1885,
  1889,
  1892,
  1895,
  1899,
  1902,
  1905,
  1909,
  1912,
  1915,
  1918,
  1922,
  1925,
  1928,
  1932,
  1935,
  1938,
  1942,
  1945,
  1948,
  1952,
  1955,
  1958,
  1962,
  1965,
  1968,
  1972,
  1975,
  1978,
  1982,
  1985,
  1988,
  1992,
  1995,
  1998,
  2002,
  2005,
  2008,
  2011,
  2015,
  2018,
  2021,
  2025,
  2028,
  2031,
  2035,
  2038,
  2041,
  2045,
  2048,
  2051,
  2055,
  2058,
  2061,
  2065,
  2068,
  2071,
  2075,
  2078,
  2081,
  2085,
  2088,
  2091,
  2095,
  2098,
  2101,
  2105,
  2108,
  2111,
  2114,
  2118,
  2121,
  2124,
  2128,
  2131,
  2134,
  2138,
  2141,
  2144,
  2148,
  2151,
  2154,
  2158,
  2161,
};

static const UINT256 multipliers1_binary64[] =
  { {{1837554224478941466ull, 10276842184138466546ull,
      11651621577776737258ull, 7754513766366540701ull}},
{{5760157408726726321ull, 11034712383513929495ull,
  9588106495324154738ull, 4846571103979087938ull}},
{{2588510742481019997ull, 4570018442537636061ull,
  2761761082300417615ull, 6058213879973859923ull}},
{{7847324446528662900ull, 1100837034744657172ull,
  17287259408157685731ull, 7572767349967324903ull}},
{{14127949815935190120ull, 16828924211211268396ull,
  17722066157739635437ull, 4732979593729578064ull}},
{{17659937269918987650ull, 7201097208731921783ull,
  3705838623464992681ull, 5916224492161972581ull}},
{{17463235568971346659ull, 13613057529342290133ull,
  9243984297758628755ull, 7395280615202465726ull}},
{{13220365239820785614ull, 6202317946625237381ull,
  1165804167671755068ull, 4622050384501541079ull}},
{{2690398494493818305ull, 7752897433281546727ull,
  15292313264871857547ull, 5777562980626926348ull}},
{{17198056173399436594ull, 5079435773174545504ull,
  668647507380270318ull, 7221953725783657936ull}},
{{3050826143039744126ull, 15572666753322957689ull,
  835809384225337897ull, 9027442157229572420ull}},
{{13435981385468309839ull, 2815387693185766699ull,
  9745752901995611994ull, 5642151348268482762ull}},
{{12183290713407999394ull, 12742606653336984182ull,
  2958819090639739184ull, 7052689185335603453ull}},
{{6005741354905223435ull, 15928258316671230228ull,
  8310209881727061884ull, 8815861481669504316ull}},
{{12976960383670540455ull, 731789411064743084ull,
  14417253212934189486ull, 5509913426043440197ull}},
{{16221200479588175569ull, 10138108800685704663ull,
  4186508460885573145ull, 6887391782554300247ull}},
{{15664814581057831557ull, 17284322019284518733ull,
  621449557679578527ull, 8609239728192875309ull}},
{{12096352122374838675ull, 17720230289693906064ull,
  2694248982763430531ull, 5380774830120547068ull}},
{{15120440152968548344ull, 17538601843689994676ull,
  3367811228454288164ull, 6725968537650683835ull}},
{{453806117501133814ull, 3476508230902941730ull,
  18044822090850023918ull, 8407460672063354793ull}},
{{4895314841865596538ull, 16007875699596502293ull,
  4360484779140183092ull, 5254662920039596746ull}},
{{10730829570759383576ull, 1563100550786076250ull,
  14673978010780004674ull, 6568328650049495932ull}},
{{4190164926594453662ull, 11177247725337371121ull,
  18342472513475005842ull, 8210410812561869915ull}},
{{14148068125190003299ull, 11597465846763244854ull,
  9158202311708184699ull, 5131506757851168697ull}},
{{8461713119632728315ull, 9885146290026668164ull,
  16059438908062618778ull, 6414383447313960871ull}},
{{10577141399540910394ull, 3133060825678559397ull,
  15462612616650885569ull, 8017979309142451089ull}},
{{8916556383926762949ull, 13487378062117569383ull,
  2746603857765721624ull, 5011237068214031931ull}},
{{6534009461481065782ull, 16859222577646961729ull,
  17268312877489315742ull, 6264046335267539913ull}},
{{12779197845278720131ull, 11850656185203926353ull,
  7750333041579480966ull, 7830057919084424892ull}},
{{1069469625658118226ull, 2794974097325066067ull,
  14067330187841951412ull, 4893786199427765557ull}},
{{15171895087354811494ull, 3493717621656332583ull,
  3749104679520275553ull, 6117232749284706947ull}},
{{14353182840766126464ull, 8978833045497803633ull, 74694830972956537ull,
  7646540936605883684ull}},
{{2053210247837747184ull, 17140985699504597031ull,
  9270056306212873643ull, 4779088085378677302ull}},
{{16401570865079347692ull, 16814546105953358384ull,
  2364198345911316246ull, 5973860106723346628ull}},
{{2055219507639632999ull, 11794810595586922173ull,
  2955247932389145308ull, 7467325133404183285ull}},
{{3590355201488464576ull, 16595128659096602166ull,
  4152872966956909769ull, 4667078208377614553ull}},
{{13711316038715356528ull, 6908852768588588995ull,
  9802777227123525116ull, 5833847760472018191ull}},
{{12527459029966807756ull, 8636065960735736244ull,
  7641785515477018491ull, 7292309700590022739ull}},
{{15659323787458509695ull, 6183396432492282401ull,
  4940545875918885210ull, 9115387125737528424ull}},
{{2869548339520486704ull, 8476308788735064405ull,
  3087841172449303256ull, 5697116953585955265ull}},
{{8198621442827996284ull, 10595385985918830506ull,
  8471487483989016974ull, 7121396191982444081ull}},
{{1024904766680219546ull, 4020860445543762325ull,
  15201045373413659122ull, 8901745239978055101ull}},
{{2946408488388831169ull, 7124723796892239357ull,
  11806496367597230903ull, 5563590774986284438ull}},
{{8294696628913426865ull, 4294218727687911292ull,
  5534748422641762821ull, 6954488468732855548ull}},
{{10368370786141783581ull, 9979459428037277019ull,
  6918435528302203526ull, 8693110585916069435ull}},
{{4174388732124920786ull, 1625476124095910233ull,
  2018179195975183252ull, 5433194116197543397ull}},
{{9829671933583538887ull, 2031845155119887791ull,
  7134410013396366969ull, 6791492645246929246ull}},
{{7675403898552035704ull, 7151492462327247643ull,
  18141384553600234519ull, 8489365806558661557ull}},
{{2491284427381328363ull, 11387211816595611633ull,
  13644208355213840526ull, 5305853629099163473ull}},
{{7725791552654048358ull, 5010642733889738733ull,
  3220202388735136946ull, 6632317036373954342ull}},
{{14268925459244948351ull, 15486675454216949224ull,
  13248625022773696990ull, 8290396295467442927ull}},
{{8918078412028092720ull, 5067486140458205361ull,
  15197919666874642475ull, 5181497684667151829ull}},
{{15759284033462503804ull, 1722671657145368797ull,
  5162341528311139382ull, 6476872105833939787ull}},
{{5864046986545966042ull, 11376711608286486805ull,
  1841240891961536323ull, 8096090132292424734ull}},
{{5970872375804922729ull, 4804601745965360301ull,
  14985833612758123914ull, 5060056332682765458ull}},
{{12075276488183541315ull, 15229124219311476184ull,
  9508919979092879084ull, 6325070415853456823ull}},
{{15094095610229426643ull, 589661200429793614ull,
  7274463955438710952ull, 7906338019816821029ull}},
{{4822123737966003748ull, 368538250268621009ull, 6852382981362888297ull,
  4941461262385513143ull}},
{{10639340690884892589ull, 5072358831263164165ull,
  3953792708276222467ull, 6176826577981891429ull}},
{{17910861882033503640ull, 1728762520651567302ull,
  9553926903772665988ull, 7721033222477364286ull}},
{{6582602657843551871ull, 10303848612262005372ull,
  1359518296430528338ull, 4825645764048352679ull}},
{{8228253322304439839ull, 3656438728472730907ull,
  15534455925820324135ull, 6032057205060440848ull}},
{{5673630634453161895ull, 18405606465873077346ull,
  971325833565853552ull, 7540071506325551061ull}},
{{8157705164960614088ull, 11503504041170673341ull,
  2912921655192352422ull, 4712544691453469413ull}},
{{14808817474628155514ull, 5156008014608565868ull,
  8252838087417828432ull, 5890680864316836766ull}},
{{64277769575642777ull, 6445010018260707336ull, 1092675572417509732ull,
  7363351080396045958ull}},
{{80347211969553471ull, 8056262522825884170ull, 10589216502376662973ull,
  9204188850495057447ull}},
{{4661903025908358824ull, 7341007085979871558ull,
  13535789341626496214ull, 5752618031559410904ull}},
{{15050750819240224337ull, 18399630894329615255ull,
  16919736677033120267ull, 7190772539449263630ull}},
{{14201752505622892517ull, 18387852599484631165ull,
  11926298809436624526ull, 8988465674311579538ull}},
{{11181938325228001776ull, 6880721856250506574ull,
  12065622774325278233ull, 5617791046444737211ull}},
{{4754050869680226411ull, 13212588338740521122ull,
  10470342449479209887ull, 7022238808055921514ull}},
{{15165935623955058822ull, 11904049404998263498ull,
  3864556024994236551ull, 8777798510069901893ull}},
{{14090395783399299668ull, 14357559905764996542ull,
  4721190524835091796ull, 5486124068793688683ull}},
{{8389622692394348777ull, 17946949882206245678ull,
  1289802137616476841ull, 6857655085992110854ull}},
{{1263656328638160163ull, 8598629297475643386ull,
  10835624708875371860ull, 8572068857490138567ull}},
{{5401471223826238006ull, 14597515347777052924ull,
  13689794470688189268ull, 5357543035931336604ull}},
{{6751839029782797507ull, 18246894184721316155ull,
  17112243088360236585ull, 6696928794914170755ull}},
{{3828112768801108980ull, 8973559675619481482ull,
  16778617842022907828ull, 8371160993642713444ull}},
{{7004256498928081017ull, 14831846834116951734ull,
  1263264114409541584ull, 5231975621026695903ull}},
{{17978692660514877079ull, 93064468936638051ull,
  15414138198294090693ull, 6539969526283369878ull}},
{{17861679807216208444ull, 4728016604598185468ull,
  10044300711012837558ull, 8174961907854212348ull}},
{{1940177842655354470ull, 16790068433156029630ull,
  15501059981237799281ull, 5109351192408882717ull}},
{{11648594340173968895ull, 7152527486162873325ull,
  5541266921265085390ull, 6386688990511103397ull}},
{{725684869935297407ull, 18164031394558367465ull,
  11538269670008744641ull, 7983361238138879246ull}},
{{11982768089778030640ull, 4434990593957897809ull,
  2599732525328077497ull, 4989600773836799529ull}},
{{1143402056940374587ull, 10155424260874760166ull,
  7861351675087484775ull, 6237000967295999411ull}},
{{10652624608030244042ull, 8082594307666062303ull,
  5215003575431968065ull, 7796251209119999264ull}},
{{13575419407659984382ull, 16580836488359758699ull,
  3259377234644980040ull, 4872657005699999540ull}},
{{12357588241147592574ull, 2279301536740146758ull,
  4074221543306225051ull, 6090821257124999425ull}},
{{6223613264579714909ull, 16684184976207347160ull,
  9704462947560169217ull, 7613526571406249281ull}},
{{3889758290362321819ull, 3510086582488510119ull,
  17594504388293575521ull, 4758454107128905800ull}},
{{250511844525514369ull, 8999294246538025553ull, 3546386411657417785ull,
  5948067633911132251ull}},
{{4924825824084280865ull, 15860803826599919845ull,
  18268041069853935943ull, 7435084542388915313ull}},
{{5383859149266369493ull, 16830531419266031759ull,
  4499996641017628108ull, 4646927838993072071ull}},
{{2118137918155573962ull, 2591420200372988083ull,
  1013309782844647232ull, 5808659798741340089ull}},
{{16482730452976631164ull, 3239275250466235103ull,
  5878323246983196944ull, 7260824748426675111ull}},
{{15991727047793401051ull, 4049094063082793879ull,
  2736218040301608276ull, 9076030935533343889ull}},
{{16912358432511957513ull, 11754055826281521982ull,
  13239351321256974932ull, 5672519334708339930ull}},
{{11917076003785171083ull, 14692569782851902478ull,
  7325817114716442857ull, 7090649168385424913ull}},
{{5672972967876688046ull, 4530654173282714386ull,
  13768957411822941476ull, 8863311460481781141ull}},
{{8157294123350317933ull, 12055030895156472299ull,
  10911441391603032374ull, 5539569662801113213ull}},
{{5584931635760509512ull, 5845416582090814566ull,
  18250987757931178372ull, 6924462078501391516ull}},
{{16204536581555412698ull, 7306770727613518207ull,
  4366990623704421349ull, 8655577598126739396ull}},
{{17045364391113214793ull, 6872574713972142831ull,
  11952741176670039151ull, 5409735998829212122ull}},
{{16695019470464130587ull, 3979032374037790635ull,
  5717554433982773131ull, 6762169998536515153ull}},
{{16257088319652775329ull, 362104449119850390ull,
  11758629060905854318ull, 8452712498170643941ull}},
{{5548994181355596677ull, 14061373335982070206ull,
  9654986172279852900ull, 5282945311356652463ull}},
{{16159614763549271654ull, 17576716669977587757ull,
  7457046696922428221ull, 6603681639195815579ull}},
{{6364460399154425855ull, 8135837782189820985ull,
  4709622352725647373ull, 8254602048994769474ull}},
{{15507002795539985920ull, 7390741623082332067ull,
  7555199988880917512ull, 5159126280621730921ull}},
{{14772067475997594496ull, 9238427028852915084ull,
  14055686004528534794ull, 6448907850777163651ull}},
{{18340271287441503ull, 2324661749211368048ull, 12957921487233280589ull,
  8061134813471454564ull}},
{{11462669554650940ull, 3758756602470798982ull, 17322072966375576176ull,
  5038209258419659102ull}},
{{9237700373798089483ull, 4698445753088498727ull,
  12429219171114694412ull, 6297761573024573878ull}},
{{6935439448820223949ull, 5873057191360623409ull,
  6313151927038592207ull, 7872201966280717348ull}},
{{15863864701581109728ull, 10588189772241471486ull,
  13169091991253895937ull, 4920126228925448342ull}},
{{10606458840121611352ull, 17846923233729227262ull,
  7237992952212594113ull, 6150157786156810428ull}},
{{4034701513297238382ull, 8473595986879370366ull,
  9047491190265742642ull, 7687697232696013035ull}},
{{16356746501092937701ull, 9907683510226994382ull,
  3348838984702395199ull, 4804810770435008147ull}},
{{11222561089511396318ull, 7772918369356355074ull,
  18021106786160157711ull, 6006013463043760183ull}},
{{4804829325034469590ull, 5104461943268055939ull,
  17914697464272809235ull, 7507516828804700229ull}},
{{697175318932849542ull, 884445705328841010ull, 13502528924384199724ull,
  4692198018002937643ull}},
{{10094841185520837735ull, 1105557131661051262ull,
  12266475137052861751ull, 5865247522503672054ull}},
{{3395179445046271361ull, 15217004469858477790ull,
  6109721884461301380ull, 7331559403129590068ull}},
{{13467346343162615009ull, 574511513613545621ull,
  7637152355576626726ull, 9164449253911987585ull}},
{{10722934473690328333ull, 14194127751290629725ull,
  16302435268303861463ull, 5727780783694992240ull}},
{{18015354110540298320ull, 13130973670685899252ull,
  1931300011670275213ull, 7159725979618740301ull}},
{{4072448564465821284ull, 2578659033075210354ull,
  7025811033015231921ull, 8949657474523425376ull}},
{{7156966371218526206ull, 13140876941740476231ull,
  4391131895634519950ull, 5593535921577140860ull}},
{{4334521945595769854ull, 7202724140320819481ull,
  5488914869543149938ull, 6991919901971426075ull}},
{{10029838450422100221ull, 18226777212255800159ull,
  2249457568501549518ull, 8739899877464282594ull}},
{{13186178059154894494ull, 6780049739232487195ull,
  6017596998740856353ull, 5462437423415176621ull}},
{{11871036555516230214ull, 13086748192467996898ull,
  12133682266853458345ull, 6828046779268970776ull}},
{{5615423657540511959ull, 2523377185302832411ull,
  15167102833566822932ull, 8535058474086213470ull}},
{{1203796776749126023ull, 10800482777669046065ull,
  4867753252551876428ull, 5334411546303883419ull}},
{{6116431989363795432ull, 13500603472086307581ull,
  1473005547262457631ull, 6668014432879854274ull}},
{{12257226005132132194ull, 12264068321680496572ull,
  11064628970932847847ull, 8335018041099817842ull}},
{{16884138290062358430ull, 14582571728691392213ull,
  11527079125260417808ull, 5209386275687386151ull}},
{{7270114807295784325ull, 18228214660864240267ull,
  9797162888148134356ull, 6511732844609232689ull}},
{{4475957490692342502ull, 4338524252370748718ull,
  16858139628612555850ull, 8139666055761540861ull}},
{{16632531486964877776ull, 7323263676159105852ull,
  12842180277096541358ull, 5087291284850963038ull}},
{{2343920284996545604ull, 18377451632053658124ull,
  6829353309515900889ull, 6359114106063703798ull}},
{{2929900356245682005ull, 9136756484784908943ull,
  17760063673749651920ull, 7948892632579629747ull}},
{{8748716750294633109ull, 5710472802990568089ull,
  8794196786879838498ull, 4968057895362268592ull}},
{{15547581956295679290ull, 16361463040592985919ull,
  10992745983599798122ull, 6210072369202835740ull}},
{{14822791426942211209ull, 11228456763886456591ull,
  13740932479499747653ull, 7762590461503544675ull}},
{{16181773669479963862ull, 9323628486642729321ull,
  6282239790473648331ull, 4851619038439715422ull}},
{{6392159031567791115ull, 7042849589876023748ull,
  17076171774946836222ull, 6064523798049644277ull}},
{{7990198789459738893ull, 18026934024199805493ull,
  7510156663401381565ull, 7580654747562055347ull}},
{{7299717252626030761ull, 13572676774338572385ull,
  2388004905412169526ull, 4737909217226284592ull}},
{{13736332584209926355ull, 7742473931068439673ull,
  2985006131765211908ull, 5922386521532855740ull}},
{{3335357674980244231ull, 9678092413835549592ull,
  3731257664706514885ull, 7402983151916069675ull}},
{{2084598546862652645ull, 8354650767860912447ull, 26193031227877851ull,
  4626864469947543547ull}},
{{16440806238860479518ull, 5831627441398752654ull,
  13867799344317011026ull, 5783580587434429433ull}},
{{11327635761720823589ull, 16512906338603216626ull,
  3499691125114100070ull, 7229475734293036792ull}},
{{4936172665296253678ull, 11417760886399244975ull,
  4374613906392625088ull, 9036844667866295990ull}},
{{10002636943451240405ull, 7136100553999528109ull,
  16569191746777554392ull, 5648027917416434993ull}},
{{17114982197741438410ull, 8920125692499410136ull,
  6876431628189779278ull, 7060034896770543742ull}},
{{2946983673467246397ull, 1926785078769486863ull,
  17818911572091999906ull, 8825043620963179677ull}},
{{8759393823558110854ull, 5815926692658317193ull,
  13442662741771193893ull, 5515652263101987298ull}},
{{15560928297875026471ull, 11881594384250284395ull,
  7579956390359216558ull, 6894565328877484123ull}},
{{14839474353916395185ull, 5628620943458079686ull,
  4863259469521632794ull, 8618206661096855154ull}},
{{4662985452770359087ull, 8129574108088687708ull,
  7651223186878408400ull, 5386379163185534471ull}},
{{5828731815962948858ull, 10161967635110859635ull,
  4952342965170622596ull, 6732973953981918089ull}},
{{2674228751526298169ull, 12702459543888574544ull,
  10802114724890666149ull, 8416217442477397611ull}},
{{1671392969703936356ull, 10244880224144053042ull,
  4445478693842972391ull, 5260135901548373507ull}},
{{11312613248984696253ull, 8194414261752678398ull,
  945162348876327585ull, 6575169876935466884ull}},
{{4917394524376094508ull, 14854703845618235902ull,
  1181452936095409481ull, 8218962346169333605ull}},
{{16908429633017222779ull, 2366660875870315582ull,
  3044251094273324878ull, 5136851466355833503ull}},
{{11912165004416752666ull, 12181698131692670286ull,
  17640371923123819809ull, 6421064332944791878ull}},
{{5666834218666165025ull, 1392064609333674146ull,
  12827092867049998954ull, 8026330416180989848ull}},
{{8153457405093741045ull, 5481726399260934245ull,
  8016933041906249346ull, 5016456510113118655ull}},
{{14803507774794564210ull, 16075530035930943614ull,
  5409480283955423778ull, 6270570637641398319ull}},
{{9281012681638429454ull, 10871040508058903710ull,
  2150164336516891819ull, 7838213297051747899ull}},
{{1188946907596630505ull, 4488557308323120867ull,
  17484753774818915051ull, 4898883310657342436ull}},
{{15321241689777951843ull, 999010616976513179ull,
  3409198144814092198ull, 6123604138321678046ull}},
{{14539866093795051900ull, 10472135308075417282ull,
  13484869717872391055ull, 7654505172902097557ull}},
{{13699102327049295341ull, 13462613595188217657ull,
  10733886582883938361ull, 4784065733063810973ull}},
{{3288819853529455465ull, 2993208938703108360ull,
  18029044247032310856ull, 5980082166329763716ull}},
{{4111024816911819331ull, 3741511173378885450ull,
  4089561235080836954ull, 7475102707912204646ull}},
{{7181076528997274986ull, 6950130501789191310ull,
  16391033827207686808ull, 4671939192445127903ull}},
{{18199717698101369540ull, 8687663127236489137ull,
  15877106265582220606ull, 5839923990556409879ull}},
{{8914589067344548213ull, 1636206872190835614ull,
  15234696813550387854ull, 7299904988195512349ull}},
{{1919864297325909458ull, 11268630627093320326ull,
  5208312961655821105ull, 9124881235244390437ull}},
{{15034973241110857124ull, 125365114292243347ull,
  5561038610248582143ull, 5703050772027744023ull}},
{{14182030532961183500ull, 13991764448147467896ull,
  2339612244383339774ull, 7128813465034680029ull}},
{{17727538166201479375ull, 8266333523329559062ull,
  7536201323906562622ull, 8911016831293350036ull}},
{{6468025335448536706ull, 554772433653586510ull,
  13933497864296377447ull, 5569385519558343772ull}},
{{17308403706165446690ull, 14528523597349146849ull,
  17416872330370471808ull, 6961731899447929715ull}},
{{7800446577424644651ull, 18160654496686433562ull,
  17159404394535701856ull, 8702164874309912144ull}},
{{9486965129317790811ull, 11350409060429020976ull,
  10724627746584813660ull, 5438853046443695090ull}},
{{11858706411647238513ull, 14188011325536276220ull,
  4182412646376241267ull, 6798566308054618863ull}},
{{14823383014559048142ull, 13123328138492957371ull,
  616329789542913680ull, 8498207885068273579ull}},
{{6958771374885711137ull, 8202080086558098357ull,
  16526107182960178714ull, 5311379928167670986ull}},
{{13310150237034526825ull, 1029228071342847138ull,
  11434261941845447585ull, 6639224910209588733ull}},
{{7414315759438382723ull, 5898221107605946827ull, 457769372024645769ull,
  8299031137761985917ull}},
{{2328104340435295250ull, 15215603238322186527ull,
  2591948866729097557ull, 5186894461101241198ull}},
{{16745188480826282774ull, 5184445992620569446ull,
  12463308120266147755ull, 6483618076376551497ull}},
{{11708113564178077660ull, 1868871472348323904ull,
  1744077095050520982ull, 8104522595470689372ull}},
{{7317570977611298537ull, 15003102725499866152ull,
  10313420221261351421ull, 5065326622169180857ull}},
{{9146963722014123172ull, 4918820351592668978ull,
  17503461295004077181ull, 6331658277711476071ull}},
{{2210332615662878157ull, 10760211457918224127ull,
  17267640600327708572ull, 7914572847139345089ull}},
{{8298986912430380704ull, 15948504198053665887ull,
  3874746347563736001ull, 4946608029462090681ull}},
{{5762047622110587976ull, 6100572192284918647ull,
  9455118952882057906ull, 6183260036827613351ull}},
{{2590873509210847066ull, 16849087277210924117ull,
  7207212672675184478ull, 7729075046034516689ull}},
{{3925138952470473368ull, 5918993529829439669ull,
  16033722966490460059ull, 4830671903771572930ull}},
{{9518109709015479614ull, 2787055893859411682ull,
  10818781671258299266ull, 6038339879714466163ull}},
{{2674265099414573710ull, 12707191904179040411ull,
  8911791070645486178ull, 7547924849643082704ull}},
{{17812316751629966233ull, 12553680958539288160ull,
  5569869419153428861ull, 4717453031026926690ull}},
{{3818651865827906175ull, 1857043142891946489ull,
  16185708810796561885ull, 5896816288783658362ull}},
{{9385000850712270622ull, 6932989947042321015ull,
  11008763976640926548ull, 7371020360979572953ull}},
{{7119565044962950374ull, 8666237433802901269ull,
  18372640989228546089ull, 9213775451224466191ull}},
{{6755571162315537936ull, 16945613442195283053ull,
  18400429645908923161ull, 5758609657015291369ull}},
{{13056149971321810324ull, 7346958747461940104ull,
  9165479002103990240ull, 7198262071269114212ull}},
{{16320187464152262904ull, 9183698434327425130ull,
  11456848752629987800ull, 8997827589086392765ull}},
{{14811803183522552219ull, 5739811521454640706ull,
  9466373479607436327ull, 5623642243178995478ull}},
{{9291381942548414466ull, 2563078383390912979ull,
  2609594812654519601ull, 7029552803973744348ull}},
{{7002541409758130179ull, 7815533997666029128ull,
  3261993515818149501ull, 8786941004967180435ull}},
{{4376588381098831362ull, 7190551757754962157ull,
  18179647011882201102ull, 5491838128104487771ull}},
{{10082421494800927106ull, 18211561734048478504ull,
  18112872746425363473ull, 6864797660130609714ull}},
{{12603026868501158883ull, 8929394112278434418ull,
  13417718896176928534ull, 8580997075163262143ull}},
{{12488577811240612206ull, 969185301746633607ull,
  15303603337751662190ull, 5363123171977038839ull}},
{{10999036245623377353ull, 10434853664038067817ull,
  14517818153762189833ull, 6703903964971298549ull}},
{{18360481325456609595ull, 17655253098474972675ull,
  4312214636920573579ull, 8379879956214123187ull}},
{{9169457819196687045ull, 8728690177333163970ull, 389291138861664535ull,
  5237424972633826992ull}},
{{2238450237141082998ull, 6299176703239067059ull, 486613923577080669ull,
  6546781215792283740ull}},
{{16633120851708517460ull, 12485656897476221727ull,
  608267404471350836ull, 8183476519740354675ull}},
{{17313229559958905269ull, 17026907597777414387ull,
  16521068192290451936ull, 5114672824837721671ull}},
{{17029850931521243682ull, 2836890423512216368ull,
  16039649221935677017ull, 6393341031047152089ull}},
{{2840569590692002986ull, 8157799047817658365ull,
  6214503472137432559ull, 7991676288808940112ull}},
{{4081199003396195818ull, 12016153432527118334ull,
  3884064670085895349ull, 4994797680505587570ull}},
{{14324870791100020581ull, 1185133735376734205ull,
  14078452874462144995ull, 6243497100631984462ull}},
{{4071030433592862014ull, 15316475224503081469ull,
  8374694056222905435ull, 7804371375789980578ull}},
{{4850237030209232711ull, 7266954006100731966ull,
  9845869803566703801ull, 4877732109868737861ull}},
{{15286168324616316697ull, 13695378526053302861ull,
  16919023272885767655ull, 6097165137335922326ull}},
{{5272652350488232159ull, 12507537139139240673ull,
  11925407054252433761ull, 7621456421669902908ull}},
{{14824622765123614859ull, 899681684320943564ull,
  16676751445762546909ull, 4763410263543689317ull}},
{{84034382694966958ull, 5736288123828567360ull, 7010881251921019924ull,
  5954262829429611647ull}},
{{105042978368708697ull, 7170360154785709200ull, 4151915546473887001ull,
  7442828536787014559ull}},
{{65651861480442936ull, 16010690142809538010ull, 9512476244187261231ull,
  4651767835491884099ull}},
{{9305436863705329478ull, 15401676660084534608ull,
  7278909286806688635ull, 5814709794364855124ull}},
{{11631796079631661847ull, 14640409806678280356ull,
  9098636608508360794ull, 7268387242956068905ull}},
{{14539745099539577309ull, 9077140221493074637ull,
  15984981779062838897ull, 9085484053695086131ull}},
{{11393183696425929770ull, 17202427684501641408ull,
  7684770602700580358ull, 5678427533559428832ull}},
{{14241479620532412213ull, 12279662568772275952ull,
  9605963253375725448ull, 7098034416949286040ull}},
{{17801849525665515266ull, 15349578210965344940ull,
  12007454066719656810ull, 8872543021186607550ull}},
{{1902783916686171233ull, 14205172400280728492ull,
  2892972773272397602ull, 5545339388241629719ull}},
{{2378479895857714042ull, 8533093463496134807ull,
  17451274021872660715ull, 6931674235302037148ull}},
{{16808157925104306264ull, 6054680810942780604ull,
  3367348453631274278ull, 8664592794127546436ull}},
{{1281726666335415607ull, 17619233562121401590ull,
  11327964820374322231ull, 5415370496329716522ull}},
{{10825530369774045317ull, 17412355934224364083ull,
  4936583988613126981ull, 6769213120412145653ull}},
{{8920226943790168742ull, 7930386862498291392ull,
  10782416004193796631ull, 8461516400515182066ull}},
{{5575141839868855464ull, 11874020816702513976ull,
  11350696021048510798ull, 5288447750321988791ull}},
{{6968927299836069330ull, 5619153984023366662ull,
  9576684007883250594ull, 6610559687902485989ull}},
{{17934531161649862470ull, 16247314516883984135ull,
  16582541028281451146ull, 8263199609878107486ull}},
{{18126611003672245900ull, 14766257591479877988ull,
  5752402124248519062ull, 5164499756173817179ull}},
{{4211519680880755759ull, 9234449952495071678ull,
  2578816636883260924ull, 6455624695217271474ull}},
{{14487771637955720506ull, 11543062440618839597ull,
  12446892832958851963ull, 8069530869021589342ull}},
{{11360700282936019269ull, 4908571016173080796ull,
  3167622002171894573ull, 5043456793138493339ull}},
{{14200875353670024086ull, 10747399788643738899ull,
  17794585557997031928ull, 6304320991423116673ull}},
{{13139408173660142203ull, 13434249735804673624ull,
  8408173892214126198ull, 7880401239278895842ull}},
{{8212130108537588877ull, 3784720066450533111ull,
  9866794701061216778ull, 4925250774549309901ull}},
{{5653476617244598192ull, 13954272119917942197ull,
  16945179394753908876ull, 6156563468186637376ull}},
{{11678531789983135644ull, 17442840149897427746ull,
  2734730169732834479ull, 7695704335233296721ull}},
{{11910768387166847682ull, 17819304121326974197ull,
  13238421402151491309ull, 4809815209520810450ull}},
{{1053402428676395890ull, 8439072096376554035ull,
  7324654715834588329ull, 6012269011901013063ull}},
{{15151811091127658574ull, 15160526138898080447ull,
  4544132376365847507ull, 7515336264876266329ull}},
{{16387410959595868465ull, 7169485827597606327ull,
  14369297781297124452ull, 4697085165547666455ull}},
{{15872577681067447677ull, 8961857284497007909ull,
  13349936208194017661ull, 5871356456934583069ull}},
{{6005664046052145885ull, 15814007624048647791ull,
  2852362204960358364ull, 7339195571168228837ull}},
{{2895394039137794452ull, 1320765456351258123ull,
  8177138774627835860ull, 9173994463960286046ull}},
{{17950522338956979196ull, 10048850447074312134ull,
  499025715715009508ull, 5733746539975178779ull}},
{{13214780886841448187ull, 12561063058842890168ull,
  14458840199925925597ull, 7167183174968973473ull}},
{{16518476108551810234ull, 1866270768271448998ull,
  4238492194625243285ull, 8958978968711216842ull}},
{{5712361549417493492ull, 3472262239383349576ull,
  7260743640068164957ull, 5599361855444510526ull}},
{{7140451936771866865ull, 8952013817656574874ull,
  18299301586939982004ull, 6999202319305638157ull}},
{{18148936957819609390ull, 11190017272070718592ull,
  9039068928392813793ull, 8749002899132047697ull}},
{{11343085598637255869ull, 76231767403117264ull,
  17178633126313978381ull, 5468126811957529810ull}},
{{14178856998296569836ull, 4706975727681284484ull,
  12249919371037697168ull, 6835158514946912263ull}},
{{17723571247870712295ull, 5883719659601605605ull,
  10700713195369733556ull, 8543948143683640329ull}},
{{13383075039132889136ull, 12900696824105779311ull,
  18217160793174553232ull, 5339967589802275205ull}},
{{12117157780488723516ull, 16125871030132224139ull,
  8936392936186027828ull, 6674959487252844007ull}},
{{10534761207183516491ull, 1710594713955728558ull,
  6558805151805146882ull, 8343699359066055009ull}},
{{1972539736062309903ull, 5680807714649718253ull,
  15628468265946686561ull, 5214812099416284380ull}},
{{7077360688505275283ull, 11712695661739535720ull,
  1088841258723806585ull, 6518515124270355476ull}},
{{8846700860631594104ull, 805811521892255938ull, 1361051573404758232ull,
  8148143905337944345ull}},
{{10140874056322134219ull, 503632201182659961ull,
  12379872279446443655ull, 5092589940836215215ull}},
{{17287778588830055677ull, 14464598306760488663ull,
  10863154330880666664ull, 6365737426045269019ull}},
{{16998037217610181693ull, 18080747883450610829ull,
  8967256895173445426ull, 7957171782556586274ull}},
{{12929616270220057510ull, 15912153445584019672ull,
  10216221577910791295ull, 4973232364097866421ull}},
{{16162020337775071888ull, 15278505788552636686ull,
  17381962990815877023ull, 6216540455122333026ull}},
{{10979153385364064051ull, 14486446217263407954ull,
  12504081701665070471ull, 7770675568902916283ull}},
{{11473656884279927936ull, 15971557913430711827ull,
  5509208054326975092ull, 4856672230564322677ull}},
{{9730385086922522016ull, 1517703318078838168ull,
  11498196086336106770ull, 6070840288205403346ull}},
{{12162981358653152520ull, 11120501184453323518ull,
  5149373071065357654ull, 7588550360256754183ull}},
{{2990177330730832421ull, 2338627221855939295ull,
  10135887197056930390ull, 4742843975160471364ull}},
{{17572779718695704238ull, 12146656064174699926ull,
  12669858996321162987ull, 5928554968950589205ull}},
{{12742602611514854490ull, 10571634061790987004ull,
  2002265690119290022ull, 7410693711188236507ull}},
{{17187498669051559864ull, 1995585270191978973ull,
  17392317120820413928ull, 4631683569492647816ull}},
{{7649315281032286118ull, 2494481587739973717ull,
  3293652327315965794ull, 5789604461865809771ull}},
{{14173330119717745552ull, 12341474021529742954ull,
  17952123464427120954ull, 7237005577332262213ull}},
{{8493290612792406132ull, 6203470490057402885ull,
  8605096275251737481ull, 9046256971665327767ull}},
{{7614149642208947785ull, 15406384102354346563ull,
  12295714199673417781ull, 5653910607290829854ull}},
{{4906001034333796827ull, 5422922072660769492ull,
  6146270712736996419ull, 7067388259113537318ull}},
{{6132501292917246033ull, 2166966572398573961ull,
  16906210427776021332ull, 8834235323891921647ull}},
{{15362028354141748531ull, 10577726144603884533ull,
  17483910545001095188ull, 5521397077432451029ull}},
{{5367477387395021951ull, 13222157680754855667ull,
  8019830125969205273ull, 6901746346790563787ull}},
{{2097660715816389535ull, 2692639045661405872ull,
  5413101639034118688ull, 8627182933488204734ull}},
{{1311037947385243460ull, 1682899403538378670ull,
  17218246579678487892ull, 5391989333430127958ull}},
{{10862169471086330132ull, 2103624254422973337ull,
  12299436187743334057ull, 6739986666787659948ull}},
{{18189397857285300569ull, 7241216336456104575ull,
  15374295234679167571ull, 8424983333484574935ull}},
{{18285902688444394712ull, 2219917201071371407ull,
  16526463549315561588ull, 5265614583427859334ull}},
{{18245692342128105486ull, 2774896501339214259ull,
  11434707399789676177ull, 6582018229284824168ull}},
{{18195429409232743953ull, 8080306645101405728ull,
  14293384249737095221ull, 8227522786606030210ull}},
{{11372143380770464971ull, 7356034662402072532ull,
  13545051174513072417ull, 5142201741628768881ull}},
{{14215179225963081214ull, 13806729346429978569ull,
  3096255912859176809ull, 6427752177035961102ull}},
{{3933915977171687805ull, 3423353627755309500ull,
  13093691927928746820ull, 8034690221294951377ull}},
{{11682069522587080686ull, 11362968054201844245ull,
  1266028427314384906ull, 5021681388309344611ull}},
{{767528847951687146ull, 4980338030897529499ull,
  15417593589425144845ull, 6277101735386680763ull}},
{{14794469115221772644ull, 10837108557049299777ull,
  14660305968354043152ull, 7846377169233350954ull}},
{{2329014169372526047ull, 6773192848155812361ull,
  13774377248648664874ull, 4903985730770844346ull}},
{{7522953730143045462ull, 17689863097049541259ull,
  7994599523956055284ull, 6129982163463555433ull}},
{{4792006144251418924ull, 3665584797602374958ull,
  14604935423372457010ull, 7662477704329444291ull}},
{{16830061895439300539ull, 6902676516928872252ull,
  6822241630394091679ull, 4789048565205902682ull}},
{{2590833295589574058ull, 4016659627733702412ull,
  17751174074847390407ull, 5986310706507378352ull}},
{{3238541619486967573ull, 409138516239740111ull, 3742223519849686393ull,
  7482888383134222941ull}},
{{8941617539820436589ull, 11784926618718307329ull,
  4644732709119747947ull, 4676805239458889338ull}},
{{15788707943202933640ull, 10119472254970496257ull,
  15029287923254460742ull, 5846006549323611672ull}},
{{5900826873721503338ull, 3425968281858344514ull, 339865830358524312ull,
  7307508186654514591ull}},
{{16599405629006654981ull, 4282460352322930642ull,
  14259890343230319102ull, 9134385233318143238ull}},
{{14986314536556547267ull, 16511595775483995363ull,
  4300745446091561534ull, 5708990770823839524ull}},
{{14121207152268296180ull, 11416122682500218396ull,
  5375931807614451918ull, 7136238463529799405ull}},
{{17651508940335370225ull, 5046781316270497187ull,
  11331600777945452802ull, 8920298079412249256ull}},
{{8726350078495912439ull, 7765924341096448646ull,
  7082250486215908001ull, 5575186299632655785ull}},
{{1684565561265114740ull, 14319091444797948712ull,
  13464499126197272905ull, 6968982874540819731ull}},
{{2105706951581393425ull, 4063806250715272178ull,
  12218937889319203228ull, 8711228593176024664ull}},
{{5927752863165758795ull, 11763250943551820919ull,
  7636836180824502017ull, 5444517870735015415ull}},
{{2798005060529810589ull, 869005624157612437ull, 4934359207603239618ull,
  6805647338418769269ull}},
{{8109192344089651141ull, 10309629067051791354ull,
  10779635027931437426ull, 8507059173023461586ull}},
{{9679931233483419867ull, 11055204185334757500ull,
  11348957910884536295ull, 5316911983139663491ull}},
{{12099914041854274834ull, 9207319213241058971ull,
  9574511370178282465ull, 6646139978924579364ull}},
{{10513206533890455638ull, 16120835034978711618ull,
  11968139212722853081ull, 8307674973655724205ull}},
{{11182440102108922678ull, 3157992869220612905ull,
  9785930017165477128ull, 5192296858534827628ull}},
{{142992072353989635ull, 3947491086525766132ull,
  12232412521456846410ull, 6490371073168534535ull}},
{{178740090442487044ull, 14157735895011983473ull,
  10678829633393670108ull, 8112963841460668169ull}},
{{11640927602595024163ull, 18071956971237265478ull,
  18203483566939513577ull, 5070602400912917605ull}},
{{5327787466389004395ull, 8754888158764418136ull,
  8919296403392228260ull, 6338253001141147007ull}},
{{6659734332986255494ull, 10943610198455522670ull,
  6537434485812897421ull, 7922816251426433759ull}},
{{17997392013398573396ull, 9145599383248395620ull,
  11003425581274142744ull, 4951760157141521099ull}},
{{4049995943038665129ull, 11431999229060494526ull,
  9142595958165290526ull, 6189700196426901374ull}},
{{14285866965653107219ull, 5066626999470842349ull,
  2204872910851837350ull, 7737125245533626718ull}},
{{11234509862746885964ull, 17001699929951440180ull,
  15213103624564562055ull, 4835703278458516698ull}},
{{14043137328433607455ull, 16640438894011912321ull,
  9793007493850926761ull, 6044629098073145873ull}},
{{3718863605259845606ull, 6965490562232726690ull,
  16852945385741046356ull, 7555786372591432341ull}},
{{6935975771714791408ull, 13576803638250229989ull,
  12838933875301847924ull, 4722366482869645213ull}},
{{13281655733070877164ull, 16971004547812787486ull,
  2213609288845146193ull, 5902958103587056517ull}},
{{7378697629483820647ull, 7378697629483820646ull,
  7378697629483820646ull, 7378697629483820646ull}},
{{0ull, 0ull, 0ull, 9223372036854775808ull}},
{{0ull, 0ull, 0ull, 5764607523034234880ull}},
{{0ull, 0ull, 0ull, 7205759403792793600ull}},
{{0ull, 0ull, 0ull, 9007199254740992000ull}},
{{0ull, 0ull, 0ull, 5629499534213120000ull}},
{{0ull, 0ull, 0ull, 7036874417766400000ull}},
{{0ull, 0ull, 0ull, 8796093022208000000ull}},
{{0ull, 0ull, 0ull, 5497558138880000000ull}},
{{0ull, 0ull, 0ull, 6871947673600000000ull}},
{{0ull, 0ull, 0ull, 8589934592000000000ull}},
{{0ull, 0ull, 0ull, 5368709120000000000ull}},
{{0ull, 0ull, 0ull, 6710886400000000000ull}},
{{0ull, 0ull, 0ull, 8388608000000000000ull}},
{{0ull, 0ull, 0ull, 5242880000000000000ull}},
{{0ull, 0ull, 0ull, 6553600000000000000ull}},
{{0ull, 0ull, 0ull, 8192000000000000000ull}},
{{0ull, 0ull, 0ull, 5120000000000000000ull}},
{{0ull, 0ull, 0ull, 6400000000000000000ull}},
{{0ull, 0ull, 0ull, 8000000000000000000ull}},
{{0ull, 0ull, 0ull, 5000000000000000000ull}},
{{0ull, 0ull, 0ull, 6250000000000000000ull}},
{{0ull, 0ull, 0ull, 7812500000000000000ull}},
{{0ull, 0ull, 0ull, 4882812500000000000ull}},
{{0ull, 0ull, 0ull, 6103515625000000000ull}},
{{0ull, 0ull, 0ull, 7629394531250000000ull}},
{{0ull, 0ull, 0ull, 4768371582031250000ull}},
{{0ull, 0ull, 0ull, 5960464477539062500ull}},
{{0ull, 0ull, 0ull, 7450580596923828125ull}},
{{0ull, 0ull, 2305843009213693952ull, 4656612873077392578ull}},
{{0ull, 0ull, 12105675798371893248ull, 5820766091346740722ull}},
{{0ull, 0ull, 5908722711110090752ull, 7275957614183425903ull}},
{{0ull, 0ull, 2774217370460225536ull, 9094947017729282379ull}},
{{0ull, 0ull, 17874786921033498624ull, 5684341886080801486ull}},
{{0ull, 0ull, 13120111614437097472ull, 7105427357601001858ull}},
{{0ull, 0ull, 7176767481191596032ull, 8881784197001252323ull}},
{{0ull, 0ull, 2179636666531053568ull, 5551115123125782702ull}},
{{0ull, 0ull, 11947917870018592768ull, 6938893903907228377ull}},
{{0ull, 0ull, 1099839282241077248ull, 8673617379884035472ull}},
{{0ull, 0ull, 687399551400673280ull, 5421010862427522170ull}},
{{0ull, 0ull, 10082621476105617408ull, 6776263578034402712ull}},
{{0ull, 0ull, 12603276845132021760ull, 8470329472543003390ull}},
{{0ull, 0ull, 3265362009780125696ull, 5293955920339377119ull}},
{{0ull, 0ull, 17916760567507320832ull, 6617444900424221398ull}},
{{0ull, 0ull, 13172578672529375232ull, 8271806125530276748ull}},
{{0ull, 0ull, 17456233707185635328ull, 5169878828456422967ull}},
{{0ull, 0ull, 17208606115554656256ull, 6462348535570528709ull}},
{{0ull, 0ull, 7675699589161156608ull, 8077935669463160887ull}},
{{0ull, 0ull, 11714841270866804736ull, 5048709793414475554ull}},
{{0ull, 0ull, 5420179551728730112ull, 6310887241768094443ull}},
{{0ull, 0ull, 2163538421233524736ull, 7888609052210118054ull}},
{{0ull, 0ull, 15187269568553116672ull, 4930380657631323783ull}},
{{0ull, 0ull, 14372400942264007936ull, 6162975822039154729ull}},
{{0ull, 0ull, 4130443122547846208ull, 7703719777548943412ull}},
{{0ull, 0ull, 11804898988447179688ull, 4814824860968089632ull}},
{{0ull, 0ull, 14756123735558974610ull, 6018531076210112040ull}},
{{0ull, 9223372036854775808ull, 18445154669448718262ull,
  7523163845262640050ull}},
{{0ull, 1152921504606846976ull, 16139907686832836818ull,
  4701977403289150031ull}},
{{0ull, 10664523917613334528ull, 15563198590113658118ull,
  5877471754111437539ull}},
{{0ull, 4107282860161892352ull, 14842312219214684744ull,
  7346839692639296924ull}},
{{0ull, 5134103575202365440ull, 106146200308804314ull,
  9183549615799121156ull}},
{{0ull, 7820500752928866304ull, 9289713412047778504ull,
  5739718509874450722ull}},
{{0ull, 9775625941161082880ull, 2388769728204947322ull,
  7174648137343063403ull}},
{{0ull, 2996160389596577792ull, 16821020215538347865ull,
  8968310171678829253ull}},
{{0ull, 13401815289566330880ull, 12818980643925161367ull,
  5605193857299268283ull}},
{{0ull, 12140583093530525696ull, 11412039786479063805ull,
  7006492321624085354ull}},
{{0ull, 1340670811630993408ull, 5041677696244053949ull,
  8758115402030106693ull}},
{{0ull, 3143762266483064832ull, 5456891569366227670ull,
  5473822126268816683ull}},
{{0ull, 13153074869958606848ull, 2209428443280396683ull,
  6842277657836020854ull}},
{{0ull, 11829657569020870656ull, 11985157590955271662ull,
  8552847072295026067ull}},
{{0ull, 2781849962210656256ull, 5184880485133350837ull,
  5345529420184391292ull}},
{{0ull, 8088998471190708224ull, 6481100606416688546ull,
  6681911775230489115ull}},
{{0ull, 887876052133609472ull, 3489689739593472779ull,
  8352389719038111394ull}},
{{0ull, 16695823597079363584ull, 6792742105673308390ull,
  5220243574398819621ull}},
{{0ull, 11646407459494428672ull, 13102613650519023392ull,
  6525304467998524526ull}},
{{0ull, 14558009324368035840ull, 7154895026294003432ull,
  8156630584998155658ull}},
{{0ull, 9098755827730022400ull, 9083495409861140049ull,
  5097894115623847286ull}},
{{0ull, 15985130803089915904ull, 2130997225471649253ull,
  6372367644529809108ull}},
{{0ull, 6146355448580231168ull, 2663746531839561567ull,
  7965459555662261385ull}},
{{0ull, 10759001183003726336ull, 13194056628468195739ull,
  4978412222288913365ull}},
{{0ull, 8837065460327270016ull, 2657512730303080962ull,
  6223015277861141707ull}},
{{0ull, 1822959788554311712ull, 17156948968161014915ull,
  7778769097326427133ull}},
{{0ull, 17280250932342302484ull, 13028936114314328273ull,
  4861730685829016958ull}},
{{0ull, 7765255610145714393ull, 7062798106038134534ull,
  6077163357286271198ull}},
{{4611686018427387904ull, 483197475827367183ull,
  18051869669402443976ull, 7596454196607838997ull}},
{{9799832789158199296ull, 301998422392104489ull,
  13588261552590221437ull, 4747783872879899373ull}},
{{16861477004875137024ull, 4989184046417518515ull,
  3150268885455613084ull, 5934729841099874217ull}},
{{16465160237666533376ull, 6236480058021898144ull,
  8549522125246904259ull, 7418412301374842771ull}},
{{10290725148541583360ull, 1591957027049992388ull,
  3037608319065621210ull, 4636507688359276732ull}},
{{12863406435676979200ull, 11213318320667266293ull,
  3797010398832026512ull, 5795634610449095915ull}},
{{2244199989314060288ull, 14016647900834082867ull,
  134576980112645236ull, 7244543263061369894ull}},
{{16640308041924739072ull, 17520809876042603583ull,
  9391593261995582353ull, 9055679078826712367ull}},
{{17317721553844043776ull, 4032977144885545383ull,
  12787274816388320827ull, 5659799424266695229ull}},
{{17035465923877666816ull, 429535412679543825ull,
  2149035465203237322ull, 7074749280333369037ull}},
{{7459274349564919808ull, 9760291302704205590ull,
  7297980349931434556ull, 8843436600416711296ull}},
{{50360450050686976ull, 15323554101044904302ull, 4561237718707146597ull,
  5527147875260444560ull}},
{{9286322599418134528ull, 5319384571023966665ull,
  5701547148383933247ull, 6908934844075555700ull}},
{{16219589267700056064ull, 2037544695352570427ull,
  7126933935479916559ull, 8636168555094444625ull}},
{{7831400283098841088ull, 8190994462236438373ull,
  15983548755743417609ull, 5397605346934027890ull}},
{{14400936372300939264ull, 14850429096222935870ull,
  10756063907824496203ull, 6747006683667534863ull}},
{{8777798428521398272ull, 13951350351851281934ull,
  8833393866353232350ull, 8433758354584418579ull}},
{{874437999398486016ull, 4107907951479663305ull, 3215028157257076267ull,
  5271098971615261612ull}},
{{5704733517675495424ull, 523198920922191227ull, 4018785196571345334ull,
  6588873714519077015ull}},
{{2519230878666981376ull, 9877370688007514842ull, 411795477286793763ull,
  8236092143148846269ull}},
{{6186205317594251264ull, 3867513670791002824ull,
  2563215182517940054ull, 5147557589468028918ull}},
{{7732756646992814080ull, 14057764125343529338ull,
  12427391015002200875ull, 6434446986835036147ull}},
{{442573771886241792ull, 12960519138252023769ull,
  10922552750325363190ull, 8043058733543795184ull}},
{{11805823653497370880ull, 3488638442980126951ull,
  6826595468953351994ull, 5026911708464871990ull}},
{{10145593548444325696ull, 13584170090579934497ull,
  17756616373046465800ull, 6283639635581089987ull}},
{{17293677953982795024ull, 16980212613224918121ull,
  17584084447880694346ull, 7854549544476362484ull}},
{{3891019693598165034ull, 15224318901692961730ull,
  1766680743070658158ull, 4909093465297726553ull}},
{{14087146653852482101ull, 9807026590261426354ull,
  6820036947265710602ull, 6136366831622158191ull}},
{{8385561280460826818ull, 3035411200972007135ull,
  3913360165654750349ull, 7670458539527697739ull}},
{{12158504827929098618ull, 4202975009821198411ull,
  140007094320525016ull, 4794036587204811087ull}},
{{10586445016483985368ull, 5253718762276498014ull,
  14010066923182819982ull, 5992545734006013858ull}},
{{4009684233750205902ull, 15790520489700398326ull,
  8289211617123749169ull, 7490682167507517323ull}},
{{16341110701376042401ull, 2951546278421667097ull,
  2874914251488649279ull, 4681676354692198327ull}},
{{6591330321437889289ull, 17524490903309247584ull,
  17428700869642975310ull, 5852095443365247908ull}},
{{8239162901797361611ull, 12682241592281783672ull,
  3339132013344167522ull, 7315119304206559886ull}},
{{10298953627246702013ull, 6629429953497453782ull,
  13397287053534985211ull, 9143899130258199857ull}},
{{1825159998601800855ull, 1837550711722214662ull,
  1455775380818283901ull, 5714936956411374911ull}},
{{11504822035107026876ull, 6908624408080156231ull,
  15654777281305018588ull, 7143671195514218638ull}},
{{9769341525456395691ull, 8635780510100195289ull,
  10345099564776497427ull, 8929588994392773298ull}},
{{17635053499478717067ull, 3091519809598928103ull,
  11077373246412698796ull, 5580993121495483311ull}},
{{17432130855921008430ull, 3864399761998660129ull,
  9235030539588485591ull, 6976241401869354139ull}},
{{7955105514619096825ull, 218813684070937258ull, 6932102156058219085ull,
  8720301752336692674ull}},
{{9583626965064323420ull, 2442601561758029738ull,
  8944249865963774832ull, 5450188595210432921ull}},
{{2756161669475628467ull, 3053251952197537173ull,
  15791998350882106444ull, 6812735744013041151ull}},
{{8056888105271923487ull, 3816564940246921466ull,
  15128311920175245151ull, 8515919680016301439ull}},
{{9647241084222340084ull, 9302882115295407772ull,
  16372723977750610075ull, 5322449800010188399ull}},
{{12059051355277925104ull, 7016916625691871811ull,
  15854218953760874690ull, 6653062250012735499ull}},
{{10462128175670018476ull, 17994517818969615572ull,
  15206087673773705458ull, 8316327812515919374ull}},
{{15762202146648537356ull, 15858259655283397636ull,
  4892118777681178007ull, 5197704882822449609ull}},
{{1256008609601120079ull, 15211138550676859142ull,
  10726834490528860413ull, 6497131103528062011ull}},
{{10793382798856175906ull, 5178865133063910215ull,
  8796857094733687613ull, 8121413879410077514ull}},
{{13663393276926191798ull, 5542633717378637836ull,
  10109721702635942662ull, 5075883674631298446ull}},
{{17079241596157739747ull, 16151664183578073103ull,
  3413780091440152519ull, 6344854593289123058ull}},
{{16737365976769786780ull, 15577894211045203475ull,
  13490597151154966457ull, 7931068241611403822ull}},
{{8155010726267422785ull, 2818654854262170316ull,
  3819937201044466132ull, 4956917651007127389ull}},
{{10193763407834278482ull, 3523318567827712895ull,
  9386607519732970569ull, 6196147063758909236ull}},
{{8130518241365460198ull, 9015834228212029023ull,
  11733259399666213211ull, 7745183829698636545ull}},
{{11999102928494494480ull, 3329053383418824187ull,
  415758097150301401ull, 4840739893561647841ull}},
{{10387192642190730196ull, 8773002747700918138ull,
  5131383639865264655ull, 6050924866952059801ull}},
{{3760618765883636937ull, 6354567416198759769ull,
  11025915568258968723ull, 7563656083690074751ull}},
{{13879601774745742846ull, 1665761625910530903ull,
  13808726257802937308ull, 4727285052306296719ull}},
{{12737816200004790653ull, 2082202032388163629ull,
  12649221803826283731ull, 5909106315382870899ull}},
{{2087212194723824604ull, 16437810595767368249ull,
  11199841236355466759ull, 7386382894228588624ull}},
{{12833722667770860138ull, 17191160649995687011ull,
  6999900772722166724ull, 4616489308892867890ull}},
{{11430467316286187268ull, 3042206738785057148ull,
  17973248002757484214ull, 5770611636116084862ull}},
{{14288084145357734085ull, 13026130460336097243ull,
  13243187966592079459ull, 7213264545145106078ull}},
{{13248419163269779702ull, 11670977056992733650ull,
  7330612921385323516ull, 9016580681431382598ull}},
{{12891947995471000218ull, 16517732697475234339ull,
  18416691131147990909ull, 5635362925894614123ull}},
{{11503248975911362368ull, 6812107816561879212ull,
  18409177895507600733ull, 7044203657368267654ull}},
{{14379061219889202960ull, 13126820789129736919ull,
  13788100332529725108ull, 8805254571710334568ull}},
{{15904442290071833706ull, 17427635030060861382ull,
  8617562707831078192ull, 5503284107318959105ull}},
{{10657180825735016325ull, 3337799713866525112ull,
  15383639403216235645ull, 6879105134148698881ull}},
{{13321476032168770406ull, 8783935660760544294ull,
  5394491198738130844ull, 8598881417685873602ull}},
{{3714236501678093600ull, 14713331824830115992ull,
  7983243017638719681ull, 5374300886053671001ull}},
{{4642795627097617000ull, 4556606725755481278ull,
  14590739790475787506ull, 6717876107567088751ull}},
{{15026866570726797057ull, 14919130444049127405ull,
  13626738719667346478ull, 8397345134458860939ull}},
{{11697634615917942113ull, 4712770509103316724ull,
  6210868690578397597ull, 5248340709036788087ull}},
{{14622043269897427641ull, 10502649154806533809ull,
  3151899844795609092ull, 6560425886295985109ull}},
{{4442496032089620839ull, 13128311443508167262ull,
  8551560824421899269ull, 8200532357869981386ull}},
{{16611618075338176737ull, 10511037661406298490ull,
  9956411533691074947ull, 5125332723668738366ull}},
{{11541150557317945113ull, 8527111058330485209ull,
  3222142380259067876ull, 6406665904585922958ull}},
{{591380141365267679ull, 10658888822913106512ull,
  13251050012178610653ull, 8008332380732403697ull}},
{{369612588353292299ull, 8967648523534385522ull, 1364377229970549802ull,
  5005207737957752311ull}},
{{9685387772296391182ull, 1986188617563206094ull,
  15540529592745350965ull, 6256509672447190388ull}},
{{2883362678515713170ull, 7094421790381395522ull, 978917917222137090ull,
  7820637090558987986ull}},
{{6413787692499708635ull, 9045699637415760105ull,
  5223509716691223585ull, 4887898181599367491ull}},
{{12628920634052023698ull, 15918810565197088035ull,
  1917701127436641577ull, 6109872726999209364ull}},
{{11174464774137641718ull, 6063455151214196332ull,
  2397126409295801972ull, 7637340908749011705ull}},
{{16207412520690801882ull, 13013031506363648515ull,
  13027419051878345992ull, 4773338067968132315ull}},
{{15647579632436114448ull, 16266289382954560644ull,
  11672587796420544586ull, 5966672584960165394ull}},
{{1112730466835591444ull, 11109489691838424998ull,
  5367362708670904925ull, 7458340731200206743ull}},
{{14530514597054408365ull, 9249274066612709575ull,
  10272130720560397434ull, 4661462957000129214ull}},
{{13551457227890622552ull, 2338220546411111161ull,
  3616791363845720985ull, 5826828696250161518ull}},
{{3104263479581114478ull, 7534461701441276856ull,
  13744361241661927039ull, 7283535870312701897ull}},
{{3880329349476393097ull, 4806391108374208166ull,
  3345393496795245087ull, 9104419837890877372ull}},
{{16260263898704909398ull, 9921523470374961959ull,
  11314242972351803987ull, 5690262398681798357ull}},
{{15713643854953748843ull, 7790218319541314545ull,
  307745660157591272ull, 7112827998352247947ull}},
{{5806996763410022342ull, 9737772899426643182ull,
  14219740130479152802ull, 8891034997940309933ull}},
{{17464431032413427676ull, 10697794080569039892ull,
  11193180590763164453ull, 5556896873712693708ull}},
{{3383794716807232979ull, 17983928619138687770ull,
  13991475738453955566ull, 6946121092140867135ull}},
{{13453115432863817032ull, 13256538737068583904ull,
  12877658654640056554ull, 8682651365176083919ull}},
{{8408197145539885645ull, 12897022729095252844ull,
  14966065686791117202ull, 5426657103235052449ull}},
{{10510246431924857056ull, 6897906374514290247ull,
  4872524053206732791ull, 6783321379043815562ull}},
{{8526122021478683416ull, 4010696949715474905ull,
  15314027103363191797ull, 8479151723804769452ull}},
{{16858041309492646895ull, 4812528602785865767ull,
  347894902747219065ull, 5299469827377980908ull}},
{{16460865618438420715ull, 10627346771909720113ull,
  434868628434023831ull, 6624337284222476135ull}},
{{6741023967765862181ull, 8672497446459762238ull,
  14378643840824693501ull, 8280421605278095168ull}},
{{18048198035135827576ull, 7726153913251045350ull,
  8986652400515433438ull, 5175263503298809480ull}},
{{13336875507065008661ull, 434320354709030880ull,
  11233315500644291798ull, 6469079379123511850ull}},
{{16671094383831260826ull, 9766272480241064408ull,
  4818272338950588939ull, 8086349223904389813ull}},
{{10419433989894538017ull, 3798077290936971303ull,
  5317263221057812039ull, 5053968264940243633ull}},
{{8412606468940784617ull, 135910595243826225ull,
  11258265044749652953ull, 6317460331175304541ull}},
{{15127444104603368675ull, 4781574262482170685ull,
  237773250654902479ull, 7896825413969130677ull}},
{{11760495574590799374ull, 9906012941692438534ull,
  2454451290873008001ull, 4935515883730706673ull}},
{{5477247431383723409ull, 16994202195542936072ull,
  7679750132018647905ull, 6169394854663383341ull}},
{{6846559289229654262ull, 7407694689146506378ull,
  14211373683450697786ull, 7711743568329229176ull}},
{{8890785574195921818ull, 9241495199143954390ull,
  8882108552156686116ull, 4819839730205768235ull}},
{{1890109930890126464ull, 11551868998929942988ull,
  6490949671768469741ull, 6024799662757210294ull}},
{{2362637413612658080ull, 604778193380265023ull,
  17337059126565362985ull, 7530999578446512867ull}},
{{8394177411148993156ull, 11907201416931135399ull,
  8529818944889657913ull, 4706874736529070542ull}},
{{5881035745508853541ull, 1048943715881755537ull,
  1438901644257296584ull, 5883593420661338178ull}},
{{11962980700313454830ull, 1311179644852194421ull,
  11021999092176396538ull, 7354491775826672722ull}},
{{1118667820109654825ull, 10862346592920018835ull,
  4554126828365719864ull, 9193114719783340903ull}},
{{16840068452064391930ull, 6788966620575011771ull,
  9763858295369656771ull, 5745696699864588064ull}},
{{16438399546653102009ull, 3874522257291376810ull,
  12204822869212070964ull, 7182120874830735080ull}},
{{11324627396461601703ull, 4843152821614221013ull,
  15256028586515088705ull, 8977651093538418850ull}},
{{9383735132002195016ull, 14556185559577357893ull,
  14146703884999318344ull, 5611031933461511781ull}},
{{16341354933430131674ull, 18195231949471697366ull,
  3848321800966984218ull, 7013789916826889727ull}},
{{11203321629932888785ull, 13520667899984845900ull,
  198716232781342369ull, 8767237396033612159ull}},
{{16225448055562831299ull, 1532888409849446831ull,
  7041726673129420837ull, 5479523372521007599ull}},
{{15670124051026151219ull, 6527796530739196443ull,
  4190472322984388142ull, 6849404215651259499ull}},
{{14975969045355301120ull, 17383117700278771362ull,
  626404385303097273ull, 8561755269564074374ull}},
{{13971666671774451104ull, 3946919535033150245ull,
  14226560796096599508ull, 5351097043477546483ull}},
{{3629525284435900168ull, 4933649418791437807ull,
  13171514976693361481ull, 6688871304346933104ull}},
{{18371964660827038922ull, 10778747791916685162ull,
  16464393720866701851ull, 8361089130433666380ull}},
{{16094163931444287230ull, 4430874360734234274ull,
  1066874038686912849ull, 5225680706521041488ull}},
{{10894332877450583230ull, 10150278969345180747ull,
  1333592548358641061ull, 6532100883151301860ull}},
{{9006230078385841133ull, 17299534730108863838ull,
  1666990685448301326ull, 8165126103939127325ull}},
{{1017207780563762804ull, 6200523187890651995ull,
  3347712187618882281ull, 5103203814961954578ull}},
{{15106567780986867217ull, 12362340003290702897ull,
  13408012271378378659ull, 6379004768702443222ull}},
{{5048151670951420310ull, 10841238985685990718ull,
  7536643302368197516ull, 7973755960878054028ull}},
{{16990152849626801406ull, 15999146402908520006ull,
  13933774100834899255ull, 4983597475548783767ull}},
{{12014319025178725949ull, 15387246985208262104ull,
  12805531607616236165ull, 6229496844435979709ull}},
{{15017898781473407436ull, 5399000676228163918ull,
  2171856454238131495ull, 7786871055544974637ull}},
{{4774500719993491744ull, 10291904450283684305ull,
  3663253293112526136ull, 4866794409715609148ull}},
{{10579811918419252584ull, 12864880562854605381ull,
  4579066616390657670ull, 6083493012144511435ull}},
{{17836450916451453633ull, 6857728666713480918ull,
  1112147252060934184ull, 7604366265180639294ull}},
{{6536095804354770617ull, 4286080416695925574ull,
  14530150087820247577ull, 4752728915737899558ull}},
{{17393491792298239079ull, 9969286539297294871ull,
  8939315572920533663ull, 5940911144672374448ull}},
{{17130178721945410945ull, 7849922155694230685ull,
  11174144466150667079ull, 7426138930840468060ull}},
{{13012204710429575793ull, 11823730374949976034ull,
  16207212328198942732ull, 4641336831775292537ull}},
{{7041883851182193933ull, 14779662968687470043ull,
  6423957354966514703ull, 5801671039719115672ull}},
{{4190668795550354512ull, 13862892692431949650ull,
  8029946693708143379ull, 7252088799648894590ull}},
{{14461708031292718948ull, 12716929847112549158ull,
  814061330280403416ull, 9065110999561118238ull}},
{{4426881501130561438ull, 7948081154445343224ull,
  14343846386707415847ull, 5665694374725698898ull}},
{{5533601876413201798ull, 5323415424629291126ull,
  8706435946529494001ull, 7082117968407123623ull}},
{{16140374382371278055ull, 11265955299214001811ull,
  6271358914734479597ull, 8852647460508904529ull}},
{{7781890979768354833ull, 9347065071222445084ull,
  15448814367777519508ull, 5532904662818065330ull}},
{{9727363724710443541ull, 11683831339028056355ull,
  10087645922867123577ull, 6916130828522581663ull}},
{{7547518637460666522ull, 769731118502906732ull, 7997871385156516568ull,
  8645163535653227079ull}},
{{13940571185267692384ull, 481081949064316707ull,
  11916198643363904711ull, 5403227209783266924ull}},
{{12814027963157227576ull, 14436410491612559596ull,
  14895248304204880888ull, 6754034012229083655ull}},
{{16017534953946534470ull, 18045513114515699495ull,
  14007374361828713206ull, 8442542515286354569ull}},
{{16928488373857665900ull, 6666759678144924280ull,
  1837079948501863898ull, 5276589072053971606ull}},
{{2713866393612530759ull, 17556821634535931159ull,
  11519721972482105680ull, 6595736340067464507ull}},
{{17227391047297827161ull, 3499282969460362332ull,
  9787966447175244197ull, 8244670425084330634ull}},
{{1543747367706366168ull, 4492894865126420410ull,
  10729165047911915527ull, 5152919015677706646ull}},
{{11153056246487733517ull, 1004432562980637608ull,
  4188084273035118601ull, 6441148769597133308ull}},
{{13941320308109666897ull, 5867226722153184914ull,
  5235105341293898251ull, 8051435961996416635ull}},
{{13325011210995929715ull, 1361173692132046619ull,
  966097829094992455ull, 5032147476247760397ull}},
{{12044577995317524239ull, 15536525170447221986ull,
  5819308304796128472ull, 6290184345309700496ull}},
{{5832350457292129491ull, 973912389349475867ull, 7274135380995160591ull,
  7862730431637125620ull}},
{{1339376026593886980ull, 7526224270984504273ull,
  13769706649976751177ull, 4914206519773203512ull}},
{{6285906051669746629ull, 14019466357158018245ull,
  17212133312470938971ull, 6142758149716504390ull}},
{{12469068583014571190ull, 12912646928020134902ull,
  12291794603733897906ull, 7678447687145630488ull}},
{{3181481845956719090ull, 12682090348439972218ull,
  7682371627333686191ull, 4799029804466019055ull}},
{{13200224344300674670ull, 11240926917122577368ull,
  4991278515739719835ull, 5998787255582523819ull}},
{{16500280430375843337ull, 9439472627975833806ull,
  1627412126247261890ull, 7498484069478154774ull}},
{{5700989250557514182ull, 10511356410912284033ull,
  14852190634186702393ull, 4686552543423846733ull}},
{{11737922581624280632ull, 17750881532067742945ull,
  4730180237451214279ull, 5858190679279808417ull}},
{{837345171748187077ull, 17576915896657290778ull,
  10524411315241405753ull, 7322738349099760521ull}},
{{10270053501540009654ull, 8136086815539449760ull,
  17767200162479145096ull, 9153422936374700651ull}},
{{6418783438462506034ull, 5085054259712156100ull,
  8798657092335771733ull, 5720889335234187907ull}},
{{8023479298078132543ull, 10968003843067583029ull,
  6386635346992326762ull, 7151111669042734884ull}},
{{14641035141025053582ull, 4486632766979702978ull,
  7983294183740408453ull, 8938889586303418605ull}},
{{13762332981568046393ull, 5109988488576008313ull,
  7295401874051449235ull, 5586805991439636628ull}},
{{3367858171677894279ull, 1775799592292622488ull,
  9119252342564311544ull, 6983507489299545785ull}},
{{4209822714597367849ull, 2219749490365778110ull,
  16010751446632777334ull, 8729384361624432231ull}},
{{16466197251905518618ull, 15222401486760775030ull,
  16924248681786567689ull, 5455865226015270144ull}},
{{11359374528027122464ull, 5192943803168805076ull,
  2708566778523657996ull, 6819831532519087681ull}},
{{14199218160033903080ull, 6491179753961006345ull,
  7997394491581960399ull, 8524789415648859601ull}},
{{1956982322380107569ull, 10974516373866710822ull,
  16527586603307195009ull, 5327993384780537250ull}},
{{11669599939829910269ull, 18329831485760776431ull,
  11436111217279217953ull, 6659991730975671563ull}},
{{9975313906359999932ull, 9077231301918806827ull,
  9683453003171634538ull, 8324989663719589454ull}},
{{3928728182261306006ull, 10284955582126642171ull,
  1440472108554883682ull, 5203118539824743409ull}},
{{299224209399244603ull, 3632822440803526906ull, 6412276154120992507ull,
  6503898174780929261ull}},
{{9597402298603831562ull, 18376086106286572344ull,
  12627031211078628537ull, 8129872718476161576ull}},
{{5998376436627394726ull, 4567524788788025859ull,
  7891894506924142836ull, 5081170449047600985ull}},
{{2886284527356855504ull, 5709405985985032324ull,
  14476554152082566449ull, 6351463061309501231ull}},
{{3607855659196069380ull, 11748443500908678309ull,
  13484006671675820157ull, 7939328826636876539ull}},
{{4560752796211237315ull, 9648620197281617895ull,
  6121661160583693646ull, 4962080516648047837ull}},
{{1089254976836658739ull, 2837403209747246561ull,
  12263762469157004962ull, 6202600645810059796ull}},
{{5973254739473211328ull, 12770126049038834009ull,
  15329703086446256202ull, 7753250807262574745ull}},
{{15262499258239226840ull, 12593014799076659159ull,
  2663535401387828270ull, 4845781754539109216ull}},
{{14466438054371645646ull, 6517896461991048141ull,
  3329419251734785338ull, 6057227193173886520ull}},
{{4247989512682393345ull, 17370742614343585985ull,
  4161774064668481672ull, 7571533991467358150ull}},
{{14184208491494965601ull, 10856714133964741240ull,
  16436166845699964757ull, 4732208744667098843ull}},
{{17730260614368707001ull, 18182578685883314454ull,
  15933522538697568042ull, 5915260930833873554ull}},
{{12939453731106107943ull, 13504851320499367260ull,
  10693531136517184245ull, 7394076163542341943ull}},
{{17310530618796093273ull, 10746375084525798489ull,
  13600985987964322009ull, 4621297602213963714ull}},
{{7803105218212952879ull, 18044654874084636016ull,
  7777860448100626703ull, 5776622002767454643ull}},
{{9753881522766191098ull, 17944132574178407116ull,
  5110639541698395475ull, 7220777503459318304ull}},
{{12192351903457738873ull, 17818479699295620991ull,
  6388299427122994344ull, 9025971879324147880ull}},
{{14537748967302168652ull, 11136549812059763119ull,
  3992687141951871465ull, 5641232424577592425ull}},
{{13560500190700322911ull, 85629209792540187ull, 9602544945867227236ull,
  7051540530721990531ull}},
{{12338939219948015734ull, 107036512240675234ull,
  7391495163906646141ull, 8814425663402488164ull}},
{{12323523030894897738ull, 2372740829364115973ull,
  13843056514296429646ull, 5509016039626555102ull}},
{{1569345733336458460ull, 12189298073559920775ull,
  8080448606015761249ull, 6886270049533193878ull}},
{{15796740221952736787ull, 1401564536667737256ull,
  877188720664925754ull, 8607837561916492348ull}},
{{9872962638720460492ull, 5487663853844723689ull,
  9771614987270354404ull, 5379898476197807717ull}},
{{16952889316827963519ull, 6859579817305904611ull,
  16826204752515330909ull, 6724873095247259646ull}},
{{16579425627607566495ull, 13186160790059768668ull,
  11809383903789387828ull, 8406091369059074558ull}},
{{1138768980399953251ull, 17464722530642131226ull,
  2769178921440979488ull, 5253807105661921599ull}},
{{10646833262354717372ull, 3384159089593112416ull,
  17296531707083388073ull, 6567258882077401998ull}},
{{13308541577943396715ull, 8841884880418778424ull,
  12397292596999459283ull, 8209073602596752498ull}},
{{8317838486214622947ull, 3220335041048042563ull,
  12359993891552049956ull, 5130671001622970311ull}},
{{5785612089340890780ull, 4025418801310053204ull,
  10838306346012674541ull, 6413338752028712889ull}}
};

static const UINT256 multipliers2_binary64[] =
  { {{918777112239470733ull, 5138421092069233273ull,
      15049182825743144437ull, 3877256883183270350ull}},
{{12103450741218138969ull, 5517356191756964747ull,
  4794053247662077369ull, 2423285551989543969ull}},
{{10517627408095285807ull, 11508381258123593838ull,
  10604252578004984615ull, 3029106939986929961ull}},
{{3923662223264331450ull, 9773790554227104394ull,
  17867001740933618673ull, 3786383674983662451ull}},
{{7063974907967595060ull, 17637834142460410006ull,
  8861033078869817718ull, 2366489796864789032ull}},
{{18053340671814269633ull, 12823920641220736699ull,
  11076291348587272148ull, 2958112246080986290ull}},
{{17954989821340449138ull, 16029900801525920874ull,
  4621992148879314377ull, 3697640307601232863ull}},
{{15833554656765168615ull, 3101158973312618690ull,
  9806274120690653342ull, 2311025192250770539ull}},
{{10568571284101684961ull, 13099820753495549171ull,
  7646156632435928773ull, 2888781490313463174ull}},
{{8599028086699718297ull, 2539717886587272752ull, 334323753690135159ull,
  3610976862891828968ull}},
{{10748785108374647871ull, 17009705413516254652ull,
  417904692112668948ull, 4513721078614786210ull}},
{{15941362729588930728ull, 1407693846592883349ull,
  4872876450997805997ull, 2821075674134241381ull}},
{{6091645356703999697ull, 6371303326668492091ull,
  10702781582174645400ull, 3526344592667801726ull}},
{{3002870677452611718ull, 7964129158335615114ull,
  4155104940863530942ull, 4407930740834752158ull}},
{{6488480191835270228ull, 365894705532371542ull,
  16431998643321870551ull, 2754956713021720098ull}},
{{17333972276648863593ull, 14292426437197628139ull,
  11316626267297562380ull, 3443695891277150123ull}},
{{17055779327383691587ull, 17865533046497035174ull,
  9534096815694565071ull, 4304619864096437654ull}},
{{6048176061187419338ull, 18083487181701728840ull,
  1347124491381715265ull, 2690387415060273534ull}},
{{7560220076484274172ull, 8769300921844997338ull,
  10907277651081919890ull, 3362984268825341917ull}},
{{226903058750566907ull, 1738254115451470865ull,
  18245783082279787767ull, 4203730336031677396ull}},
{{11671029457787574077ull, 8003937849798251146ull,
  2180242389570091546ull, 2627331460019798373ull}},
{{5365414785379691788ull, 781550275393038125ull, 7336989005390002337ull,
  3284164325024747966ull}},
{{11318454500152002639ull, 5588623862668685560ull,
  18394608293592278729ull, 4105205406280934957ull}},
{{7074034062595001650ull, 15022104960236398235ull,
  13802473192708868157ull, 2565753378925584348ull}},
{{4230856559816364158ull, 4942573145013334082ull,
  17253091490886085197ull, 3207191723656980435ull}},
{{14511942736625231005ull, 10789902449694055506ull,
  16954678345180218592ull, 4008989654571225544ull}},
{{13681650228818157283ull, 6743689031058784691ull,
  10596673965737636620ull, 2505618534107015965ull}},
{{12490376767595308699ull, 8429611288823480864ull,
  17857528475599433679ull, 3132023167633769956ull}},
{{15612970959494135874ull, 5925328092601963176ull,
  3875166520789740483ull, 3915028959542212446ull}},
{{9758106849683834921ull, 1397487048662533033ull,
  16257037130775751514ull, 2446893099713882778ull}},
{{16809319580532181555ull, 10970230847682942099ull,
  11097924376614913584ull, 3058616374642353473ull}},
{{16399963457237839040ull, 13712788559603677624ull,
  37347415486478268ull, 3823270468302941842ull}},
{{10249977160773649400ull, 17793864886607074323ull,
  4635028153106436821ull, 2389544042689338651ull}},
{{8200785432539673846ull, 8407273052976679192ull,
  1182099172955658123ull, 2986930053361673314ull}},
{{10250981790674592308ull, 5897405297793461086ull,
  10700996003049348462ull, 3733662566702091642ull}},
{{1795177600744232288ull, 17520936366403076891ull,
  11299808520333230692ull, 2333539104188807276ull}},
{{16079030056212454072ull, 3454426384294294497ull,
  14124760650416538366ull, 2916923880236009095ull}},
{{6263729514983403878ull, 13541405017222643930ull,
  13044264794593285053ull, 3646154850295011369ull}},
{{17053033930584030656ull, 3091698216246141200ull,
  2470272937959442605ull, 4557693562868764212ull}},
{{10658146206615019160ull, 4238154394367532202ull,
  10767292623079427436ull, 2848558476792977632ull}},
{{4099310721413998142ull, 5297692992959415253ull,
  13459115778849284295ull, 3560698095991222040ull}},
{{9735824420194885581ull, 2010430222771881162ull,
  16823894723561605369ull, 4450872619989027550ull}},
{{10696576281049191393ull, 12785733935300895486ull,
  5903248183798615451ull, 2781795387493142219ull}},
{{4147348314456713433ull, 11370481400698731454ull,
  2767374211320881410ull, 3477244234366427774ull}},
{{14407557429925667599ull, 4989729714018638509ull,
  12682589801005877571ull, 4346555292958034717ull}},
{{11310566402917236201ull, 812738062047955116ull,
  10232461634842367434ull, 2716597058098771698ull}},
{{14138208003646545252ull, 10239294614414719703ull,
  3567205006698183484ull, 3395746322623464623ull}},
{{13061073986130793660ull, 12799118268018399629ull,
  18294064313654893067ull, 4244682903279330778ull}},
{{10469014250545439990ull, 5693605908297805816ull,
  16045476214461696071ull, 2652926814549581736ull}},
{{13086267813181799987ull, 2505321366944869366ull,
  1610101194367568473ull, 3316158518186977171ull}},
{{7134462729622474176ull, 7743337727108474612ull,
  15847684548241624303ull, 4145198147733721463ull}},
{{13682411242868822168ull, 11757115107083878488ull,
  16822331870292097045ull, 2590748842333575914ull}},
{{17103014053586027710ull, 861335828572684398ull,
  11804542801010345499ull, 3238436052916969893ull}},
{{12155395530127758829ull, 14911727840998019210ull,
  920620445980768161ull, 4048045066146212367ull}},
{{12208808224757237173ull, 2402300872982680150ull,
  7492916806379061957ull, 2530028166341382729ull}},
{{6037638244091770658ull, 7614562109655738092ull,
  13977832026401215350ull, 3162535207926728411ull}},
{{7547047805114713322ull, 294830600214896807ull,
  12860604014574131284ull, 3953169009908410514ull}},
{{11634433905837777682ull, 9407641161989086312ull,
  12649563527536219956ull, 2470730631192756571ull}},
{{14543042382297222103ull, 11759551452486357890ull,
  11200268390992887041ull, 3088413288990945714ull}},
{{8955430941016751820ull, 864381260325783651ull, 4776963451886332994ull,
  3860516611238682143ull}},
{{3291301328921775936ull, 5151924306131002686ull,
  9903131185070039977ull, 2412822882024176339ull}},
{{13337498698006995728ull, 11051591401091141261ull,
  7767227962910162067ull, 3016028602530220424ull}},
{{2836815317226580948ull, 9202803232936538673ull,
  9709034953637702584ull, 3770035753162775530ull}},
{{13302224619335082852ull, 5751752020585336670ull,
  10679832864450952019ull, 2356272345726734706ull}},
{{7404408737314077757ull, 2578004007304282934ull,
  4126419043708914216ull, 2945340432158418383ull}},
{{32138884787821389ull, 3222505009130353668ull, 546337786208754866ull,
  3681675540198022979ull}},
{{40173605984776736ull, 13251503298267717893ull,
  14517980288043107294ull, 4602094425247528723ull}},
{{2330951512954179412ull, 3670503542989935779ull,
  6767894670813248107ull, 2876309015779705452ull}},
{{16748747446474887977ull, 18423187484019583435ull,
  8459868338516560133ull, 3595386269724631815ull}},
{{16324248289666222067ull, 9193926299742315582ull,
  5963149404718312263ull, 4494232837155789769ull}},
{{5590969162614000888ull, 12663732964980029095ull,
  15256183424017414924ull, 2808895523222368605ull}},
{{2377025434840113206ull, 15829666206225036369ull,
  5235171224739604943ull, 3511119404027960757ull}},
{{7582967811977529411ull, 15175396739353907557ull,
  11155650049351894083ull, 4388899255034950946ull}},
{{7045197891699649834ull, 7178779952882498271ull,
  11583967299272321706ull, 2743062034396844341ull}},
{{4194811346197174389ull, 18196846977957898647ull,
  644901068808238420ull, 3428827542996055427ull}},
{{631828164319080082ull, 4299314648737821693ull,
  14641184391292461738ull, 4286034428745069283ull}},
{{2700735611913119003ull, 7298757673888526462ull,
  6844897235344094634ull, 2678771517965668302ull}},
{{12599291551746174562ull, 18346819129215433885ull,
  17779493581034894100ull, 3348464397457085377ull}},
{{1914056384400554490ull, 4486779837809740741ull,
  8389308921011453914ull, 4185580496821356722ull}},
{{3502128249464040509ull, 7415923417058475867ull,
  9855004094059546600ull, 2615987810513347951ull}},
{{18212718367112214348ull, 9269904271323094833ull,
  7707069099147045346ull, 3269984763141684939ull}},
{{8930839903608104222ull, 2364008302299092734ull,
  5022150355506418779ull, 4087480953927106174ull}},
{{970088921327677235ull, 17618406253432790623ull,
  16973902027473675448ull, 2554675596204441358ull}},
{{15047669206941760256ull, 3576263743081436662ull,
  11994005497487318503ull, 3193344495255551698ull}},
{{9586214471822424512ull, 18305387734133959540ull,
  5769134835004372320ull, 3991680619069439623ull}},
{{15214756081743791128ull, 11440867333833724712ull,
  10523238299518814556ull, 2494800386918399764ull}},
{{571701028470187294ull, 14301084167292155891ull,
  13154047874398518195ull, 3118500483647999705ull}},
{{14549684340869897829ull, 13264669190687806959ull,
  2607501787715984032ull, 3898125604559999632ull}},
{{16011081740684767999ull, 8290418244179879349ull,
  1629688617322490020ull, 2436328502849999770ull}},
{{6178794120573796287ull, 10363022805224849187ull,
  11260482808507888333ull, 3045410628562499712ull}},
{{3111806632289857455ull, 17565464524958449388ull,
  14075603510634860416ull, 3806763285703124640ull}},
{{11168251182035936718ull, 10978415328099030867ull,
  8797252194146787760ull, 2379227053564452900ull}},
{{9348627959117532993ull, 13723019160123788584ull,
  10996565242683484700ull, 2974033816955566125ull}},
{{11685784948896916241ull, 17153773950154735730ull,
  18357392571781743779ull, 3717542271194457656ull}},
{{11915301611487960555ull, 8415265709633015879ull,
  11473370357363589862ull, 2323463919496536035ull}},
{{10282440995932562789ull, 1295710100186494041ull,
  9730026928277099424ull, 2904329899370670044ull}},
{{17464737263343091390ull, 1619637625233117551ull,
  12162533660346374280ull, 3630412374213337555ull}},
{{17219235560751476334ull, 2024547031541396939ull,
  10591481057005579946ull, 4538015467766671944ull}},
{{8456179216255978757ull, 5877027913140760991ull,
  6619675660628487466ull, 2836259667354169965ull}},
{{5958538001892585542ull, 16569656928280727047ull,
  12886280594212997236ull, 3545324584192712456ull}},
{{2836486483938344023ull, 2265327086641357193ull,
  16107850742766246546ull, 4431655730240890570ull}},
{{13302019098529934775ull, 6027515447578236149ull,
  14679092732656291995ull, 2769784831400556606ull}},
{{2792465817880254756ull, 2922708291045407283ull,
  9125493878965589186ull, 3462231039250695758ull}},
{{17325640327632482157ull, 12876757400661534911ull,
  2183495311852210674ull, 4327788799063369698ull}},
{{17746054232411383205ull, 12659659393840847223ull,
  5976370588335019575ull, 2704867999414606061ull}},
{{17570881772086841102ull, 11212888223873671125ull,
  12082149253846162373ull, 3381084999268257576ull}},
{{8128544159826387665ull, 181052224559925195ull,
  15102686567307702967ull, 4226356249085321970ull}},
{{2774497090677798339ull, 7030686667991035103ull,
  14050865122994702258ull, 2641472655678326231ull}},
{{17303179418629411635ull, 18011730371843569686ull,
  12951895385315989918ull, 3301840819597907789ull}},
{{12405602236431988736ull, 13291290927949686300ull,
  2354811176362823686ull, 4127301024497384737ull}},
{{16976873434624768768ull, 3695370811541166033ull,
  13000972031295234564ull, 2579563140310865460ull}},
{{7386033737998797248ull, 4619213514426457542ull,
  16251215039119043205ull, 3224453925388581825ull}},
{{9170135643720752ull, 10385702911460459832ull, 6478960743616640294ull,
  4030567406735727282ull}},
{{5731334777325470ull, 1879378301235399491ull, 8661036483187788088ull,
  2519104629209829551ull}},
{{13842222223753820550ull, 2349222876544249363ull,
  6214609585557347206ull, 3148880786512286939ull}},
{{12691091761264887783ull, 12159900632535087512ull,
  3156575963519296103ull, 3936100983140358674ull}},
{{7931932350790554864ull, 14517466922975511551ull,
  6584545995626947968ull, 2460063114462724171ull}},
{{5303229420060805676ull, 18146833653719389439ull,
  3618996476106297056ull, 3075078893078405214ull}},
{{2017350756648619191ull, 4236797993439685183ull,
  13747117631987647129ull, 3843848616348006517ull}},
{{8178373250546468851ull, 14177213791968272999ull,
  10897791529205973407ull, 2402405385217504073ull}},
{{5611280544755698159ull, 13109831221532953345ull,
  18233925429934854663ull, 3003006731521880091ull}},
{{11625786699372010603ull, 11775603008488803777ull,
  18180720768991180425ull, 3753758414402350114ull}},
{{348587659466424771ull, 442222852664420505ull, 15974636499046875670ull,
  2346099009001468821ull}},
{{5047420592760418868ull, 9776150602685301439ull,
  6133237568526430875ull, 2932623761251836027ull}},
{{1697589722523135681ull, 7608502234929238895ull,
  3054860942230650690ull, 3665779701564795034ull}},
{{15957045208436083313ull, 287255756806772810ull,
  13041948214643089171ull, 4582224626955993792ull}},
{{14584839273699939975ull, 16320435912500090670ull,
  8151217634151930731ull, 2863890391847496120ull}},
{{9007677055270149160ull, 15788858872197725434ull,
  10189022042689913414ull, 3579862989809370150ull}},
{{2036224282232910642ull, 10512701553392380985ull,
  3512905516507615960ull, 4474828737261712688ull}},
{{12801855222464038911ull, 6570438470870238115ull,
  2195565947817259975ull, 2796767960788570430ull}},
{{11390633009652660735ull, 3601362070160409740ull,
  11967829471626350777ull, 3495959950985713037ull}},
{{14238291262065825919ull, 9113388606127900079ull,
  1124728784250774759ull, 4369949938732141297ull}},
{{15816461066432223055ull, 12613396906471019405ull,
  12232170536225203984ull, 2731218711707588310ull}},
{{5935518277758115107ull, 15766746133088774257ull,
  6066841133426729172ull, 3414023389634485388ull}},
{{12031083865625031788ull, 1261688592651416205ull,
  7583551416783411466ull, 4267529237043106735ull}},
{{9825270425229338820ull, 5400241388834523032ull,
  11657248663130714022ull, 2667205773151941709ull}},
{{12281588031536673524ull, 15973673772897929598ull,
  736502773631228815ull, 3334007216439927137ull}},
{{6128613002566066097ull, 15355406197695024094ull,
  5532314485466423923ull, 4167509020549908921ull}},
{{17665441181885955023ull, 7291285864345696106ull,
  14986911599484984712ull, 2604693137843693075ull}},
{{12858429440502667971ull, 9114107330432120133ull,
  14121953480928842986ull, 3255866422304616344ull}},
{{2237978745346171251ull, 2169262126185374359ull,
  17652441851161053733ull, 4069833027880770430ull}},
{{8316265743482438888ull, 3661631838079552926ull,
  6421090138548270679ull, 2543645642425481519ull}},
{{1171960142498272802ull, 18412097852881604870ull,
  3414676654757950444ull, 3179557053031851899ull}},
{{10688322214977616811ull, 4568378242392454471ull,
  18103403873729601768ull, 3974446316289814873ull}},
{{13597730412002092363ull, 2855236401495284044ull,
  4397098393439919249ull, 2484028947681134296ull}},
{{16997163015002615453ull, 8180731520296492959ull,
  5496372991799899061ull, 3105036184601417870ull}},
{{16634767750325881413ull, 14837600418798004103ull,
  16093838276604649634ull, 3881295230751772337ull}},
{{17314258871594757739ull, 13885186280176140468ull,
  3141119895236824165ull, 2425809519219857711ull}},
{{3196079515783895558ull, 3521424794938011874ull,
  17761457924328193919ull, 3032261899024822138ull}},
{{13218471431584645255ull, 18236839048954678554ull,
  12978450368555466590ull, 3790327373781027673ull}},
{{12873230663167791189ull, 6786338387169286192ull,
  1194002452706084763ull, 2368954608613142296ull}},
{{16091538328959738986ull, 3871236965534219836ull,
  1492503065882605954ull, 2961193260766427870ull}},
{{1667678837490122116ull, 14062418243772550604ull,
  11089000869208033250ull, 3701491575958034837ull}},
{{10265671310286102131ull, 13400697420785232031ull,
  9236468552468714733ull, 2313432234973771773ull}},
{{8220403119430239759ull, 2915813720699376327ull,
  16157271709013281321ull, 2891790293717214716ull}},
{{5663817880860411795ull, 8256453169301608313ull,
  1749845562557050035ull, 3614737867146518396ull}},
{{11691458369502902647ull, 5708880443199622487ull,
  2187306953196312544ull, 4518422333933147995ull}},
{{14224690508580396011ull, 3568050276999764054ull,
  17507967910243553004ull, 2824013958708217496ull}},
{{8557491098870719205ull, 4460062846249705068ull,
  3438215814094889639ull, 3530017448385271871ull}},
{{10696863873588399007ull, 963392539384743431ull,
  18132827822900775761ull, 4412521810481589838ull}},
{{13603068948633831235ull, 12131335383183934404ull,
  6721331370885596946ull, 2757826131550993649ull}},
{{17003836185792289044ull, 5940797192125142197ull,
  13013350232034384087ull, 3447282664438742061ull}},
{{7419737176958197593ull, 2814310471729039843ull,
  2431629734760816397ull, 4309103330548427577ull}},
{{2331492726385179544ull, 4064787054044343854ull,
  13048983630293980008ull, 2693189581592767235ull}},
{{12137737944836250237ull, 5080983817555429817ull,
  11699543519440087106ull, 3366486976990959044ull}},
{{1337114375763149085ull, 15574601808799063080ull,
  14624429399300108882ull, 4208108721238698805ull}},
{{835696484851968178ull, 14345812148926802329ull,
  11446111383776262003ull, 2630067950774186753ull}},
{{5656306624492348127ull, 13320579167731115007ull,
  472581174438163792ull, 3287584938467733442ull}},
{{2458697262188047254ull, 16650723959663893759ull,
  9814098504902480548ull, 4109481173084666802ull}},
{{8454214816508611390ull, 1183330437935157791ull,
  10745497583991438247ull, 2568425733177916751ull}},
{{5956082502208376333ull, 15314221102701110951ull,
  8820185961561909904ull, 3210532166472395939ull}},
{{2833417109333082513ull, 696032304666837073ull, 6413546433524999477ull,
  4013165208090494924ull}},
{{13300100739401646331ull, 2740863199630467122ull,
  13231838557807900481ull, 2508228255056559327ull}},
{{7401753887397282105ull, 8037765017965471807ull,
  11928112178832487697ull, 3135285318820699159ull}},
{{4640506340819214727ull, 14658892290884227663ull,
  10298454205113221717ull, 3919106648525873949ull}},
{{9817845490653091061ull, 11467650691016336241ull,
  8742376887409457525ull, 2449441655328671218ull}},
{{16883992881743751730ull, 499505308488256589ull,
  1704599072407046099ull, 3061802069160839023ull}},
{{7269933046897525950ull, 14459439690892484449ull,
  15965806895790971335ull, 3827252586451048778ull}},
{{16072923200379423479ull, 15954678834448884636ull,
  14590315328296744988ull, 2392032866531905486ull}},
{{1644409926764727733ull, 1496604469351554180ull,
  9014522123516155428ull, 2990041083164881858ull}},
{{2055512408455909666ull, 1870755586689442725ull,
  2044780617540418477ull, 3737551353956102323ull}},
{{3590538264498637493ull, 3475065250894595655ull,
  17418888950458619212ull, 2335969596222563951ull}},
{{18323230885905460578ull, 4343831563618244568ull,
  17161925169645886111ull, 2919961995278204939ull}},
{{4457294533672274107ull, 818103436095417807ull,
  16840720443629969735ull, 3649952494097756174ull}},
{{959932148662954729ull, 14857687350401435971ull,
  11827528517682686360ull, 4562440617622195218ull}},
{{16740858657410204370ull, 9286054594000897481ull,
  12003891341979066879ull, 2851525386013872011ull}},
{{7091015266480591750ull, 6995882224073733948ull,
  10393178159046445695ull, 3564406732517340014ull}},
{{8863769083100739688ull, 4133166761664779531ull,
  3768100661953281311ull, 4455508415646675018ull}},
{{3234012667724268353ull, 9500758253681569063ull,
  6966748932148188723ull, 2784692759779171886ull}},
{{17877573889937499153ull, 7264261798674573424ull,
  17931808202040011712ull, 3480865949723964857ull}},
{{3900223288712322326ull, 9080327248343216781ull,
  8579702197267850928ull, 4351082437154956072ull}},
{{4743482564658895406ull, 5675204530214510488ull,
  5362313873292406830ull, 2719426523221847545ull}},
{{5929353205823619257ull, 16317377699622913918ull,
  11314578360042896441ull, 3399283154027309431ull}},
{{16635063544134299879ull, 6561664069246478685ull,
  9531536931626232648ull, 4249103942534136789ull}},
{{12702757724297631377ull, 4101040043279049178ull,
  8263053591480089357ull, 2655689964083835493ull}},
{{6655075118517263413ull, 9737986072526199377ull,
  14940503007777499600ull, 3319612455104794366ull}},
{{12930529916573967170ull, 12172482590657749221ull,
  9452256722867098692ull, 4149515568880992958ull}},
{{10387424207072423433ull, 16831173656015869071ull,
  1295974433364548778ull, 2593447230550620599ull}},
{{8372594240413141387ull, 11815595033165060531ull,
  15455026096987849685ull, 3241809038188275748ull}},
{{5854056782089038830ull, 934435736174161952ull, 872038547525260491ull,
  4052261297735344686ull}},
{{3658785488805649269ull, 16724923399604708884ull,
  14380082147485451518ull, 2532663311084590428ull}},
{{4573481861007061586ull, 11682782212651110297ull,
  17975102684356814398ull, 3165829138855738035ull}},
{{10328538344686214887ull, 5380105728959112063ull,
  17857192337018630094ull, 3957286423569672544ull}},
{{13372865493069966160ull, 17197624135881608751ull,
  11160745210636643808ull, 2473304014731045340ull}},
{{12104395847910069796ull, 3050286096142459323ull,
  13950931513295804761ull, 3091630018413806675ull}},
{{10518808791460199341ull, 8424543638605462058ull,
  12826978373192368047ull, 3864537523017258344ull}},
{{11185941513090012492ull, 12182868801769495642ull,
  8016861483245230029ull, 2415335951885786465ull}},
{{4759054854507739807ull, 1393527946929705841ull,
  14632762872483925441ull, 3019169939857233081ull}},
{{10560504586562062663ull, 6353595952089520205ull,
  4455895535322743089ull, 3773962424821541352ull}},
{{8906158375814983117ull, 15500212516124419888ull,
  2784934709576714430ull, 2358726515513463345ull}},
{{11132697969768728896ull, 10151893608300749052ull,
  8092854405398280942ull, 2948408144391829181ull}},
{{13915872462210911119ull, 3466494973521160507ull,
  14727754025175239082ull, 3685510180489786476ull}},
{{12783154559336250995ull, 13556490753756226442ull,
  18409692531469048852ull, 4606887725612233095ull}},
{{12601157618012544776ull, 17696178757952417334ull,
  18423586859809237388ull, 2879304828507645684ull}},
{{6528074985660905162ull, 3673479373730970052ull,
  4582739501051995120ull, 3599131035634557106ull}},
{{8160093732076131452ull, 4591849217163712565ull,
  14951796413169769708ull, 4498913794543196382ull}},
{{7405901591761276110ull, 12093277797582096161ull,
  4733186739803718163ull, 2811821121589497739ull}},
{{13869063008128983041ull, 10504911228550232297ull,
  1304797406327259800ull, 3514776401986872174ull}},
{{3501270704879065090ull, 13131139035687790372ull,
  10854368794763850558ull, 4393470502483590217ull}},
{{11411666227404191489ull, 3595275878877481078ull,
  18313195542795876359ull, 2745919064052243885ull}},
{{5041210747400463553ull, 18329152903879015060ull,
  9056436373212681736ull, 3432398830065304857ull}},
{{6301513434250579442ull, 4464697056139217209ull,
  15932231484943240075ull, 4290498537581631071ull}},
{{15467660942475081911ull, 484592650873316803ull,
  16875173705730606903ull, 2681561585988519419ull}},
{{14722890159666464485ull, 14440798868873809716ull,
  16482281113735870724ull, 3351951982485649274ull}},
{{18403612699583080606ull, 18050998586092262145ull,
  11379479355315062597ull, 4189939978107061593ull}},
{{4584728909598343523ull, 13587717125521357793ull,
  194645569430832267ull, 2618712486316913496ull}},
{{10342597155425317307ull, 12372960388474309337ull,
  243306961788540334ull, 3273390607896141870ull}},
{{17539932462709034538ull, 6242828448738110863ull,
  9527505739090451226ull, 4091738259870177337ull}},
{{17879986816834228443ull, 8513453798888707193ull,
  17483906133000001776ull, 2557336412418860835ull}},
{{8514925465760621841ull, 10641817248610883992ull,
  17243196647822614316ull, 3196670515523576044ull}},
{{10643656832200777301ull, 13302271560763604990ull,
  3107251736068716279ull, 3995838144404470056ull}},
{{2040599501698097909ull, 15231448753118334975ull,
  1942032335042947674ull, 2497398840252793785ull}},
{{16385807432404786099ull, 9815938904543142910ull,
  7039226437231072497ull, 3121748550315992231ull}},
{{11258887253651206815ull, 16881609649106316542ull,
  4187347028111452717ull, 3902185687894990289ull}},
{{2425118515104616356ull, 12856849039905141791ull,
  14146306938638127708ull, 2438866054934368930ull}},
{{16866456199162934157ull, 16071061299881427238ull,
  8459511636442883827ull, 3048582568667961163ull}},
{{11859698212098891888ull, 15477140606424396144ull,
  5962703527126216880ull, 3810728210834951454ull}},
{{7412311382561807430ull, 9673212879015247590ull,
  17561747759736049262ull, 2381705131771844658ull}},
{{42017191347483479ull, 2868144061914283680ull, 12728812662815285770ull,
  2977131414714805823ull}},
{{52521489184354349ull, 12808552114247630408ull,
  11299329810091719308ull, 3721414268393507279ull}},
{{32825930740221468ull, 17228717108259544813ull,
  13979610158948406423ull, 2325883917745942049ull}},
{{4652718431852664739ull, 16924210366897043112ull,
  3639454643403344317ull, 2907354897182427562ull}},
{{5815898039815830924ull, 7320204903339140178ull,
  13772690341108956205ull, 3634193621478034452ull}},
{{16493244586624564463ull, 13761942147601313126ull,
  17215862926386195256ull, 4542742026847543065ull}},
{{5696591848212964885ull, 8601213842250820704ull,
  3842385301350290179ull, 2839213766779714416ull}},
{{7120739810266206107ull, 6139831284386137976ull,
  4802981626687862724ull, 3549017208474643020ull}},
{{8900924762832757633ull, 7674789105482672470ull,
  6003727033359828405ull, 4436271510593303775ull}},
{{951391958343085617ull, 7102586200140364246ull,
  10669858423490974609ull, 2772669694120814859ull}},
{{10412611984783632829ull, 13489918768602843211ull,
  8725637010936330357ull, 3465837117651018574ull}},
{{8404078962552153132ull, 3027340405471390302ull,
  1683674226815637139ull, 4332296397063773218ull}},
{{640863333167707804ull, 18032988817915476603ull,
  5663982410187161115ull, 2707685248164858261ull}},
{{14636137221741798467ull, 17929550003966957849ull,
  11691664031161339298ull, 3384606560206072826ull}},
{{4460113471895084371ull, 13188565468103921504ull,
  5391208002096898315ull, 4230758200257591033ull}},
{{2787570919934427732ull, 5937010408351256988ull,
  14898720047379031207ull, 2644223875160994395ull}},
{{3484463649918034665ull, 2809576992011683331ull,
  14011714040796401105ull, 3305279843951242994ull}},
{{18190637617679707043ull, 8123657258441992067ull,
  8291270514140725573ull, 4131599804939053743ull}},
{{9063305501836122950ull, 7383128795739938994ull,
  12099573098979035339ull, 2582249878086908589ull}},
{{2105759840440377880ull, 4617224976247535839ull,
  1289408318441630462ull, 3227812347608635737ull}},
{{16467257855832636061ull, 14994903257164195606ull,
  6223446416479425981ull, 4034765434510794671ull}},
{{5680350141468009635ull, 11677657544941316206ull,
  10807183037940723094ull, 2521728396569246669ull}},
{{16323809713689787851ull, 5373699894321869449ull,
  18120664815853291772ull, 3152160495711558336ull}},
{{6569704086830071102ull, 6717124867902336812ull,
  4204086946107063099ull, 3940200619639447921ull}},
{{13329437091123570247ull, 1892360033225266555ull,
  14156769387385384197ull, 2462625387274654950ull}},
{{12050110345477074904ull, 6977136059958971098ull,
  8472589697376954438ull, 3078281734093318688ull}},
{{5839265894991567822ull, 17944792111803489681ull,
  10590737121721193047ull, 3847852167616648360ull}},
{{15178756230438199649ull, 18133024097518262906ull,
  6619210701075745654ull, 2404907604760405225ull}},
{{9750073251192973753ull, 13442908085043052825ull,
  12885699394772069972ull, 3006134505950506531ull}},
{{16799277582418605095ull, 16803635106303816031ull,
  11495438225037699561ull, 3757668132438133164ull}},
{{17417077516652710041ull, 3584742913798803163ull,
  16408020927503338034ull, 2348542582773833227ull}},
{{17159660877388499647ull, 13704300679103279762ull,
  15898340140951784638ull, 2935678228467291534ull}},
{{12226204059880848751ull, 7907003812024323895ull,
  10649553139334954990ull, 3669597785584114418ull}},
{{10671069056423673034ull, 660382728175629061ull,
  4088569387313917930ull, 4586997231980143023ull}},
{{8975261169478489598ull, 5024425223537156067ull,
  9472884894712280562ull, 2866873269987589389ull}},
{{6607390443420724094ull, 15503903566276220892ull,
  16452792136817738606ull, 3583591587484486736ull}},
{{8259238054275905117ull, 10156507420990500307ull,
  2119246097312621642ull, 4479489484355608421ull}},
{{2856180774708746746ull, 10959503156546450596ull,
  3630371820034082478ull, 2799680927722255263ull}},
{{3570225968385933433ull, 4476006908828287437ull,
  18373022830324766810ull, 3499601159652819078ull}},
{{9074468478909804695ull, 14818380672890135104ull,
  13742906501051182704ull, 4374501449566023848ull}},
{{5671542799318627935ull, 9261487920556334440ull,
  8589316563156989190ull, 2734063405978764905ull}},
{{7089428499148284918ull, 2353487863840642242ull,
  15348331722373624392ull, 3417579257473456131ull}},
{{18085157660790131956ull, 2941859829800802802ull,
  14573728634539642586ull, 4271974071841820164ull}},
{{15914909556421220376ull, 6450348412052889655ull,
  18331952433442052424ull, 2669983794901137602ull}},
{{15281950927099137566ull, 8062935515066112069ull,
  13691568504947789722ull, 3337479743626422003ull}},
{{5267380603591758246ull, 855297356977864279ull,
  12502774612757349249ull, 4171849679533027504ull}},
{{10209641904885930760ull, 12063775894179634934ull,
  7814234132973343280ull, 2607406049708142190ull}},
{{3538680344252637642ull, 15079719867724543668ull,
  544420629361903292ull, 3259257562135177738ull}},
{{4423350430315797052ull, 402905760946127969ull, 9903897823557154924ull,
  4074071952668972172ull}},
{{14293809065015842918ull, 9475188137446105788ull,
  15413308176577997635ull, 2546294970418107607ull}},
{{17867261331269803647ull, 7232299153380244331ull,
  14654949202295109140ull, 3182868713022634509ull}},
{{17722390645659866655ull, 9040373941725305414ull,
  4483628447586722713ull, 3978585891278293137ull}},
{{6464808135110028755ull, 17179448759646785644ull,
  14331482825810171455ull, 2486616182048933210ull}},
{{8081010168887535944ull, 16862624931131094151ull,
  8690981495407938511ull, 3108270227561166513ull}},
{{5489576692682032026ull, 16466595145486479785ull,
  15475412887687311043ull, 3885337784451458141ull}},
{{14960200478994739776ull, 7985778956715355913ull,
  11977976064018263354ull, 2428336115282161338ull}},
{{4865192543461261008ull, 758851659039419084ull, 5749098043168053385ull,
  3035420144102701673ull}},
{{6081490679326576260ull, 5560250592226661759ull,
  11798058572387454635ull, 3794275180128377091ull}},
{{10718460702220192019ull, 1169313610927969647ull,
  5067943598528465195ull, 2371421987580235682ull}},
{{8786389859347852119ull, 15296700068942125771ull,
  15558301535015357301ull, 2964277484475294602ull}},
{{6371301305757427245ull, 5285817030895493502ull,
  10224504881914420819ull, 3705346855594118253ull}},
{{17817121371380555740ull, 997792635095989486ull,
  8696158560410206964ull, 2315841784746323908ull}},
{{13048029677370918867ull, 1247240793869986858ull,
  10870198200512758705ull, 2894802230932904885ull}},
{{7086665059858872776ull, 6170737010764871477ull,
  18199433769068336285ull, 3618502788666131106ull}},
{{13470017343250978874ull, 12325107281883477250ull,
  13525920174480644548ull, 4523128485832663883ull}},
{{13030446857959249701ull, 16926564088031949089ull,
  6147857099836708890ull, 2826955303645414927ull}},
{{2453000517166898414ull, 11934833073185160554ull,
  3073135356368498209ull, 3533694129556768659ull}},
{{12289622683313398825ull, 1083483286199286980ull,
  17676477250742786474ull, 4417117661945960823ull}},
{{16904386213925650074ull, 5288863072301942266ull,
  17965327309355323402ull, 2760698538716225514ull}},
{{11907110730552286784ull, 15834450877232203641ull,
  13233287099839378444ull, 3450873173395281893ull}},
{{1048830357908194768ull, 1346319522830702936ull,
  2706550819517059344ull, 4313591466744102367ull}},
{{655518973692621730ull, 841449701769189335ull, 8609123289839243946ull,
  2695994666715063979ull}},
{{14654456772397940874ull, 10275184164066262476ull,
  6149718093871667028ull, 3369993333393829974ull}},
{{18318070965497426093ull, 12843980205082828095ull,
  16910519654194359593ull, 4212491666742287467ull}},
{{18366323381076973164ull, 1109958600535685703ull,
  8263231774657780794ull, 2632807291713929667ull}},
{{18346218207918828551ull, 10610820287524382937ull,
  5717353699894838088ull, 3291009114642412084ull}},
{{9097714704616371977ull, 13263525359405478672ull,
  7146692124868547610ull, 4113761393303015105ull}},
{{5686071690385232486ull, 12901389368055812074ull,
  15995897624111312016ull, 2571100870814384440ull}},
{{16330961649836316415ull, 16126736710069765092ull,
  1548127956429588404ull, 3213876088517980551ull}},
{{1966957988585843903ull, 1711676813877654750ull,
  15770218000819149218ull, 4017345110647475688ull}},
{{15064406798148316151ull, 5681484027100922122ull,
  9856386250511968261ull, 2510840694154672305ull}},
{{9607136460830619381ull, 11713541052303540557ull,
  16932168831567348230ull, 3138550867693340381ull}},
{{16620606594465662130ull, 5418554278524649888ull,
  7330152984177021576ull, 3923188584616675477ull}},
{{10387879121541038832ull, 3386596424077906180ull,
  6887188624324332437ull, 2451992865385422173ull}},
{{12984848901926298539ull, 8844931548524770629ull,
  13220671798832803450ull, 3064991081731777716ull}},
{{2396003072125709462ull, 1832792398801187479ull,
  16525839748541004313ull, 3831238852164722145ull}},
{{8415030947719650270ull, 12674710295319211934ull,
  3411120815197045839ull, 2394524282602951341ull}},
{{1295416647794787029ull, 11231701850721627014ull,
  8875587037423695203ull, 2993155353253689176ull}},
{{10842642846598259595ull, 9427941294974645863ull,
  11094483796779619004ull, 3741444191567111470ull}},
{{13694180806764994103ull, 15115835346213929472ull,
  2322366354559873973ull, 2338402619729444669ull}},
{{17117726008456242628ull, 5059736127485248128ull,
  7514643961627230371ull, 2923003274661805836ull}},
{{2950413436860751669ull, 1712984140929172257ull,
  9393304952034037964ull, 3653754093327257295ull}},
{{8299702814503327491ull, 2141230176161465321ull,
  7129945171615159551ull, 4567192616659071619ull}},
{{16716529305133049442ull, 8255797887741997681ull,
  2150372723045780767ull, 2854495385411919762ull}},
{{7060603576134148090ull, 5708061341250109198ull,
  11911337940662001767ull, 3568119231764899702ull}},
{{18049126507022460921ull, 2523390658135248593ull,
  5665800388972726401ull, 4460149039706124628ull}},
{{4363175039247956220ull, 13106334207403000131ull,
  12764497279962729808ull, 2787593149816327892ull}},
{{842282780632557370ull, 16382917759253750164ull,
  15955621599953412260ull, 3484491437270409865ull}},
{{1052853475790696713ull, 2031903125357636089ull,
  6109468944659601614ull, 4355614296588012332ull}},
{{12187248468437655206ull, 15104997508630686267ull,
  13041790127267026816ull, 2722258935367507707ull}},
{{10622374567119681103ull, 434502812078806218ull,
  11690551640656395617ull, 3402823669209384634ull}},
{{4054596172044825571ull, 5154814533525895677ull,
  5389817513965718713ull, 4253529586511730793ull}},
{{4839965616741709934ull, 14750974129522154558ull,
  14897850992297043955ull, 2658455991569831745ull}},
{{15273329057781913225ull, 13827031643475305293ull,
  4787255685089141232ull, 3323069989462289682ull}},
{{5256603266945227819ull, 17283789554344131617ull,
  15207441643216202348ull, 4153837486827862102ull}},
{{14814592087909237147ull, 1578996434610306452ull,
  4892965008582738564ull, 2596148429267413814ull}},
{{71496036176994818ull, 1973745543262883066ull, 15339578297583199013ull,
  3245185536584267267ull}},
{{9312742082076019330ull, 7078867947505991736ull,
  14562786853551610862ull, 4056481920730334084ull}},
{{5820463801297512082ull, 18259350522473408547ull,
  18325113820324532596ull, 2535301200456458802ull}},
{{2663893733194502198ull, 4377444079382209068ull,
  13683020238550889938ull, 3169126500570573503ull}},
{{3329867166493127747ull, 14695177136082537143ull,
  12492089279761224518ull, 3961408125713216879ull}},
{{8998696006699286698ull, 4572799691624197810ull,
  14725084827491847180ull, 2475880078570760549ull}},
{{2024997971519332565ull, 5715999614530247263ull,
  4571297979082645263ull, 3094850098213450687ull}},
{{16366305519681329418ull, 2533313499735421174ull,
  1102436455425918675ull, 3868562622766813359ull}},
{{5617254931373442982ull, 17724222001830495898ull,
  7606551812282281027ull, 2417851639229258349ull}},
{{16244940701071579536ull, 17543591483860731968ull,
  14119875783780239188ull, 3022314549036572936ull}},
{{1859431802629922803ull, 3482745281116363345ull,
  17649844729725298986ull, 3777893186295716170ull}},
{{12691359922712171512ull, 6788401819125114994ull,
  15642838974505699770ull, 2361183241434822606ull}},
{{6640827866535438582ull, 17708874310761169551ull,
  10330176681277348904ull, 2951479051793528258ull}},
{{3689348814741910324ull, 3689348814741910323ull,
  3689348814741910323ull, 3689348814741910323ull}},
{{0ull, 0ull, 0ull, 4611686018427387904ull}},
{{0ull, 0ull, 0ull, 2882303761517117440ull}},
{{0ull, 0ull, 0ull, 3602879701896396800ull}},
{{0ull, 0ull, 0ull, 4503599627370496000ull}},
{{0ull, 0ull, 0ull, 2814749767106560000ull}},
{{0ull, 0ull, 0ull, 3518437208883200000ull}},
{{0ull, 0ull, 0ull, 4398046511104000000ull}},
{{0ull, 0ull, 0ull, 2748779069440000000ull}},
{{0ull, 0ull, 0ull, 3435973836800000000ull}},
{{0ull, 0ull, 0ull, 4294967296000000000ull}},
{{0ull, 0ull, 0ull, 2684354560000000000ull}},
{{0ull, 0ull, 0ull, 3355443200000000000ull}},
{{0ull, 0ull, 0ull, 4194304000000000000ull}},
{{0ull, 0ull, 0ull, 2621440000000000000ull}},
{{0ull, 0ull, 0ull, 3276800000000000000ull}},
{{0ull, 0ull, 0ull, 4096000000000000000ull}},
{{0ull, 0ull, 0ull, 2560000000000000000ull}},
{{0ull, 0ull, 0ull, 3200000000000000000ull}},
{{0ull, 0ull, 0ull, 4000000000000000000ull}},
{{0ull, 0ull, 0ull, 2500000000000000000ull}},
{{0ull, 0ull, 0ull, 3125000000000000000ull}},
{{0ull, 0ull, 0ull, 3906250000000000000ull}},
{{0ull, 0ull, 0ull, 2441406250000000000ull}},
{{0ull, 0ull, 0ull, 3051757812500000000ull}},
{{0ull, 0ull, 0ull, 3814697265625000000ull}},
{{0ull, 0ull, 0ull, 2384185791015625000ull}},
{{0ull, 0ull, 0ull, 2980232238769531250ull}},
{{0ull, 0ull, 9223372036854775808ull, 3725290298461914062ull}},
{{0ull, 0ull, 1152921504606846976ull, 2328306436538696289ull}},
{{0ull, 0ull, 6052837899185946624ull, 2910383045673370361ull}},
{{0ull, 0ull, 12177733392409821184ull, 3637978807091712951ull}},
{{0ull, 0ull, 10610480722084888576ull, 4547473508864641189ull}},
{{0ull, 0ull, 8937393460516749312ull, 2842170943040400743ull}},
{{0ull, 0ull, 6560055807218548736ull, 3552713678800500929ull}},
{{0ull, 0ull, 12811755777450573824ull, 4440892098500626161ull}},
{{0ull, 0ull, 1089818333265526784ull, 2775557561562891351ull}},
{{0ull, 0ull, 15197330971864072192ull, 3469446951953614188ull}},
{{0ull, 0ull, 549919641120538624ull, 4336808689942017736ull}},
{{0ull, 0ull, 343699775700336640ull, 2710505431213761085ull}},
{{0ull, 0ull, 5041310738052808704ull, 3388131789017201356ull}},
{{0ull, 0ull, 6301638422566010880ull, 4235164736271501695ull}},
{{0ull, 0ull, 10856053041744838656ull, 2646977960169688559ull}},
{{0ull, 0ull, 8958380283753660416ull, 3308722450212110699ull}},
{{0ull, 0ull, 6586289336264687616ull, 4135903062765138374ull}},
{{0ull, 0ull, 17951488890447593472ull, 2584939414228211483ull}},
{{0ull, 0ull, 17827675094632103936ull, 3231174267785264354ull}},
{{0ull, 0ull, 13061221831435354112ull, 4038967834731580443ull}},
{{0ull, 0ull, 5857420635433402368ull, 2524354896707237777ull}},
{{0ull, 0ull, 11933461812719140864ull, 3155443620884047221ull}},
{{0ull, 0ull, 1081769210616762368ull, 3944304526105059027ull}},
{{0ull, 0ull, 16817006821131334144ull, 2465190328815661891ull}},
{{0ull, 0ull, 16409572507986779776ull, 3081487911019577364ull}},
{{0ull, 0ull, 2065221561273923104ull, 3851859888774471706ull}},
{{0ull, 0ull, 5902449494223589844ull, 2407412430484044816ull}},
{{0ull, 0ull, 7378061867779487305ull, 3009265538105056020ull}},
{{0ull, 4611686018427387904ull, 9222577334724359131ull,
  3761581922631320025ull}},
{{0ull, 576460752303423488ull, 17293325880271194217ull,
  2350988701644575015ull}},
{{0ull, 5332261958806667264ull, 17004971331911604867ull,
  2938735877055718769ull}},
{{0ull, 2053641430080946176ull, 7421156109607342372ull,
  3673419846319648462ull}},
{{0ull, 2567051787601182720ull, 53073100154402157ull,
  4591774807899560578ull}},
{{0ull, 3910250376464433152ull, 4644856706023889252ull,
  2869859254937225361ull}},
{{0ull, 4887812970580541440ull, 10417756900957249469ull,
  3587324068671531701ull}},
{{0ull, 10721452231653064704ull, 17633882144623949740ull,
  4484155085839414626ull}},
{{0ull, 15924279681637941248ull, 15632862358817356491ull,
  2802596928649634141ull}},
{{0ull, 15293663583620038656ull, 5706019893239531902ull,
  3503246160812042677ull}},
{{0ull, 9893707442670272512ull, 11744210884976802782ull,
  4379057701015053346ull}},
{{0ull, 1571881133241532416ull, 11951817821537889643ull,
  2736911063134408341ull}},
{{0ull, 15799909471834079232ull, 1104714221640198341ull,
  3421138828918010427ull}},
{{0ull, 5914828784510435328ull, 15215950832332411639ull,
  4276423536147513033ull}},
{{0ull, 10614297017960103936ull, 2592440242566675418ull,
  2672764710092195646ull}},
{{0ull, 4044499235595354112ull, 12463922340063120081ull,
  3340955887615244557ull}},
{{0ull, 9667310062921580544ull, 1744844869796736389ull,
  4176194859519055697ull}},
{{0ull, 8347911798539681792ull, 12619743089691430003ull,
  2610121787199409810ull}},
{{0ull, 5823203729747214336ull, 6551306825259511696ull,
  3262652233999262263ull}},
{{0ull, 7279004662184017920ull, 3577447513147001716ull,
  4078315292499077829ull}},
{{0ull, 13772749950719787008ull, 4541747704930570024ull,
  2548947057811923643ull}},
{{0ull, 17215937438399733760ull, 1065498612735824626ull,
  3186183822264904554ull}},
{{0ull, 12296549761144891392ull, 10555245302774556591ull,
  3982729777831130692ull}},
{{0ull, 14602872628356638976ull, 15820400351088873677ull,
  2489206111144456682ull}},
{{0ull, 4418532730163635008ull, 10552128402006316289ull,
  3111507638930570853ull}},
{{0ull, 10134851931131931664ull, 17801846520935283265ull,
  3889384548663213566ull}},
{{0ull, 17863497503025927050ull, 6514468057157164136ull,
  2430865342914508479ull}},
{{9223372036854775808ull, 3882627805072857196ull,
  3531399053019067267ull, 3038581678643135599ull}},
{{11529215046068469760ull, 241598737913683591ull,
  18249306871555997796ull, 3798227098303919498ull}},
{{14123288431433875456ull, 9374371248050828052ull,
  16017502813149886526ull, 2373891936439949686ull}},
{{17654110539292344320ull, 2494592023208759257ull,
  10798506479582582350ull, 2967364920549937108ull}},
{{8232580118833266688ull, 12341612065865724880ull,
  13498133099478227937ull, 3709206150687421385ull}},
{{5145362574270791680ull, 795978513524996194ull, 1518804159532810605ull,
  2318253844179638366ull}},
{{15655075254693265408ull, 5606659160333633146ull,
  11121877236270789064ull, 2897817305224547957ull}},
{{10345472031511805952ull, 7008323950417041433ull, 67288490056322618ull,
  3622271631530684947ull}},
{{17543526057817145344ull, 17983776974876077599ull,
  13919168667852566984ull, 4527839539413356183ull}},
{{17882232813776797696ull, 11239860609297548499ull,
  15617009445048936221ull, 2829899712133347614ull}},
{{17741104998793609216ull, 214767706339771912ull,
  10297889769456394469ull, 3537374640166684518ull}},
{{3729637174782459904ull, 4880145651352102795ull,
  3648990174965717278ull, 4421718300208355648ull}},
{{25180225025343488ull, 16885149087377227959ull, 2280618859353573298ull,
  2763573937630222280ull}},
{{13866533336563843072ull, 11883064322366759140ull,
  2850773574191966623ull, 3454467422037777850ull}},
{{17333166670704803840ull, 10242144384531061021ull,
  12786839004594734087ull, 4318084277547222312ull}},
{{13139072178404196352ull, 13318869267972994994ull,
  7991774377871708804ull, 2698802673467013945ull}},
{{7200468186150469632ull, 16648586584966243743ull,
  14601403990767023909ull, 3373503341833767431ull}},
{{4388899214260699136ull, 6975675175925640967ull,
  13640068970031391983ull, 4216879177292209289ull}},
{{9660591036554018816ull, 11277326012594607460ull,
  1607514078628538133ull, 2635549485807630806ull}},
{{12075738795692523520ull, 261599460461095613ull,
  11232764635140448475ull, 3294436857259538507ull}},
{{1259615439333490688ull, 14162057380858533229ull,
  9429269775498172689ull, 4118046071574423134ull}},
{{3093102658797125632ull, 1933756835395501412ull,
  1281607591258970027ull, 2573778794734014459ull}},
{{3866378323496407040ull, 16252254099526540477ull,
  15437067544355876245ull, 3217223493417518073ull}},
{{9444658922797896704ull, 6480259569126011884ull,
  5461276375162681595ull, 4021529366771897592ull}},
{{15126283863603461248ull, 1744319221490063475ull,
  3413297734476675997ull, 2513455854232435995ull}},
{{14296168811076938656ull, 6792085045289967248ull,
  18101680223378008708ull, 3141819817790544993ull}},
{{17870211013846173320ull, 8490106306612459060ull,
  8792042223940347173ull, 3927274772238181242ull}},
{{1945509846799082517ull, 7612159450846480865ull,
  10106712408390104887ull, 2454546732648863276ull}},
{{7043573326926241051ull, 4903513295130713177ull,
  12633390510487631109ull, 3068183415811079095ull}},
{{13416152677085189217ull, 10741077637340779375ull,
  11180052119682150982ull, 3835229269763848869ull}},
{{15302624450819325117ull, 2101487504910599205ull,
  9293375584015038316ull, 2397018293602405543ull}},
{{5293222508241992684ull, 2626859381138249007ull,
  7005033461591409991ull, 2996272867003006929ull}},
{{2004842116875102951ull, 17118632281704974971ull,
  13367977845416650392ull, 3745341083753758661ull}},
{{17393927387542797009ull, 10699145176065609356ull,
  10660829162599100447ull, 2340838177346099163ull}},
{{3295665160718944645ull, 8762245451654623792ull,
  8714350434821487655ull, 2926047721682623954ull}},
{{4119581450898680806ull, 6341120796140891836ull,
  1669566006672083761ull, 3657559652103279943ull}},
{{5149476813623351007ull, 12538087013603502699ull,
  15922015563622268413ull, 4571949565129099928ull}},
{{912579999300900428ull, 10142147392715883139ull,
  9951259727263917758ull, 2857468478205687455ull}},
{{14975783054408289246ull, 3454312204040078115ull,
  7827388640652509294ull, 3571835597757109319ull}},
{{14108042799582973654ull, 13541262291904873452ull,
  5172549782388248713ull, 4464794497196386649ull}},
{{18040898786594134342ull, 1545759904799464051ull,
  14762058660061125206ull, 2790496560747741655ull}},
{{17939437464815280023ull, 11155571917854105872ull,
  13840887306649018603ull, 3488120700934677069ull}},
{{3977552757309548413ull, 9332778878890244437ull,
  3466051078029109542ull, 4360150876168346337ull}},
{{4791813482532161710ull, 1221300780879014869ull,
  13695496969836663224ull, 2725094297605216460ull}},
{{10601452871592590042ull, 1526625976098768586ull,
  17119371212295829030ull, 3406367872006520575ull}},
{{4028444052635961744ull, 11131654506978236541ull,
  16787527996942398383ull, 4257959840008150719ull}},
{{4823620542111170042ull, 13874813094502479694ull,
  17409734025730080845ull, 2661224900005094199ull}},
{{15252897714493738360ull, 3508458312845935905ull,
  17150481513735213153ull, 3326531125006367749ull}},
{{5231064087835009238ull, 8997258909484807786ull,
  7603043836886852729ull, 4158163906257959687ull}},
{{7881101073324268678ull, 17152501864496474626ull,
  11669431425695364811ull, 2598852441411224804ull}},
{{628004304800560040ull, 16828941312193205379ull,
  14586789282119206014ull, 3248565551764031005ull}},
{{14620063436282863761ull, 11812804603386730915ull,
  4398428547366843806ull, 4060706939705038757ull}},
{{6831696638463095899ull, 2771316858689318918ull,
  5054860851317971331ull, 2537941837315649223ull}},
{{17762992834933645682ull, 17299204128643812359ull,
  1706890045720076259ull, 3172427296644561529ull}},
{{17592055025239669198ull, 17012319142377377545ull,
  6745298575577483228ull, 3965534120805701911ull}},
{{4077505363133711393ull, 1409327427131085158ull,
  11133340637377008874ull, 2478458825503563694ull}},
{{14320253740771915049ull, 10985031320768632255ull,
  4693303759866485284ull, 3098073531879454618ull}},
{{13288631157537505907ull, 13731289150960790319ull,
  15090001736687882413ull, 3872591914849318272ull}},
{{15222923501102023048ull, 10887898728564187901ull,
  9431251085429926508ull, 2420369946780823920ull}},
{{5193596321095365098ull, 13609873410705234877ull,
  11789063856787408135ull, 3025462433476029900ull}},
{{11103681419796594277ull, 12400655744954155692ull,
  14736329820984260169ull, 3781828041845037375ull}},
{{16163172924227647231ull, 832880812955265451ull,
  16127735165756244462ull, 2363642526153148359ull}},
{{15592280136857171135ull, 10264473053048857622ull,
  15547982938767917673ull, 2954553157691435449ull}},
{{10266978134216688110ull, 17442277334738459932ull,
  5599920618177733379ull, 3693191447114294312ull}},
{{15640233370740205877ull, 8595580324997843505ull,
  3499950386361083362ull, 2308244654446433945ull}},
{{5715233658143093634ull, 1521103369392528574ull,
  8986624001378742107ull, 2885305818058042431ull}},
{{16367414109533642851ull, 15736437267022824429ull,
  6621593983296039729ull, 3606632272572553039ull}},
{{6624209581634889851ull, 5835488528496366825ull,
  3665306460692661758ull, 4508290340715691299ull}},
{{15669346034590275917ull, 17482238385592392977ull,
  18431717602428771262ull, 2817681462947307061ull}},
{{5751624487955681184ull, 12629425945135715414ull,
  9204588947753800366ull, 3522101828684133827ull}},
{{16412902646799377288ull, 6563410394564868459ull,
  6894050166264862554ull, 4402627285855167284ull}},
{{7952221145035916853ull, 8713817515030430691ull,
  13532153390770314904ull, 2751642053659479552ull}},
{{5328590412867508163ull, 10892271893788038364ull,
  16915191738462893630ull, 3439552567074349440ull}},
{{6660738016084385203ull, 4391967830380272147ull,
  2697245599369065422ull, 4299440708842936801ull}},
{{1857118250839046800ull, 16580037949269833804ull,
  13214993545674135648ull, 2687150443026835500ull}},
{{2321397813548808500ull, 2278303362877740639ull,
  16518741932092669561ull, 3358938053783544375ull}},
{{16736805322218174337ull, 7459565222024563702ull,
  16036741396688449047ull, 4198672567229430469ull}},
{{5848817307958971057ull, 11579757291406434170ull,
  12328806382143974606ull, 2624170354518394043ull}},
{{16534393671803489629ull, 5251324577403266904ull,
  10799321959252580354ull, 3280212943147992554ull}},
{{2221248016044810420ull, 15787527758608859439ull,
  4275780412210949634ull, 4100266178934990693ull}},
{{8305809037669088369ull, 14478890867557925053ull,
  4978205766845537473ull, 2562666361834369183ull}},
{{14993947315513748365ull, 4263555529165242604ull,
  1611071190129533938ull, 3203332952292961479ull}},
{{295690070682633840ull, 14552816448311329064ull,
  15848897042944081134ull, 4004166190366201848ull}},
{{184806294176646150ull, 4483824261767192761ull, 9905560651840050709ull,
  2502603868978876155ull}},
{{4842693886148195591ull, 10216466345636378855ull,
  7770264796372675482ull, 3128254836223595194ull}},
{{1441681339257856585ull, 3547210895190697761ull, 489458958611068545ull,
  3910318545279493993ull}},
{{12430265883104630126ull, 13746221855562655860ull,
  11835126895200387600ull, 2443949090799683745ull}},
{{15537832353880787657ull, 17182777319453319825ull,
  958850563718320788ull, 3054936363499604682ull}},
{{5587232387068820859ull, 3031727575607098166ull,
  10421935241502676794ull, 3818670454374505852ull}},
{{17327078297200176749ull, 6506515753181824257ull,
  15737081562793948804ull, 2386669033984066157ull}},
{{7823789816218057224ull, 8133144691477280322ull,
  5836293898210272293ull, 2983336292480082697ull}},
{{556365233417795722ull, 14778116882773988307ull,
  11907053391190228270ull, 3729170365600103371ull}},
{{16488629335381979991ull, 4624637033306354787ull,
  5136065360280198717ull, 2330731478500064607ull}},
{{15999100650800087084ull, 10392482310060331388ull,
  1808395681922860492ull, 2913414348125080759ull}},
{{1552131739790557239ull, 12990602887575414236ull,
  16095552657685739327ull, 3641767935156350948ull}},
{{1940164674738196549ull, 11626567591041879891ull,
  1672696748397622543ull, 4552209918945438686ull}},
{{17353503986207230507ull, 14184133772042256787ull,
  14880493523030677801ull, 2845131199340899178ull}},
{{17080193964331650230ull, 3895109159770657272ull,
  9377244866933571444ull, 3556413999176123973ull}},
{{2903498381705011171ull, 4868886449713321591ull,
  16333242102094352209ull, 4445517498970154966ull}},
{{8732215516206713838ull, 14572269077139295754ull,
  5596590295381582226ull, 2778448436856346854ull}},
{{1691897358403616490ull, 8991964309569343885ull,
  16219109906081753591ull, 3473060546070433567ull}},
{{6726557716431908516ull, 6628269368534291952ull,
  15662201364174804085ull, 4341325682588041959ull}},
{{4204098572769942823ull, 6448511364547626422ull,
  16706404880250334409ull, 2713328551617526224ull}},
{{14478495252817204336ull, 12672325224111920931ull,
  2436262026603366395ull, 3391660689521907781ull}},
{{13486433047594117516ull, 11228720511712513260ull,
  7657013551681595898ull, 4239575861902384726ull}},
{{17652392691601099256ull, 11629636338247708691ull,
  173947451373609532ull, 2649734913688990454ull}},
{{17453804846073986166ull, 14537045422809635864ull,
  9440806351071787723ull, 3312168642111238067ull}},
{{3370511983882931091ull, 13559620760084656927ull,
  7189321920412346750ull, 4140210802639047584ull}},
{{9024099017567913788ull, 3863076956625522675ull,
  4493326200257716719ull, 2587631751649404740ull}},
{{6668437753532504331ull, 217160177354515440ull, 5616657750322145899ull,
  3234539689561755925ull}},
{{8335547191915630413ull, 14106508276975308012ull,
  11632508206330070277ull, 4043174611952194906ull}},
{{14433089031802044817ull, 11122410682323261459ull,
  11882003647383681827ull, 2526984132470121816ull}},
{{13429675271325168117ull, 9291327334476688920ull,
  14852504559229602284ull, 3158730165587652270ull}},
{{16787094089156460146ull, 11614159168095861150ull,
  9342258662182227047ull, 3948412706984565338ull}},
{{5880247787295399687ull, 14176378507700995075ull,
  10450597682291279808ull, 2467757941865353336ull}},
{{2738623715691861705ull, 17720473134626243844ull,
  13063247102864099760ull, 3084697427331691670ull}},
{{3423279644614827131ull, 3703847344573253189ull,
  7105686841725348893ull, 3855871784164614588ull}},
{{4445392787097960909ull, 4620747599571977195ull,
  13664426312933118866ull, 2409919865102884117ull}},
{{945054965445063232ull, 14999306536319747302ull,
  3245474835884234870ull, 3012399831378605147ull}},
{{10404690743661104848ull, 9525761133544908319ull,
  17891901600137457300ull, 3765499789223256433ull}},
{{13420460742429272386ull, 15176972745320343507ull,
  4264909472444828956ull, 2353437368264535271ull}},
{{12163889909609202579ull, 524471857940877768ull, 719450822128648292ull,
  2941796710330669089ull}},
{{15204862387011503223ull, 655589822426097210ull,
  5510999546088198269ull, 3677245887913336361ull}},
{{9782705946909603221ull, 5431173296460009417ull,
  11500435451037635740ull, 4596557359891670451ull}},
{{17643406262886971773ull, 12617855347142281693ull,
  4881929147684828385ull, 2872848349932294032ull}},
{{8219199773326551005ull, 1937261128645688405ull,
  6102411434606035482ull, 3591060437415367540ull}},
{{14885685735085576660ull, 11644948447661886314ull,
  7628014293257544352ull, 4488825546769209425ull}},
{{13915239602855873316ull, 7278092779788678946ull,
  16296723979354434980ull, 2805515966730755890ull}},
{{8170677466715065837ull, 9097615974735848683ull,
  11147532937338267917ull, 3506894958413444863ull}},
{{5601660814966444393ull, 15983705986847198758ull,
  9322730153245446992ull, 4383618698016806079ull}},
{{17336096064636191458ull, 9989816241779499223ull,
  12744235373419486226ull, 2739761686260503799ull}},
{{17058434062367851418ull, 3263898265369598221ull,
  11318608198346969879ull, 3424702107825629749ull}},
{{7487984522677650560ull, 17914930886994161489ull,
  313202192651548636ull, 4280877634782037187ull}},
{{16209205372742001360ull, 1973459767516575122ull,
  16336652434903075562ull, 2675548521738773241ull}},
{{11038134679072725892ull, 11690196746250494711ull,
  6585757488346680740ull, 3344435652173466552ull}},
{{9185982330413519461ull, 14612745932813118389ull,
  8232196860433350925ull, 4180544565216833190ull}},
{{8047081965722143615ull, 11438809217221892945ull,
  533437019343456424ull, 2612840353260520744ull}},
{{14670538475580067423ull, 14298511521527366181ull,
  666796274179320530ull, 3266050441575650930ull}},
{{4503115039192920567ull, 8649767365054431919ull,
  10056867379578926471ull, 4082563051969563662ull}},
{{9731975927136657210ull, 12323633630800101805ull,
  1673856093809441140ull, 2551601907480977289ull}},
{{16776655927348209417ull, 15404542038500127256ull,
  6704006135689189329ull, 3189502384351221611ull}},
{{2524075835475710155ull, 5420619492842995359ull,
  3768321651184098758ull, 3986877980439027014ull}},
{{8495076424813400703ull, 17222945238309035811ull,
  16190259087272225435ull, 2491798737774391883ull}},
{{6007159512589362975ull, 16916995529458906860ull,
  15626137840662893890ull, 3114748422217989854ull}},
{{7508949390736703718ull, 11922872374968857767ull,
  10309300263973841555ull, 3893435527772487318ull}},
{{11610622396851521680ull, 5145952225141842152ull,
  1831626646556263068ull, 2433397204857804574ull}},
{{14513277996064402100ull, 6432440281427302690ull,
  11512905345050104643ull, 3041746506072255717ull}},
{{8918225458225726817ull, 3428864333356740459ull, 556073626030467092ull,
  3802183132590319647ull}},
{{3268047902177385309ull, 11366412245202738595ull,
  7265075043910123788ull, 2376364457868949779ull}},
{{17920117933003895348ull, 14208015306503423243ull,
  4469657786460266831ull, 2970455572336187224ull}},
{{17788461397827481281ull, 13148333114701891150ull,
  5587072233075333539ull, 3713069465420234030ull}},
{{6506102355214787897ull, 5911865187474988017ull,
  17326978200954247174ull, 2320668415887646268ull}},
{{12744313962445872775ull, 16613203521198510829ull,
  3211978677483257351ull, 2900835519859557836ull}},
{{2095334397775177256ull, 16154818383070750633ull,
  4014973346854071689ull, 3626044399824447295ull}},
{{7230854015646359474ull, 6358464923556274579ull, 407030665140201708ull,
  4532555499780559119ull}},
{{2213440750565280719ull, 13197412614077447420ull,
  7171923193353707923ull, 2832847187362849449ull}},
{{2766800938206600899ull, 11885079749169421371ull,
  13576590010119522808ull, 3541058984203561811ull}},
{{17293559228040414836ull, 14856349686461776713ull,
  12359051494222015606ull, 4426323730254452264ull}},
{{3890945489884177417ull, 4673532535611222542ull,
  7724407183888759754ull, 2766452331409032665ull}},
{{14087053899209997579ull, 15065287706368803985ull,
  14267194998288337596ull, 3458065414261290831ull}},
{{3773759318730333261ull, 384865559251453366ull,
  13222307729433034092ull, 4322581767826613539ull}},
{{16193657629488622000ull, 9463913011386934161ull,
  5958099321681952355ull, 2701613604891633462ull}},
{{6407013981578613788ull, 7218205245806279798ull,
  16670996188957216252ull, 3377017006114541827ull}},
{{17232139513828043043ull, 9022756557257849747ull,
  16227059217769132411ull, 4221271257643177284ull}},
{{8464244186928832950ull, 3333379839072462140ull, 918539974250931949ull,
  2638294536026985803ull}},
{{10580305233661041188ull, 8778410817267965579ull,
  14983233023095828648ull, 3297868170033732253ull}},
{{8613695523648913581ull, 10973013521584956974ull,
  4893983223587622098ull, 4122335212542165317ull}},
{{771873683853183084ull, 11469819469417986013ull,
  5364582523955957763ull, 2576459507838853323ull}},
{{5576528123243866759ull, 9725588318345094612ull,
  2094042136517559300ull, 3220574384798566654ull}},
{{6970660154054833449ull, 12156985397931368265ull,
  11840924707501724933ull, 4025717980998208317ull}},
{{15885877642352740666ull, 9903958882920799117ull,
  9706420951402272035ull, 2516073738123880198ull}},
{{6022288997658762120ull, 7768262585223610993ull,
  2909654152398064236ull, 3145092172654850248ull}},
{{12139547265500840554ull, 9710328231529513741ull,
  3637067690497580295ull, 3931365215818562810ull}},
{{9893060050151719298ull, 12986484172347027944ull,
  6884853324988375588ull, 2457103259886601756ull}},
{{12366325062689649123ull, 16233105215433784930ull,
  8606066656235469485ull, 3071379074858252195ull}},
{{6234534291507285595ull, 6456323464010067451ull,
  6145897301866948953ull, 3839223843572815244ull}},
{{1590740922978359545ull, 15564417211074761917ull,
  13064557850521618903ull, 2399514902233009527ull}},
{{6600112172150337335ull, 14843835495416064492ull,
  11719011294724635725ull, 2999393627791261909ull}},
{{8250140215187921669ull, 4719736313987916903ull, 813706063123630945ull,
  3749242034739077387ull}},
{{12073866662133532899ull, 14479050242310917824ull,
  16649467353948127004ull, 2343276271711923366ull}},
{{15092333327666916124ull, 18098812802888647280ull,
  11588462155580382947ull, 2929095339639904208ull}},
{{418672585874093539ull, 18011829985183421197ull,
  14485577694475478684ull, 3661369174549880260ull}},
{{5135026750770004827ull, 4068043407769724880ull,
  18106972118094348356ull, 4576711468187350325ull}},
{{3209391719231253017ull, 11765899166710853858ull,
  13622700583022661674ull, 2860444667617093953ull}},
{{13235111685893842080ull, 5484001921533791514ull,
  3193317673496163381ull, 3575555834521367442ull}},
{{7320517570512526791ull, 11466688420344627297ull,
  13215019128724980034ull, 4469444793151709302ull}},
{{16104538527638799005ull, 11778366281142779964ull,
  3647700937025724617ull, 2793402995719818314ull}},
{{1683929085838947140ull, 887899796146311244ull,
  13782998208136931580ull, 3491753744649772892ull}},
{{2104911357298683925ull, 1109874745182889055ull,
  17228747760171164475ull, 4364692180812216115ull}},
{{8233098625952759309ull, 16834572780235163323ull,
  8462124340893283844ull, 2727932613007635072ull}},
{{5679687264013561232ull, 2596471901584402538ull,
  10577655426116604806ull, 3409915766259543840ull}},
{{16322981116871727348ull, 12468961913835278980ull,
  13222069282645756007ull, 4262394707824429800ull}},
{{978491161190053785ull, 14710630223788131219ull,
  8263793301653597504ull, 2663996692390268625ull}},
{{15058172006769730943ull, 18388287779735164023ull,
  14941427645494384784ull, 3329995865487835781ull}},
{{14211028990034775774ull, 4538615650959403413ull,
  4841726501585817269ull, 4162494831859794727ull}},
{{11187736127985428811ull, 5142477791063321085ull,
  9943608091132217649ull, 2601559269912371704ull}},
{{149612104699622302ull, 11039783257256539261ull,
  12429510113915272061ull, 3251949087390464630ull}},
{{4798701149301915781ull, 18411415089998061980ull,
  6313515605539314268ull, 4064936359238080788ull}},
{{12222560255168473171ull, 2283762394394012929ull,
  13169319290316847226ull, 2540585224523800492ull}},
{{1443142263678427752ull, 12078075029847291970ull,
  16461649112896059032ull, 3175731530654750615ull}},
{{11027299866452810498ull, 15097593787309114962ull,
  15965375372692685886ull, 3969664413318438269ull}},
{{11503748434960394466ull, 4824310098640808947ull,
  12284202617146622631ull, 2481040258324023918ull}},
{{9767999525273105178ull, 1418701604873623280ull,
  6131881234578502481ull, 3101300322905029898ull}},
{{12209999406591381472ull, 6385063024519417004ull,
  16888223580077903909ull, 3876625403631287372ull}},
{{16854621665974389228ull, 6296507399538329579ull,
  1331767700693914135ull, 2422890877269554608ull}},
{{16456591064040598631ull, 3258948230995524070ull,
  1664709625867392669ull, 3028613596586943260ull}},
{{11347366793195972481ull, 8685371307171792992ull,
  2080887032334240836ull, 3785766995733679075ull}},
{{7092104245747482801ull, 14651729103837146428ull,
  17441455459704758186ull, 2366104372333549421ull}},
{{8865130307184353501ull, 9091289342941657227ull,
  7966761269348784021ull, 2957630465416936777ull}},
{{6469726865553053972ull, 15975797697104459438ull,
  14570137605113367930ull, 3697038081771170971ull}},
{{17878637346252822445ull, 14596559579117675052ull,
  6800492993982161004ull, 2310648801106981857ull}},
{{3901552609106476440ull, 18245699473897093816ull,
  13112302260905089159ull, 2888311001383727321ull}},
{{4876940761383095549ull, 18195438323943979366ull,
  2555319770849197737ull, 3610388751729659152ull}},
{{15319547988583645245ull, 8909239849647810495ull,
  3194149713561497172ull, 4512985939662073940ull}},
{{16492246520505860134ull, 14791646942884657367ull,
  11219715607830711540ull, 2820616212288796212ull}},
{{16003622132204937264ull, 42814604896270093ull,
  14024644509788389426ull, 3525770265360995265ull}},
{{6169469609974007867ull, 9276890292975113425ull,
  3695747581953323070ull, 4407212831701244082ull}},
{{15385133552302224677ull, 1186370414682057986ull,
  6921528257148214823ull, 2754508019813277551ull}},
{{10008044903523005038ull, 15318021073634736195ull,
  4040224303007880624ull, 3443135024766596939ull}},
{{7898370110976368394ull, 700782268333868628ull, 438594360332462877ull,
  4303918780958246174ull}},
{{14159853356215006054ull, 2743831926922361844ull,
  14109179530489953010ull, 2689949238098903858ull}},
{{17699816695268757568ull, 12653161945507728113ull,
  8413102376257665454ull, 3362436547623629823ull}},
{{8289712813803783248ull, 6593080395029884334ull,
  5904691951894693914ull, 4203045684529537279ull}},
{{569384490199976626ull, 8732361265321065613ull,
  10607961497575265552ull, 2626903552830960799ull}},
{{5323416631177358686ull, 10915451581651332016ull,
  8648265853541694036ull, 3283629441038700999ull}},
{{6654270788971698358ull, 13644314477064165020ull,
  6198646298499729641ull, 4104536801298376249ull}},
{{13382291279962087282ull, 1610167520524021281ull,
  15403368982630800786ull, 2565335500811485155ull}},
{{2892806044670445390ull, 11236081437509802410ull,
  14642525209861113078ull, 3206669376014356444ull}}
};

// **********************************************************************

#if __ENABLE_BINARY80__

static const UINT128 breakpoints_binary80[] =
  { {{6337302757928054309ull, 494016656451265ull}},
{{5069842206342443447ull, 395213325161012ull}},
{{15123920209299685727ull, 316170660128809ull}},
{{13130225890653766194ull, 505873056206095ull}},
{{10504180712523012955ull, 404698444964876ull}},
{{4713995755276500041ull, 323758755971901ull}},
{{163695578958579419ull, 518014009555042ull}},
{{11199002907392594505ull, 414411207644033ull}},
{{16337899955397896250ull, 331528966115226ull}},
{{315198225443261738ull, 530446345784363ull}},
{{7630856209838430037ull, 424357076627490ull}},
{{6104684967870744030ull, 339485661301992ull}},
{{13456844763335100771ull, 543177058083187ull}},
{{3386778181184259970ull, 434541646466550ull}},
{{2709422544947407976ull, 347633317173240ull}},
{{4335076071915852762ull, 556213307477184ull}},
{{7157409672274592533ull, 444970645981747ull}},
{{16793974182045404996ull, 355976516785397ull}},
{{6056481716152503350ull, 284781213428318ull}},
{{6001021931102095037ull, 455649941485309ull}},
{{8490166359623586353ull, 364519953188247ull}},
{{17860179531924600052ull, 291615962550597ull}},
{{13818891992111718790ull, 466585540080956ull}},
{{7365764778947464709ull, 373268432064765ull}},
{{5892611823157971767ull, 298614745651812ull}},
{{13117527731794665151ull, 477783593042899ull}},
{{14183371000177642444ull, 382226874434319ull}},
{{15036045614884024278ull, 305781499547455ull}},
{{5610928910104887229ull, 489250399275929ull}},
{{8178091942825820106ull, 391400319420743ull}},
{{13921171183744476731ull, 313120255536594ull}},
{{11205827449765431801ull, 500992408858551ull}},
{{5275313145070435117ull, 400793927086841ull}},
{{530901701314437771ull, 320635141669473ull}},
{{15606837981070741726ull, 513016226671156ull}},
{{8796121570114683058ull, 410412981336925ull}},
{{7036897256091746446ull, 328330385069540ull}},
{{11259035609746794314ull, 525328616111264ull}},
{{12696577302539345774ull, 420262892889011ull}},
{{6467913027289566296ull, 336210314311209ull}},
{{17727358473147126720ull, 537936502897934ull}},
{{17871235593259611699ull, 430349202318347ull}},
{{6918290845123868713ull, 344279361854678ull}},
{{7379916537456279618ull, 550846978967485ull}},
{{5903933229965023694ull, 440677583173988ull}},
{{12101844213455839602ull, 352542066539190ull}},
{{9681475370764671681ull, 282033653231352ull}},
{{732965334255833398ull, 451253845170164ull}},
{{4275721082146577041ull, 361003076136131ull}},
{{18177972124684902926ull, 288802460908904ull}},
{{18016708955270113712ull, 462083937454247ull}},
{{7034669534732270323ull, 369667149963398ull}},
{{13006433257269636905ull, 295733719970718ull}},
{{17120944396889508724ull, 473173951953149ull}},
{{17386104332253517303ull, 378539161562519ull}},
{{17598232280544724165ull, 302831329250015ull}},
{{9710427575162007049ull, 484530126800025ull}},
{{7768342060129605639ull, 387624101440020ull}},
{{6214673648103684511ull, 310099281152016ull}},
{{2564780207482074571ull, 496158849843226ull}},
{{16809219424953300950ull, 396927079874580ull}},
{{13447375539962640760ull, 317541663899664ull}},
{{10447754419714494246ull, 508066662239463ull}},
{{15736901165255416043ull, 406453329791570ull}},
{{12589520932204332835ull, 325162663833256ull}},
{{12764535862043111889ull, 520260262133210ull}},
{{10211628689634489511ull, 416208209706568ull}},
{{15548000581191412255ull, 332966567765254ull}},
{{13808754485680528639ull, 532746508424407ull}},
{{3668305959060602265ull, 426197206739526ull}},
{{17692040026216123105ull, 340957765391620ull}},
{{9860519968236245352ull, 545532424626593ull}},
{{15267113604072816928ull, 436425939701274ull}},
{{15903039698000163865ull, 349140751761019ull}},
{{14376817072574531215ull, 558625202817631ull}},
{{7812104843317714649ull, 446900162254105ull}},
{{6249683874654171719ull, 357520129803284ull}},
{{8689095914465247698ull, 286016103842627ull}},
{{17591902277886306641ull, 457625766148203ull}},
{{3005475378083314343ull, 366100612918563ull}},
{{9783077931950472121ull, 292880490334850ull}},
{{15652924691120755393ull, 468608784535760ull}},
{{12522339752896604314ull, 374887027628608ull}},
{{17396569431801104098ull, 299909622102886ull}},
{{2009069387688394294ull, 479855395364619ull}},
{{5296604324892625759ull, 383884316291695ull}},
{{4237283459914100607ull, 307107453033356ull}},
{{17847699980088291941ull, 491371924853369ull}},
{{17967508798812543876ull, 393097539882695ull}},
{{14374007039050035101ull, 314478031906156ull}},
{{15619713632996235515ull, 503164851049850ull}},
{{12495770906396988412ull, 402531880839880ull}},
{{9996616725117590729ull, 322025504671904ull}},
{{4926540315962414197ull, 515240807475047ull}},
{{15009278696995662327ull, 412192645980037ull}},
{{4628725328112709215ull, 329754116784030ull}},
{{7405960524980334745ull, 527606586854448ull}},
{{13303466049468088442ull, 422085269483558ull}},
{{18021470469058291400ull, 337668215586846ull}},
{{3008911047299893978ull, 540269144938955ull}},
{{2407128837839915182ull, 432215315951164ull}},
{{5615051885013842469ull, 345772252760931ull}},
{{1605385386538327304ull, 553235604417490ull}},
{{1284308309230661843ull, 442588483533992ull}},
{{12095493091610260444ull, 354070786827193ull}},
{{17055092102772029002ull, 283256629461754ull}},
{{16220100920209515433ull, 453210607138807ull}},
{{5597383106683791700ull, 362568485711046ull}},
{{788557670605123037ull, 290054788568837ull}},
{{4951041087710107183ull, 464087661710139ull}},
{{7650181684909996069ull, 371270129368111ull}},
{{2430796533186086532ull, 297016103494489ull}},
{{11267972082581559098ull, 475225765591182ull}},
{{1635680036581426632ull, 380180612472946ull}},
{{16065939288232782598ull, 304144489978356ull}},
{{18326805231688631511ull, 486631183965370ull}},
{{14661444185350905209ull, 389304947172296ull}},
{{8039806533538813844ull, 311443957737837ull}},
{{16553039268404012473ull, 498310332380539ull}},
{{16931780229465120302ull, 398648265904431ull}},
{{9856075368830185918ull, 318918612723545ull}},
{{15769720590128297469ull, 510269780357672ull}},
{{5237078842618817329ull, 408215824286138ull}},
{{11568360703578874509ull, 326572659428910ull}},
{{62633052016647599ull, 522516255086257ull}},
{{11118152885839049049ull, 418013004069005ull}},
{{8894522308671239239ull, 334410403255204ull}},
{{3163189249648251813ull, 535056645208327ull}},
{{13598597843944332420ull, 428045316166661ull}},
{{7189529460413555613ull, 342436252933329ull}},
{{435200692435958011ull, 547898004693327ull}},
{{11416206998174497378ull, 438318403754661ull}},
{{5443616783797687579ull, 350654723003729ull}},
{{16088484483560120774ull, 561047556805966ull}},
{{9181438772106186296ull, 448838045444773ull}},
{{14723848647168769683ull, 359070436355818ull}},
{{711032473509284777ull, 287256349084655ull}},
{{1137651957614855643ull, 459610158535448ull}},
{{8288819195575705161ull, 367688126828358ull}},
{{14009752985944384775ull, 294150501462686ull}},
{{15036907148027194994ull, 470640802340298ull}},
{{961479274196025025ull, 376512641872239ull}},
{{4458532234098730343ull, 301210113497791ull}},
{{18201698018783699519ull, 481936181596465ull}},
{{14561358415026959615ull, 385548945277172ull}},
{{4270389102537747046ull, 308439156221738ull}},
{{3143273749318484950ull, 493502649954781ull}},
{{17272014258422429253ull, 394802119963824ull}},
{{17506960221479853725ull, 315841695971059ull}},
{{16943089910142034991ull, 505346713553695ull}},
{{13554471928113627993ull, 404277370842956ull}},
{{7154228727748992071ull, 323421896674365ull}},
{{11446765964398387314ull, 517475034678984ull}},
{{12846761586260620174ull, 413980027743187ull}},
{{2898711639524675493ull, 331184022194550ull}},
{{4637938623239480789ull, 529894435511280ull}},
{{3710350898591584631ull, 423915548409024ull}},
{{6657629533615178028ull, 339132438727219ull}},
{{18030904883268105491ull, 542611901963550ull}},
{{14424723906614484393ull, 434089521570840ull}},
{{11539779125291587514ull, 347271617256672ull}},
{{3706251341498898730ull, 555634587610676ull}},
{{17722396332166760277ull, 444507670088540ull}},
{{14177917065733408221ull, 355606136070832ull}},
{{3963636023102905931ull, 284484908856666ull}},
{{17409864081190380459ull, 455175854170665ull}},
{{13927891264952304367ull, 364140683336532ull}},
{{3763615382478022847ull, 291312546669226ull}},
{{17089831056190567525ull, 466100074670761ull}},
{{9982516030210543697ull, 372880059736609ull}},
{{11675361638910345281ull, 298304047789287ull}},
{{3923183363288911157ull, 477286476462860ull}},
{{3138546690631128925ull, 381829181170288ull}},
{{9889534981988723786ull, 305463344936230ull}},
{{15823255971181958059ull, 488741351897968ull}},
{{1590558332719835477ull, 390993081518375ull}},
{{1272446666175868382ull, 312794465214700ull}},
{{2035914665881389411ull, 500471144343520ull}},
{{1628731732705111529ull, 400376915474816ull}},
{{16060380645131730516ull, 320301532379852ull}},
{{10939213773243127533ull, 512482451807764ull}},
{{12440719833336412349ull, 409985961446211ull}},
{{6263227051927219556ull, 327988769156969ull}},
{{17399860912567371936ull, 524782030651150ull}},
{{13919888730053897549ull, 419825624520920ull}},
{{11135910984043118039ull, 335860499616736ull}},
{{10438759944985168216ull, 537376799386778ull}},
{{15729705585471955219ull, 429901439509422ull}},
{{5205066838893743529ull, 343921151607538ull}},
{{4638758127488079324ull, 550273842572061ull}},
{{21657687248553136ull, 440219074057649ull}},
{{3706674964540752832ull, 352175259246119ull}},
{{6654688786374512588ull, 281740207396895ull}},
{{10647502058199220142ull, 450784331835032ull}},
{{1139304017075555467ull, 360627465468026ull}},
{{15668838472628085666ull, 288501972374420ull}},
{{6623397482495385450ull, 461603155799073ull}},
{{12677415615480129006ull, 369282524639258ull}},
{{17520630121867923851ull, 295426019711406ull}},
{{2207566491795305900ull, 472681631538251ull}},
{{16523448452403886013ull, 378145305230600ull}},
{{13218758761923108810ull, 302516244184480ull}},
{{2703269945367422481ull, 484025990695169ull}},
{{5851964771035848308ull, 387220792556135ull}},
{{4681571816828678646ull, 309776634044908ull}},
{{3801166092183975511ull, 495642614471853ull}},
{{10419630503231001055ull, 396514091577482ull}},
{{957006773100980197ull, 317211273261986ull}},
{{12599257281187299286ull, 507538037219177ull}},
{{2700708195466018782ull, 406030429775342ull}},
{{13228613000598545995ull, 324824343820273ull}},
{{17476431986215763269ull, 519718950112437ull}},
{{6602447959488789969ull, 415775160089950ull}},
{{5281958367591031975ull, 332620128071960ull}},
{{8451133388145651160ull, 532192204915136ull}},
{{3071557895774610605ull, 425753763932109ull}},
{{6146595131361598807ull, 340603011145687ull}},
{{13523901024920468415ull, 544964817833099ull}},
{{14508469634678285055ull, 435971854266479ull}},
{{15296124522484538367ull, 348777483413183ull}},
{{2337706347523799448ull, 558043973461094ull}},
{{5559513892760949882ull, 446435178768875ull}},
{{4447611114208759905ull, 357148143015100ull}},
{{3558088891367007924ull, 285718514412080ull}},
{{5692942226187212679ull, 457149623059328ull}},
{{11933051410433590789ull, 365719698447462ull}},
{{2167743498863051985ull, 292575758757970ull}},
{{3468389598180883176ull, 468121214012752ull}},
{{13842758122770437511ull, 374496971210201ull}},
{{7384857683474439685ull, 299597576968161ull}},
{{4437074664075282850ull, 479356123149058ull}},
{{10928357360744046927ull, 383484898519246ull}},
{{5053337073853327218ull, 306787918815397ull}},
{{11774688132907233872ull, 490860670104635ull}},
{{9419750506325787098ull, 392688536083708ull}},
{{14914498034544450324ull, 314150828866966ull}},
{{16484499225787299873ull, 502641326187146ull}},
{{9498250565887929575ull, 402113060949717ull}},
{{219902823226523014ull, 321690448759774ull}},
{{7730542146646257468ull, 514704718015638ull}},
{{13563131346800826621ull, 411763774412510ull}},
{{10850505077440661297ull, 329411019530008ull}},
{{13671459309163147752ull, 527057631248013ull}},
{{18315865076814338848ull, 421646104998410ull}},
{{14652692061451471078ull, 337316883998728ull}},
{{1308214409870891786ull, 539707014397966ull}},
{{15803966786864354722ull, 431765611518372ull}},
{{5264475800007663131ull, 345412489214698ull}},
{{4733812465270350686ull, 552659982743517ull}},
{{14855096416442011519ull, 442127986194813ull}},
{{816030688927878245ull, 353702388955851ull}},
{{15410219810109943889ull, 282961911164680ull}},
{{6209607622466358606ull, 452739057863489ull}},
{{8657034912714997208ull, 362191246290791ull}},
{{3236279115430087443ull, 289752997032633ull}},
{{1488697769946229586ull, 463604795252213ull}},
{{8569655845440804315ull, 370883836201770ull}},
{{6855724676352643452ull, 296707068961416ull}},
{{3590461852680408877ull, 474731310338266ull}},
{{17629764741111968395ull, 379785048270612ull}},
{{6725114163405754069ull, 303828038616490ull}},
{{10760182661449206511ull, 486124861786384ull}},
{{12297494943901275532ull, 388899889429107ull}},
{{2459298325637199779ull, 311119911543286ull}},
{{15002923765245250616ull, 497791858469257ull}},
{{4623641382712379847ull, 398233486775406ull}},
{{9564291427993554ull, 318586789420325ull}},
{{15302866284789687ull, 509738863072520ull}},
{{12242293027831749ull, 407791090458016ull}},
{{14767189093389906692ull, 326232872366412ull}},
{{8870107290456209415ull, 521972595786260ull}},
{{7096085832364967532ull, 417578076629008ull}},
{{13055566295375794672ull, 334062461303206ull}},
{{13510208443117450829ull, 534499938085130ull}},
{{10808166754493960663ull, 427599950468104ull}},
{{12335882218337078853ull, 342079960374483ull}},
{{16048062734597415842ull, 547327936599173ull}},
{{1770403743452201704ull, 437862349279339ull}},
{{5105671809503671686ull, 350289879423471ull}},
{{790377265722054052ull, 560463807077554ull}},
{{4321650627319553565ull, 448371045662043ull}},
{{10836018131339463498ull, 358696836529634ull}},
{{12358163319813481122ull, 286957469223707ull}},
{{5015666052733928502ull, 459131950757932ull}},
{{15080579286412873771ull, 367305560606345ull}},
{{12064463429130299017ull, 293844448485076ull}},
{{11924443857124657781ull, 470151117576122ull}},
{{2160857456215905578ull, 376120894060898ull}},
{{9107383594456545109ull, 300896715248718ull}},
{{10882464936388561851ull, 481434744397949ull}},
{{12395320763852759804ull, 385147795518359ull}},
{{13605605425824118166ull, 308118236414687ull}},
{{7011573422350947774ull, 492989178263500ull}},
{{5609258737880758219ull, 394391342610800ull}},
{{4487406990304606575ull, 315513074088640ull}},
{{7179851184487370520ull, 504820918541824ull}},
{{9433229762331806739ull, 403856734833459ull}},
{{11235932624607355715ull, 323085387866767ull}},
{{3220096940404127851ull, 516936620586828ull}},
{{9954775181807122927ull, 413549296469462ull}},
{{585122515961877695ull, 330839437175570ull}},
{{936196025539004313ull, 529343099480912ull}},
{{11817003264656934420ull, 423474479584729ull}},
{{13142951426467457859ull, 338779583667783ull}},
{{17339373467606022251ull, 542047333868453ull}},
{{2803452329859086831ull, 433637867094763ull}},
{{9621459493371090111ull, 346910293675810ull}},
{{15394335189393744178ull, 555056469881296ull}},
{{8626119336773085019ull, 444045175905037ull}},
{{17968941913644198985ull, 355236140724029ull}},
{{18064502345657269511ull, 284188912579223ull}},
{{6767110864600169279ull, 454702260126758ull}},
{{12792386321163956069ull, 363761808101406ull}},
{{6544560242189254532ull, 291009446481125ull}},
{{10471296387502807252ull, 465615114369800ull}},
{{8377037110002245801ull, 372492091495840ull}},
{{6701629688001796641ull, 297993673196672ull}},
{{14411956315544784949ull, 476789877114675ull}},
{{11529565052435827959ull, 381431901691740ull}},
{{9223652041948662367ull, 305145521353392ull}},
{{448008150218495ull, 488232834165428ull}},
{{7379056036003995442ull, 390586267332342ull}},
{{16971291273028927323ull, 312469013865873ull}},
{{5017973148394821778ull, 499950422185398ull}},
{{11393076148199678069ull, 399960337748318ull}},
{{16493158548043563102ull, 319968270198654ull}},
{{15321007232643969993ull, 511949232317847ull}},
{{4878108156631355348ull, 409559385854278ull}},
{{11281184154788904925ull, 327647508683422ull}},
{{3292499388694606587ull, 524236013893476ull}},
{{17391394769923326562ull, 419388811114780ull}},
{{13913115815938661250ull, 335511048891824ull}},
{{11192938861276127030ull, 536817678226919ull}},
{{12643699903762811947ull, 429454142581535ull}},
{{10114959923010249558ull, 343563314065228ull}},
{{12494587062074488970ull, 549701302504365ull}},
{{9995669649659591176ull, 439761042003492ull}},
{{617838090243852294ull, 351808833602794ull}},
{{8367238573873984317ull, 562894133764470ull}},
{{6693790859099187453ull, 450315307011576ull}},
{{1665683872537439639ull, 360252245609261ull}},
{{16089942356997593004ull, 288201796487408ull}},
{{3607814882744686868ull, 461122874379854ull}},
{{6575600720937659817ull, 368898299503883ull}},
{{12639178206233948500ull, 295118639603106ull}},
{{12843987500490496954ull, 472189823364970ull}},
{{10275190000392397563ull, 377751858691976ull}},
{{4530803185572007727ull, 302201486953581ull}},
{{18317331541140943334ull, 483522379125729ull}},
{{18343214047654664990ull, 386817903300583ull}},
{{3606524793898001022ull, 309454322640467ull}},
{{9459788484978711959ull, 495126916224747ull}},
{{189133158499148921ull, 396101532979798ull}},
{{7530004156283139783ull, 316881226383838ull}},
{{8358657835311113330ull, 507009962214141ull}},
{{2997577453506980341ull, 405607969771313ull}},
{{9776759592289404919ull, 324486375817050ull}},
{{15642815347663047870ull, 519178201307280ull}},
{{12514252278130438296ull, 415342561045824ull}},
{{13700750637246260960ull, 332274048836659ull}},
{{10853154575368286567ull, 531638478138655ull}},
{{8682523660294629253ull, 425310782510924ull}},
{{10635367742977613726ull, 340248626008739ull}},
{{5948541944538450992ull, 544397801613983ull}},
{{12137531185114581440ull, 435518241291186ull}},
{{6020676133349754829ull, 348414593032949ull}},
{{17011779442843428373ull, 557463348852718ull}},
{{2541377110049011728ull, 445970679082175ull}},
{{2033101688039209383ull, 356776543265740ull}},
{{1626481350431367506ull, 285421234612592ull}},
{{6291718975432098333ull, 456673975380147ull}},
{{16101421624571409636ull, 365339180304117ull}},
{{5502439670173307062ull, 292271344243294ull}},
{{16182601101761111946ull, 467634150789270ull}},
{{12946080881408889557ull, 374107320631416ull}},
{{6667515890385201322ull, 299285856505133ull}},
{{6978676609874411793ull, 478857370408213ull}},
{{12961638917383350080ull, 383085896326570ull}},
{{10369311133906680064ull, 306468717061256ull}},
{{9212200184766867457ull, 490349947298010ull}},
{{7369760147813493965ull, 392279957838408ull}},
{{13274505747734615819ull, 313823966270726ull}},
{{13860511566891564664ull, 502118346033162ull}},
{{3709711624029431084ull, 401694676826530ull}},
{{2967769299223544867ull, 321355741461224ull}},
{{12127128508241492434ull, 514169186337958ull}},
{{17080400436077014594ull, 411335349070366ull}},
{{9974971534119701352ull, 329068279256293ull}},
{{12270605639849611840ull, 526509246810069ull}},
{{13505833326621599795ull, 421207397448055ull}},
{{10804666661297279836ull, 336965917958444ull}},
{{6219420213849916768ull, 539145468733511ull}},
{{1286187356338023091ull, 431316374986809ull}},
{{4718298699812328796ull, 345053099989447ull}},
{{11238626734441636397ull, 552084959983115ull}},
{{8990901387553309118ull, 441667967986492ull}},
{{18260767554268378264ull, 353334374389193ull}},
{{3540567599188971641ull, 282667499511355ull}},
{{5664908158702354626ull, 452267999218168ull}},
{{11910624156445704347ull, 361814399374534ull}},
{{13217848139898473801ull, 289451519499627ull}},
{{6391161764869916789ull, 463122431199404ull}},
{{8802278226637843754ull, 370497944959523ull}},
{{14420520210794095650ull, 296398355967618ull}},
{{936739448819091101ull, 474237369548190ull}},
{{749391559055272880ull, 379389895638552ull}},
{{11667559691469949274ull, 303511916510841ull}},
{{11289397876868098192ull, 485619066417346ull}},
{{5342169486752568230ull, 388495253133877ull}},
{{15341782033627785554ull, 310796202507101ull}},
{{17168153624320636240ull, 497273924011362ull}},
{{6355825269972688346ull, 397819139209090ull}},
{{5084660215978150676ull, 318255311367272ull}},
{{11824805160306951406ull, 509208498187635ull}},
{{9459844128245561124ull, 407366798550108ull}},
{{14946572932080269546ull, 325893438840086ull}},
{{16535819061844610627ull, 521429502144138ull}},
{{2160608805249957532ull, 417143601715311ull}},
{{16485882303167607318ull, 333714881372248ull}},
{{4241318796616709770ull, 533943810195598ull}},
{{10771752666777188463ull, 427155048156478ull}},
{{15996099762905571416ull, 341724038525182ull}},
{{10836364361681272974ull, 546758461640292ull}},
{{1290393859861197733ull, 437406769312234ull}},
{{4721663902630868509ull, 349925415449787ull}},
{{11244011058951299938ull, 559880664719659ull}},
{{12684557661902950274ull, 447904531775727ull}},
{{2768948500038539572ull, 358323625420582ull}},
{{13283205244256562627ull, 286658900336465ull}},
{{2806384317100948588ull, 458654240538345ull}},
{{2245107453680758870ull, 366923392430676ull}},
{{16553481221912248389ull, 293538713944540ull}},
{{8038825881350045807ull, 469661942311265ull}},
{{6431060705080036645ull, 375729553849012ull}},
{{16212895008289760286ull, 300583643079209ull}},
{{14872585569037885488ull, 480933828926735ull}},
{{11898068455230308390ull, 384747063141388ull}},
{{16897152393668067358ull, 307797650513110ull}},
{{8588699756159356158ull, 492476240820977ull}},
{{17939006249153215896ull, 393980992656781ull}},
{{10661856184580662393ull, 315184794125425ull}},
{{17058969895329059830ull, 504295670600680ull}},
{{13647175916263247864ull, 403436536480544ull}},
{{14607089547752508614ull, 322749229184435ull}},
{{4924599202694462167ull, 516398766695097ull}},
{{15007725806381300703ull, 413119013356077ull}},
{{4627483015621219916ull, 330495210684862ull}},
{{11093321639735862189ull, 528792337095779ull}},
{{12564006126530600074ull, 423033869676623ull}},
{{17429902530708300706ull, 338427095741298ull}},
{{5751751160681819190ull, 541483353186078ull}},
{{11980098558029275998ull, 433186682548862ull}},
{{2205381216939600152ull, 346549346039090ull}},
{{3528609947103360244ull, 554478953662544ull}},
{{6512236772424598518ull, 443583162930035ull}},
{{5209789417939678814ull, 354866530344028ull}},
{{11546529163835563698ull, 283893224275222ull}},
{{3717051403169260624ull, 454229158840356ull}},
{{17731036381503049792ull, 363383327072284ull}},
{{17874177919944350157ull, 290706661657827ull}},
{{13841289412943318958ull, 465130658652524ull}},
{{14762380345096565490ull, 372104526922019ull}},
{{15499253090819162715ull, 297683621537615ull}},
{{6352060871601108728ull, 476293794460185ull}},
{{5081648697280886982ull, 381035035568148ull}},
{{11444016587308530232ull, 304828028454518ull}},
{{14621077724951738048ull, 487724845527229ull}},
{{15386210994703300762ull, 390179876421783ull}},
{{1240922351536909640ull, 312143901137427ull}},
{{5674824577200965747ull, 499430241819883ull}},
{{11918557291244593244ull, 399544193455906ull}},
{{5845497018253764272ull, 319635354764725ull}},
{{9352795229206022835ull, 511416567623560ull}},
{{7482236183364818268ull, 409133254098848ull}},
{{13364486576175675261ull, 327306603279078ull}},
{{17693829707139170094ull, 523690565246525ull}},
{{14155063765711336075ull, 418952452197220ull}},
{{11324051012569068860ull, 335161961757776ull}},
{{10739783990626689530ull, 536259138812442ull}},
{{1213129563017530978ull, 429007311049954ull}},
{{4659852465155935105ull, 343205848839963ull}},
{{3766415129507585846ull, 549129358143941ull}},
{{17770527362573709969ull, 439303486515152ull}},
{{6837724260575147329ull, 351442789212122ull}},
{{14629707631662146050ull, 562308462739395ull}},
{{11703766105329716840ull, 449846770191516ull}},
{{5673664069521863148ull, 359877416153213ull}},
{{11917628885101311165ull, 287901932922570ull}},
{{621462142452546248ull, 460643092676113ull}},
{{7875867343445857645ull, 368514474140890ull}},
{{6300693874756686116ull, 294811579312712ull}},
{{13770459014352608109ull, 471698526900339ull}},
{{14705716026223996810ull, 377358821520271ull}},
{{8075224006237287125ull, 301887057216217ull}},
{{16609707224721569723ull, 483019291545947ull}},
{{5909068150293435132ull, 386415433236758ull}},
{{12105952149718568752ull, 309132346589406ull}},
{{11990825810065889357ull, 494611754543050ull}},
{{9592660648052711486ull, 395689403634440ull}},
{{7674128518442169188ull, 316551522907552ull}},
{{15967954444249381025ull, 506482436652083ull}},
{{1706317111173773850ull, 405185949321667ull}},
{{12433100133164750050ull, 324148759457333ull}},
{{16203611398321689757ull, 518638015131733ull}},
{{1894842674431620836ull, 414910412105387ull}},
{{12583920583771027638ull, 331928329684309ull}},
{{9066226489807913251ull, 531085327494895ull}},
{{7252981191846330601ull, 424868261995916ull}},
{{2113036138735154157ull, 339894609596733ull}},
{{18138253080943887945ull, 543831375354772ull}},
{{7131904835271289710ull, 435065100283818ull}},
{{13084221497700852414ull, 348052080227054ull}},
{{9866707952095632893ull, 556883328363287ull}},
{{514668732192685668ull, 445506662690630ull}},
{{411734985754148534ull, 356405330152504ull}},
{{4018736803345229150ull, 285124264122003ull}},
{{2740630070610456318ull, 456198822595205ull}},
{{2192504056488365054ull, 364959058076164ull}},
{{5443352059932602366ull, 291967246460931ull}},
{{1330665666408343140ull, 467147594337490ull}},
{{1064532533126674512ull, 373718075469992ull}},
{{11919672470727070579ull, 298974460375993ull}},
{{15382127138421402604ull, 478359136601589ull}},
{{15995050525479032406ull, 382687309281271ull}},
{{9106691605641315602ull, 306149847425017ull}},
{{18260055383768015286ull, 489839755880027ull}},
{{7229346677530591582ull, 391871804704022ull}},
{{16851523786250204235ull, 313497443763217ull}},
{{12205042799032685484ull, 501595910021148ull}},
{{17142731868709969034ull, 401276728016918ull}},
{{2646139050742244257ull, 321021382413535ull}},
{{4233822481187590812ull, 513634211861656ull}},
{{18144453243917713942ull, 410907369489324ull}},
{{18204911409876081477ull, 328725895591459ull}},
{{18059811811575999394ull, 525961432946335ull}},
{{14447849449260799515ull, 420769146357068ull}},
{{490233115182908642ull, 336615317085655ull}},
{{784372984292653828ull, 538584507337048ull}},
{{8006196016917943708ull, 430867605869638ull}},
{{13783654443018175613ull, 344694084695710ull}},
{{3607103035119529365ull, 551510535513137ull}},
{{13953728872321354462ull, 441208428410509ull}},
{{14852331912598993892ull, 352966742728407ull}},
{{4503167900595374467ull, 282373394182726ull}},
{{18273115085178330118ull, 451797430692361ull}},
{{10929143253400753771ull, 361437944553889ull}},
{{12432663417462513340ull, 289150355643111ull}},
{{12513563838456200698ull, 462640569028978ull}},
{{17389548700248781204ull, 370112455223182ull}},
{{6532941330715204317ull, 296089964178546ull}},
{{3074008499660506261ull, 473743942685674ull}},
{{6148555614470315332ull, 378995154148539ull}},
{{8608193306318162589ull, 303196123318831ull}},
{{6394411660625239496ull, 485113797310130ull}},
{{5115529328500191597ull, 388091037848104ull}},
{{7781772277542063600ull, 310472830278483ull}},
{{8761486829325391438ull, 496756528445573ull}},
{{14387887092944133796ull, 397405222756458ull}},
{{442263230129576067ull, 317924178205167ull}},
{{4396969982949232031ull, 508678685128267ull}},
{{14585622430585116595ull, 406942948102613ull}},
{{600451500242362306ull, 325554358482091ull}},
{{12028768844613510660ull, 520886973571345ull}},
{{9623015075690808528ull, 416709578857076ull}},
{{4009063245810736499ull, 333367663085661ull}},
{{17482547637522909368ull, 533388260937057ull}},
{{6607340480534506848ull, 426710608749646ull}},
{{1596523569685695155ull, 341368486999717ull}},
{{6243786526239022571ull, 546189579199547ull}},
{{16063075665216949027ull, 436951663359637ull}},
{{5471762902689738575ull, 349561330687710ull}},
{{8754820644303581720ull, 559298129100336ull}},
{{3314507700700955053ull, 447438503280269ull}},
{{6340954975302674365ull, 357950802624215ull}},
{{5072763980242139492ull, 286360642099372ull}},
{{11805771183129333511ull, 458177027358995ull}},
{{9444616946503466809ull, 366541621887196ull}},
{{3866344742460863124ull, 293233297509757ull}},
{{9875500402679291321ull, 469173276015611ull}},
{{4211051507401522734ull, 375338620812489ull}},
{{7058190020663128510ull, 300270896649991ull}},
{{3914406403577184970ull, 480433434639986ull}},
{{17888920381829389269ull, 384346747711988ull}},
{{3243089861237780445ull, 307477398169591ull}},
{{16256990222206179682ull, 491963837071345ull}},
{{13005592177764943746ull, 393571069657076ull}},
{{6715124927470044673ull, 314856855725661ull}},
{{3365502254468250831ull, 503770969161058ull}},
{{10071099433058421311ull, 403016775328846ull}},
{{4367530731704826726ull, 322413420263077ull}},
{{10677397985469633085ull, 515861472420923ull}},
{{15920616017859527114ull, 412689177936738ull}},
{{1668446370061890721ull, 330151342349391ull}},
{{13737560636324756124ull, 528242147759025ull}},
{{10990048509059804899ull, 422593718207220ull}},
{{8792038807247843919ull, 338074974565776ull}},
{{6688564462112729625ull, 540919959305242ull}},
{{16418898013915914669ull, 432735967444193ull}},
{{2067071966907000766ull, 346188773955355ull}},
{{3307315147051201226ull, 553902038328568ull}},
{{10024549747124781627ull, 443121630662854ull}},
{{11708988612441735624ull, 354497304530283ull}},
{{16745888519437209146ull, 283597843624226ull}},
{{967979927906162371ull, 453756549798763ull}},
{{8153081571808750543ull, 363005239839010ull}},
{{6522465257447000435ull, 290404191871208ull}},
{{6746595597173290372ull, 464646706993933ull}},
{{12775974107222452944ull, 371717365595146ull}},
{{6531430471036052032ull, 297373892476117ull}},
{{14139637568399593575ull, 475798227961787ull}},
{{3933012425235854213ull, 380638582369430ull}},
{{3146409940188683371ull, 304510865895544ull}},
{{12412953533785714040ull, 487217385432870ull}},
{{9930362827028571232ull, 389773908346296ull}},
{{4254941446880946662ull, 311819126677037ull}},
{{10497255129751424983ull, 498910602683259ull}},
{{12087152918543050309ull, 399128482146607ull}},
{{2291024705350619601ull, 319302785717286ull}},
{{14733685972786722331ull, 510884457147657ull}},
{{4408251148745557219ull, 408707565718126ull}},
{{18283996177964087068ull, 326966052574500ull}},
{{10807649811032987692ull, 523145684119201ull}},
{{4956771034084479831ull, 418516547295361ull}},
{{276068012525673541ull, 334813237836289ull}},
{{7820406449524898313ull, 535701180538062ull}},
{{17324371603845649620ull, 428560944430449ull}},
{{17548846097818430019ull, 342848755544359ull}},
{{17010107312283757061ull, 548558008870975ull}},
{{13608085849827005649ull, 438846407096780ull}},
{{10886468679861604519ull, 351077125677424ull}},
{{6350303443552836261ull, 561723401083879ull}},
{{8769591569584179332ull, 449378720867103ull}},
{{14394370885151164112ull, 359502976693682ull}},
{{4136799078637110643ull, 287602381354946ull}},
{{17686924970045107998ull, 460163810167913ull}},
{{3081493531810355429ull, 368131048134331ull}},
{{17222590084415925636ull, 294504838507464ull}},
{{16488097690839750048ull, 471207741611943ull}},
{{2122431708446069069ull, 376966193289555ull}},
{{1697945366756855255ull, 301572954631644ull}},
{{10095410216294789055ull, 482516727410630ull}},
{{8076328173035831244ull, 386013381928504ull}},
{{10150411353170575318ull, 308810705542803ull}},
{{12551309350331010186ull, 494097128868485ull}},
{{10041047480264808149ull, 395277703094788ull}},
{{15411535613695667165ull, 316222162475830ull}},
{{6211712908203515849ull, 505955459961329ull}},
{{8658719141304723002ull, 404764367969063ull}},
{{14305672942527599048ull, 323811494375250ull}},
{{4442332634334606861ull, 518098391000401ull}},
{{18311261366435326781ull, 414478712800320ull}},
{{14649009093148261425ull, 331582970240256ull}},
{{16059716919553397634ull, 530532752384410ull}},
{{12847773535642718107ull, 424426201907528ull}},
{{17656916457997995132ull, 339540961526022ull}},
{{13493671073829150919ull, 543265538441636ull}},
{{7105588044321410412ull, 434612430753309ull}},
{{9373819250199038652ull, 347689944602647ull}},
{{240715541350820551ull, 556303911364236ull}},
{{14949967692048297734ull, 445043129091388ull}},
{{891927709412907217ull, 356034503273111ull}},
{{15470937426497967066ull, 284827602618488ull}},
{{2617406993945285367ull, 455724164189582ull}},
{{13161972039381959263ull, 364579331351665ull}},
{{10529577631505567411ull, 291663465081332ull}},
{{2089928951441266565ull, 466661544130132ull}},
{{12739989605378744221ull, 373329235304105ull}},
{{10191991684302995377ull, 298663388243284ull}},
{{5239140250659061634ull, 477861421189255ull}},
{{4191312200527249307ull, 382289136951404ull}},
{{7042398575163709769ull, 305831309561123ull}},
{{7578488905520025307ull, 489330095297797ull}},
{{17130837568641751215ull, 391464076238237ull}},
{{6325972425429580325ull, 313171260990590ull}},
{{10121555880687328521ull, 501074017584944ull}},
{{11786593519291773140ull, 400859214067955ull}},
{{9429274815433418512ull, 320687371254364ull}},
{{4018793260467738650ull, 513099794006983ull}},
{{10593732237858011566ull, 410479835205586ull}},
{{4785636975544498930ull, 328383868164469ull}},
{{15035716790355018934ull, 525414189063150ull}},
{{12028573432284015147ull, 420331351250520ull}},
{{9622858745827212118ull, 336265081000416ull}},
{{8017876363839718742ull, 538024129600666ull}},
{{2724952276329864670ull, 430419303680533ull}},
{{9558659450547712383ull, 344335442944426ull}},
{{7915157491392519166ull, 550936708711082ull}},
{{17400172437339746302ull, 440749366968865ull}},
{{13920137949871797042ull, 352599493575092ull}},
{{3757412730413616987ull, 282079594860074ull}},
{{13390557998145607826ull, 451327351776118ull}},
{{18091144028000306907ull, 361061881420894ull}},
{{18162264037142155849ull, 288849505136715ull}},
{{10612878385717897742ull, 462159208218745ull}},
{{8490302708574318193ull, 369727366574996ull}},
{{3102893352117544231ull, 295781893259997ull}},
{{8653978178129981094ull, 473251029215995ull}},
{{6923182542503984875ull, 378600823372796ull}},
{{1849197219261277577ull, 302880658698237ull}},
{{6648064365559954446ull, 484609053917179ull}},
{{9007800307189873880ull, 387687243133743ull}},
{{14584937875235719750ull, 310149794506994ull}},
{{12267854156151420631ull, 496239671211191ull}},
{{6124934510179226182ull, 396991736968953ull}},
{{12278645237627201592ull, 317593389575162ull}},
{{4888437121235881254ull, 508149423320260ull}},
{{3910749696988705003ull, 406519538656208ull}},
{{10507297387074784649ull, 325215630924966ull}},
{{9432978189835834792ull, 520345009479946ull}},
{{3857033737126757510ull, 416276007583957ull}},
{{14153673433927136978ull, 333020806067165ull}},
{{4199133420573867549ull, 532833289707465ull}},
{{3359306736459094039ull, 426266631765972ull}},
{{13755491833393006201ull, 341013305412777ull}},
{{7251391674461168629ull, 545621288660444ull}},
{{9490462154310845226ull, 436497030928355ull}},
{{7592369723448676181ull, 349197624742684ull}},
{{1079745113292150920ull, 558716199588295ull}},
{{863796090633720736ull, 446972959670636ull}},
{{15448432131474617881ull, 357578367736508ull}},
{{1290699260953963335ull, 286062694189207ull}},
{{5754467632268251660ull, 457700310702731ull}},
{{914225291072691005ull, 366160248562185ull}},
{{731380232858152804ull, 292928198849748ull}},
{{15927603631540685779ull, 468685118159596ull}},
{{9052734090490638300ull, 374948094527677ull}},
{{18310233716618241609ull, 299958475622141ull}},
{{3470932243395814313ull, 479933560995427ull}},
{{13844792238942382420ull, 383946848796341ull}},
{{7386484976411995613ull, 307157479037073ull}},
{{8129027147517282657ull, 491451966459317ull}},
{{17571268162239557095ull, 393161573167453ull}},
{{2988968085565914707ull, 314529258533963ull}},
{{1093000122163553208ull, 503246813654341ull}},
{{15631795356698483859ull, 402597450923472ull}},
{{5126738655874966440ull, 322077960738778ull}},
{{4513433034658035982ull, 515324737182045ull}},
{{3610746427726428785ull, 412259789745636ull}},
{{17645992401148784321ull, 329807831796508ull}},
{{6097494953386592975ull, 527692530874414ull}},
{{8567344777451184703ull, 422154024699531ull}},
{{3164527007219037439ull, 337723219759625ull}},
{{5063243211550459903ull, 540357151615400ull}},
{{4050594569240367922ull, 432285721292320ull}},
{{3240475655392294338ull, 345828577033856ull}},
{{16252807492853401910ull, 553325723254169ull}},
{{16691594809024631851ull, 442660578603335ull}},
{{13353275847219705481ull, 354128462882668ull}},
{{18061318307259585031ull, 283302770306134ull}},
{{17830062847389605080ull, 453284432489815ull}},
{{14264050277911684064ull, 362627545991852ull}},
{{4032542592845526605ull, 290102036793482ull}},
{{10141416963294752891ull, 464163258869571ull}},
{{4423784755893891990ull, 371330607095657ull}},
{{14607074248940844561ull, 297064485676525ull}},
{{4924574724595799682ull, 475303177082441ull}},
{{250310964934729422ull, 380242541665953ull}},
{{7578946401431604184ull, 304194033332762ull}},
{{15815663057032477018ull, 486710453332419ull}},
{{16341879260367891938ull, 389368362665935ull}},
{{13073503408294313550ull, 311494690132748ull}},
{{17228256638528991357ull, 498391504212397ull}},
{{6403907681339372439ull, 398713203369918ull}},
{{12501823774555318598ull, 318970562695934ull}},
{{8934871595062778787ull, 510352900313495ull}},
{{7147897276050223030ull, 408282320250796ull}},
{{2028969006098268100ull, 326625856200637ull}},
{{6935699224499139284ull, 522601369921019ull}},
{{9237908194341221750ull, 418081095936815ull}},
{{7390326555472977400ull, 334464876749452ull}},
{{15513871303498674164ull, 535143802799123ull}},
{{1343050598573208361ull, 428115042239299ull}},
{{4763789293600477012ull, 342492033791439ull}},
{{15000760499244583866ull, 547987254066302ull}},
{{4621910769911846446ull, 438389803253042ull}},
{{14765575060155208127ull, 350711842602433ull}},
{{1488827207796871064ull, 561138948163894ull}},
{{4880410580979407174ull, 448911158531115ull}},
{{3904328464783525739ull, 359128926824892ull}},
{{14191509216052551561ull, 287303141459913ull}},
{{570321857232620558ull, 459685026335862ull}},
{{11524303930011827416ull, 367748021068689ull}},
{{12908791958751372256ull, 294198416854951ull}},
{{13275369504518374964ull, 470717466967922ull}},
{{3241597974130879324ull, 376573973574338ull}},
{{9971976008788524106ull, 301259178859470ull}},
{{15955161614061638570ull, 482014686175152ull}},
{{5385431661765490209ull, 385611748940122ull}},
{{15376391773638123137ull, 308489399152097ull}},
{{9844831578853355726ull, 493583038643356ull}},
{{4186516448340774258ull, 394866430914685ull}},
{{3349213158672619406ull, 315893144731748ull}},
{{1669392239134280727ull, 505429031570797ull}},
{{12403560235533155551ull, 404343225256637ull}},
{{2544150558942703794ull, 323474580205310ull}},
{{4070640894308326071ull, 517559328328496ull}},
{{18013907974414302150ull, 414047462662796ull}},
{{10721777564789531397ull, 331237970130237ull}},
{{2397448844695608942ull, 529980752208380ull}},
{{1917959075756487153ull, 423984601766704ull}},
{{5223716075347100046ull, 339187681413363ull}},
{{4668596905813449750ull, 542700290261381ull}},
{{45528709908849477ull, 434160232209105ull}},
{{36422967927079582ull, 347328185767284ull}},
{{7436974378167147977ull, 555725097227654ull}},
{{9638928317275628705ull, 444580077782123ull}},
{{15089840283304323610ull, 355664062225698ull}},
{{1003825782417727918ull, 284531249780559ull}},
{{8984818881352185316ull, 455249999648894ull}},
{{10877203919823658576ull, 364199999719115ull}},
{{8701763135858926861ull, 291359999775292ull}},
{{17612169832116193301ull, 466175999640467ull}},
{{6711038236209133994ull, 372940799712374ull}},
{{9058179403709217518ull, 298352639769899ull}},
{{3425040601709017060ull, 477364223631839ull}},
{{6429381296109123971ull, 381891378905471ull}},
{{1454156222145388854ull, 305513103124377ull}},
{{6015998770174532489ull, 488820964999003ull}},
{{12191496645623446638ull, 391056771999202ull}},
{{2374499687014936664ull, 312845417599362ull}},
{{7488548313965808985ull, 500552668158979ull}},
{{9680187465914557511ull, 400442134527183ull}},
{{15122847602215466655ull, 320353707621746ull}},
{{16817858534060926003ull, 512565932194794ull}},
{{17143635641990651125ull, 410052745755835ull}},
{{13714908513592520900ull, 328042196604668ull}},
{{18254504807006123117ull, 524867514567469ull}},
{{18292952660346808817ull, 419894011653975ull}},
{{14634362128277447053ull, 335915209323180ull}},
{{4968235331534363670ull, 537464334917089ull}},
{{7663937079969401259ull, 429971467933671ull}},
{{2441800849233610684ull, 343977174346937ull}},
{{7596230173515687418ull, 550363478955099ull}},
{{9766332953554460257ull, 440290783164079ull}},
{{11502415177585478529ull, 352232626531263ull}},
{{16580629771552203469ull, 281786101225010ull}},
{{8082263560773973935ull, 450857761960017ull}},
{{17533857292844910118ull, 360686209568013ull}},
{{2959039390050197124ull, 288548967654411ull}},
{{15802509468306046369ull, 461678348247057ull}},
{{5263309945161016449ull, 369342678597646ull}},
{{521299141386902836ull, 295474142878117ull}},
{{4523427440960954861ull, 472758628604987ull}},
{{14686788396994494858ull, 378206902883989ull}},
{{15438779532337506209ull, 302565522307191ull}},
{{17323349622256189289ull, 484104835691506ull}},
{{10169330883063041108ull, 387283868553205ull}},
{{8135464706450432886ull, 309827094842564ull}},
{{1948697086094961649ull, 495723351748103ull}},
{{8937655298359789965ull, 396578681398482ull}},
{{18218170682913562942ull, 317262945118785ull}},
{{10702329018952149091ull, 507620712190057ull}},
{{1183165585677898626ull, 406096569752046ull}},
{{15703927727509960194ull, 324877255801636ull}},
{{17747586734532115664ull, 519803609282618ull}},
{{3130022943399961561ull, 415842887426095ull}},
{{2504018354719969249ull, 332674309940876ull}},
{{15074475811777681768ull, 532278895905401ull}},
{{8370231834680235091ull, 425823116724321ull}},
{{3006836653002277750ull, 340658493379457ull}},
{{8500287459545554723ull, 545053589407131ull}},
{{3110881152894533455ull, 436042871525705ull}},
{{2488704922315626764ull, 348834297220564ull}},
{{11360625505188823469ull, 558134875552902ull}},
{{1709802774667238129ull, 446507900442322ull}},
{{12435888663959521473ull, 357206320353857ull}},
{{2570013301683796532ull, 285765056283086ull}},
{{15180067726919805421ull, 457224090052937ull}},
{{4765356552052023690ull, 365779272042350ull}},
{{3812285241641618952ull, 292623417633880ull}},
{{6099656386626590323ull, 468197468214208ull}},
{{12258422738785092905ull, 374557974571366ull}},
{{6117389376286164001ull, 299646379657093ull}},
{{6098474187315952078ull, 479434207451349ull}},
{{8568128164594671986ull, 383547365961079ull}},
{{10543851346417647912ull, 306837892768863ull}},
{{13180813339526326336ull, 490940628430181ull}},
{{6855301856879150745ull, 392752502744145ull}},
{{5484241485503320596ull, 314202002195316ull}},
{{1396088747321492308ull, 502723203512506ull}},
{{15874266256824835139ull, 402178562810004ull}},
{{16388761820201778434ull, 321742850248003ull}},
{{4085926023871383556ull, 514788560396806ull}},
{{18026136078064748137ull, 411830848317444ull}},
{{18110257677193708833ull, 329464678653955ull}},
{{10529668209800382517ull, 527143485846329ull}},
{{12113083382582216337ull, 421714788677063ull}},
{{17069164335549593716ull, 337371830941650ull}},
{{8863918863169798329ull, 539794929506641ull}},
{{3401786275793928340ull, 431835943605313ull}},
{{10100126650118963318ull, 345468754884250ull}},
{{16160202640190341310ull, 552750007814800ull}},
{{12928162112152273048ull, 442200006251840ull}},
{{10342529689721818438ull, 353760005001472ull}},
{{895326122293634104ull, 283008004001178ull}},
{{16189917054637455859ull, 452812806401884ull}},
{{16641282458451875011ull, 362250245121507ull}},
{{5934328337277679362ull, 289800196097206ull}},
{{2116227710160466333ull, 463680313755530ull}},
{{1692982168128373066ull, 370944251004424ull}},
{{5043734549244608776ull, 296755400803539ull}},
{{15448672908275194689ull, 474808641285662ull}},
{{4980240697136335104ull, 379846913028530ull}},
{{3984192557709068083ull, 303877530422824ull}},
{{13753405721818329580ull, 486204048676518ull}},
{{18381422206938484310ull, 388963238941214ull}},
{{18394486580292697771ull, 311170591152971ull}},
{{3605736825274944172ull, 497872945844755ull}},
{{2884589460219955338ull, 398298356675804ull}},
{{5997020382917874593ull, 318638685340643ull}},
{{5905883797926689026ull, 509821896545029ull}},
{{8414055853083261544ull, 407857517236023ull}},
{{14109942311950429882ull, 326286013788818ull}},
{{439814810669225872ull, 522057622062110ull}},
{{351851848535380697ull, 417646097649688ull}},
{{7660179108312125204ull, 334116878119750ull}},
{{12256286573299400327ull, 534587004991600ull}},
{{9805029258639520261ull, 427669603993280ull}},
{{7844023406911616209ull, 342135683194624ull}},
{{1482391006832854965ull, 547417093111399ull}},
{{4875261620208194295ull, 437933674489119ull}},
{{7589558110908465759ull, 350346939591295ull}},
{{12143292977453545215ull, 560555103346072ull}},
{{2335936752479015526ull, 448444082676858ull}},
{{9247447031467033067ull, 358755266141486ull}},
{{3708608810431716130ull, 287004212913189ull}},
{{13312471726174566455ull, 459206740661102ull}},
{{3271279751455832517ull, 367365392528882ull}},
{{13685070245390396983ull, 293892314023105ull}},
{{3449368318915083558ull, 470227702436969ull}},
{{6448843469873977169ull, 376182161949575ull}},
{{5159074775899181735ull, 300945729559660ull}},
{{8254519641438690777ull, 481513167295456ull}},
{{2914266898409042298ull, 385210533836365ull}},
{{2331413518727233838ull, 308168427069092ull}},
{{7419610444705484465ull, 493069483310547ull}},
{{17003734799990118541ull, 394455586648437ull}},
{{6224290210508274187ull, 315564469318750ull}},
{{9958864336813238699ull, 504903150910000ull}},
{{7967091469450590959ull, 403922520728000ull}},
{{6373673175560472767ull, 323138016582400ull}},
{{10197877080896756428ull, 517020826531840ull}},
{{8158301664717405142ull, 413616661225472ull}},
{{17594687775999655083ull, 330893328980377ull}},
{{13394105182631806841ull, 529429326368604ull}},
{{14404632960847355796ull, 423543461094883ull}},
{{455659924452153667ull, 338834768875907ull}},
{{4418404693865356190ull, 542135630201451ull}},
{{18292119014059926245ull, 433708504161160ull}},
{{14633695211247940996ull, 346966803328928ull}},
{{1277819449545243655ull, 555146885326286ull}},
{{15779650818603836216ull, 444117508261028ull}},
{{1555674210657338003ull, 355294006608823ull}},
{{8623236998009691049ull, 284235205287058ull}},
{{10107830382073595355ull, 454776328459293ull}},
{{15464961935142696931ull, 363821062767434ull}},
{{16061318362856067868ull, 291056850213947ull}},
{{10940714121602067296ull, 465690960342316ull}},
{{5063222482539743513ull, 372552768273853ull}},
{{11429275615515615457ull, 298042214619082ull}},
{{3529445725857343439ull, 476867543390532ull}},
{{13891603024911605720ull, 381494034712425ull}},
{{11113282419929284576ull, 305195227769940ull}},
{{17781251871886855322ull, 488312364431904ull}},
{{17914350312251394581ull, 390649891545523ull}},
{{3263433805575384695ull, 312519913236419ull}},
{{12600191718404436159ull, 500031861178270ull}},
{{10080153374723548927ull, 400025488942616ull}},
{{4374773885036928818ull, 320020391154093ull}},
{{3310289401317175786ull, 512032625846549ull}},
{{6337580335795650952ull, 409626100677239ull}},
{{8759413083378431085ull, 327700880541791ull}},
{{6636363303921669089ull, 524321408866866ull}},
{{1619741828395424948ull, 419457127093493ull}},
{{8674491092200160605ull, 335565701674794ull}},
{{2811139303294525999ull, 536905122679671ull}},
{{17006306701603262092ull, 429524098143736ull}},
{{9915696546540699350ull, 343619278514989ull}},
{{4797068030239387991ull, 549790845623983ull}},
{{11216352053675331039ull, 439832676499186ull}},
{{5283732828198354508ull, 351866141199349ull}},
{{7916335077300593929ull, 281492912959479ull}},
{{1598089679455219318ull, 450388660735167ull}},
{{12346518187789906424ull, 360310928588133ull}},
{{17255912179715745785ull, 288248742870506ull}},
{{1784017784351820994ull, 461197988592811ull}},
{{16184609486449098088ull, 368958390874248ull}},
{{1879641144933547501ull, 295166712699399ull}},
{{10386123461377496648ull, 472266740319038ull}},
{{15687596398585817965ull, 377813392255230ull}},
{{12550077118868654372ull, 302250713804184ull}},
{{9012076945964116025ull, 483601142086695ull}},
{{7209661556771292820ull, 386880913669356ull}},
{{2078380430675123933ull, 309504730935485ull}},
{{3325408689080198293ull, 495207569496776ull}},
{{17417722210231799927ull, 396166055597420ull}},
{{13934177768185439941ull, 316932844477936ull}},
{{14915986799612883260ull, 507092551164698ull}},
{{864742995464575638ull, 405674040931759ull}},
{{4381143211113570834ull, 324539232745407ull}},
{{10699177952523623658ull, 519262772392651ull}},
{{4869993547276988603ull, 415410217914121ull}},
{{206646023079680559ull, 332328174331297ull}},
{{4019982451669399218ull, 531725078930075ull}},
{{3215985961335519374ull, 425380063144060ull}},
{{2572788769068415499ull, 340304050515248ull}},
{{427113215767554476ull, 544486480824397ull}},
{{11409737016839774550ull, 435589184659517ull}},
{{1749091983987998994ull, 348471347727614ull}},
{{10177244803864619036ull, 557554156364182ull}},
{{763098213607874583ull, 446043325091346ull}},
{{15367873829853940959ull, 356834660073076ull}},
{{8604950249141242444ull, 285467728058461ull}},
{{6389222769142167264ull, 456748364893538ull}},
{{12490075844797554457ull, 365398691914830ull}},
{{9992060675838043566ull, 292318953531864ull}},
{{4919250637115138736ull, 467710325650983ull}},
{{11314098139175931635ull, 374168260520786ull}},
{{5361929696598834985ull, 299334608416629ull}},
{{15957785144041956622ull, 478935373466606ull}},
{{9076879300491654975ull, 383148298773285ull}},
{{7261503440393323980ull, 306518639018628ull}},
{{7929056689887408044ull, 490429822429805ull}},
{{6343245351909926435ull, 392343857943844ull}},
{{8763945096269851471ull, 313875086355075ull}},
{{14022312154031762355ull, 502200138168120ull}},
{{11217849723225409884ull, 401760110534496ull}},
{{5284930963838417584ull, 321408088427597ull}},
{{12145238356883378457ull, 514252941484155ull}},
{{9716190685506702766ull, 411402353187324ull}},
{{11462301363147272536ull, 329121882549859ull}},
{{7271635736809905088ull, 526595012079775ull}},
{{5817308589447924070ull, 421276009663820ull}},
{{4653846871558339256ull, 337020807731056ull}},
{{67457365009522164ull, 539233292369690ull}},
{{53965892007617731ull, 431386633895752ull}},
{{11111219157831825154ull, 345109307116601ull}},
{{10399253023047099600ull, 552174891386562ull}},
{{940704788953859034ull, 441739913109250ull}},
{{752563831163087227ull, 353391930487400ull}},
{{602051064930469781ull, 282713544389920ull}},
{{963281703888751651ull, 452341671023872ull}},
{{11838671807336732290ull, 361873336819097ull}},
{{2092239816385565186ull, 289498669455278ull}},
{{18104978965184545590ull, 463197871128444ull}},
{{18173331986889546795ull, 370558296902755ull}},
{{14538665589511637436ull, 296446637522204ull}},
{{12193818498992888928ull, 474314620035527ull}},
{{2376357169710490496ull, 379451696028422ull}},
{{12969132179994123366ull, 303561356822737ull}},
{{5993216229022956094ull, 485698170916380ull}},
{{4794572983218364875ull, 388558536733104ull}},
{{7525007201316602223ull, 310846829386483ull}},
{{8350662707364653234ull, 497354927018373ull}},
{{14059227795375543233ull, 397883941614698ull}},
{{179335792074703617ull, 318307153291759ull}},
{{7665634896803346434ull, 509291445266814ull}},
{{9821856732184587470ull, 407433156213451ull}},
{{4168136571005759653ull, 325946524970761ull}},
{{17737064957834946414ull, 521514439953217ull}},
{{6810954336784136485ull, 417211551962574ull}},
{{9138112284169219511ull, 333769241570059ull}},
{{3552933210445020249ull, 534030786512095ull}},
{{2842346568356016199ull, 427224629209676ull}},
{{17031272513652454252ull, 341779703367740ull}},
{{8803291948134375187ull, 546847525388385ull}},
{{7042633558507500150ull, 437478020310708ull}},
{{13012804476289820766ull, 349982416248566ull}},
{{13441789532579892579ull, 559971865997706ull}},
{{7064082811322003740ull, 447977492798165ull}},
{{5651266249057602992ull, 358381994238532ull}},
{{15589059443471813363ull, 286705595390825ull}},
{{6495751035845349765ull, 458728952625321ull}},
{{1507252013934369489ull, 366983162100257ull}},
{{12273848055373226561ull, 293586529680205ull}},
{{1191412814887610881ull, 469738447488329ull}},
{{4642479066651999028ull, 375790757990663ull}},
{{11092680882805419869ull, 300632606392530ull}},
{{17748289412488671790ull, 481012170228048ull}},
{{3130585085765206463ull, 384809736182439ull}},
{{6193816883354075493ull, 307847788945951ull}},
{{2531409383882700143ull, 492556462313522ull}},
{{13093173951331891084ull, 394045169850817ull}},
{{3095841531581692221ull, 315236135880654ull}},
{{12332044080014528200ull, 504377817409046ull}},
{{6176286449269712237ull, 403502253927237ull}},
{{16009075603641500759ull, 322801803141789ull}},
{{14546474521600670245ull, 516482885026863ull}},
{{569133173054805226ull, 413186308021491ull}},
{{15212701797411485474ull, 330549046417192ull}},
{{9582927616890735465ull, 528878474267508ull}},
{{15045039722996409018ull, 423102779414006ull}},
{{8346682963655216891ull, 338482223531205ull}},
{{13354692741848347027ull, 541571557649928ull}},
{{18062451822962498268ull, 433257246119942ull}},
{{7071263828886177968ull, 346605796895954ull}},
{{245975681992153779ull, 554569275033527ull}},
{{11264826989819453993ull, 443655420026821ull}},
{{5322512777113652871ull, 354924336021457ull}},
{{15326056665916653266ull, 283939468817165ull}},
{{6074946591757093610ull, 454303150107465ull}},
{{4859957273405674888ull, 363442520085972ull}},
{{14956012262950270880ull, 290754016068777ull}},
{{9172224361752792115ull, 465206425710044ull}},
{{11027128304144144015ull, 372165140568035ull}},
{{8821702643315315212ull, 297732112454428ull}},
{{10425375414562594017ull, 476371379927085ull}},
{{8340300331650075213ull, 381097103941668ull}},
{{14050937894803880817ull, 304877683153334ull}},
{{11413454187460478338ull, 487804293045335ull}},
{{9130763349968382670ull, 390243434436268ull}},
{{14683308309458526782ull, 312194747549014ull}},
{{12425246850907911882ull, 499511596078423ull}},
{{17318895110210150152ull, 399609276862738ull}},
{{2787069643942389152ull, 319687421490191ull}},
{{15527357874533553613ull, 511499874384305ull}},
{{12421886299626842890ull, 409199899507444ull}},
{{13626857854443384635ull, 327359919605955ull}},
{{3356228493399863801ull, 523775871369529ull}},
{{6374331609461801364ull, 419020697095623ull}},
{{12478162917053261737ull, 335216557676498ull}},
{{16275711852543308457ull, 536346492282397ull}},
{{5641871852550826119ull, 429077193825918ull}},
{{11892195111524481542ull, 343261755060734ull}},
{{7959465734213439497ull, 549218808097175ull}},
{{6367572587370751598ull, 439375046477740ull}},
{{5094058069896601278ull, 351500037182192ull}},
{{11839841726576472368ull, 562400059491507ull}},
{{2093175751777357248ull, 449920047593206ull}},
{{16431935860389527091ull, 359936038074564ull}},
{{16834897503053531996ull, 287948830459651ull}},
{{1110394301692278932ull, 460718128735443ull}},
{{8267013070837643792ull, 368574502988354ull}},
{{10302959271412025356ull, 294859602390683ull}},
{{12795386019517330247ull, 471775363825093ull}},
{{17615006445097684844ull, 377420291060074ull}},
{{17781353970820058198ull, 301936232848059ull}},
{{17382119909086362148ull, 483097972556895ull}},
{{13905695927269089718ull, 386478378045516ull}},
{{7435207927073361451ull, 309182702436413ull}},
{{8206983868575467999ull, 494692323898261ull}},
{{2876238280118464076ull, 395753859118609ull}},
{{5990339438836681584ull, 316603087294887ull}},
{{13273891916880600858ull, 506564939671819ull}},
{{14308462348246391010ull, 405251951737455ull}},
{{11446769878597112808ull, 324201561389964ull}},
{{7246785361529649523ull, 518722498223943ull}},
{{13176125918707540264ull, 414977998579154ull}},
{{14230249549707942535ull, 331982398863323ull}},
{{632306391081246117ull, 531171838181318ull}},
{{7884542742348817540ull, 424937470545054ull}},
{{9996983008620964355ull, 339949976436043ull}},
{{12305823999051632645ull, 543919962297669ull}},
{{13534008013983216439ull, 435135969838135ull}},
{{10827206411186573151ull, 348108775870508ull}},
{{13634181443156606719ull, 556974041392813ull}},
{{18286042784009106021ull, 445579233114250ull}},
{{14628834227207284817ull, 356463386491400ull}},
{{11703067381765827853ull, 285170709193120ull}},
{{278163737115772950ull, 456273134708993ull}},
{{7601228619176439006ull, 365018507767194ull}},
{{9770331710083061528ull, 292014806213755ull}},
{{15632530736132898445ull, 467223689942008ull}},
{{1437978144680587786ull, 373778951953607ull}},
{{12218428959970201199ull, 299023161562885ull}},
{{1102742262242770302ull, 478437058500617ull}},
{{11950240254019947211ull, 382749646800493ull}},
{{16938889832699778415ull, 306199717440394ull}},
{{16034177288093914495ull, 489919547904631ull}},
{{9137993015733221273ull, 391935638323705ull}},
{{7310394412586577018ull, 313548510658964ull}},
{{628584615912792260ull, 501677617054343ull}},
{{7881565322214054454ull, 401342093643474ull}},
{{9994601072513153886ull, 321073674914779ull}},
{{4923315271795315249ull, 513717879863647ull}},
{{15006698661661983169ull, 410974303890917ull}},
{{4626661299845765888ull, 328779443112734ull}},
{{14781355709237046068ull, 526047108980374ull}},
{{15514433382131547178ull, 420837687184299ull}},
{{16100895520447148065ull, 336670149747439ull}},
{{14693386388489705935ull, 538672239595903ull}},
{{686662666566033778ull, 430937791676723ull}},
{{7928027762736647669ull, 344750233341378ull}},
{{8995495605636725947ull, 551600373346205ull}},
{{7196396484509380758ull, 441280298676964ull}},
{{9446466002349414929ull, 353024238941571ull}},
{{3867823987137621620ull, 282419391153257ull}},
{{9877867194162104916ull, 451871025845211ull}},
{{4212944940587773609ull, 361496820676169ull}},
{{7059704767212129211ull, 289197456540935ull}},
{{11295527627539406737ull, 462715930465496ull}},
{{5347073287289615066ull, 370172744372397ull}},
{{15345705074057423023ull, 296138195497917ull}},
{{9795732859524235544ull, 473821112796668ull}},
{{15215283917103209081ull, 379056890237334ull}},
{{15861575948424477588ull, 303245512189867ull}},
{{10621126258511522848ull, 485192819503788ull}},
{{15875598636293038925ull, 388154255603030ull}},
{{12700478909034431140ull, 310523404482424ull}},
{{9252719810229358855ull, 496837447171879ull}},
{{11091524662925397407ull, 397469957737503ull}},
{{16251917359824138572ull, 317975966190002ull}},
{{11245672516750980422ull, 508761545904004ull}},
{{12685886828142694661ull, 407009236723203ull}},
{{17527407091997976375ull, 325607389378562ull}},
{{13286456088229120908ull, 520971823005700ull}},
{{10629164870583296726ull, 416777458404560ull}},
{{8503331896466637381ull, 333421966723648ull}},
{{9915982219604709486ull, 533475146757837ull}},
{{554088146199946942ull, 426780117406270ull}},
{{443270516959957554ull, 341424093925016ull}},
{{11777279271361663056ull, 546278550280025ull}},
{{9421823417089330445ull, 437022840224020ull}},
{{7537458733671464356ull, 349618272179216ull}},
{{4681236344390522323ull, 559389235486746ull}},
{{55640260770507535ull, 447511388389397ull}},
{{11112558652842136998ull, 358009110711517ull}},
{{1511349292789888952ull, 286407288569214ull}},
{{9796856497947642969ull, 458251661710742ull}},
{{458787568874293729ull, 366601329368594ull}},
{{4056378869841345306ull, 293281063494875ull}},
{{6490206191746152490ull, 469249701591800ull}},
{{5192164953396921992ull, 375399761273440ull}},
{{4153731962717537594ull, 300319809018752ull}},
{{10335319955089970473ull, 480511694430003ull}},
{{15646953593555797025ull, 384409355544002ull}},
{{5138865245360816973ull, 307527484435202ull}},
{{11911533207319217481ull, 492043975096323ull}},
{{16907924195339194631ull, 393635180077058ull}},
{{2458292912045624735ull, 314908144061647ull}},
{{7622617474014909900ull, 503853030498635ull}},
{{6098093979211927920ull, 403082424398908ull}},
{{12257172812853362982ull, 322465939519126ull}},
{{12232778871081560125ull, 515945503230602ull}},
{{2407525467381427454ull, 412756402584482ull}},
{{12994066818130872932ull, 330205122067585ull}},
{{2343762835299845076ull, 528328195308137ull}},
{{12943056712465607030ull, 422662556246509ull}},
{{14043794184714395947ull, 338130044997207ull}},
{{7712675436575392223ull, 541008071995532ull}},
{{17238186793486044748ull, 432806457596425ull}},
{{13790549434788835798ull, 346245166077140ull}},
{{3618135021952585662ull, 553992265723425ull}},
{{2894508017562068529ull, 443193812578740ull}},
{{2315606414049654823ull, 354555050062992ull}},
{{12920531575465454828ull, 283644040050393ull}},
{{16983501706002817402ull, 453830464080629ull}},
{{17276150179544164245ull, 363064371264503ull}},
{{2752873699409600426ull, 290451497011603ull}},
{{715249104313450359ull, 464722395218565ull}},
{{572199283450760287ull, 371777916174852ull}},
{{11525805870986339199ull, 297422332939881ull}},
{{11062591764094322073ull, 475875732703810ull}},
{{8850073411275457658ull, 380700586163048ull}},
{{14458756358504186773ull, 304560468930438ull}},
{{997917285155236897ull, 487296750288702ull}},
{{11866380272349920487ull, 389837400230961ull}},
{{5803755403138026067ull, 311869920184769ull}},
{{16664706274504662353ull, 498991872295630ull}},
{{13331765019603729883ull, 399193497836504ull}},
{{14354760830424894229ull, 319354798269203ull}},
{{831524440228368828ull, 510967677230726ull}},
{{15422614811150336355ull, 408774141784580ull}},
{{12338091848920269084ull, 327019313427664ull}},
{{8672900514046699565ull, 523230901484263ull}},
{{14317018040721180298ull, 418584721187410ull}},
{{11453614432576944238ull, 334867776949928ull}},
{{14636434277381200459ull, 535788443119885ull}},
{{11709147421904960367ull, 428630754495908ull}},
{{16746015567007788940ull, 342904603596726ull}},
{{968183204019090041ull, 548647365754763ull}},
{{8153244192699092679ull, 438917892603810ull}},
{{6522595354159274143ull, 351134314083048ull}},
{{6746803751912928307ull, 561814902532877ull}},
{{16465489445756073615ull, 449451922026301ull}},
{{9483042741862948569ull, 359561537621041ull}},
{{3897085378748448532ull, 287649230096833ull}},
{{2545987791255607328ull, 460238768154933ull}},
{{9415487862488306508ull, 368191014523946ull}},
{{3843041475248734883ull, 294552811619157ull}},
{{9838215175139886137ull, 471284498590651ull}},
{{4181223325369998586ull, 377027598872521ull}},
{{18102373919263640162ull, 301622079098016ull}},
{{3138356567628451997ull, 482595326556827ull}},
{{13578731698328492567ull, 386076261245461ull}},
{{7173636543920883730ull, 308861008996369ull}},
{{409772026047682999ull, 494177614394191ull}},
{{15085212879805787692ull, 395342091515352ull}},
{{4689472674360809507ull, 316273673212282ull}},
{{11192505093719205535ull, 506037877139651ull}},
{{5264655260233454104ull, 404830301711721ull}},
{{522375393444852960ull, 323864241369377ull}},
{{4525149444253675060ull, 518182786191003ull}},
{{10998817184886760694ull, 414546228952802ull}},
{{1420356118425587909ull, 331636983162242ull}},
{{5961918604222850978ull, 530619173059587ull}},
{{15837581327604011752ull, 424495338447669ull}},
{{16359413876825119724ull, 339596270758135ull}},
{{7728318129210639943ull, 543354033213017ull}},
{{17250700947594242924ull, 434683226570413ull}},
{{2732514313849663370ull, 347746581256331ull}},
{{15440069346385192361ull, 556394530010129ull}},
{{16041404291850064212ull, 445115624008103ull}},
{{1765076989254320400ull, 356092499206483ull}},
{{8790759220887276966ull, 284873999365186ull}},
{{6686517123935822500ull, 455798398984298ull}},
{{12727911328632478646ull, 364638719187438ull}},
{{17561026692389803563ull, 291710975349950ull}},
{{9650898634114134086ull, 466737560559921ull}},
{{4031370092549396945ull, 373390048447937ull}},
{{14293142518265248526ull, 298712038758349ull}},
{{11800981584998666672ull, 477939262013359ull}},
{{13130134082740843661ull, 382351409610687ull}},
{{3125409636708854282ull, 305881127688550ull}},
{{5000655418734166851ull, 489409804301680ull}},
{{4000524334987333481ull, 391527843441344ull}},
{{6889768282731777108ull, 313222274753075ull}},
{{11023629252370843373ull, 501155639604920ull}},
{{8818903401896674698ull, 400924511683936ull}},
{{3365773906775429435ull, 320739609347149ull}},
{{12763935880324507743ull, 513183374955438ull}},
{{17589846333743426841ull, 410546699964350ull}},
{{14071877066994741473ull, 328437359971480ull}},
{{4068259233482034740ull, 525499775954369ull}},
{{6943956201527538115ull, 420399820763495ull}},
{{5555164961222030492ull, 336319856610796ull}},
{{1509566308471428142ull, 538111770577274ull}},
{{4897001861519052836ull, 430489416461819ull}},
{{7606950303957152592ull, 344391533169455ull}},
{{12171120486331444148ull, 551026453071128ull}},
{{17115594018548975964ull, 440821162456902ull}},
{{6313777585355360125ull, 352656929965522ull}},
{{16119068512510019070ull, 282125543972417ull}},
{{11033114361048389219ull, 451400870355868ull}},
{{16205189118322532021ull, 361120696284694ull}},
{{16653500109399935940ull, 288896557027755ull}},
{{8198856101330345889ull, 462234491244409ull}},
{{10248433695806187034ull, 369787592995527ull}},
{{820049327161128981ull, 295830074396422ull}},
{{5001427738199716693ull, 473328119034275ull}},
{{4001142190559773354ull, 378662495227420ull}},
{{3200913752447818683ull, 302929996181936ull}},
{{16189508448142240863ull, 484687993891097ull}},
{{5572909129029972044ull, 387750395112878ull}},
{{11837024932707798281ull, 310200316090302ull}},
{{4181844633364835958ull, 496320505744484ull}},
{{7034824521433779089ull, 397056404595587ull}},
{{16695906061372754241ull, 317645123676469ull}},
{{15645403253970675816ull, 508232197882351ull}},
{{8826973788434630330ull, 406585758305881ull}},
{{3372230216005793940ull, 325268606644705ull}},
{{5395568345609270305ull, 520429770631528ull}},
{{11695152305971236890ull, 416343816505222ull}},
{{1977424215293168866ull, 333075053204178ull}},
{{17921274003436711478ull, 532920085126684ull}},
{{18026368017491279506ull, 426336068101347ull}},
{{7042396784509202958ull, 341068854481078ull}},
{{7578486040472814410ull, 545710167169725ull}},
{{6062788832378251528ull, 436568133735780ull}},
{{4850231065902601222ull, 349254506988624ull}},
{{15139067334927982602ull, 558807211181798ull}},
{{1043207423716655112ull, 447045768945439ull}},
{{4523914753715234413ull, 357636615156351ull}},
{{18376527061939828823ull, 286109292125080ull}},
{{10955699225394174501ull, 457774867400129ull}},
{{12453908195057249924ull, 366219893920103ull}},
{{17341824185529620585ull, 292975915136082ull}},
{{12989523437879751644ull, 468761464217732ull}},
{{3012921120819980669ull, 375009171374186ull}},
{{17167732155623625828ull, 300007337099348ull}},
{{5332278560546339385ull, 480011739358958ull}},
{{11644520477920892155ull, 384009391487166ull}},
{{5626267567594803400ull, 307207513189733ull}},
{{5312679293409775118ull, 491532021103573ull}},
{{11628841064211640740ull, 393225616882858ull}},
{{16681770480853133239ull, 314580493506286ull}},
{{865391066171640920ull, 503328789610059ull}},
{{4381661667679223059ull, 402663031688047ull}},
{{14573375778369109417ull, 322130425350437ull}},
{{8560005986422933774ull, 515408680560700ull}},
{{6848004789138347019ull, 412326944448560ull}},
{{5478403831310677615ull, 329861555558848ull}},
{{5076097315355173862ull, 527778488894157ull}},
{{15128924296509870059ull, 422222791115325ull}},
{{12103139437207896047ull, 337778232892260ull}},
{{918279025823082059ull, 540445172627617ull}},
{{11802669664884196617ull, 432356138102093ull}},
{{16820833361391177940ull, 345884910481674ull}},
{{15845286934000153734ull, 553415856770679ull}},
{{16365578361942033311ull, 442732685416543ull}},
{{2024416245327895679ull, 354186148333235ull}},
{{1619532996262316543ull, 283348918666588ull}},
{{17348648052987347762ull, 453358269866540ull}},
{{13878918442389878209ull, 362686615893232ull}},
{{3724437124428081921ull, 290149292714586ull}},
{{17027145843310662043ull, 464238868343337ull}},
{{6243019045164708988ull, 371391094674670ull}},
{{4994415236131767191ull, 297112875739736ull}},
{{612366748327006859ull, 475380601183578ull}},
{{7868591028145426133ull, 380304480946862ull}},
{{17362919266742071876ull, 304243584757489ull}},
{{16712624382561584033ull, 486789735611983ull}},
{{2302053061823536256ull, 389431788489587ull}},
{{12909688893684559975ull, 311545430791669ull}},
{{9587455785669564990ull, 498472689266671ull}},
{{3980615813793741669ull, 398778151413337ull}},
{{14252539095260724304ull, 319022521130669ull}},
{{11736016108191427918ull, 510436033809071ull}},
{{5699464071811232011ull, 408348827047257ull}},
{{15627617701674716578ull, 326679061637805ull}},
{{6557444248969994910ull, 522686498620489ull}},
{{8935304213917906251ull, 418149198896391ull}},
{{3458894556392414677ull, 334519359117113ull}},
{{1844882475485953161ull, 535230974587381ull}},
{{16233301239356403821ull, 428184779669904ull}},
{{16675989806227033380ull, 342547823735923ull}},
{{4545490801511791469ull, 548076517977478ull}},
{{11015090270693253822ull, 438461214381982ull}},
{{1433374587070782411ull, 350768971505586ull}},
{{13361445783538982827ull, 561230354408937ull}},
{{3310458997347365615ull, 448984283527150ull}},
{{2648367197877892492ull, 359187426821720ull}},
{{2118693758302313994ull, 287349941457376ull}},
{{14457956457509433360ull, 459759906331801ull}},
{{7877016351265636365ull, 367807925065441ull}},
{{2612264266270598768ull, 294246340052353ull}},
{{490274011291047706ull, 470794144083765ull}},
{{392219209032838165ull, 376635315267012ull}},
{{11381821811452001502ull, 301308252213609ull}},
{{7142868454097471433ull, 482093203541775ull}},
{{5714294763277977146ull, 385674562833420ull}},
{{4571435810622381717ull, 308539650266736ull}},
{{18382343741221541717ull, 493663440426777ull}},
{{7327177363493412727ull, 394930752341422ull}},
{{16929788335020461151ull, 315944601873137ull}},
{{12330266077065096550ull, 505511362997020ull}},
{{9864212861652077240ull, 404409090397616ull}},
{{4202021474579751468ull, 323527272318093ull}},
{{3033885544585692026ull, 517643635708949ull}},
{{6116457250410463944ull, 414114908567159ull}},
{{8582514615070281478ull, 331291926853727ull}},
{{17421372198854360689ull, 530067082965963ull}},
{{2869051314857757582ull, 424053666372771ull}},
{{17052636310853847358ull, 339242933098216ull}},
{{1458776394172783511ull, 542788692957147ull}},
{{12235067559563957778ull, 434230954365717ull}},
{{2409356418167345576ull, 347384763492574ull}},
{{11233667898551573568ull, 555815621588118ull}},
{{16365631948325079501ull, 444652497270494ull}},
{{16781854373401973924ull, 355721997816395ull}},
{{13425483498721579139ull, 284577598253116ull}},
{{14102075968470705976ull, 455324157204986ull}},
{{7592311960034654458ull, 364259325763989ull}},
{{9763198382769633889ull, 291407460611191ull}},
{{8242419782947593577ull, 466251936977906ull}},
{{2904587011616164538ull, 373001549582325ull}},
{{2323669609292931630ull, 298401239665860ull}},
{{3717871374868690609ull, 477441983465376ull}},
{{17731692358862593780ull, 381953586772300ull}},
{{14185353887090075024ull, 305562869417840ull}},
{{4249822145634568422ull, 488900591068545ull}},
{{3399857716507654738ull, 391120472854836ull}},
{{17477281432173765083ull, 312896378283868ull}},
{{5827557403026562194ull, 500634205254190ull}},
{{4662045922421249755ull, 400507364203352ull}},
{{14797683182162730773ull, 320405891362681ull}},
{{16297595461976548591ull, 512649426180290ull}},
{{13038076369581238873ull, 410119540944232ull}},
{{3051763466181170452ull, 328095632755386ull}},
{{15950867990115603693ull, 524953012408617ull}},
{{5381996762608662308ull, 419962409926894ull}},
{{7994946224828840169ull, 335969927941515ull}},
{{12791913959726144271ull, 537551884706424ull}},
{{13922879982522825740ull, 430041507765139ull}},
{{14827652800760170915ull, 344033206212111ull}},
{{16345546851732452818ull, 550453129939378ull}},
{{2008391037160231285ull, 440362503951503ull}},
{{8985410459212005674ull, 352290003161202ull}},
{{18256374811595335509ull, 281832002528961ull}},
{{3384757995359164552ull, 450931204046339ull}},
{{6397155211029241965ull, 360744963237071ull}},
{{1428375354081483248ull, 288595970589657ull}},
{{5974749381272283521ull, 461753552943451ull}},
{{1090450690275916493ull, 369402842354761ull}},
{{15629755811188374487ull, 295522273883808ull}},
{{2871516409449937241ull, 472835638214094ull}},
{{5986561942301860116ull, 378268510571275ull}},
{{4789249553841488093ull, 302614808457020ull}},
{{7662799286146380949ull, 484183693531232ull}},
{{17198285873142835728ull, 387346954824985ull}},
{{13758628698514268583ull, 309877563859988ull}},
{{18324457102880919409ull, 495804102175981ull}},
{{10970216867562825204ull, 396643281740785ull}},
{{8776173494050260163ull, 317314625392628ull}},
{{10352528775738505938ull, 507703400628205ull}},
{{8282023020590804750ull, 406162720502564ull}},
{{10314967231214554123ull, 324930176402051ull}},
{{9125249940459465951ull, 519888282243282ull}},
{{18368246396593303731ull, 415910625794625ull}},
{{14694597117274642984ull, 332728500635700ull}},
{{5064611313929877159ull, 532365601017121ull}},
{{362340236401991404ull, 425892480813697ull}},
{{11357918633347324093ull, 340713984650957ull}},
{{3415274554388077256ull, 545142375441532ull}},
{{13800266087736192774ull, 436113900353225ull}},
{{11040212870188954219ull, 348891120282580ull}},
{{17664340592302326751ull, 558225792452128ull}},
{{3063426029616130431ull, 446580633961703ull}},
{{9829438453176724991ull, 357264507169362ull}},
{{484853133057559347ull, 285811605735490ull}},
{{775765012892094955ull, 457298569176784ull}},
{{4309960825055586287ull, 365838855341427ull}},
{{14516015104270199999ull, 292671084273141ull}},
{{15846926537348499352ull, 468273734837026ull}},
{{8988192415136889159ull, 374618987869621ull}},
{{3501205117367601004ull, 299695190295697ull}},
{{9291277002530071929ull, 479512304473115ull}},
{{7433021602024057543ull, 383609843578492ull}},
{{17014463725844977004ull, 306887874862793ull}},
{{5087049072900501268ull, 491020599780470ull}},
{{4069639258320401014ull, 392816479824376ull}},
{{18013106665623962104ull, 314253183859500ull}},
{{10374226591288787751ull, 502805094175201ull}},
{{4610032458289119877ull, 402244075340161ull}},
{{18445421225598937194ull, 321795260272128ull}},
{{7376581072506837572ull, 514872416435406ull}},
{{2211916043263559735ull, 411897933148325ull}},
{{1769532834610847788ull, 329518346518660ull}},
{{2831252535377356460ull, 527229354429856ull}},
{{17022397287269526461ull, 421783483543884ull}},
{{17307266644557531492ull, 337426786835107ull}},
{{12934231372324409095ull, 539882858936172ull}},
{{2968687468375706629ull, 431906287148938ull}},
{{9753647604184385950ull, 345525029719150ull}},
{{15605836166695017520ull, 552840047550640ull}},
{{12484668933356014016ull, 442272038040512ull}},
{{2609037517200990566ull, 353817630432410ull}},
{{2087230013760792453ull, 283054104345928ull}},
{{18096963280984909217ull, 452886566953484ull}},
{{18166919439529837697ull, 362309253562787ull}},
{{7154837922140049511ull, 289847402850230ull}},
{{11447740675424079218ull, 463755844560368ull}},
{{16536890169823084021ull, 371004675648294ull}},
{{16918860950600377540ull, 296803740518635ull}},
{{8623433447251052448ull, 474885984829817ull}},
{{17966793202026572928ull, 379908787863853ull}},
{{3305388117395527373ull, 303927030291083ull}},
{{1599272173090933473ull, 486283248465733ull}},
{{8658115367956567425ull, 389026598772586ull}},
{{3237143479623343617ull, 311221279018069ull}},
{{12558127196881170433ull, 497954046428910ull}},
{{10046501757504936346ull, 398363237143128ull}},
{{15415899035487769723ull, 318690589714502ull}},
{{9908043197812790265ull, 509904943543204ull}},
{{11615783372992142535ull, 407923954834563ull}},
{{16671324327877534674ull, 326339163867650ull}},
{{8227374850894503863ull, 522142662188241ull}},
{{2892551065973692767ull, 417714129750593ull}},
{{9692738482262774860ull, 334171303800474ull}},
{{4440335127394708807ull, 534674086080759ull}},
{{7241616916657677369ull, 427739268864607ull}},
{{16861339977551872864ull, 342191415091685ull}},
{{8531399890373444967ull, 547506264146697ull}},
{{17893166356524486943ull, 438005011317357ull}},
{{6935835455735768908ull, 350404009053886ull}},
{{3718639099693409607ull, 560646414486218ull}},
{{10353608909238548332ull, 448517131588974ull}},
{{11972235942132748989ull, 358813705271179ull}},
{{13267137568448109514ull, 287050964216943ull}},
{{17538071294775064900ull, 459281542747109ull}},
{{17719805850561962243ull, 367425234197687ull}},
{{6797147050965749148ull, 293940187358150ull}},
{{10875435281545198637ull, 470304299773040ull}},
{{8700348225236158909ull, 376243439818432ull}},
{{18028325024414658097ull, 300994751854745ull}},
{{10398575965353901339ull, 481591602967593ull}},
{{15697558401766941718ull, 385273282374074ull}},
{{16247395536155463697ull, 308218625899259ull}},
{{14927786413623010946ull, 493149801438815ull}},
{{11942229130898408757ull, 394519841151052ull}},
{{2175085675234906359ull, 315615872920842ull}},
{{7169485895117760498ull, 504985396673347ull}},
{{16803635160319939368ull, 403988317338677ull}},
{{6064210498772130848ull, 323190653870942ull}},
{{13392085612777319680ull, 517105046193507ull}},
{{3334970860738035098ull, 413684036954806ull}},
{{17425371947558069371ull, 330947229563844ull}},
{{16812548671867180024ull, 529515567302151ull}},
{{9760690122751833696ull, 423612453841721ull}},
{{4119203283459556633ull, 338889963073377ull}},
{{10280074068277200937ull, 542223940917403ull}},
{{15602756884105581396ull, 433779152733922ull}},
{{5103507877800644470ull, 347023322187138ull}},
{{4476263789739120829ull, 555237315499421ull}},
{{18338406290758937956ull, 444189852399536ull}},
{{10981376217865240042ull, 355351881919629ull}},
{{12474449789034102356ull, 284281505535703ull}},
{{16269770847712653447ull, 454850408857125ull}},
{{13015816678170122758ull, 363880327085700ull}},
{{10412653342536098206ull, 291104261668560ull}},
{{16660245348057757130ull, 465766818669696ull}},
{{9638847463704295381ull, 372613454935757ull}},
{{332380341479615658ull, 298090763948606ull}},
{{11599854990593116023ull, 476945222317769ull}},
{{12969232807216403141ull, 381556177854215ull}},
{{10375386245773122513ull, 305244942283372ull}},
{{1843222734269354728ull, 488391907653396ull}},
{{16231973446383125075ull, 390713526122716ull}},
{{9296229942364589737ull, 312570820898173ull}},
{{11184619093041433256ull, 500113313437077ull}},
{{1568997644949325959ull, 400090650749662ull}},
{{12323244560185191736ull, 320072520599729ull}},
{{8649144852070575809ull, 512116032959567ull}},
{{17987362325882191617ull, 409692826367653ull}},
{{3321843416480022324ull, 327754261094123ull}},
{{1625600651626125395ull, 524406817750597ull}},
{{12368526965526631285ull, 419525454200477ull}},
{{2516123942937484382ull, 335620363360382ull}},
{{7715147123441885334ull, 536992581376611ull}},
{{2482768884011597944ull, 429594065101289ull}},
{{5675563921951188678ull, 343675252081031ull}},
{{1702204645638081239ull, 549880403329650ull}},
{{1361763716510464991ull, 439904322663720ull}},
{{1089410973208371993ull, 351923458130976ull}},
{{15628924037534338887ull, 281538766504780ull}},
{{6559534386345390604ull, 450462026407649ull}},
{{8936976323818222806ull, 360369621126119ull}},
{{10838929873796488568ull, 288295696900895ull}},
{{17342287798074381709ull, 461273115041432ull}},
{{6495132608975684721ull, 369018492033146ull}},
{{1506757272438637453ull, 295214793626517ull}},
{{6100160450643730249ull, 472343669802427ull}},
{{15948174804740715168ull, 377874935841941ull}},
{{9069191029050661811ull, 302299948673553ull}},
{{10821356831739148575ull, 483679917877685ull}},
{{8657085465391318860ull, 386943934302148ull}},
{{14304366001796875735ull, 309555147441718ull}},
{{750892714423539236ull, 495288235906750ull}},
{{600714171538831389ull, 396230588725400ull}},
{{480571337231065111ull, 316984470980320ull}},
{{768914139569704178ull, 507175153568512ull}},
{{11683177755881494312ull, 405740122854809ull}},
{{13035891019447105773ull, 324592098283847ull}},
{{6100030372147727944ull, 519347357254156ull}},
{{1190675482976272032ull, 415477885803325ull}},
{{952540386381017625ull, 332382308642660ull}},
{{1524064618209628201ull, 531811693828256ull}},
{{15976646953535343853ull, 425449355062604ull}},
{{16470666377570185406ull, 340359484050083ull}},
{{4216973315660834710ull, 544575174480134ull}},
{{7062927467270578091ull, 435660139584107ull}},
{{16718388418042193443ull, 348528111667285ull}},
{{8302677395157957892ull, 557644978667657ull}},
{{17710188360352097283ull, 446115982934125ull}},
{{14168150688281677827ull, 356892786347300ull}},
{{11334520550625342261ull, 285514229077840ull}},
{{18135232881000547618ull, 456822766524544ull}},
{{18197535119542348418ull, 365458213219635ull}},
{{14558028095633878734ull, 292366570575708ull}},
{{1156752064562744035ull, 467786512921134ull}},
{{4614750466392105551ull, 374229210336907ull}},
{{14759846817339415411ull, 299383368269525ull}},
{{5169010834033513041ull, 479013389231241ull}},
{{445859852484900110ull, 383210711384993ull}},
{{7735385511471740734ull, 306568569107994ull}},
{{1308570374129054205ull, 490509710572791ull}},
{{15804251558270884657ull, 392407768458232ull}},
{{5264703617132887079ull, 313926214766586ull}},
{{1044828157928798680ull, 502281943626538ull}},
{{8214560155826859591ull, 401825554901230ull}},
{{6571648124661487672ull, 321460443920984ull}},
{{17893334628942200923ull, 514336710273574ull}},
{{18004016517895671061ull, 411469368218859ull}},
{{18092562029058447172ull, 329175494575087ull}},
{{14190703987525874183ull, 526680791320140ull}},
{{11352563190020699346ull, 421344633056112ull}},
{{1703352922532738830ull, 337075706444890ull}},
{{2725364676052382129ull, 539321130311824ull}},
{{5869640555583816026ull, 431456904249459ull}},
{{8385061259208963144ull, 345165523399567ull}},
{{17105446829476251354ull, 552264837439307ull}},
{{6305659834097180437ull, 441811869951446ull}},
{{1355179052535834026ull, 353449495961157ull}},
{{12152189686254398190ull, 282759596768925ull}},
{{996759424297485489ull, 452415354830281ull}},
{{15554802798405629684ull, 361932283864224ull}},
{{16133191053466414070ull, 289545827091379ull}},
{{14745059241320531543ull, 463273323346207ull}},
{{4417349763572604588ull, 370618658676966ull}},
{{18291275069825724963ull, 296494926941572ull}},
{{14508644852753518648ull, 474391883106516ull}},
{{7917567067460904595ull, 379513506485213ull}},
{{13712751283452544323ull, 303610805188170ull}},
{{3493657979814519300ull, 485777288301073ull}},
{{10173624013335436087ull, 388621830640858ull}},
{{15517596840152169516ull, 310897464512686ull}},
{{17449457314759650579ull, 497435943220298ull}},
{{2891519407581989493ull, 397948754576239ull}},
{{6002564340807501918ull, 318359003660991ull}},
{{2225405315808182422ull, 509374405857586ull}},
{{16537719511614187231ull, 407499524686068ull}},
{{2162129165065618815ull, 325999619748855ull}},
{{3459406664104990104ull, 521599391598168ull}},
{{10146222960767812729ull, 417279513278534ull}},
{{11806327183356160507ull, 333823610622827ull}},
{{4132728234402215518ull, 534117776996524ull}},
{{6995531402263682738ull, 427294221597219ull}},
{{9285773936552856513ull, 341835377277775ull}},
{{14857238298484570421ull, 546936603644440ull}},
{{11885790638787656337ull, 437549282915552ull}},
{{2129934881546304423ull, 350039426332442ull}},
{{7097244625215997401ull, 560063082131907ull}},
{{16745842144398528890ull, 448050465705525ull}},
{{13396673715518823112ull, 358440372564420ull}},
{{10717338972415058489ull, 286752298051536ull}},
{{9769044726380272937ull, 458803676882458ull}},
{{15193933410588038996ull, 367042941505966ull}},
{{8465797913728520873ull, 293634353204773ull}},
{{9855927847223723074ull, 469814965127637ull}},
{{506044648295157813ull, 375851972102110ull}},
{{404835718636126250ull, 300681577681688ull}},
{{15405132408785443294ull, 481090524290700ull}},
{{12324105927028354635ull, 384872419432560ull}},
{{9859284741622683708ull, 307897935546048ull}},
{{12085506771854383610ull, 492636696873677ull}},
{{2289707787999686241ull, 394109357498942ull}},
{{12899812674625479962ull, 315287485999153ull}},
{{16950351464658857617ull, 504459977598645ull}},
{{13560281171727086093ull, 403567982078916ull}},
{{7158876122639758551ull, 322854385663133ull}},
{{7764852981481703359ull, 516567017061013ull}},
{{13590580014669183334ull, 413253613648810ull}},
{{10872464011735346667ull, 330602890919048ull}},
{{13706593604034644344ull, 528964625470477ull}},
{{3586577253743894829ull, 423171700376382ull}},
{{13937308247220846833ull, 338537360301105ull}},
{{3852949121843803316ull, 541659776481769ull}},
{{6771708112216952976ull, 433327821185415ull}},
{{5417366489773562381ull, 346662256948332ull}},
{{12357135198379610133ull, 554659611117331ull}},
{{6196359343961777783ull, 443727688893865ull}},
{{4957087475169422226ull, 354982151115092ull}},
{{15033716424361268751ull, 283985720892073ull}},
{{1917853390526568062ull, 454377153427318ull}},
{{8912980341905075096ull, 363501722741854ull}},
{{10819733088265970400ull, 290801378193483ull}},
{{13622224126483642317ull, 465282205109573ull}},
{{18276476930670734500ull, 372225764087658ull}},
{{3553135100310856630ull, 297780611270127ull}},
{{9374364975239280932ull, 476448978032203ull}},
{{14878189609675245392ull, 381159182425762ull}},
{{4523854058256375667ull, 304927345940610ull}},
{{7238166493210201067ull, 487883753504976ull}},
{{2101184379826250531ull, 390307002803981ull}},
{{16438342762828641717ull, 312245602243184ull}},
{{15233301976300095778ull, 499592963589095ull}},
{{12186641581040076622ull, 399674370871276ull}},
{{6059964450090150975ull, 319739496697021ull}},
{{2317245490660420913ull, 511583194715234ull}},
{{5543145207270247054ull, 409266555772187ull}},
{{15502562610041928612ull, 327413244617749ull}},
{{13736053731841354811ull, 523861191388399ull}},
{{14678191800214994172ull, 419088953110719ull}},
{{15431902254913905660ull, 335271162488575ull}},
{{6244299534152697441ull, 536433859981721ull}},
{{1306090812580247629ull, 429147087985377ull}},
{{12112919094289929073ull, 343317670388301ull}},
{{12001972921380065871ull, 549308272621282ull}},
{{2222880707620232050ull, 439446618097026ull}},
{{16535699825063826933ull, 351557294477620ull}},
{{8010375646392571477ull, 562491671164193ull}},
{{13786998146597877828ull, 449993336931354ull}},
{{14718947332020212585ull, 359994669545083ull}},
{{707111421390439099ull, 287995735636067ull}},
{{4820727088966612881ull, 460793177017707ull}},
{{14924628115399021274ull, 368634541614165ull}},
{{11939702492319217019ull, 294907633291332ull}},
{{4346128728743105939ull, 471852213266132ull}},
{{14544949427220215720ull, 377481770612905ull}},
{{11635959541776172576ull, 301985416490324ull}},
{{7549488822616145153ull, 483176666384519ull}},
{{9728939872834826445ull, 386541333107615ull}},
{{7783151898267861156ull, 309233066486092ull}},
{{16142391851970488173ull, 494772906377747ull}},
{{5535215852092569892ull, 395818325102198ull}},
{{11806870311157876560ull, 316654660081758ull}},
{{15201643683110692173ull, 506647456130813ull}},
{{1093268502262822769ull, 405317964904651ull}},
{{15632010060777899508ull, 324254371923720ull}},
{{6564472023535087597ull, 518806995077953ull}},
{{12630275248311890724ull, 415045596062362ull}},
{{2725522569165691932ull, 332036476849890ull}},
{{4360836110665107092ull, 531258362959824ull}},
{{7178017703273995997ull, 425006690367859ull}},
{{9431762977361107120ull, 340005352294287ull}},
{{333425504810130100ull, 544008563670860ull}},
{{266740403848104080ull, 435206850936688ull}},
{{7592089952562303910ull, 348165480749350ull}},
{{12147343924099686257ull, 557064769198960ull}},
{{9717875139279749005ull, 445651815359168ull}},
{{15152997740907619851ull, 356521452287334ull}},
{{15811747007468006204ull, 285217161829867ull}},
{{10541399952981168633ull, 456347458927788ull}},
{{15811817591868755553ull, 365077967142230ull}},
{{12649454073495004442ull, 292062373713784ull}},
{{9171080073366276138ull, 467299797942055ull}},
{{7336864058693020911ull, 373839838353644ull}},
{{9558840061696327052ull, 299071870682915ull}},
{{15294144098714123283ull, 478514993092664ull}},
{{15924664093713208949ull, 382811994474131ull}},
{{9050382460228656836ull, 306249595579305ull}},
{{14480611936365850938ull, 489999352926888ull}},
{{516443104866949781ull, 391999482341511ull}},
{{15170549742861201117ull, 313599585873208ull}},
{{2136786700126459849ull, 501759337397134ull}},
{{5398778174843078202ull, 401407469917707ull}},
{{15387068984100193531ull, 321125975934165ull}},
{{6172566300850758034ull, 513801561494665ull}},
{{4938053040680606427ull, 411041249195732ull}},
{{15018488876770216111ull, 328832999356585ull}},
{{5582838129122794162ull, 526132798970537ull}},
{{15534316947523966299ull, 420906239176429ull}},
{{16116802372761083363ull, 336724991341143ull}},
{{3650790907966271441ull, 538759986145830ull}},
{{2920632726373017153ull, 431007988916664ull}},
{{6025854995840324045ull, 344806391133331ull}},
{{2262670363860697827ull, 551690225813330ull}},
{{1810136291088558261ull, 441352180650664ull}},
{{5137457847612756932ull, 353081744520531ull}},
{{420617463348295222ull, 282465395616425ull}},
{{672987941357272356ull, 451944632986280ull}},
{{538390353085817885ull, 361555706389024ull}},
{{4120061097210564631ull, 289244565111219ull}},
{{13970795385020724056ull, 462791304177950ull}},
{{11176636308016579245ull, 370233043342360ull}},
{{8941309046413263396ull, 296186434673888ull}},
{{10616745659519311110ull, 473898295478221ull}},
{{4804047712873538565ull, 379118636382577ull}},
{{14911284614524561821ull, 303294909106061ull}},
{{16479357753755478268ull, 485271854569698ull}},
{{2115439758778651645ull, 388217483655759ull}},
{{5381700621764831639ull, 310573986924607ull}},
{{12300069809565640946ull, 496918379079371ull}},
{{6150707032910602433ull, 397534703263497ull}},
{{15988612070554212916ull, 318027762610797ull}},
{{10824384053919099374ull, 508844420177276ull}},
{{4970158428393369176ull, 407075536141821ull}},
{{286777927972785017ull, 325660428913457ull}},
{{4148193499498366351ull, 521056686261531ull}},
{{18075950058566334373ull, 416845349009224ull}},
{{18150108861594977822ull, 333476279207379ull}},
{{17972127734326233546ull, 533562046731807ull}},
{{6999004557977166190ull, 426849637385446ull}},
{{1909854831639822629ull, 341479709908357ull}},
{{6745116545365626529ull, 546367535853371ull}},
{{1706744421550590900ull, 437094028682697ull}},
{{12433441981466203690ull, 349675222946157ull}},
{{5136111911378284611ull, 559480356713852ull}},
{{15176935973328358658ull, 447584285371081ull}},
{{8452199963920776603ull, 358067428296865ull}},
{{6761759971136621283ull, 286453942637492ull}},
{{14508164768560504376ull, 458326308219987ull}},
{{4227834185364582854ull, 366661046575990ull}},
{{3382267348291666283ull, 293328837260792ull}},
{{9100976572008576376ull, 469326139617267ull}},
{{18348827701832592071ull, 375460911693813ull}},
{{3611015717240342687ull, 300368729355051ull}},
{{16845671591810279269ull, 480589966968081ull}},
{{9787188458706313092ull, 384471973574465ull}},
{{7829750766965050473ull, 307577578859572ull}},
{{16216950041885991081ull, 492124126175315ull}},
{{12973560033508792865ull, 393699300940252ull}},
{{3000150397323213645ull, 314959440752202ull}},
{{8489589450459052156ull, 503935105203523ull}},
{{14170369189851062371ull, 403148084162818ull}},
{{268248907655118927ull, 322518467330255ull}},
{{429198252248190284ull, 516029547728408ull}},
{{7722056231282372873ull, 412823638182726ull}},
{{2488296170283987975ull, 330258910546181ull}},
{{15049320316680111730ull, 528414256873889ull}},
{{15728805068085999707ull, 422731405499111ull}},
{{8893695239726889443ull, 338185124399289ull}},
{{3161865939337292139ull, 541096199038863ull}},
{{9908190380953654357ull, 432876959231090ull}},
{{7926552304762923486ull, 346301567384872ull}},
{{16371832502362587901ull, 554082507815795ull}},
{{13097466001890070320ull, 443266006252636ull}},
{{6788623986770145933ull, 354612805002109ull}},
{{9120248004158027070ull, 283690244001687ull}},
{{18281745621394753635ull, 453904390402699ull}},
{{18314745311857713231ull, 363123512322159ull}},
{{18341145064228080908ull, 290498809857727ull}},
{{14588436843797288160ull, 464798095772364ull}},
{{15360098289779740851ull, 371838476617891ull}},
{{8598729817081882358ull, 297470781294313ull}},
{{10068618892589101449ull, 475953250070901ull}},
{{4365546299329370836ull, 380762600056721ull}},
{{18249832298431137962ull, 304610080045376ull}},
{{3374289974296448476ull, 487376128072603ull}},
{{10078129608920979427ull, 389900902458082ull}},
{{683806057652962895ull, 311920721966466ull}},
{{12162136136470471603ull, 499073155146345ull}},
{{9729708909176377282ull, 399258524117076ull}},
{{4094418312599191502ull, 319406819293661ull}},
{{17619115744384437374ull, 511050910869857ull}},
{{6716594966023729252ull, 408840728695886ull}},
{{1683927158077073079ull, 327072582956709ull}},
{{10072981082407137572ull, 523316132730734ull}},
{{11747733680667620381ull, 418652906184587ull}},
{{2019489315050275658ull, 334922324947670ull}},
{{3231182904080441054ull, 535875719916272ull}},
{{13652992767490083812ull, 428700575933017ull}},
{{3543696584508246403ull, 342960460746414ull}},
{{13048612164697014892ull, 548736737194262ull}},
{{3060192102273791267ull, 438989389755410ull}},
{{2448153681819033014ull, 351191511804328ull}},
{{227697076168542499ull, 561906418886925ull}},
{{182157660934833999ull, 449525135109540ull}},
{{145726128747867199ull, 359620108087632ull}},
{{11184627347224024729ull, 287696086470105ull}},
{{17895403755558439566ull, 460313738352168ull}},
{{3248276560221020683ull, 368250990681735ull}},
{{2598621248176816547ull, 294600792545388ull}},
{{468445182340996152ull, 471361268072621ull}},
{{15132151404840438214ull, 377089014458096ull}},
{{8416372309130440248ull, 301671211566477ull}},
{{17155544509350614720ull, 482673938506363ull}},
{{2656389163254760807ull, 386139150805091ull}},
{{16882506589571449938ull, 308911320644072ull}},
{{12254615284346678608ull, 494258113030516ull}},
{{6114343412735432563ull, 395406490424413ull}},
{{12270172359672166697ull, 316325192339530ull}},
{{1185531701765915099ull, 506120307743249ull}},
{{4637774176154642403ull, 404896246194599ull}},
{{7399568155665624245ull, 323916996955679ull}},
{{771262604839267823ull, 518267195129087ull}},
{{11685056528097145228ull, 414613756103269ull}},
{{13037394037219626505ull, 331691004882615ull}},
{{2413086385841850793ull, 530705607812185ull}},
{{1930469108673480634ull, 424564486249748ull}},
{{8923072916422605154ull, 339651588999798ull}},
{{10587567851534257923ull, 543442542399677ull}},
{{1091356651743585692ull, 434754033919742ull}},
{{11941131765620599523ull, 347803227135793ull}},
{{15416462010251048914ull, 556485163417269ull}},
{{16022518422942749454ull, 445188130733815ull}},
{{12818014738354199563ull, 356150504587052ull}},
{{2875714161199539004ull, 284920403669642ull}},
{{8290491472661172730ull, 455872645871427ull}},
{{17700439622354669154ull, 364698116697141ull}},
{{10471002883141825000ull, 291758493357713ull}},
{{13064255798285009676ull, 466813589372341ull}},
{{6762055823886097418ull, 373450871497873ull}},
{{12788342288592698581ull, 298760697198298ull}},
{{16771998847006407406ull, 478017115517277ull}},
{{6038901448121305278ull, 382413692413822ull}},
{{15899167602722775192ull, 305930953931057ull}},
{{10681272905388799015ull, 489489526289692ull}},
{{1166320694827218565ull, 391591621031754ull}},
{{4622405370603685175ull, 313273296825403ull}},
{{3706499778223985958ull, 501237274920645ull}},
{{2965199822579188766ull, 400989819936516ull}},
{{17129555117030992306ull, 320791855949212ull}},
{{12649892928281946397ull, 513266969518740ull}},
{{10119914342625557117ull, 410613575614992ull}},
{{717233844616625047ull, 328490860491994ull}},
{{8526271780870420722ull, 525585376787190ull}},
{{6821017424696336578ull, 420468301429752ull}},
{{16524860383982800232ull, 336374641143801ull}},
{{614334911179108109ull, 538199425830083ull}},
{{7870165558427107133ull, 430559540664066ull}},
{{2606783631999775383ull, 344447632531253ull}},
{{481504996457730290ull, 551116212050005ull}},
{{385203997166184232ull, 440892969640004ull}},
{{3997512012474857709ull, 352714375712003ull}},
{{10576707239463706813ull, 282171500569602ull}},
{{2165336324174289609ull, 451474400911364ull}},
{{5421617874081342010ull, 361179520729091ull}},
{{647945484523163285ull, 288943616583273ull}},
{{15794108034204702549ull, 462309786533236ull}},
{{8945937612621851716ull, 369847829226589ull}},
{{10846098904839391696ull, 295878263381271ull}},
{{9975060618259206067ull, 473405221410034ull}},
{{11669397309349275177ull, 378724177128027ull}},
{{1956820217995599495ull, 302979341702422ull}},
{{6820261163534869515ull, 484766946723875ull}},
{{5456208930827895612ull, 387813557379100ull}},
{{4364967144662316490ull, 310250845903280ull}},
{{6983947431459706384ull, 496401353445248ull}},
{{12965855574651585753ull, 397121082756198ull}},
{{17751382089205089249ull, 317696866204958ull}},
{{6266118454276680859ull, 508314985927934ull}},
{{8702243578163255011ull, 406651988742347ull}},
{{18029841306756334978ull, 325321590993877ull}},
{{14090350831842494672ull, 520514545590204ull}},
{{14961629480215906061ull, 416411636472163ull}},
{{901257139946993879ull, 333129309177731ull}},
{{12510057868140921176ull, 533006894684369ull}},
{{13697395109254647264ull, 426405515747495ull}},
{{10957916087403717811ull, 341124412597996ull}},
{{10153968110362127852ull, 545799060156794ull}},
{{11812523303031612605ull, 436639248125435ull}},
{{9450018642425290084ull, 349311398500348ull}},
{{11430681013138553811ull, 558898237600557ull}},
{{1765847181027022402ull, 447118590080446ull}},
{{16170073003789259214ull, 357694872064356ull}},
{{9246709588289497048ull, 286155897651485ull}},
{{14794735341263195277ull, 457849436242376ull}},
{{8146439458268645899ull, 366279548993901ull}},
{{2827802751873006396ull, 293023639195121ull}},
{{15592530847222541203ull, 468837822712193ull}},
{{1405978233552301993ull, 375070258169755ull}},
{{1124782586841841594ull, 300056206535804ull}},
{{9178349768430767197ull, 480089930457286ull}},
{{3653331000002703434ull, 384071944365829ull}},
{{6612013614744073071ull, 307257555492663ull}},
{{6889872968848606590ull, 491612088788261ull}},
{{1822549560336974949ull, 393289671030609ull}},
{{5147388463011490282ull, 314631736824487ull}},
{{11925170355560294775ull, 503410778919179ull}},
{{13229485099190146143ull, 402728623135343ull}},
{{17962285708835937561ull, 322182898508274ull}},
{{17671610689911769128ull, 515492637613239ull}},
{{17826637366671325625ull, 412394110090591ull}},
{{10571961078595150177ull, 329915288072473ull}},
{{13225788911010329960ull, 527864460915957ull}},
{{3201933499324443322ull, 422291568732766ull}},
{{17318942058427195950ull, 337833254986212ull}},
{{12952912034515872228ull, 540533207977940ull}},
{{10362329627612697782ull, 432426566382352ull}},
{{911166072606337579ull, 345941253105882ull}},
{{5147214530912050450ull, 553506004969411ull}},
{{428422809987730037ull, 442804803975529ull}},
{{4032087062732094352ull, 354243843180423ull}},
{{10604367279669496128ull, 283395074544338ull}},
{{13277638832729283482ull, 453432119270941ull}},
{{6932762251441516463ull, 362745695416753ull}},
{{12924907430637033816ull, 290196556333402ull}},
{{5922456630051612814ull, 464314490133444ull}},
{{8427314118783200574ull, 371451592106755ull}},
{{6741851295026560459ull, 297161273685404ull}},
{{18165659701526317381ull, 475458037896646ull}},
{{10843178946479143582ull, 380366430317317ull}},
{{1295845527699494219ull, 304293144253854ull}},
{{9452050473803011397ull, 486869030806166ull}},
{{3872291564300498794ull, 389495224644933ull}},
{{10476530880924219682ull, 311596179715946ull}},
{{9383751779994930845ull, 498553887545514ull}},
{{11196350238737854999ull, 398843110036411ull}},
{{5267731376248373676ull, 319074488029129ull}},
{{15807067831481218528ull, 510519180846606ull}},
{{8956305450443064499ull, 408415344677285ull}},
{{7165044360354451599ull, 326732275741828ull}},
{{7774722161825212236ull, 522771641186925ull}},
{{6219777729460169788ull, 418217312949540ull}},
{{4975822183568135831ull, 334573850359632ull}},
{{11650664308450927653ull, 535318160575411ull}},
{{5631182632018831799ull, 428254528460329ull}},
{{8194294920356975762ull, 342603622768263ull}},
{{9421523057829250896ull, 548165796429221ull}},
{{3847869631521490394ull, 438532637143377ull}},
{{14146342149442923285ull, 350826109714701ull}},
{{15255449809624856609ull, 561321775543522ull}},
{{4825662218216064641ull, 449057420434818ull}},
{{11239227404056672359ull, 359245936347854ull}},
{{12680730737987248210ull, 287396749078283ull}},
{{16599820366037686814ull, 459834798525253ull}},
{{2211809848604418481ull, 367867838820203ull}},
{{9148145508367355431ull, 294294271056162ull}},
{{18326381628129679013ull, 470870833689859ull}},
{{18350454117245653534ull, 376696666951887ull}},
{{7301665664312702181ull, 301357333561510ull}},
{{11682665062900323489ull, 482171733698416ull}},
{{5656783235578348468ull, 385737386958733ull}},
{{11904124217946499421ull, 308589909566986ull}},
{{11667901119230578427ull, 493743855307178ull}},
{{16713018524868283388ull, 394995084245742ull}},
{{5991717190410806064ull, 315996067396594ull}},
{{16965445134141110349ull, 505593707834550ull}},
{{13572356107312888279ull, 404474966267640ull}},
{{10857884885850310623ull, 323579973014112ull}},
{{2615220558392855705ull, 517727956822580ull}},
{{2092176446714284564ull, 414182365458064ull}},
{{5363089972113337974ull, 331345892366451ull}},
{{1202246325897520112ull, 530153427786322ull}},
{{12029843504943747059ull, 424122742229057ull}},
{{2245177174471177001ull, 339298193783246ull}},
{{14660329923379614171ull, 542877110053193ull}},
{{660217494477960367ull, 434301688042555ull}},
{{528173995582368294ull, 347441350434044ull}},
{{8223776022415609917ull, 555906160694470ull}},
{{6579020817932487933ull, 444724928555576ull}},
{{1573867839604080023ull, 355779942844461ull}},
{{16016489530650905311ull, 284623954275568ull}},
{{3490290360589986559ull, 455398326840910ull}},
{{2792232288471989247ull, 364318661472728ull}},
{{9612483460261412044ull, 291454929178182ull}},
{{622578277450617978ull, 466327886685092ull}},
{{11566109066186225352ull, 373062309348073ull}},
{{16631584882432800928ull, 298449847478458ull}},
{{4474442923441019546ull, 477519755965534ull}},
{{7268903153494725960ull, 382015804772427ull}},
{{16883168967021511737ull, 305612643817941ull}},
{{1187628644041046518ull, 488980230108707ull}},
{{12018149359458568184ull, 391184184086965ull}},
{{9614519487566854547ull, 312947347269572ull}},
{{625835921139325982ull, 500715755631316ull}},
{{15258063995879102079ull, 400572604505052ull}},
{{4827753567219461016ull, 320458083604042ull}},
{{11413754522293047950ull, 512732933766467ull}},
{{1752305988350617713ull, 410186347013174ull}},
{{5091193605422404494ull, 328149077610539ull}},
{{15524607398159667837ull, 525038524176862ull}},
{{5040988289043913623ull, 420030819341490ull}},
{{4032790631235130898ull, 336024655473192ull}},
{{10141813824718119760ull, 537639448757107ull}},
{{734753430290675162ull, 430111559005686ull}},
{{15345198003200181422ull, 344089247204548ull}},
{{2416223916668828337ull, 550542795527278ull}},
{{9311676762818883316ull, 440434236421822ull}},
{{70643780771286006ull, 352347389137458ull}},
{{7435212654100849451ull, 281877911309966ull}},
{{4517642617077538476ull, 451004658095946ull}},
{{18371509352629672073ull, 360803726476756ull}},
{{11007858667361827335ull, 288642981181405ull}},
{{17612573867778923737ull, 461828769890248ull}},
{{3022012649997408020ull, 369463015912199ull}},
{{6106958934739836739ull, 295570412729759ull}},
{{17149831925067559429ull, 472912660367614ull}},
{{17409214354795957866ull, 378330128294091ull}},
{{10238022669094855970ull, 302664102635273ull}},
{{12691487455809859229ull, 484262564216437ull}},
{{2774492335164066736ull, 387410051373150ull}},
{{2219593868131253389ull, 309928041098520ull}},
{{3551350189010005423ull, 495884865757632ull}},
{{13909126595433735308ull, 396707892606105ull}},
{{11127301276346988246ull, 317366314084884ull}},
{{6735635597929450224ull, 507786102535815ull}},
{{5388508478343560179ull, 406228882028652ull}},
{{15378853226900579113ull, 324983105622921ull}},
{{17227467533557105935ull, 519972968996674ull}},
{{17471322841587595071ull, 415978375197339ull}},
{{17666407088011986380ull, 332782700157871ull}},
{{2440809637625805945ull, 532452320252595ull}},
{{1952647710100644756ull, 425961856202076ull}},
{{16319513427048157098ull, 340769484961660ull}},
{{7664477409567499741ull, 545231175938657ull}},
{{17199628371879730762ull, 436184940750925ull}},
{{13759702697503784610ull, 348947952600740ull}},
{{3568780242296503760ull, 558316724161185ull}},
{{2855024193837203008ull, 446653379328948ull}},
{{9662716984553583052ull, 357322703463158ull}},
{{15108871217126687088ull, 285858162770526ull}},
{{16795496317918878695ull, 457373060432842ull}},
{{6057699424851282309ull, 365898448346274ull}},
{{8535508354622936171ull, 292718758677019ull}},
{{2588766923170966904ull, 468350013883231ull}},
{{16828408797504414816ull, 374680011106584ull}},
{{17152075852745442176ull, 299744008885267ull}},
{{12685926105425066189ull, 479590414216428ull}},
{{17527438513823873597ull, 383672331373142ull}},
{{6643253181575278231ull, 306937865098514ull}},
{{18007902720004265817ull, 491100584157622ull}},
{{7027624546519592007ull, 392880467326098ull}},
{{13000797266699494252ull, 314304373860878ull}},
{{17111926811977280480ull, 502886998177405ull}},
{{13689541449581824384ull, 402309598541924ull}},
{{14640981974407369830ull, 321847678833539ull}},
{{12357524714826060759ull, 514956286133663ull}},
{{17264717401344669253ull, 411965028906930ull}},
{{13811773921075735403ull, 329572023125544ull}},
{{11030791829495445675ull, 527315237000871ull}},
{{5135284648854446217ull, 421852189600697ull}},
{{15176274163309287943ull, 337481751680557ull}},
{{9524643402327219416ull, 539970802688892ull}},
{{241017092377954886ull, 431976642151114ull}},
{{3882162488644274232ull, 345581313720891ull}},
{{17279506426056569741ull, 552930101953425ull}},
{{13823605140845255793ull, 442344081562740ull}},
{{11058884112676204634ull, 353875265250192ull}},
{{1468409660657143061ull, 283100212200154ull}},
{{9728153086535249544ull, 452960339520246ull}},
{{4093173654486289312ull, 362368271616197ull}},
{{14342585367814762419ull, 289894617292957ull}},
{{8190741329535978578ull, 463831387668732ull}},
{{17620639507854513832ull, 371065110134985ull}},
{{14096511606283611066ull, 296852088107988ull}},
{{418325681602315766ull, 474963340972782ull}},
{{11402706989507583582ull, 379970672778225ull}},
{{9122165591606066866ull, 303976538222580ull}},
{{14595464946569706985ull, 486362461156128ull}},
{{608325513030034619ull, 389089968924903ull}},
{{7865358039907848341ull, 311271975139922ull}},
{{16273921678594467669ull, 498035160223875ull}},
{{13019137342875574135ull, 398428128179100ull}},
{{10415309874300459308ull, 318742502543280ull}},
{{16664495798880734894ull, 509988004069248ull}},
{{2263550194878856945ull, 407990403255399ull}},
{{5500188970644995879ull, 326392322604319ull}},
{{16178999982515814053ull, 522227716166910ull}},
{{12943199986012651243ull, 417782172933528ull}},
{{17733257618293941640ull, 334225738346822ull}},
{{13615816930302665332ull, 534761181354916ull}},
{{7203304729500221942ull, 427808945083933ull}},
{{13141341413083998200ull, 342247156067146ull}},
{{13647448631450576474ull, 547595449707434ull}},
{{14607307719902371503ull, 438076359765947ull}},
{{4307148546438076556ull, 350461087812758ull}},
{{3202088859559012166ull, 560737740500413ull}},
{{9940368717131030379ull, 448590192400330ull}},
{{7952294973704824303ull, 358872153920264ull}},
{{10051184793705769766ull, 287097723136211ull}},
{{8703198040445410979ull, 459356357017938ull}},
{{14341256061840149429ull, 367485085614350ull}},
{{11473004849472119543ull, 293988068491480ull}},
{{18356807759155391270ull, 470380909586368ull}},
{{3617399763098582046ull, 376304727669095ull}},
{{2893919810478865637ull, 301043782135276ull}},
{{15698318140991915989ull, 481670051416441ull}},
{{8869305698051622468ull, 385336041133153ull}},
{{14474142187925118620ull, 308268832906522ull}},
{{8401232241712548500ull, 493230132650436ull}},
{{3031636978628128477ull, 394584106120349ull}},
{{6114658397644413105ull, 315667284896279ull}},
{{17162151065714881614ull, 505067655834046ull}},
{{10040372037829994968ull, 404054124667237ull}},
{{653600000780175328ull, 323243299733790ull}},
{{1045760001248280525ull, 517189279574064ull}},
{{4525956815740534743ull, 413751423659251ull}},
{{18378160711560069087ull, 331001138927400ull}},
{{10958313064786558924ull, 529601822283841ull}},
{{5077301637087336816ull, 423681457827073ull}},
{{11440538939153690099ull, 338945166261658ull}},
{{14615513487903993835ull, 542312266018653ull}},
{{624364346097464098ull, 433849812814923ull}},
{{7878189106361791925ull, 347079850251938ull}},
{{8915753755436956757ull, 555327760403101ull}},
{{3443254189607655082ull, 444262208322481ull}},
{{17511998610653765359ull, 355409766657984ull}},
{{17698947703264922610ull, 284327813326387ull}},
{{13560921066256234884ull, 454924501322220ull}},
{{10848736853004987907ull, 363939601057776ull}},
{{4989640667662080002ull, 291151680846221ull}},
{{604727438775507357ull, 465842689353954ull}},
{{4173130765762316209ull, 372674151483163ull}},
{{10717202242093673613ull, 298139321186530ull}},
{{17147523587349877782ull, 477022913898448ull}},
{{2649972425654171256ull, 381618331118759ull}},
{{5809326755265247328ull, 305294664895007ull}},
{{12984271623166306048ull, 488471463832011ull}},
{{6698068483791134515ull, 390777171065609ull}},
{{9047803601774817935ull, 312621736852487ull}},
{{18165834577581619020ull, 500194778963979ull}},
{{18222016476807205539ull, 400155823171183ull}},
{{3509566737220033461ull, 320124658536947ull}},
{{9304655594293963862ull, 512199453659115ull}},
{{7443724475435171089ull, 409759562927292ull}},
{{17023026024573867841ull, 327807650341833ull}},
{{5100748750866726606ull, 524492240546934ull}},
{{7769947815435291608ull, 419593792437547ull}},
{{17284004696573964256ull, 335675033950037ull}},
{{12897012255550701517ull, 537080054320060ull}},
{{10317609804440561214ull, 429664043456048ull}},
{{15632785473036269617ull, 343731234764838ull}},
{{2876363868406569449ull, 549969975623742ull}},
{{13369137538950986528ull, 439975980498993ull}},
{{18074007660644609869ull, 351980784399194ull}},
{{18148554943257598218ull, 281584627519355ull}},
{{10590943835502605534ull, 450535404030969ull}},
{{12162103883143994750ull, 360428323224775ull}},
{{9729683106515195800ull, 288342658579820ull}},
{{15567492970424313280ull, 461348253727712ull}},
{{5075296746855629978ull, 369078602982170ull}},
{{4060237397484503982ull, 295262882385736ull}},
{{17564426280200937341ull, 472420611817177ull}},
{{6672843394676929226ull, 377936489453742ull}},
{{16406321159967274351ull, 302349191562993ull}},
{{4114020967496177022ull, 483758706500790ull}},
{{3291216773996941618ull, 387006965200632ull}},
{{13701019863423284264ull, 309605572160505ull}},
{{3474887707767703206ull, 495368915456809ull}},
{{6469258980956072888ull, 396295132365447ull}},
{{16243453628990589280ull, 317036105892357ull}},
{{11232130547417301555ull, 507257769427772ull}},
{{1607006808450020598ull, 405806215542218ull}},
{{8664303076243837124ull, 324644972433774ull}},
{{2794838477764408430ull, 519431955894039ull}},
{{5925219596953437067ull, 415545564715231ull}},
{{1050826862820839330ull, 332436451772185ull}},
{{1681322980513342929ull, 531898322835496ull}},
{{16102453643378315636ull, 425518658268396ull}},
{{9192614099960742185ull, 340414926614717ull}},
{{18397531374679097820ull, 544663882583547ull}},
{{7339327470259457609ull, 435731106066838ull}},
{{13250159605691386734ull, 348584884853470ull}},
{{2753511295396667158ull, 557735815765553ull}},
{{9581506665801154373ull, 446188652612442ull}},
{{286507703157102852ull, 356950922089954ull}},
{{3918554977267592605ull, 285560737671963ull}},
{{2580339148886237845ull, 456897180275141ull}},
{{16821666578076631568ull, 365517744220112ull}},
{{6078635632977484608ull, 292414195376090ull}},
{{9725817012763975373ull, 467862712601744ull}},
{{11470002424953090622ull, 374290170081395ull}},
{{9176001939962472497ull, 299432136065116ull}},
{{7302905474456135350ull, 479091417704186ull}},
{{2152975564822997956ull, 383273134163349ull}},
{{5411729266600308688ull, 306618507330679ull}},
{{16037464456044314548ull, 490589611729086ull}},
{{9140622750093541315ull, 392471689383269ull}},
{{11001847014816743375ull, 313977351506615ull}},
{{17602955223706789400ull, 502363762410584ull}},
{{17771712993707341843ull, 401891009928467ull}},
{{6838672765482052828ull, 321512807942774ull}},
{{18320574054255105172ull, 514420492708438ull}},
{{3588412799178353168ull, 411536394166751ull}},
{{17628125498310323827ull, 329229115333400ull}},
{{9758256723586966507ull, 526766584533441ull}},
{{4117256564127662883ull, 421413267626753ull}},
{{10672502880785950952ull, 337130614101402ull}},
{{2318609350289880231ull, 539408982562244ull}},
{{5544236294973814508ull, 431527186049795ull}},
{{4435389035979051606ull, 345221748839836ull}},
{{18164668901792213540ull, 552354798143737ull}},
{{7153037491949950186ull, 441883838514990ull}},
{{5722429993559960148ull, 353507070811992ull}},
{{15645990439073699088ull, 282805656649593ull}},
{{2897491814066456602ull, 452489050639350ull}},
{{2317993451253165282ull, 361991240511480ull}},
{{1854394761002532225ull, 289592992409184ull}},
{{10345729247087872207ull, 463348787854694ull}},
{{11965932212412208089ull, 370679030283755ull}},
{{9572745769929766471ull, 296543224227004ull}},
{{4248346787661895384ull, 474469158763207ull}},
{{14466723874355247277ull, 379575327010565ull}},
{{11573379099484197821ull, 303660261608452ull}},
{{3760011300207075222ull, 485856418573524ull}},
{{6697357854907570501ull, 388685134858819ull}},
{{9047235098667966724ull, 310948107887055ull}},
{{14475576157868746758ull, 497516972619288ull}},
{{512414482069266437ull, 398013578095431ull}},
{{15167326844623054442ull, 318410862476344ull}},
{{13199676507171156138ull, 509457379962151ull}},
{{6870392390995014587ull, 407565903969721ull}},
{{1806965098054101346ull, 326052723175777ull}},
{{6580492971628472478ull, 521684357081243ull}},
{{12643092006786598628ull, 417347485664994ull}},
{{13803822420171189226ull, 333877988531995ull}},
{{3639371798564351146ull, 534204781651193ull}},
{{10290195068335301563ull, 427363825320954ull}},
{{11921504869410151573ull, 341891060256763ull}},
{{15385058976314332194ull, 547025696410821ull}},
{{8618698366309555432ull, 437620557128657ull}},
{{17963005137273375315ull, 350096445702925ull}},
{{10294064145927848889ull, 560154313124681ull}},
{{4545902502000368788ull, 448123450499745ull}},
{{3636722001600295030ull, 358498760399796ull}},
{{17666772860247877317ull, 286799008319836ull}},
{{2441394873203231445ull, 458878413311739ull}},
{{5642464713304495479ull, 367102730649391ull}},
{{824622955901686060ull, 293682184519513ull}},
{{16076791988410338989ull, 469891495231220ull}},
{{12861433590728271191ull, 375913196184976ull}},
{{6599798057840706629ull, 300730556947981ull}},
{{3180979263061309961ull, 481168891116770ull}},
{{2544783410449047969ull, 384935112893416ull}},
{{16793221987326879668ull, 307948090314732ull}},
{{12111759920755366176ull, 492716944503572ull}},
{{2310710307120472294ull, 394173555602858ull}},
{{9227265875180198482ull, 315338844482286ull}},
{{7384927770804496924ull, 504542151171658ull}},
{{13286639846127418186ull, 403633720937326ull}},
{{6939963062160024225ull, 322906976749861ull}},
{{3725243269972218115ull, 516651162799778ull}},
{{10358892245461595138ull, 413320930239822ull}},
{{908416166885455464ull, 330656744191858ull}},
{{16210861125984370035ull, 529050790706972ull}},
{{5589991271303675382ull, 423240632565578ull}},
{{11850690646526760952ull, 338592506052462ull}},
{{4203709775475176230ull, 541748009683940ull}},
{{3362967820380140984ull, 433398407747152ull}},
{{13758420700529843757ull, 346718726197721ull}},
{{14634775491363929365ull, 554749961916354ull}},
{{15397169207833053815ull, 443799969533083ull}},
{{1249688922040712082ull, 355039975626467ull}},
{{12067797581858300635ull, 284031980501173ull}},
{{15619127316231370693ull, 454451168801877ull}},
{{5116604223501275908ull, 363560935041502ull}},
{{15161329823026751696ull, 290848748033201ull}},
{{16879430087358982068ull, 465357996853122ull}},
{{6124846440403365008ull, 372286397482498ull}},
{{12278574781806512652ull, 297829117985998ull}},
{{15956370836148509921ull, 476526588777597ull}},
{{5386399039434987290ull, 381221271022078ull}},
{{11687816861031810479ull, 304977016817662ull}},
{{3943111718683255473ull, 487963226908260ull}},
{{3154489374946604378ull, 390370581526608ull}},
{{9902289129441104149ull, 312296465221286ull}},
{{8464964977621945992ull, 499674344354058ull}},
{{14150669611581377440ull, 399739475483246ull}},
{{7631186874523191629ull, 319791580386597ull}},
{{15899247813979016930ull, 511666528618555ull}},
{{12719398251183213544ull, 409333222894844ull}},
{{13864867415688481158ull, 327466578315875ull}},
{{3737043791392018237ull, 523946525305401ull}},
{{17747030292081255882ull, 419157220244320ull}},
{{14197624233665004706ull, 335325776195456ull}},
{{15337501144380186883ull, 536521241912730ull}},
{{12270000915504149506ull, 429216993530184ull}},
{{13505349547145229928ull, 343373594824147ull}},
{{6851164016464726593ull, 549397751718636ull}},
{{1791582398429870951ull, 439518201374909ull}},
{{5122614733485807084ull, 351614561099927ull}},
{{11885532388319201658ull, 562583297759883ull}},
{{16887123540139181972ull, 450066638207906ull}},
{{9820350017369435255ull, 360053310566325ull}},
{{7856280013895548204ull, 288042648453060ull}},
{{12570048022232877126ull, 460868237524896ull}},
{{6366689603044391378ull, 368694590019917ull}},
{{16161398126661244072ull, 294955672015933ull}},
{{3722144114206528576ull, 471929075225494ull}},
{{6667064106107133184ull, 377543260180395ull}},
{{5333651284885706547ull, 302034608144316ull}},
{{1155144426333309829ull, 483255373030906ull}},
{{15681510800034289156ull, 386604298424724ull}},
{{16234557454769341648ull, 309283438739779ull}},
{{14907245483405215667ull, 494853501983647ull}},
{{4547098757240351887ull, 395882801586918ull}},
{{11016376635276102156ull, 316706241269534ull}},
{{6558156172216032480ull, 506729986031255ull}},
{{5246524937772825984ull, 405383988825004ull}},
{{7886568764960171110ull, 324307191060003ull}},
{{8929161209194363454ull, 518891505696005ull}},
{{7143328967355490763ull, 415113204556804ull}},
{{9404011988626302933ull, 332090563645443ull}},
{{11357070367060174370ull, 531344901832709ull}},
{{12775005108390049819ull, 425075921466167ull}},
{{2841306457228219209ull, 340060737172934ull}},
{{11924787961048971381ull, 544097179476694ull}},
{{13229179183581087428ull, 435277743581355ull}},
{{10583343346864869942ull, 348222194865084ull}},
{{5865302910758060938ull, 557155511784135ull}},
{{4692242328606448751ull, 445724409427308ull}},
{{11132491492368979647ull, 356579527541846ull}},
{{5216644379153273394ull, 285263622033477ull}},
{{12035979821387147754ull, 456421795253563ull}},
{{17007481486593538850ull, 365137436202850ull}},
{{13605985189274831080ull, 292109948962280ull}},
{{3322832229130178112ull, 467375918339649ull}},
{{6347614598046052812ull, 373900734671719ull}},
{{8767440493178752573ull, 299120587737375ull}},
{{14027904789086004117ull, 478592940379800ull}},
{{11222323831268803294ull, 382874352303840ull}},
{{8977859065015042635ull, 306299481843072ull}},
{{18053923318765978539ull, 490079170948915ull}},
{{14443138655012782831ull, 392063336759132ull}},
{{4175813294526405618ull, 313650669407306ull}},
{{17749347715467979959ull, 501841071051689ull}},
{{17888826987116294291ull, 401472856841351ull}},
{{10621712774951125109ull, 321178285473081ull}},
{{9616042810437979529ull, 513885256756930ull}},
{{7692834248350383623ull, 411108205405544ull}},
{{9843616213422217221ull, 328886564324435ull}},
{{15749785941475547554ull, 526218502919096ull}},
{{8910479938438527720ull, 420974802335277ull}},
{{18196430394976553146ull, 336779841868221ull}},
{{3288846928769112771ull, 538847746989155ull}},
{{2631077543015290217ull, 431078197591324ull}},
{{5794210849154142496ull, 344862558073059ull}},
{{16649434988130448641ull, 551780092916894ull}},
{{17008896805246269236ull, 441424074333515ull}},
{{13607117444197015389ull, 353139259466812ull}},
{{3506996325873791664ull, 282511407573450ull}},
{{5611194121398066663ull, 452018252117520ull}},
{{4488955297118453331ull, 361614601694016ull}},
{{18348559496662403957ull, 289291681355212ull}},
{{14600299935692205039ull, 462866690168340ull}},
{{11680239948553764031ull, 370293352134672ull}},
{{1965494329359190578ull, 296234681707738ull}},
{{17902186185942346219ull, 473975490732380ull}},
{{14321748948753876975ull, 379180392585904ull}},
{{15146747973745011903ull, 303344314068723ull}},
{{2098703869540557106ull, 485350902509958ull}},
{{9057660725116266331ull, 388280722007966ull}},
{{3556779765351102741ull, 310624577606373ull}},
{{2001498809819854063ull, 496999324170197ull}},
{{12669245492081614220ull, 397599459336157ull}},
{{2756698764181470730ull, 318079567468926ull}},
{{15478764466916084137ull, 508927307950281ull}},
{{8693662758790956987ull, 407141846360225ull}},
{{6954930207032765589ull, 325713477088180ull}},
{{11127888331252424943ull, 521141563341088ull}},
{{16281008294485760601ull, 416913250672870ull}},
{{13024806635588608480ull, 333530600538296ull}},
{{13460992987457952923ull, 533648960861274ull}},
{{14458143204708272661ull, 426919168689019ull}},
{{15255863378508528452ull, 341535334951215ull}},
{{5962637331904093908ull, 546456535921945ull}},
{{4770109865523275126ull, 437165228737556ull}},
{{126739077676709777ull, 349732182990045ull}},
{{202782524282735644ull, 559571492784072ull}},
{{11230272463651919485ull, 447657194227257ull}},
{{1605520341437714941ull, 358125755381806ull}},
{{16041811532117813246ull, 286500604305444ull}},
{{14598852007162770224ull, 458400966888711ull}},
{{7989732790988305856ull, 366720773510969ull}},
{{10081135047532555008ull, 293376618808775ull}},
{{16129816076052088013ull, 469402590094040ull}},
{{12903852860841670410ull, 375522072075232ull}},
{{2944384659189515682ull, 300417657660186ull}},
{{15779061898928956060ull, 480668252256297ull}},
{{5244551889659344202ull, 384534601805038ull}},
{{11574339141211296008ull, 307627681444030ull}},
{{72198552228521997ull, 492204290310449ull}},
{{3747107656524727921ull, 393763432248359ull}},
{{6687034939961692660ull, 315010745798687ull}},
{{14388604718680618579ull, 504017193277899ull}},
{{15200232589686405186ull, 403213754622319ull}},
{{15849534886491034472ull, 322571003697855ull}},
{{6912511744676103539ull, 516113605916569ull}},
{{9219358210482793155ull, 412890884733255ull}},
{{7375486568386234524ull, 330312707786604ull}},
{{732732065192244269ull, 528500332458567ull}},
{{11654232096379526384ull, 422800265966853ull}},
{{16702083306587441754ull, 338240212773482ull}},
{{11965938031572265514ull, 541184340437572ull}},
{{2194052795773991764ull, 432947472350058ull}},
{{9133939866103014058ull, 346357977880046ull}},
{{7235606156281001846ull, 554172764608074ull}},
{{9477833739766711800ull, 443338211686459ull}},
{{11271615806555279763ull, 354670569349167ull}},
{{1638595015760403164ull, 283736455479334ull}},
{{10000449654700465709ull, 453978328766934ull}},
{{11689708538502282890ull, 363182663013547ull}},
{{1973069201318005666ull, 290546130410838ull}},
{{17914305981076450358ull, 464873808657340ull}},
{{14331444784861160287ull, 371899046925872ull}},
{{4086458198405107583ull, 297519237540698ull}},
{{2848984302706261810ull, 476030780065117ull}},
{{13347233886390740417ull, 380824624052093ull}},
{{18056484738596412980ull, 304659699241674ull}},
{{17822329137528529799ull, 487455518786679ull}},
{{17947212124764734162ull, 389964415029343ull}},
{{3289723255586056360ull, 311971532023475ull}},
{{5263557208937690176ull, 499154451237560ull}},
{{4210845767150152141ull, 399323560990048ull}},
{{10747374243203942359ull, 319458848792038ull}},
{{13506449974384397452ull, 511134158067261ull}},
{{7115811164765607638ull, 408907326453809ull}},
{{9381997746554396434ull, 327125861163047ull}},
{{253801135519393001ull, 523401377860876ull}},
{{14960436167383155694ull, 418721102288700ull}},
{{11968348933906524555ull, 334976881830960ull}},
{{702614220540887672ull, 535963010929537ull}},
{{11630137820658441107ull, 428770408743629ull}},
{{12993459071268663209ull, 343016326994903ull}},
{{17100185699287950811ull, 548826123191845ull}},
{{13680148559430360649ull, 439060898553476ull}},
{{7254770032802378196ull, 351248718842781ull}},
{{4228934422999984467ull, 561997950148450ull}},
{{3383147538399987574ull, 449598360118760ull}},
{{2706518030719990059ull, 359678688095008ull}},
{{9543912054059812693ull, 287742950476006ull}},
{{7891561657011879663ull, 460388720761610ull}},
{{6313249325609503730ull, 368310976609288ull}},
{{12429297089971423631ull, 294648781287430ull}},
{{1440131270244726193ull, 471438050059889ull}},
{{4841453830937691278ull, 377150440047911ull}},
{{183814250008242699ull, 301720352038329ull}},
{{7672800429497008965ull, 482752563261326ull}},
{{2448891528855696849ull, 386202050609061ull}},
{{16716508482052198772ull, 308961640487248ull}},
{{4610320682832056096ull, 494338624779598ull}},
{{11066954175749465523ull, 395470899823678ull}},
{{16232260970083393065ull, 316376719858942ull}},
{{11214222293165787611ull, 506202751774308ull}},
{{16350075464016450735ull, 404962201419446ull}},
{{9390711556471250265ull, 323969761135557ull}},
{{267743231386359131ull, 518351617816892ull}},
{{11282241029334818274ull, 414681294253513ull}},
{{16404490452951675266ull, 331745035402810ull}},
{{7800440651013128809ull, 530792056644497ull}},
{{17308398965036234017ull, 424633645315597ull}},
{{6468021542545166567ull, 339706916252478ull}},
{{6659485653330356185ull, 543531066003965ull}},
{{5327588522664284948ull, 434824852803172ull}},
{{15330117262357158928ull, 347859882242537ull}},
{{9770792360803812992ull, 556575811588060ull}},
{{7816633888643050393ull, 445260649270448ull}},
{{13632004740398260961ull, 356208519416358ull}},
{{18284301421802429415ull, 284966815533086ull}},
{{3429440571690514802ull, 455946904852939ull}},
{{6432901272094322165ull, 364757523882351ull}},
{{1456972202933547408ull, 291806019105881ull}},
{{13399201968919406823ull, 466889630569409ull}},
{{14408710389877435782ull, 373511704455527ull}},
{{4148270682418127979ull, 298809363564422ull}},
{{10326581906610915090ull, 478094981703075ull}},
{{8261265525288732072ull, 382475985362460ull}},
{{6609012420230985657ull, 305980788289968ull}},
{{6885071057627666729ull, 489569261263949ull}},
{{9197405660844043706ull, 391655409011159ull}},
{{11047273343417145288ull, 313324327208927ull}},
{{2918242090499791168ull, 501318923534284ull}},
{{6023942487141743258ull, 401055138827427ull}},
{{15887200433939125576ull, 320844111061941ull}},
{{18040823064818780275ull, 513350577699106ull}},
{{10743309637113113897ull, 410680462159285ull}},
{{8594647709690491117ull, 328544369727428ull}},
{{10062087520762875465ull, 525670991563885ull}},
{{8049670016610300372ull, 420536793251108ull}},
{{13818433642772060944ull, 336429434600886ull}},
{{14730796198951476864ull, 538287095361418ull}},
{{716590514935450521ull, 430629676289135ull}},
{{573272411948360417ull, 344503741031308ull}},
{{15674631118085017960ull, 551205985650092ull}},
{{5161007264984193722ull, 440964788520074ull}},
{{7818154626729265300ull, 352771830816059ull}},
{{9943872516125322563ull, 282217464652847ull}},
{{1152800766832874809ull, 451547943444556ull}},
{{15679635872433941140ull, 361238354755644ull}},
{{16233057512689063235ull, 288990683804515ull}},
{{7526147946592949560ull, 462385094087225ull}},
{{6020918357274359648ull, 369908075269780ull}},
{{4816734685819487718ull, 295926460215824ull}},
{{15085473126795000996ull, 473482336345318ull}},
{{1000332057210269827ull, 378785869076255ull}},
{{800265645768215862ull, 303028695261004ull}},
{{8659122662712966025ull, 484845912417606ull}},
{{3237949315428462497ull, 387876729934085ull}},
{{2590359452342769997ull, 310301383947268ull}},
{{455226309006521673ull, 496482214315629ull}},
{{4053529861947127662ull, 397185771452503ull}},
{{10621521519041522776ull, 317748617162002ull}},
{{2237039171498795148ull, 508397787459204ull}},
{{5478980151940946442ull, 406718229967363ull}},
{{11761881751036577800ull, 325374583973890ull}},
{{372266727948972864ull, 520599334358225ull}},
{{297813382359178291ull, 416479467486580ull}},
{{238250705887342633ull, 333183573989264ull}},
{{7759898758903568859ull, 533093718382822ull}},
{{17275965451348586057ull, 426474974706257ull}},
{{6442074731595048199ull, 341179979765006ull}},
{{2928621941068256472ull, 545887967624010ull}},
{{2342897552854605178ull, 436710374099208ull}},
{{9253015671767504788ull, 349368299279366ull}},
{{7426127445344187015ull, 558989278846986ull}},
{{2251553141533439289ull, 447191423077589ull}},
{{5490591327968661754ull, 357753138462071ull}},
{{703124247633019080ull, 286202510769657ull}},
{{4814347610954740852ull, 457924017231451ull}},
{{162129274021882358ull, 366339213785161ull}},
{{14887098678185147179ull, 293071371028128ull}},
{{1683264996644773548ull, 468914193645006ull}},
{{16104007256283460131ull, 375131354916004ull}},
{{16572554619768678428ull, 300105083932803ull}},
{{4379994503178423545ull, 480168134292486ull}},
{{18261390861510380129ull, 384134507433988ull}},
{{3541066244982573134ull, 307307605947191ull}},
{{16733752436197847984ull, 491692169515505ull}},
{{13387001948958278387ull, 393353735612404ull}},
{{14398950373908533033ull, 314682988489923ull}},
{{902227709802190913ull, 503492781583878ull}},
{{8100479797325573377ull, 402794225267102ull}},
{{17548430282086189671ull, 322235380213681ull}},
{{2252046748144531211ull, 515576608341891ull}},
{{16559032657483266262ull, 412461286673512ull}},
{{5868528496502792363ull, 329969029338810ull}},
{{9389645594404467781ull, 527950446942096ull}},
{{3822367660781663902ull, 422360357553677ull}},
{{14125940572851062091ull, 337888286042941ull}},
{{15222807287077878699ull, 540621257668706ull}},
{{8488897014920392636ull, 432497006134965ull}},
{{6791117611936314109ull, 345997604907972ull}},
{{14555136993840012897ull, 553596167852755ull}},
{{11644109595072010318ull, 442876934282204ull}},
{{13004636490799518577ull, 354301547425763ull}},
{{17782406822123435508ull, 283441237940610ull}},
{{10005106841687945197ull, 453505980704977ull}},
{{625387843866535511ull, 362804784563982ull}},
{{11568356719318959379ull, 290243827651185ull}},
{{62626677200783390ull, 464390124241897ull}},
{{11118147785986357682ull, 371512099393517ull}},
{{1515820599305265499ull, 297209679514814ull}},
{{9804010588372245445ull, 475535487223702ull}},
{{464510841213975709ull, 380428389778962ull}},
{{11439655117196911537ull, 304342711823169ull}},
{{7235401743289327490ull, 486948338917071ull}},
{{2098972579889551669ull, 389558671133657ull}},
{{12747224508137372304ull, 311646936906925ull}},
{{1948815139310244071ull, 498635099051081ull}},
{{16316447370415836550ull, 398908079240864ull}},
{{16742506711074579563ull, 319126463392691ull}},
{{962569034525955038ull, 510602341428307ull}},
{{11838101671846495000ull, 408481873142645ull}},
{{9470481337477196000ull, 326785498514116ull}},
{{7774072510479692954ull, 522856797622586ull}},
{{2529909193641844040ull, 418285438098069ull}},
{{5713276169655385555ull, 334628350478455ull}},
{{9141241871448616888ull, 535405360765528ull}},
{{14691691126642714157ull, 428324288612422ull}},
{{4374655271830350679ull, 342659430889938ull}},
{{3310099620186650764ull, 548255089423901ull}},
{{17405474955116961904ull, 438604071539120ull}},
{{13924379964093569523ull, 350883257231296ull}},
{{14900310313065890590ull, 561413211570074ull}},
{{15609597065194622795ull, 449130569256059ull}},
{{16177026466897608559ull, 359304455404847ull}},
{{5562923544034266201ull, 287443564323878ull}},
{{5211328855712915599ull, 459909702918205ull}},
{{4169063084570332479ull, 367927762334564ull}},
{{7024599282398176306ull, 294342209867651ull}},
{{3860661222353261444ull, 470947535788242ull}},
{{14156575422108340125ull, 376758028630593ull}},
{{257213893460941130ull, 301406422904475ull}},
{{411542229537505808ull, 482250276647160ull}},
{{329233783630004647ull, 385800221317728ull}},
{{7642084656387824364ull, 308640177054182ull}},
{{15916684264962429305ull, 493824283286691ull}},
{{9043998597228033121ull, 395059426629353ull}},
{{14613896507266247143ull, 316047541303482ull}},
{{8624839152658354136ull, 505676066085572ull}},
{{17967917766352414278ull, 404540852868457ull}},
{{6995636583598110776ull, 323632682294766ull}},
{{3814320904273156596ull, 517812291671626ull}},
{{17808851982386166569ull, 414249833337300ull}},
{{14247081585908933255ull, 331399866669840ull}},
{{4348586463744741593ull, 530239786671745ull}},
{{3478869170995793274ull, 424191829337396ull}},
{{17540490595764275912ull, 339353463469916ull}},
{{2239343250029469197ull, 542965541551867ull}},
{{12859521044249306327ull, 434372433241493ull}},
{{17666314464883265708ull, 347497946593194ull}},
{{17198056699587494164ull, 555996714549111ull}},
{{10069096544928085008ull, 444797371639289ull}},
{{11744626050684378329ull, 355837897311431ull}},
{{5706352025805592340ull, 284670317849145ull}},
{{9130163241288947745ull, 455472508558632ull}},
{{18372177037256889165ull, 364378006846905ull}},
{{14697741629805511332ull, 291502405477524ull}},
{{12448340163463087162ull, 466403848764039ull}},
{{13648020945512380053ull, 373123079011231ull}},
{{7229067941667993719ull, 298498463208985ull}},
{{11566508706668789950ull, 477597541134376ull}},
{{5563858150593121637ull, 382078032907501ull}},
{{761737705732586986ull, 305662426326001ull}},
{{12286826773397870148ull, 489059882121601ull}},
{{6140112603976385795ull, 391247905697281ull}},
{{1222741268439198313ull, 312998324557825ull}},
{{1956386029502717301ull, 500797319292520ull}},
{{1565108823602173840ull, 400637855434016ull}},
{{16009482317849380365ull, 320510284347212ull}},
{{10857776449591367292ull, 512816454955540ull}},
{{8686221159673093833ull, 410253163964432ull}},
{{18017023371964206036ull, 328202531171545ull}},
{{10380493321433178042ull, 525124049874473ull}},
{{15683092286630363080ull, 420099239899578ull}},
{{1478427385078559494ull, 336079391919663ull}},
{{17122879075093336484ull, 537727027071460ull}},
{{13698303260074669187ull, 430181621657168ull}},
{{18337340237543555996ull, 344145297325734ull}},
{{18271697935843958624ull, 550632475721175ull}},
{{14617358348675166899ull, 440505980576940ull}},
{{11693886678940133519ull, 352404784461552ull}},
{{1976411713668286169ull, 281923827569242ull}},
{{6851607556611168194ull, 451078124110787ull}},
{{16549332489514665525ull, 360862499288629ull}},
{{16928814806353642743ull, 288689999430903ull}},
{{4950010801714366449ull, 461903999089446ull}},
{{270659826629582836ull, 369523199271557ull}},
{{11284574305529397238ull, 295618559417245ull}},
{{18055318888847035582ull, 472989695067592ull}},
{{7065557481593807819ull, 378391756054074ull}},
{{9341794800016956578ull, 302713404843259ull}},
{{3878825235801399556ull, 484341447749215ull}},
{{3103060188641119645ull, 387473158199372ull}},
{{13550494595138626685ull, 309978526559497ull}},
{{6923396093254161404ull, 495965642495196ull}},
{{1849368059861418800ull, 396772513996157ull}},
{{12547540892114866009ull, 317418011196925ull}},
{{1629321353674233999ull, 507868817915081ull}},
{{16060852341907028492ull, 406295054332064ull}},
{{16538030688267533117ull, 325036043465651ull}},
{{635407398034680725ull, 520057669545043ull}},
{{7887023547911565226ull, 416046135636034ull}},
{{9998967653071162504ull, 332836908508827ull}},
{{1240952985946218714ull, 532539053614124ull}},
{{4682111203498885294ull, 426031242891299ull}},
{{7435037777541018558ull, 340824994313039ull}},
{{828013999839898724ull, 545319990900863ull}},
{{8041108829355739626ull, 436255992720690ull}},
{{6432887063484591700ull, 349004794176552ull}},
{{13981968116317257044ull, 558407670682483ull}},
{{117528048828074666ull, 446726136545987ull}},
{{11162068883288190702ull, 357380909236789ull}},
{{12619003921372462885ull, 285904727389431ull}},
{{12811708644712119969ull, 457447563823090ull}},
{{10249366915769695975ull, 365958051058472ull}},
{{820795903131936134ull, 292766440846778ull}},
{{16070668703978739107ull, 468426305354844ull}},
{{16545883777924901609ull, 374741044283875ull}},
{{13236707022339921287ull, 299792835427100ull}},
{{2731987162034322444ull, 479668536683361ull}},
{{16942984988595099248ull, 383734829346688ull}},
{{2486341546650348428ull, 306987863477351ull}},
{{15046192918866288455ull, 491180581563761ull}},
{{8347605520351120441ull, 392944465251009ull}},
{{10367433231022806676ull, 314355572200807ull}},
{{1830497910668849389ull, 502968915521292ull}},
{{12532444772760810481ull, 402375132417033ull}},
{{17404653447692469031ull, 321900105933626ull}},
{{2022003813114578187ull, 515040169493803ull}},
{{8996300679975483196ull, 412032135595042ull}},
{{18265086988206117526ull, 329625708476033ull}},
{{7088046292678326103ull, 527401133561654ull}},
{{9359785848884571206ull, 421920906849323ull}},
{{14866526308591477611ull, 337536725479458ull}},
{{1650349205294902238ull, 540058760767134ull}},
{{5009628178977832114ull, 432047008613707ull}},
{{15075748987407996661ull, 345637606890965ull}},
{{5674454306143243041ull, 553020171025545ull}},
{{4539563444914594433ull, 442416136820436ull}},
{{18389046014899316839ull, 353932909456348ull}},
{{3643190367693722501ull, 283146327565079ull}},
{{13207802217793776649ull, 453034124104126ull}},
{{6876892959493110996ull, 362427299283301ull}},
{{1812165552852578473ull, 289941839426641ull}},
{{13967511328789856527ull, 463906943082625ull}},
{{11174009063031885222ull, 371125554466100ull}},
{{8939207250425508177ull, 296900443572880ull}},
{{14302731600680813084ull, 475040709716608ull}},
{{374138836318919498ull, 380032567773287ull}},
{{11367357513280866568ull, 304026054218629ull}},
{{7119725577023655539ull, 486441686749807ull}},
{{16763826905844655401ull, 389153349399845ull}},
{{13411061524675724320ull, 311322679519876ull}},
{{14079000809997338266ull, 498116287231802ull}},
{{3884503018514049967ull, 398493029785442ull}},
{{14175648859036970943ull, 318794423828353ull}},
{{544945286007691570ull, 510071078125366ull}},
{{15193351487773794548ull, 408056862500292ull}},
{{4775983560735214992ull, 326445490000234ull}},
{{15020271326660164634ull, 522312784000374ull}},
{{15705565876070042031ull, 417850227200299ull}},
{{16253801515597943948ull, 334280181760239ull}},
{{14938035980730979347ull, 534848290816383ull}},
{{882382340359052508ull, 427878632653107ull}},
{{11773952316512972976ull, 342302906122485ull}},
{{391579632711205145ull, 547684649795977ull}},
{{11381310150394695086ull, 438147719836781ull}},
{{5415699305573845745ull, 350518175869425ull}},
{{8665118888918153193ull, 560829081391080ull}},
{{6932095111134522554ull, 448663265112864ull}},
{{9235024903649528366ull, 358930612090291ull}},
{{3698671108177712370ull, 287144489672233ull}},
{{2228524958342429469ull, 459431183475573ull}},
{{9161517596157764221ull, 367544946780458ull}},
{{14707911706410032023ull, 294035957424366ull}},
{{16153961100772230591ull, 470457531878986ull}},
{{9233820065875874150ull, 376366025503189ull}},
{{11076404867442609643ull, 301092820402551ull}},
{{10343550158424354783ull, 481748512644082ull}},
{{896142497255663180ull, 385398810115266ull}},
{{15474309256772171836ull, 308319048092212ull}},
{{10001499551867833646ull, 493310476947540ull}},
{{8001199641494266916ull, 394648381558032ull}},
{{17469006157421144503ull, 315718705246425ull}},
{{9503665778164279588ull, 505149928394281ull}},
{{3913583807789513347ull, 404119942715425ull}},
{{3130867046231610678ull, 323295954172340ull}},
{{5009387273970577085ull, 517273526675744ull}},
{{7696858633918371991ull, 413818821340595ull}},
{{6157486907134697593ull, 331055057072476ull}},
{{2473281421931695502ull, 529688091315962ull}},
{{13046671581771087371ull, 423750473052769ull}},
{{14126686080158780220ull, 339000378442215ull}},
{{4155953654544496737ull, 542400605507545ull}},
{{3324762923635597389ull, 433920484406036ull}},
{{17417205597876119204ull, 347136387524828ull}},
{{5731436068150328788ull, 555418220039726ull}},
{{895800039778352707ull, 444334576031781ull}},
{{15474035290790323458ull, 355467660825424ull}},
{{16068577047374169090ull, 284374128660339ull}},
{{14641676831572939574ull, 454998605856543ull}},
{{645295021032620689ull, 363998884685235ull}},
{{516236016826096551ull, 291199107748188ull}},
{{15583372885889395775ull, 465918572397100ull}},
{{12466698308711516620ull, 372734857917680ull}},
{{9973358646969213296ull, 298187886334144ull}},
{{4889327390925010305ull, 477100618134631ull}},
{{222113097998097920ull, 381680494507705ull}},
{{177690478398478336ull, 305344395606164ull}},
{{7663002394921385985ull, 488551032969862ull}},
{{17198448360162839757ull, 390840826375889ull}},
{{17448107502872182129ull, 312672661100711ull}},
{{2091530301402119144ull, 500276257761139ull}},
{{5362573055863605638ull, 400221006208911ull}},
{{600709629948974187ull, 320176804967129ull}},
{{8339833037402179346ull, 512282887947406ull}},
{{2982517615179833154ull, 409826310357925ull}},
{{2386014092143866523ull, 327861048286340ull}},
{{3817622547430186437ull, 524577677258144ull}},
{{6743446852686059473ull, 419662141806515ull}},
{{5394757482148847578ull, 335729713445212ull}},
{{12320960786180066448ull, 537167541512339ull}},
{{13546117443685963482ull, 429734033209871ull}},
{{7147545140206860462ull, 343787226567897ull}},
{{15125421039072887063ull, 550059562508635ull}},
{{12100336831258309650ull, 440047650006908ull}},
{{17058967094490468367ull, 352038120005526ull}},
{{9957824860850464370ull, 281630496004421ull}},
{{8553822147876922346ull, 450608793607074ull}},
{{10532406533043448200ull, 360487034885659ull}},
{{12115274041176668883ull, 288389627908527ull}},
{{4627043206915028920ull, 461423404653644ull}},
{{7390983380273933459ull, 369138723722915ull}},
{{5912786704219146767ull, 295310978978332ull}},
{{13149807541492545151ull, 472497566365331ull}},
{{6830497218452125798ull, 377998053092265ull}},
{{5464397774761700638ull, 302398442473812ull}},
{{12432385254360631344ull, 483837507958099ull}},
{{13635257018230415399ull, 387070006366479ull}},
{{14597554429326242642ull, 309656005093183ull}},
{{1219994198470526288ull, 495449608149094ull}},
{{4665344173518331354ull, 396359686519275ull}},
{{3732275338814665083ull, 317087749215420ull}},
{{5971640542103464133ull, 507340398744672ull}},
{{15845358877908502276ull, 405872318995737ull}},
{{5297589472842981174ull, 324697855196590ull}},
{{8476143156548769879ull, 519516568314544ull}},
{{10470263339980926226ull, 415613254651635ull}},
{{8376210671984740981ull, 332490603721308ull}},
{{9712588260433675246ull, 531984965954093ull}},
{{15148768237830760843ull, 425587972763274ull}},
{{15808363405006518998ull, 340470378210619ull}},
{{14225335003784699427ull, 544752605136991ull}},
{{7690919188285849219ull, 435802084109593ull}},
{{13531432980112500021ull, 348641667287674ull}},
{{10582246323954269064ull, 557826667660279ull}},
{{12155145873905325575ull, 446261334128223ull}},
{{17102814328608081106ull, 357009067302578ull}},
{{2614205018660733915ull, 285607253842063ull}},
{{493379215115263941ull, 456971606147301ull}},
{{15152098631059852446ull, 365577284917840ull}},
{{12121678904847881957ull, 292461827934272ull}},
{{4637290988788969838ull, 467938924694836ull}},
{{20483976289265547ull, 374351139755869ull}},
{{3705735995773322761ull, 299480911804695ull}},
{{5929177593237316417ull, 479169458887512ull}},
{{15811388518815584103ull, 383335567110009ull}},
{{16338459629794377606ull, 306668453688007ull}},
{{11384140148703362877ull, 490669525900812ull}},
{{1728614489478869655ull, 392535620720650ull}},
{{1382891591583095724ull, 314028496576520ull}},
{{2212626546532953159ull, 502445594522432ull}},
{{12838147681452093496ull, 401956475617945ull}},
{{10270518145161674797ull, 321565180494356ull}},
{{9054131402774859029ull, 514504288790970ull}},
{{7243305122219887223ull, 411603431032776ull}},
{{2105295283033999455ull, 329282744826221ull}},
{{14436518897080130098ull, 526852391721953ull}},
{{481168673438373109ull, 421481913377563ull}},
{{7763632568234519133ull, 337185530702050ull}},
{{12421812109175230614ull, 539496849123280ull}},
{{9937449687340184491ull, 431597479298624ull}},
{{11639308564614057916ull, 345277983438899ull}},
{{7554847259156761696ull, 552444773502239ull}},
{{9733226622067319680ull, 441955818801791ull}},
{{4097232482911945421ull, 353564655041433ull}},
{{10656483615813376983ull, 282851724033146ull}},
{{9671676155817582526ull, 452562758453034ull}},
{{11426689739395976344ull, 362050206762427ull}},
{{1762654162032960429ull, 289640165409942ull}},
{{6509595473994647010ull, 463424264655907ull}},
{{16275722823421448577ull, 370739411724725ull}},
{{13020578258737158862ull, 296591529379780ull}},
{{2386181140269902563ull, 474546447007649ull}},
{{5598293726957832374ull, 379637157606119ull}},
{{8167983796308176222ull, 303709726084895ull}},
{{13068774074093081955ull, 485935561735832ull}},
{{3076321629790644918ull, 388748449388666ull}},
{{17218452562800157227ull, 310998759510932ull}},
{{12792128841512610271ull, 497598015217492ull}},
{{2855005443726267570ull, 398078412173994ull}},
{{5973353169722924379ull, 318462729739195ull}},
{{9557365071556679007ull, 509540367582712ull}},
{{267194427761522559ull, 407632294066170ull}},
{{213755542209218047ull, 326105835252936ull}},
{{11410055311760479845ull, 521769336404697ull}},
{{1749346619924563230ull, 417415469123758ull}},
{{8778174925423471230ull, 333932375299006ull}},
{{6666382251193733322ull, 534291800478410ull}},
{{5333105800954986657ull, 427433440382728ull}},
{{11645182270247809972ull, 341946752306182ull}},
{{3874896373428854663ull, 547114803689892ull}},
{{14167963542968814700ull, 437691842951913ull}},
{{266324390149320790ull, 350153474361531ull}},
{{11494165468464644234ull, 560245558978449ull}},
{{12884681189513625711ull, 448196447182759ull}},
{{13997093766352810892ull, 358557157746207ull}},
{{3818977383598428067ull, 286845726196966ull}},
{{17178410257983215877ull, 458953161915145ull}},
{{13742728206386572701ull, 367162529532116ull}},
{{7304833750367347838ull, 293730023625693ull}},
{{7998385185845846217ull, 469968037801109ull}},
{{10088056963418587297ull, 375974430240887ull}},
{{691747941251049191ull, 300779544192710ull}},
{{1106796706001678706ull, 481247270708336ull}},
{{15642832623768984258ull, 384997816566668ull}},
{{1446219654789456436ull, 307998253253335ull}},
{{2313951447663130299ull, 492797205205336ull}},
{{16608556417098145532ull, 394237764164268ull}},
{{2218798689452785456ull, 315390211331415ull}},
{{3550077903124456729ull, 504624338130264ull}},
{{6529411137241475706ull, 403699470504211ull}},
{{1534180095051270242ull, 322959576403369ull}},
{{9833385781565853034ull, 516735322245390ull}},
{{7866708625252682427ull, 413388257796312ull}},
{{17361413344427876911ull, 330710606237049ull}},
{{16710214906858872088ull, 529136969979279ull}},
{{17057520740229007994ull, 423309575983423ull}},
{{2577970147957475425ull, 338647660786739ull}},
{{11503449866215781327ull, 541836257258782ull}},
{{1824062263488804415ull, 433469005807026ull}},
{{16216645069758684825ull, 346775204645620ull}},
{{7499888037904344104ull, 554840327432993ull}},
{{13378608059807295930ull, 443872261946394ull}},
{{14392235262587747067ull, 355097809557115ull}},
{{11513788210070197653ull, 284078247645692ull}},
{{3664665877144674953ull, 454525196233108ull}},
{{10310430331199560608ull, 363620156986486ull}},
{{4558995450217738163ull, 290896125589189ull}},
{{14673090349832201708ull, 465433800942702ull}},
{{4359774650381940720ull, 372347040754162ull}},
{{14555866164531283546ull, 297877632603329ull}},
{{12221339419024322704ull, 476604212165327ull}},
{{2398373905735637516ull, 381283369732262ull}},
{{12986745568814240983ull, 305026695785809ull}},
{{9710746465877054603ull, 488042713257295ull}},
{{7768597172701643682ull, 390434170605836ull}},
{{2525528923419404623ull, 312347336484669ull}},
{{11419543906954868043ull, 499755738375470ull}},
{{9135635125563894434ull, 399804590700376ull}},
{{3619159285709205224ull, 319843672560301ull}},
{{16858701301360459328ull, 511749876096481ull}},
{{9797612226346457139ull, 409399900877185ull}},
{{7838089781077165711ull, 327519920701748ull}},
{{8851594834981554815ull, 524031873122797ull}},
{{18149322312210974822ull, 419225498498237ull}},
{{7140760220284959211ull, 335380398798590ull}},
{{11425216352455934738ull, 536608638077744ull}},
{{12829521896706658113ull, 429286910462195ull}},
{{10263617517365326490ull, 343429528369756ull}},
{{9043090398300701739ull, 549487245391610ull}},
{{7234472318640561391ull, 439589796313288ull}},
{{13166275484396269759ull, 351671837050630ull}},
{{2619296701324479999ull, 562674939281009ull}},
{{5784786175801494322ull, 450139951424807ull}},
{{15695875384866926427ull, 360111961139845ull}},
{{12556700307893541142ull, 288089568911876ull}},
{{12712022863145845180ull, 460943310259002ull}},
{{2790920661032855498ull, 368754648207202ull}},
{{13300782973052015368ull, 295003718565761ull}},
{{13902555127399403942ull, 472005949705218ull}},
{{53997657693792184ull, 377604759764175ull}},
{{43198126155033747ull, 302083807811340ull}},
{{69117001848053996ull, 483334092498144ull}},
{{3744642416220353520ull, 386667273998515ull}},
{{2995713932976282816ull, 309333819198812ull}},
{{8482491107503962829ull, 494934110718099ull}},
{{10475341700745080586ull, 395947288574479ull}},
{{12069622175337974792ull, 316757830859583ull}},
{{15622046665798849344ull, 506812529375333ull}},
{{1429590888413348506ull, 405450023500267ull}},
{{12211719154956409774ull, 324360018800213ull}},
{{15849401833188345316ull, 518976030080341ull}},
{{8990172651808765929ull, 415180824064273ull}},
{{14570835750930833390ull, 332144659251418ull}},
{{1177244313037871484ull, 531431454802270ull}},
{{941795450430297187ull, 425145163841816ull}},
{{15510831619311879043ull, 340116131073452ull}},
{{10059935331931365176ull, 544185809717524ull}},
{{11737297080287002464ull, 435348647774019ull}},
{{13079186478971512294ull, 348278918219215ull}},
{{2479954292644868055ull, 557246269150745ull}},
{{1983963434115894444ull, 445797015320596ull}},
{{16344566006260356848ull, 356637612256476ull}},
{{9386303990266375155ull, 285310089805181ull}},
{{7639388754942379602ull, 456496143688290ull}},
{{6111511003953903681ull, 365196914950632ull}},
{{15957255247388853915ull, 292157531960505ull}},
{{7084864322112614648ull, 467452051136809ull}},
{{9357240272432002041ull, 373961640909447ull}},
{{107094588461780986ull, 299169312727558ull}},
{{14928746600506490871ull, 478670900364092ull}},
{{4564299650921372051ull, 382936720291274ull}},
{{7340788535479007964ull, 306349376233019ull}},
{{677215212540681772ull, 490159001972831ull}},
{{15299167429000186711ull, 392127201578264ull}},
{{15928682757942059692ull, 313701761262611ull}},
{{18107194783223474860ull, 501922818020178ull}},
{{3417709382353048919ull, 401538254416143ull}},
{{10112865135366259781ull, 321230603532914ull}},
{{5112537772360284681ull, 513968965652663ull}},
{{11468727847372048391ull, 411175172522130ull}},
{{9174982277897638713ull, 328940138017704ull}},
{{3611925200410490971ull, 526304220828327ull}},
{{13957586604554123746ull, 421043376662661ull}},
{{7476720468901388674ull, 336834701330129ull}},
{{894706306016490908ull, 538935522128207ull}},
{{11783811489038923696ull, 431148417702565ull}},
{{9427049191231138957ull, 344918734162052ull}},
{{325883447002181039ull, 551869974659284ull}},
{{3950055572343655154ull, 441495979727427ull}},
{{14228090902100655093ull, 353196783781941ull}},
{{7693123906938613751ull, 282557427025553ull}},
{{8619649436359871678ull, 452091883240885ull}},
{{6895719549087897343ull, 361673506592708ull}},
{{12895273268754138520ull, 289338805274166ull}},
{{13253739600522800987ull, 462942088438666ull}},
{{6913642865676330466ull, 370353670750933ull}},
{{12909611922024885019ull, 296282936600746ull}},
{{13276681445755995384ull, 474052698561194ull}},
{{14310693971346706631ull, 379242158848955ull}},
{{11448555177077365304ull, 303393727079164ull}},
{{7249641839098053518ull, 485429963326663ull}},
{{13178411100762263460ull, 388343970661330ull}},
{{10542728880609810768ull, 310675176529064ull}},
{{5800319764749966260ull, 497080282446503ull}},
{{12018953441283793654ull, 397664225957202ull}},
{{2236465123543214277ull, 318131380765762ull}},
{{7267693012411053167ull, 509010209225219ull}},
{{9503503224670752856ull, 407208167380175ull}},
{{7602802579736602285ull, 325766533904140ull}},
{{12164484127578563656ull, 521226454246624ull}},
{{13420936116804761248ull, 416981163397299ull}},
{{14426097708185719322ull, 333584930717839ull}},
{{12013709888871419945ull, 533735889148543ull}},
{{16989665540580956603ull, 426988711318834ull}},
{{17281081247206675605ull, 341590969055067ull}},
{{12892334736563039676ull, 546545550488108ull}},
{{17692565418734252387ull, 437236440390486ull}},
{{10464703520245491586ull, 349789152312389ull}},
{{5675479188167055569ull, 559662643699823ull}},
{{11919080980017465101ull, 447730114959858ull}},
{{16913962413497792727ull, 358184091967886ull}},
{{9841821116056323858ull, 286547273574309ull}},
{{4678867341464387204ull, 458475637718895ull}},
{{3743093873171509763ull, 366780510175116ull}},
{{17751870357504849103ull, 293424408140092ull}},
{{13645597313040117273ull, 469479053024148ull}},
{{18295175479915914465ull, 375583242419318ull}},
{{3568093939707000602ull, 300466593935455ull}},
{{5708950303531200963ull, 480746550296728ull}},
{{11945857872308781417ull, 384597240237382ull}},
{{2177988668363204487ull, 307677792189906ull}},
{{14552828313606858149ull, 492284467503849ull}},
{{15331611465627396843ull, 393827574003079ull}},
{{15954637987243827797ull, 315062059202463ull}},
{{3391327891138662537ull, 504099294723942ull}},
{{13781108757136660999ull, 403279435779153ull}},
{{18403584635193149445ull, 322623548623322ull}},
{{14688340157341397820ull, 516197677797316ull}},
{{8061323311131207933ull, 412958142237853ull}},
{{13827756278388786992ull, 330366513790282ull}},
{{7367014786454417895ull, 528586422064452ull}},
{{16961658273389265286ull, 422869137651561ull}},
{{9879977803969501905ull, 338295310121249ull}},
{{4739918042125472079ull, 541272496193999ull}},
{{7481283248442287987ull, 433017996955199ull}},
{{9674375413495740712ull, 346414397564159ull}},
{{4410954217367454170ull, 554263036102655ull}},
{{3528763373893963336ull, 443410428882124ull}},
{{6512359513857080992ull, 354728343105699ull}},
{{8899236425827575117ull, 283782674484559ull}},
{{3170731837098389218ull, 454052279175295ull}},
{{2536585469678711374ull, 363241823340236ull}},
{{16786663634710610392ull, 290593458672188ull}},
{{4722568927085514688ull, 464949533875502ull}},
{{14846101585894142720ull, 371959627100401ull}},
{{8187532453973403853ull, 297567701680321ull}},
{{5721354296873625518ull, 476108322688514ull}},
{{8266432252240810738ull, 380886658150811ull}},
{{2923796987050738267ull, 304709326520649ull}},
{{12056772808765001874ull, 487534922433038ull}},
{{17024115876495822145ull, 390027937946430ull}},
{{13619292701196657716ull, 312022350357144ull}},
{{10722821877688921376ull, 499235760571431ull}},
{{4888908687409226778ull, 399388608457145ull}},
{{3911126949927381422ull, 319510886765716ull}},
{{17325849564109541245ull, 511217418825145ull}},
{{13860679651287632996ull, 408973935060116ull}},
{{7399194906288196074ull, 327179148048093ull}},
{{8149363035319203395ull, 523486636876949ull}},
{{10208839242997273039ull, 418789309501559ull}},
{{11856420209139728754ull, 335031447601247ull}},
{{4212877075655924714ull, 536050316161996ull}},
{{18127696919492381064ull, 428840252929596ull}},
{{10812808720851994528ull, 343072202343677ull}},
{{2543098694395549952ull, 548915523749884ull}},
{{5723827770258350285ull, 439132418999907ull}},
{{15647108660432411197ull, 351305935199925ull}},
{{6588629782982306300ull, 562089496319881ull}},
{{1581555011643934717ull, 449671597055905ull}},
{{1265244009315147773ull, 359737277644724ull}},
{{4701544022194028542ull, 287789822115779ull}},
{{14901168064994266314ull, 460463715385246ull}},
{{8231585637253502728ull, 368370972308197ull}},
{{17653314954028533152ull, 294696777846557ull}},
{{13487908667478011750ull, 471514844554492ull}},
{{3411629304498588754ull, 377211875643594ull}},
{{6418652258340781326ull, 301769500514875ull}},
{{10269843613345250122ull, 482831200823800ull}},
{{8215874890676200097ull, 386264960659040ull}},
{{6572699912540960078ull, 309011968527232ull}},
{{14205668674807446448ull, 494419149643571ull}},
{{7675186125104046835ull, 395535319714857ull}},
{{17208195344308968438ull, 316428255771885ull}},
{{9086368477184797884ull, 506285209235017ull}},
{{18337141225973569277ull, 405028167388013ull}},
{{3601666536553124452ull, 324022533910411ull}},
{{16830712902710730093ull, 518436054256657ull}},
{{6085872692684763428ull, 414748843405326ull}},
{{1179349339405900419ull, 331799074724261ull}},
{{12955005387275171640ull, 530878519558817ull}},
{{2985306680336316666ull, 424702815647054ull}},
{{6077594159010963656ull, 339762252517643ull}},
{{6034801839675631526ull, 543619604028229ull}},
{{8517190286482415544ull, 434895683222583ull}},
{{14192449858669753082ull, 347916546578066ull}},
{{15329222144387784284ull, 556666474524906ull}},
{{8574028900768317104ull, 445333179619925ull}},
{{6859223120614653683ull, 356266543695940ull}},
{{5487378496491722946ull, 285013234956752ull}},
{{12469154409128667038ull, 456021175930803ull}},
{{17354021156786754277ull, 364816940744642ull}},
{{6504519295945582775ull, 291853552595714ull}},
{{17785928502996753086ull, 466965684153142ull}},
{{6850045172913581823ull, 373572547322514ull}},
{{9169384953072775781ull, 298858037858011ull}},
{{7292318295432620604ull, 478172860572818ull}},
{{13212552265829917129ull, 382538288458254ull}},
{{14259390627405844027ull, 306030630766603ull}},
{{678932115397888504ull, 489649009226566ull}},
{{15300540951285952096ull, 391719207381252ull}},
{{4861735131544941030ull, 313375365905002ull}},
{{11468125025213815971ull, 501400585448003ull}},
{{16553197649654873423ull, 401120468358402ull}},
{{5863860490240078092ull, 320896374686722ull}},
{{13071525599126035271ull, 513434199498755ull}},
{{10457220479300828217ull, 410747359599004ull}},
{{12055125198182572897ull, 328597887679203ull}},
{{15598851502350206312ull, 525756620286725ull}},
{{12479081201880165049ull, 420605296229380ull}},
{{9983264961504132039ull, 336484236983504ull}},
{{4905177494180880293ull, 538374779173607ull}},
{{14992188439570435204ull, 430699823338885ull}},
{{11993750751656348163ull, 344559858671108ull}},
{{15500652387908246738ull, 551295773873773ull}},
{{1332475466100866421ull, 441036619099019ull}},
{{4755329187622603460ull, 352829295279215ull}},
{{3804263350098082768ull, 282263436223372ull}},
{{9776170174898842752ull, 451621497957395ull}},
{{7820936139919074202ull, 361297198365916ull}},
{{2567400097193349038ull, 289037758692733ull}},
{{418491340767448138ull, 462460413908373ull}},
{{7713490702097779157ull, 369968331126698ull}},
{{13549490191162043972ull, 295974664901358ull}},
{{17989835491117360032ull, 473559463842173ull}},
{{3323821948668157056ull, 378847571073739ull}},
{{6348406373676435968ull, 303078056858991ull}},
{{2778752568398476902ull, 484924890974386ull}},
{{16980397313686422814ull, 387939912779508ull}},
{{2516271406723407282ull, 310351930223607ull}},
{{7715383065499361974ull, 496563088357771ull}},
{{2482957637657579256ull, 397250470686217ull}},
{{13054412554351794374ull, 317800376548973ull}},
{{17197711272220960676ull, 508480602478357ull}},
{{6379471388292947894ull, 406784481982686ull}},
{{1414228295892447992ull, 325427585586149ull}},
{{9641462902911737434ull, 520684136937838ull}},
{{15091867951813210594ull, 416547309550270ull}},
{{12073494361450568475ull, 333237847640216ull}},
{{11938893348837088914ull, 533180556224346ull}},
{{5861765864327760808ull, 426544444979477ull}},
{{15757459135687939616ull, 341235555983581ull}},
{{17833236987616882739ull, 545976889573730ull}},
{{14266589590093506191ull, 436781511658984ull}},
{{15102620486816715276ull, 349425209327187ull}},
{{9406797519939103149ull, 559080334923500ull}},
{{7525438015951282519ull, 447264267938800ull}},
{{6020350412761026015ull, 357811414351040ull}},
{{4816280330208820812ull, 286249131480832ull}},
{{11395397343076023623ull, 457998610369331ull}},
{{5426969059718908575ull, 366398888295465ull}},
{{4341575247775126860ull, 293119110636372ull}},
{{10635869211182113299ull, 468990577018195ull}},
{{8508695368945690639ull, 375192461614556ull}},
{{3117607480414642188ull, 300153969291645ull}},
{{4988171968663427501ull, 480246350866632ull}},
{{15058584019156472970ull, 384197080693305ull}},
{{12046867215325178376ull, 307357664554644ull}},
{{8206941100294554433ull, 491772263287431ull}},
{{2876204065493733223ull, 393417810629945ull}},
{{2300963252394986578ull, 314734248503956ull}},
{{14749587648057709495ull, 503574797606329ull}},
{{15489018933188077919ull, 402859838085063ull}},
{{1323168702324731366ull, 322287870468051ull}},
{{13185116367945301155ull, 515660592748881ull}},
{{6858744279614330601ull, 412528474199105ull}},
{{5486995423691464480ull, 330022779359284ull}},
{{16157890307390163815ull, 528036446974854ull}},
{{16615661060654041375ull, 422429157579883ull}},
{{2224482404297502131ull, 337943326063907ull}},
{{7248520661617913732ull, 540709321702251ull}},
{{2109467714552420663ull, 432567457361801ull}},
{{16444969430609577823ull, 346053965889440ull}},
{{7865207015265772901ull, 553686345423105ull}},
{{6292165612212618321ull, 442949076338484ull}},
{{8723081304512004980ull, 354359261070787ull}},
{{18046511487835334953ull, 283487408856629ull}},
{{17806371936310804956ull, 453579854170607ull}},
{{6866399919564823318ull, 362863883336486ull}},
{{1803771120909948331ull, 290291106669189ull}},
{{10264731422939737977ull, 464465770670702ull}},
{{833087508867969735ull, 371572616536562ull}},
{{11734516451320106757ull, 297258093229249ull}},
{{7707179877886439842ull, 475612949166799ull}},
{{9855092717051062197ull, 380490359333439ull}},
{{11573422988382760081ull, 304392287466751ull}},
{{11138779151928595483ull, 487027659946802ull}},
{{1532325692059055740ull, 389622127957442ull}},
{{12293906997872975561ull, 311697702365953ull}},
{{15980902381854850575ull, 498716323785525ull}},
{{12784721905483880460ull, 398973059028420ull}},
{{10227777524387104368ull, 319178447222736ull}},
{{8985746409535546343ull, 510685515556378ull}},
{{14567294757112257721ull, 408548412445102ull}},
{{4275138176205985530ull, 326838729956082ull}},
{{10529569896671487171ull, 522941967929731ull}},
{{4734307102595279414ull, 418353574343785ull}},
{{3787445682076223531ull, 334682859475028ull}},
{{2370564276580047327ull, 535492575160045ull}},
{{1896451421264037861ull, 428394060128036ull}},
{{16274556395978871582ull, 342715248102428ull}},
{{3903197345114732592ull, 548344396963886ull}},
{{17879953135059427366ull, 438675517571108ull}},
{{3235916063821810923ull, 350940414056887ull}},
{{8866814516856807801ull, 561504662491019ull}},
{{10782800428227356564ull, 449203729992815ull}},
{{8626240342581885251ull, 359362983994252ull}},
{{17969038718291239170ull, 287490387195401ull}},
{{2925020246072610410ull, 459984619512643ull}},
{{9718713826341908974ull, 367987695610114ull}},
{{11464319875815437503ull, 294390156488091ull}},
{{10964214171820879358ull, 471024250380946ull}},
{{5082022522714793163ull, 376819400304757ull}},
{{15133664462397565500ull, 301455520243805ull}},
{{5767119066126553184ull, 482328832390089ull}},
{{8303044067643152871ull, 385863065912071ull}},
{{2953086439372611973ull, 308690452729657ull}},
{{8414287117738089480ull, 493904724367451ull}},
{{3042080879448561261ull, 395123779493961ull}},
{{17191059962526490302ull, 316099023595168ull}},
{{5369603051590922544ull, 505758437752270ull}},
{{4295682441272738035ull, 404606750201816ull}},
{{18193941211985831721ull, 323685400161452ull}},
{{14352910680209689460ull, 517896640258324ull}},
{{15171677358909661891ull, 414317312206659ull}},
{{15826690701869639836ull, 331453849765327ull}},
{{10565309864023782445ull, 530326159624524ull}},
{{12141596705960936279ull, 424260927699619ull}},
{{13402626179510659347ull, 339408742159695ull}},
{{2997457813507503339ull, 543053987455513ull}},
{{9776663880289823317ull, 434443189964410ull}},
{{7821331104231858654ull, 347554551971528ull}},
{{8824780952029063523ull, 556087283154445ull}},
{{7059824761623250819ull, 444869826523556ull}},
{{1958510994556690332ull, 355895861218845ull}},
{{1566808795645352265ull, 284716688975076ull}},
{{13574940517258294594ull, 455546702360121ull}},
{{7170603599064725352ull, 364437361888097ull}},
{{16804529323477511251ull, 291549889510477ull}},
{{12129851658596376709ull, 466479823216764ull}},
{{13393230141619011690ull, 373183858573411ull}},
{{7025235298553299029ull, 298547086858729ull}},
{{172330033459547477ull, 477675338973967ull}},
{{11205910470993368951ull, 382140271179173ull}},
{{16343426006278515807ull, 305712216943338ull}},
{{4013388721594163353ull, 489139547109342ull}},
{{14278757421501061652ull, 391311637687473ull}},
{{354959492975118352ull, 313049310149979ull}},
{{7946632818244010009ull, 500878896239966ull}},
{{2667957439853297684ull, 400703116991973ull}},
{{9513063581366458794ull, 320562493593578ull}},
{{11531552915444423747ull, 512899989749725ull}},
{{9225242332355538998ull, 410319991799780ull}},
{{7380193865884431198ull, 328255993439824ull}},
{{740263741189358947ull, 525209589503719ull}},
{{4281559807693397481ull, 420167671602975ull}},
{{3425247846154717985ull, 336134137282380ull}},
{{5480396553847548776ull, 537814619651808ull}},
{{11763014872561859667ull, 430251695721446ull}},
{{5721063083307577410ull, 344201356577157ull}},
{{12843049748034034180ull, 550722170523451ull}},
{{6585090983685317021ull, 440577736418761ull}},
{{1578723972206343293ull, 352462189135009ull}},
{{4952327992506984958ull, 281969751308007ull}},
{{11613073602753086256ull, 451151602092811ull}},
{{5601110067460558681ull, 360921281674249ull}},
{{8170236868710357268ull, 288737025339399ull}},
{{2004332545710840660ull, 461979240543039ull}},
{{5292814851310582851ull, 369583392434431ull}},
{{544903066306555957ull, 295666713947545ull}},
{{871844906090489532ull, 473066742316072ull}},
{{11765522369098122595ull, 378453393852857ull}},
{{2033720265794677430ull, 302762715082286ull}},
{{14321998869497214857ull, 484420344131657ull}},
{{4078901466113951239ull, 387536275305326ull}},
{{18020516431858802284ull, 310029020244260ull}},
{{10386082217264532039ull, 496046432390817ull}},
{{930168144327804985ull, 396837145912654ull}},
{{4433483330204154311ull, 317469716730123ull}},
{{3404224513584736575ull, 507951546768197ull}},
{{13791426055093520229ull, 406361237414557ull}},
{{3654443214590995537ull, 325088989931646ull}},
{{16915155587571323829ull, 520142383890633ull}},
{{2464078025831328093ull, 416113907112507ull}},
{{13039308864890793444ull, 332891125690005ull}},
{{2416150110115717895ull, 532625801104009ull}},
{{5622268902834484639ull, 426100640883207ull}},
{{15565861566493318681ull, 340880512706565ull}},
{{6458634432679758274ull, 545408820330505ull}},
{{5166907546143806619ull, 436327056264404ull}},
{{7822874851656955618ull, 349061645011523ull}},
{{8827250947909218666ull, 558498632018437ull}},
{{18129847202553105902ull, 446798905614749ull}},
{{18193226576784395045ull, 357439124491799ull}},
{{18243930076169426359ull, 285951299593439ull}},
{{18122241677645351205ull, 457522079349503ull}},
{{3429746897890549994ull, 366017663479603ull}},
{{10122495147796260642ull, 292814130783682ull}},
{{1438596977506375734ull, 468502609253892ull}},
{{12218924026230831557ull, 374802087403113ull}},
{{17153836850468485892ull, 299841669922490ull}},
{{8999394887040025811ull, 479746671875985ull}},
{{7199515909632020649ull, 383797337500788ull}},
{{13138310357189437166ull, 307037870000630ull}},
{{2574552497793547849ull, 491260592001009ull}},
{{5748990812976748602ull, 393008473600807ull}},
{{15667239094607129851ull, 314406778880645ull}},
{{6620838477661856147ull, 503050846209033ull}},
{{12675368411613305564ull, 402440676967226ull}},
{{6450945914548734128ull, 321952541573781ull}},
{{2942815833794153958ull, 515124066518050ull}},
{{2354252667035323166ull, 412099253214440ull}},
{{1883402133628258533ull, 329679402571552ull}},
{{6702792228547123976ull, 527487044114483ull}},
{{12740931412321519827ull, 421989635291586ull}},
{{6503396315115305539ull, 337591708233269ull}},
{{17784131733668309508ull, 540146733173230ull}},
{{14227305386934647607ull, 432117386538584ull}},
{{15071193124289628408ull, 345693909230867ull}},
{{9356513739895764161ull, 553110254769388ull}},
{{14863908621400431975ull, 442488203815510ull}},
{{11891126897120345580ull, 353990563052408ull}},
{{16891599147180097110ull, 283192450441926ull}},
{{1201116932294783114ull, 453107920707083ull}},
{{8339591175319647138ull, 362486336565666ull}},
{{2982324125513807387ull, 289989069252533ull}},
{{1082369786080181496ull, 463982510804053ull}},
{{8244593458347965843ull, 371186008643242ull}},
{{17663721210904103644ull, 296948806914593ull}},
{{6125861048995103892ull, 475118091063350ull}},
{{4900688839196083113ull, 380094472850680ull}},
{{3920551071356866490ull, 304075578280544ull}},
{{13651579343654807031ull, 486520925248870ull}},
{{10921263474923845625ull, 389216740199096ull}},
{{5047661965197166177ull, 311373392159277ull}},
{{11765607959057376206ull, 498197427454843ull}},
{{16791183996729721611ull, 398557941963874ull}},
{{17122296012125687612ull, 318846353571099ull}},
{{16327627175175369210ull, 510154165713759ull}},
{{16751450554882205691ull, 408123332571007ull}},
{{6022462814421943906ull, 326498666056806ull}},
{{2257242873591289604ull, 522397865690890ull}},
{{1805794298873031683ull, 417918292552712ull}},
{{12512681883324156316ull, 334334634042169ull}},
{{8952244569092919136ull, 534935414467471ull}},
{{3472446840532424986ull, 427948331573977ull}},
{{13846003916651670958ull, 342358665259181ull}},
{{14774908637158852887ull, 547773864414690ull}},
{{11819926909727082310ull, 438219091531752ull}},
{{2077243898297845201ull, 350575273225402ull}},
{{7012939052018462645ull, 560920437160643ull}},
{{12989048871098590763ull, 448736349728514ull}},
{{14080587911620782933ull, 358989079782811ull}},
{{7575121514554716023ull, 287191263826249ull}},
{{1052147979061814668ull, 459506022121999ull}},
{{4531067197991362057ull, 367604817697599ull}},
{{7314202573134999969ull, 294083854158079ull}},
{{634677672790268981ull, 470534166652927ull}},
{{11575788582457946154ull, 376427333322341ull}},
{{5571282051224446600ull, 301141866657873ull}},
{{5224702467217204237ull, 481826986652597ull}},
{{15247808417999494359ull, 385461589322077ull}},
{{4819549104915774841ull, 308369271457662ull}},
{{11400627382607150069ull, 493390834332259ull}},
{{12809850720827630378ull, 394712667465807ull}},
{{2869182947178283656ull, 315770133972646ull}},
{{15658739159710984820ull, 505232214356233ull}},
{{1458944883543056886ull, 404185771484987ull}},
{{12235202351060176478ull, 323348617187989ull}},
{{8508277317470551396ull, 517357787500783ull}},
{{14185319483460261763ull, 413886230000626ull}},
{{7658906772026299087ull, 331108984000501ull}},
{{4875553205758257894ull, 529774374400802ull}},
{{14968489008832337284ull, 423819499520641ull}},
{{8285442392323959504ull, 339055599616513ull}},
{{9567359012976424884ull, 542488959386421ull}},
{{3964538395639229584ull, 433991167509137ull}},
{{14239677160737114637ull, 347192934007309ull}},
{{11715437012953652449ull, 555508694411695ull}},
{{9372349610362921959ull, 444406955529356ull}},
{{3808530873548427244ull, 355525564423485ull}},
{{3046824698838741795ull, 284420451538788ull}},
{{1185570703400076549ull, 455072722462061ull}},
{{15705851821687702532ull, 364058177969648ull}},
{{1496635013124431056ull, 291246542375719ull}},
{{9773313650482910336ull, 465994467801150ull}},
{{7818650920386328269ull, 372795574240920ull}},
{{6254920736309062615ull, 298236459392736ull}},
{{2629175548610679538ull, 477178335028378ull}},
{{9482038068372364277ull, 381742668022702ull}},
{{206932825214070775ull, 305394134418162ull}},
{{4020441335084423563ull, 488630615069059ull}},
{{6905701882809449174ull, 390904492055247ull}},
{{16592607950473290309ull, 312723593644197ull}},
{{11790777461789623201ull, 500357749830716ull}},
{{5743273154689788238ull, 400286199864573ull}},
{{11973316153235651236ull, 320228959891658ull}},
{{15467957030435131655ull, 512366335826653ull}},
{{1306319180122374355ull, 409893068661323ull}},
{{8423752973581720130ull, 327914454929058ull}},
{{9788655942988841885ull, 524663127886493ull}},
{{15209622383874894154ull, 419730502309194ull}},
{{15857046721841825647ull, 335784401847355ull}},
{{6924530681237369419ull, 537255042955769ull}},
{{9228973359731805858ull, 429804034364615ull}},
{{7383178687785444686ull, 343843227491692ull}},
{{15502434715198621822ull, 550149163986707ull}},
{{5023250142675076811ull, 440119331189366ull}},
{{329251299398151125ull, 352095464951493ull}},
{{7642098669002341547ull, 281676371961194ull}},
{{1159311426178015505ull, 450682195137911ull}},
{{15684844399910053697ull, 360545756110328ull}},
{{1479829075702311988ull, 288436604888263ull}},
{{17125121780091340474ull, 461498567821220ull}},
{{13700097424073072379ull, 369198854256976ull}},
{{7270729124516547580ull, 295359083405581ull}},
{{4254468969742655482ull, 472574533448930ull}},
{{3403575175794124385ull, 378059626759144ull}},
{{6412208955377209831ull, 302447701407315ull}},
{{10259534328603535730ull, 483916322251704ull}},
{{11896976277624738907ull, 387133057801363ull}},
{{16896278651583611772ull, 309706446241090ull}},
{{8587301768824227220ull, 495530313985745ull}},
{{6869841415059381776ull, 396424251188596ull}},
{{1806524317305595097ull, 317139400950877ull}},
{{6579787722430862479ull, 507423041521403ull}},
{{12642527807428510630ull, 405938433217122ull}},
{{2735324616458987857ull, 324750746573698ull}},
{{687170571592470248ull, 519601194517917ull}},
{{11617782901499707168ull, 415680955614333ull}},
{{16672923950683586381ull, 332544764491466ull}},
{{851236617900365947ull, 532071623186347ull}},
{{11749035738546023727ull, 425657298549077ull}},
{{2020530961352998335ull, 340525838839262ull}},
{{6922198352906707660ull, 544841342142819ull}},
{{9227107497067276451ull, 435873073714255ull}},
{{7381685997653821161ull, 348698458971404ull}},
{{742651152020382888ull, 557917534354247ull}},
{{11662167365842037280ull, 446334027483397ull}},
{{1951036263189809178ull, 357067221986718ull}},
{{8939526640035667988ull, 285653777589374ull}},
{{3235196179831337812ull, 457046044142999ull}},
{{6277505758606980573ull, 365636835314399ull}},
{{8711353421627494781ull, 292509468251519ull}},
{{2870119030378260681ull, 468015149202431ull}},
{{17053490483270249837ull, 374412119361944ull}},
{{17332141201358110193ull, 299529695489555ull}},
{{9284681848463424693ull, 479247512783289ull}},
{{11117094293512650077ull, 383398010226631ull}},
{{5204326620068209739ull, 306718408181305ull}},
{{8326922592109135582ull, 490749453090088ull}},
{{14040235703171129112ull, 392599562472070ull}},
{{11232188562536903290ull, 314079649977656ull}},
{{10592804070575224617ull, 502527439964250ull}},
{{8474243256460179694ull, 402021951971400ull}},
{{6779394605168143755ull, 321617561577120ull}},
{{10847031368269030008ull, 514588098523392ull}},
{{1298927465131403360ull, 411670478818714ull}},
{{4728490786847033011ull, 329336383054971ull}},
{{186887629471432172ull, 526938212887954ull}},
{{3838858918319056060ull, 421550570310363ull}},
{{10449784764139065495ull, 337240456248290ull}},
{{16719655622622504792ull, 539584729997264ull}},
{{17065073312839914156ull, 431667783997811ull}},
{{9962709835530021002ull, 345334227198249ull}},
{{4872289292622302634ull, 552534763517199ull}},
{{7587180248839752430ull, 442027810813759ull}},
{{9759093013813712267ull, 353622248651007ull}},
{{428576781567149167ull, 282897798920806ull}},
{{11753769294733169637ull, 452636478273289ull}},
{{13092364250528446033ull, 362109182618631ull}},
{{6784542585680846503ull, 289687346094905ull}},
{{10855268137089354405ull, 463499753751848ull}},
{{16062912139155304170ull, 370799803001478ull}},
{{1782283267098512367ull, 296639842401183ull}},
{{17609048486325261080ull, 474623747841892ull}},
{{6708541159576388217ull, 379698998273514ull}},
{{9056181742403020897ull, 303759198618811ull}},
{{7111193158361012789ull, 486014717790098ull}},
{{13067652156172630878ull, 388811774232078ull}},
{{17832819354421925348ull, 311049419385662ull}},
{{13775115708107439265ull, 497679071017060ull}},
{{11020092566485951412ull, 398143256813648ull}},
{{16194771682672581776ull, 318514605450918ull}},
{{3775541803824668902ull, 509623368721470ull}},
{{3020433443059735122ull, 407698694977176ull}},
{{17173742013415429390ull, 326158955981740ull}},
{{9031243147755135408ull, 521854329570785ull}},
{{7224994518204108327ull, 417483463656628ull}},
{{13158693244047107308ull, 333986770925302ull}},
{{6296513931507730400ull, 534378833480484ull}},
{{8726559959948094643ull, 427503066784387ull}},
{{18049294412184206684ull, 342002453427509ull}},
{{17810824615268999725ull, 547203925484015ull}},
{{14248659692215199780ull, 437763140387212ull}},
{{4020230124288339177ull, 350210512309770ull}},
{{6432368198861342684ull, 560336819695632ull}},
{{16213941003314805117ull, 448269455756505ull}},
{{12971152802651844093ull, 358615564605204ull}},
{{14066271056863385598ull, 286892451684163ull}},
{{369940802529955017ull, 459027922694662ull}},
{{11363999086249694983ull, 367222338155729ull}},
{{12780548083741666310ull, 293777870524583ull}},
{{16759528119244755773ull, 470044592839333ull}},
{{2339576051170073649ull, 376035674271467ull}},
{{12939707285161789888ull, 300828539417173ull}},
{{17014182841516953498ull, 481325663067477ull}},
{{6232648643729742152ull, 385060530453982ull}},
{{16054165359209524691ull, 308048424363185ull}},
{{7239920501025687890ull, 492877478981097ull}},
{{16859982845046281282ull, 394301983184877ull}},
{{6109288646553204379ull, 315441586547902ull}},
{{13464210649227037330ull, 504706538476643ull}},
{{18150066148865450510ull, 403765230781314ull}},
{{18209401733834270731ull, 323012184625051ull}},
{{3309601070941460908ull, 516819495400083ull}},
{{10026378486236989373ull, 413455596320066ull}},
{{4331753974247681175ull, 330764477056053ull}},
{{3241457544054379557ull, 529223163289685ull}},
{{2593166035243503645ull, 423378530631748ull}},
{{9453230457678623562ull, 338702824505398ull}},
{{11435819917543887377ull, 541924519208637ull}},
{{1769958304551289255ull, 433539615366910ull}},
{{1415966643641031404ull, 346831692293528ull}},
{{17022941888793291540ull, 554930707669644ull}},
{{17307702325776543555ull, 443944566135715ull}},
{{13846161860621234844ull, 355155652908572ull}},
{{3698231859013167228ull, 284124522326858ull}},
{{2227822159679157243ull, 454599235722973ull}},
{{9160955357227146440ull, 363679388578378ull}},
{{14707461915265537799ull, 290943510862702ull}},
{{8774543805457219185ull, 465509617380324ull}},
{{10708983859107685671ull, 372407693904259ull}},
{{12256535902028058860ull, 297926155123407ull}},
{{4853062184277252884ull, 476681848197452ull}},
{{14950496191647533277ull, 381345478557961ull}},
{{8271048138576116298ull, 305076382846369ull}},
{{2165630577496055107ull, 488122212554191ull}},
{{16489899720964485379ull, 390497770043352ull}},
{{5813222147287767656ull, 312398216034682ull}},
{{12990504250402338574ull, 499837145655491ull}},
{{6703054585579960536ull, 399869716524393ull}},
{{12741141297947789075ull, 319895773219514ull}},
{{9317779632490731550ull, 511833237151223ull}},
{{14832921335476405887ull, 409466589720978ull}},
{{798290624155393740ull, 327573271776783ull}},
{{16034660257616271276ull, 524117234842852ull}},
{{5449030576609196375ull, 419293787874282ull}},
{{15427270905513088069ull, 335435030299425ull}},
{{6236889375111389295ull, 536696048479081ull}},
{{1300162685347201113ull, 429356838783265ull}},
{{1040130148277760890ull, 343485471026612ull}},
{{5353557051986327748ull, 549576753642579ull}},
{{7972194456330972521ull, 439661402914063ull}},
{{13756453194548598663ull, 351729122331250ull}},
{{3563581037568206246ull, 562766595730001ull}},
{{17608260089022206289ull, 450213276584000ull}},
{{14086608071217765031ull, 360170621267200ull}},
{{11269286456974212025ull, 288136497013760ull}},
{{18030858331158739240ull, 461018395222016ull}},
{{10735337850185081069ull, 368814716177613ull}},
{{15966967909631885501ull, 295051772942090ull}},
{{7100404581701465186ull, 472082836707345ull}},
{{5680323665361172149ull, 377666269365876ull}},
{{854910117547027396ull, 302133015492701ull}},
{{12435902632300974803ull, 483412824788321ull}},
{{6259373291098869519ull, 386730259830657ull}},
{{16075545077104826585ull, 309384207864525ull}},
{{7274128049658170920ull, 495014732583241ull}},
{{2129953624984626413ull, 396011786066593ull}},
{{9082660529471521777ull, 316809428853274ull}},
{{3464210402928703873ull, 506895086165239ull}},
{{6460717137084873422ull, 405516068932191ull}},
{{1479224894925988414ull, 324412855145753ull}},
{{17124155090849222756ull, 519060568233204ull}},
{{17388672887421288528ull, 415248454586563ull}},
{{2842891865711299852ull, 332198763669251ull}},
{{15616673429363810734ull, 531518021870801ull}},
{{8803989928749138264ull, 425214417496641ull}},
{{3353843128257400288ull, 340171533997313ull}},
{{1676800190469930137ull, 544274454395701ull}},
{{16098835411343585403ull, 435419563516560ull}},
{{12879068329074868322ull, 348335650813248ull}},
{{16917160511777878992ull, 557337041301197ull}},
{{6155030779938482547ull, 445869633040958ull}},
{{12302722253434606684ull, 356695706432766ull}},
{{6152828988005775024ull, 285356565146213ull}},
{{6155177566067329716ull, 456570504233941ull}},
{{1234793238111953449ull, 365256403387153ull}},
{{8366532219973383406ull, 292205122709722ull}},
{{17075800366699323773ull, 467528196335555ull}},
{{13660640293359459018ull, 374022557068444ull}},
{{14617861049429477537ull, 299218045654755ull}},
{{4941833605377612444ull, 478748873047609ull}},
{{7642815699044000278ull, 382999098438087ull}},
{{17182299003460931192ull, 306399278750469ull}},
{{16423631961311758938ull, 490238846000751ull}},
{{9449556754307496827ull, 392191076800601ull}},
{{3870296588704087139ull, 313752861440481ull}},
{{17260520986152270392ull, 502004578304769ull}},
{{17497765603663726636ull, 401603662643815ull}},
{{13998212482930981309ull, 321282930115052ull}},
{{7639744713721928802ull, 514052688184084ull}},
{{9801144585719453365ull, 411242150547267ull}},
{{462218039091742045ull, 328993720437814ull}},
{{8118246492030607919ull, 526389952700502ull}},
{{17562643637850217305ull, 421111962160401ull}},
{{10360766095538263520ull, 336889569728321ull}},
{{9198528123377400987ull, 539023311565314ull}},
{{11048171313443831112ull, 431218649252251ull}},
{{5149188236013154567ull, 344974919401801ull}},
{{860003548137226661ull, 551959871042882ull}},
{{11756049282735512298ull, 441567896834305ull}},
{{9404839426188409838ull, 353254317467444ull}},
{{11213220355692638194ull, 282603453973955ull}},
{{17941152569108221110ull, 452165526358328ull}},
{{3284875611060845918ull, 361732421086663ull}},
{{10006598118332497381ull, 289385936869330ull}},
{{16010556989331995810ull, 463017498990928ull}},
{{1740399147239865678ull, 370413999192743ull}},
{{8771016947275713189ull, 296331199354194ull}},
{{2965580671415410133ull, 474129918966711ull}},
{{17129859796099969399ull, 379303935173368ull}},
{{2635841392654244550ull, 303443148138695ull}},
{{4217346228246791280ull, 485509037021912ull}},
{{14441923426823163993ull, 388407229617529ull}},
{{15242887556200441518ull, 310725783694023ull}},
{{2252527201469244489ull, 497161253910438ull}},
{{9180719390659216238ull, 397729003128350ull}},
{{7344575512527372990ull, 318183202502680ull}},
{{11751320820043796785ull, 509093124004288ull}},
{{16779754285518858074ull, 407274499203430ull}},
{{13423803428415086459ull, 325819599362744ull}},
{{10410039041238407365ull, 521311358980391ull}},
{{4638682418248815569ull, 417049087184313ull}},
{{11089643564082873101ull, 333639269747450ull}},
{{17743429702532596963ull, 533822831595920ull}},
{{14194743762026077570ull, 427058265276736ull}},
{{7666446194878951733ull, 341646612221389ull}},
{{1198267467580591803ull, 546634579554223ull}},
{{8337311603548294089ull, 437307663643378ull}},
{{14048546912322455917ull, 349846130914702ull}},
{{7720279800748288175ull, 559753809463524ull}},
{{9865572655340540863ull, 447803047570819ull}},
{{11581806939014343014ull, 358242438056655ull}},
{{9265445551211474411ull, 286593950445324ull}},
{{3756666437712628088ull, 458550320712519ull}},
{{6694681964912012793ull, 366840256570015ull}},
{{5355745571929610235ull, 293472205256012ull}},
{{12258541729829286699ull, 469555528409619ull}},
{{13496182198605339682ull, 375644422727695ull}},
{{10796945758884271746ull, 300515538182156ull}},
{{9896415584731014147ull, 480824861091450ull}},
{{7917132467784811318ull, 384659888873160ull}},
{{6333705974227849054ull, 307727911098528ull}},
{{6444580744022648163ull, 492364657757645ull}},
{{5155664595218118531ull, 393891726206116ull}},
{{435182861432584501ull, 315113380964893ull}},
{{15453687837259776495ull, 504181409543828ull}},
{{1294903825582090226ull, 403345127635063ull}},
{{8414620689949492827ull, 322676102108050ull}},
{{13463393103919188524ull, 516281763372880ull}},
{{10770714483135350819ull, 413025410698304ull}},
{{12305920401250190978ull, 330420328558643ull}},
{{16000123827258395243ull, 528672525693829ull}},
{{16489447876548626517ull, 422938020555063ull}},
{{2123511857013170244ull, 338350416444051ull}},
{{14465665415446803360ull, 541360666310481ull}},
{{7883183517615532365ull, 433088533048385ull}},
{{6306546814092425892ull, 346470826438708ull}},
{{6401126087805971104ull, 554353322301933ull}},
{{12499598499728597530ull, 443482657841546ull}},
{{6310329985040967700ull, 354786126273237ull}},
{{16116310432258505130ull, 283828901018589ull}},
{{14718050247387877238ull, 454126241629743ull}},
{{706393753684570821ull, 363300993303795ull}},
{{565115002947656657ull, 290640794643036ull}},
{{11972230448941981621ull, 465025271428857ull}},
{{2199086729669764650ull, 372020217143086ull}},
{{16516664642703453013ull, 297616173714468ull}},
{{4290570539874062881ull, 476185877943150ull}},
{{3432456431899250305ull, 380948702354520ull}},
{{2745965145519400244ull, 304758961883616ull}},
{{15461590677056771360ull, 487614339013785ull}},
{{12369272541645417088ull, 390091471211028ull}},
{{17274115662800154317ull, 312073176968822ull}},
{{12881189801512605614ull, 499317083150116ull}},
{{6615603026468174168ull, 399453666520093ull}},
{{12671180050658359981ull, 319562933216074ull}},
{{9205841636827645000ull, 511300693145719ull}},
{{11054022124204026323ull, 409040554516575ull}},
{{8843217699363221058ull, 327232443613260ull}},
{{14149148318981153694ull, 523571909781216ull}},
{{7629969840443012632ull, 418857527824973ull}},
{{13482673501838230752ull, 335086022259978ull}},
{{17882928788199258880ull, 536137635615965ull}},
{{14306343030559407104ull, 428910108492772ull}},
{{4066376794963705036ull, 343128086794218ull}},
{{2816854057200017735ull, 549004938870749ull}},
{{5942832060501924511ull, 439203951096599ull}},
{{8443614463143449932ull, 351363160877279ull}},
{{2441736696803788922ull, 562181057403647ull}},
{{13021435801668762107ull, 449744845922917ull}},
{{3038451011851189039ull, 359795876738334ull}},
{{6120109624222861555ull, 287836701390667ull}},
{{13481524213498488811ull, 460538722225067ull}},
{{3406521741314970402ull, 368430977780054ull}},
{{6414566207793886645ull, 294744782224043ull}},
{{6573957117728308309ull, 471591651558469ull}},
{{8948514508924556970ull, 377273321246775ull}},
{{7158811607139645576ull, 301818656997420ull}},
{{11454098571423432922ull, 482909851195872ull}},
{{1784581227654925691ull, 386327880956698ull}},
{{8806362611607761199ull, 309062304765358ull}},
{{10400831363830507596ull, 494499687624573ull}},
{{15699362720548226723ull, 395599750099658ull}},
{{1491443732212850409ull, 316479800079727ull}},
{{6075658786282470977ull, 506367680127563ull}},
{{12239224658509797428ull, 405094144102050ull}},
{{9791379726807837942ull, 324075315281640ull}},
{{15666207562892540708ull, 518520504450624ull}},
{{16222314865055942890ull, 414816403560499ull}},
{{16667200706786664635ull, 331853122848399ull}},
{{15599474686632932446ull, 530964996557439ull}},
{{16168928564048256280ull, 424771997245951ull}},
{{9245794036496694701ull, 339817597796761ull}},
{{7414572828910890875ull, 543708156474818ull}},
{{13310355892612533346ull, 434966525179854ull}},
{{14337633528831937000ull, 347973220143883ull}},
{{804120757679637262ull, 556757152230214ull}},
{{4332645420885620132ull, 445405721784171ull}},
{{18223511595676137399ull, 356324577427336ull}},
{{10889460461798999596ull, 285059661941869ull}},
{{6355090294652668384ull, 456095459106991ull}},
{{1394723420980224384ull, 364876367285593ull}},
{{8494476366268000153ull, 291901093828474ull}},
{{2523115741803069276ull, 467041750125559ull}},
{{5707841408184365744ull, 373633400100447ull}},
{{15634319570773223564ull, 298906720080357ull}},
{{10257516054269516411ull, 478250752128572ull}},
{{827315213931792482ull, 382600601702858ull}},
{{8040549800629254632ull, 306080481362286ull}},
{{5486182051522986765ull, 489728770179658ull}},
{{11767643270702210058ull, 391783016143726ull}},
{{5724765801819857723ull, 313426412914981ull}},
{{1780927653427951711ull, 501482260663970ull}},
{{1424742122742361369ull, 401185808531176ull}},
{{15897188957161530388ull, 320948646824940ull}},
{{6988758257748897005ull, 513517834919905ull}},
{{5591006606199117604ull, 410814267935924ull}},
{{8162154099701204406ull, 328651414348739ull}},
{{1991400115296196080ull, 525842262957983ull}},
{{8971817721720777511ull, 420673810366386ull}},
{{3488105362634711685ull, 336539048293109ull}},
{{12959666209699359343ull, 538462477268974ull}},
{{14057081782501397798ull, 430769981815179ull}},
{{14935014240743028561ull, 344615985452143ull}},
{{1759929896737383759ull, 551385576723430ull}},
{{1407943917389907007ull, 441108461378744ull}},
{{4815703948653835929ull, 352886769102995ull}},
{{3852563158923068743ull, 282309415282396ull}},
{{17232147498502640958ull, 451695064451833ull}},
{{2717671554576381797ull, 361356051561467ull}},
{{13242183687886836407ull, 289084841249173ull}},
{{17498145085877027929ull, 462535745998677ull}},
{{6619818439217801696ull, 370028596798942ull}},
{{16363901195599972327ull, 296022877439153ull}},
{{4046149024508493784ull, 473636603902646ull}},
{{17994314478574436320ull, 378909283122116ull}},
{{10706102768117638732ull, 303127426497693ull}},
{{13440415614246311649ull, 485003882396309ull}},
{{14441681306138959642ull, 388003105917047ull}},
{{4174647415427347067ull, 310402484733638ull}},
{{2990087049941844985ull, 496643975573821ull}},
{{17149464898921117280ull, 397315180459056ull}},
{{10030223104394983501ull, 317852144367245ull}},
{{16048356967031973602ull, 508563430987592ull}},
{{5459987944141758235ull, 406850744790074ull}},
{{8057339170055316911ull, 325480595832059ull}},
{{1823696227862776089ull, 520768953331295ull}},
{{1458956982290220871ull, 416615162665036ull}},
{{15924560844799817989ull, 333292130132028ull}},
{{3343204463228246844ull, 533267408211246ull}},
{{17431958829550238768ull, 426613926568996ull}},
{{10256218248898280691ull, 341291141255197ull}},
{{1652553939269607813ull, 546065826008316ull}},
{{16079438410383327543ull, 436852660806652ull}},
{{5484853098822841388ull, 349482128645322ull}},
{{12465113772858456544ull, 559171405832515ull}},
{{9972091018286765235ull, 447337124666012ull}},
{{598975185145591542ull, 357869699732810ull}},
{{479180148116473233ull, 286295759786248ull}},
{{15524083495953998467ull, 458073215657996ull}},
{{8729917982021288450ull, 366458572526397ull}},
{{18051980829842761729ull, 293166858021117ull}},
{{14125774068780777475ull, 469066972833788ull}},
{{232572810798891010ull, 375253578267031ull}},
{{14943453507606754101ull, 300202862613624ull}},
{{12841479167945075592ull, 480324580181799ull}},
{{13962532149097970797ull, 384259664145439ull}},
{{14859374534020286960ull, 307407731316351ull}},
{{16396301624948638490ull, 491852370106162ull}},
{{5738343670475090146ull, 393481896084930ull}},
{{4590674936380072117ull, 314785516867944ull}},
{{14723777527691936033ull, 503656826988710ull}},
{{11779022022153548826ull, 402925461590968ull}},
{{16801915247206659707ull, 322340369272774ull}},
{{15815017951304924563ull, 515744590836439ull}},
{{16341363175785849973ull, 412595672669151ull}},
{{9383741725886769655ull, 330076538135321ull}},
{{7635289131935010802ull, 528122461016514ull}},
{{9797580120289918965ull, 422497968813211ull}},
{{4148715281490024849ull, 337998375050569ull}},
{{14016642079867860405ull, 540797400080910ull}},
{{11213313663894288324ull, 432637920064728ull}},
{{16349348560599251305ull, 346110336051782ull}},
{{11401562437991160796ull, 553776537682852ull}},
{{1742552320909107990ull, 443021230146282ull}},
{{12462088300953017362ull, 354416984117025ull}},
{{9969670640762413889ull, 283533587293620ull}},
{{15951473025219862223ull, 453653739669792ull}},
{{5382480790692069132ull, 362922991735834ull}},
{{7995333447295565629ull, 290338393388667ull}},
{{16481882330414815329ull, 464541429421867ull}},
{{5806808234848031617ull, 371633143537494ull}},
{{8334795402620335617ull, 297306514829995ull}},
{{13335672644192536987ull, 475690423727992ull}},
{{3289840485870208943ull, 380552338982394ull}},
{{6321221203438077478ull, 304441871185915ull}},
{{10113953925500923964ull, 487106993897464ull}},
{{11780511955142649495ull, 389685595117971ull}},
{{5735060749372209272ull, 311748476094377ull}},
{{12865446013737445159ull, 498797561751003ull}},
{{17671054440473776774ull, 399038049400802ull}},
{{6758145922895200772ull, 319230439520642ull}},
{{14502382291374231559ull, 510768703233027ull}},
{{4223208203615564601ull, 408614962586422ull}},
{{14446613007118182650ull, 326891970069137ull}},
{{8357185552421450948ull, 523027152110620ull}},
{{6685748441937160758ull, 418421721688496ull}},
{{1659249938807818283ull, 334737377350797ull}},
{{6344148716834419577ull, 535579803761275ull}},
{{5075318973467535661ull, 428463843009020ull}},
{{4060255178774028529ull, 342771074407216ull}},
{{17564454730264176616ull, 548433719051545ull}},
{{14051563784211341293ull, 438746975241236ull}},
{{7551902212627162711ull, 350997580192989ull}},
{{1014997095977729368ull, 561596128308783ull}},
{{8190695306266004141ull, 449276902647026ull}},
{{2863207430270892990ull, 359421522117621ull}},
{{17047961203184355684ull, 287537217694096ull}},
{{1451296221901596833ull, 460059548310555ull}},
{{1161036977521277466ull, 368047638648444ull}},
{{4618178396758932296ull, 294438110918755ull}},
{{7389085434814291674ull, 471100977470008ull}},
{{13289965977335253985ull, 376880781976006ull}},
{{6942623967126292865ull, 301504625580805ull}},
{{11108198347402068584ull, 482407400929288ull}},
{{16265256307405475514ull, 385925920743430ull}},
{{13012205045924380411ull, 308740736594744ull}},
{{9751481629253277688ull, 493985178551591ull}},
{{4111836488660711827ull, 395188142841273ull}},
{{10668166820412390108ull, 316150514273018ull}},
{{13379718097917913850ull, 505840822836829ull}},
{{14393123293076241403ull, 404672658269463ull}},
{{446452190235262153ull, 323738126615571ull}},
{{11782369948602150414ull, 517981002584913ull}},
{{16804593588365540978ull, 414384802067930ull}},
{{13443674870692432782ull, 331507841654344ull}},
{{10441833348882161482ull, 530412546646951ull}},
{{4664117864363818862ull, 424330037317561ull}},
{{41945476749144767ull, 339464029854049ull}},
{{7445810392282452273ull, 543142447766478ull}},
{{13335345943309782465ull, 434513958213182ull}},
{{3289579125164005326ull, 347611166570546ull}},
{{16331373044488139491ull, 556177866512873ull}},
{{1997051991364780623ull, 444942293210299ull}},
{{5286990407833734821ull, 355953834568239ull}},
{{7918941141008898180ull, 284763067654591ull}},
{{5291608196130416442ull, 455620908247346ull}},
{{543937742162422831ull, 364496726597877ull}},
{{11503196637955669234ull, 291597381278301ull}},
{{11026416991245250128ull, 466555810045282ull}},
{{1442435963512379456ull, 373244648036226ull}},
{{15911344029777544858ull, 298595718428980ull}},
{{7011406373934520156ull, 477753149486369ull}},
{{9298473913889526448ull, 382202519589095ull}},
{{7438779131111621158ull, 305762015671276ull}},
{{4523348980294773207ull, 489219225074042ull}},
{{14686725628461549535ull, 391375380059233ull}},
{{681334058543508659ull, 313100304047387ull}},
{{4779483308411524177ull, 500960486475819ull}},
{{7512935461471129665ull, 400768389180655ull}},
{{6010348369176903732ull, 320614711344524ull}},
{{16995255020166866618ull, 512983538151238ull}},
{{2528157571907762324ull, 410386830520991ull}},
{{16779921316493851152ull, 328309464416792ull}},
{{12090478847422520551ull, 525295143066868ull}},
{{17051080707421837087ull, 420236114453494ull}},
{{17330213380679379993ull, 336188891562795ull}},
{{9281597335377456373ull, 537902226500473ull}},
{{14803975497785785745ull, 430321781200378ull}},
{{775133954002897626ull, 344257424960303ull}},
{{15997609585372277495ull, 550811879936484ull}},
{{16487436483039732319ull, 440649503949187ull}},
{{5811251556947965209ull, 352519603159350ull}},
{{4649001245558372167ull, 282015682527480ull}},
{{7438401992893395467ull, 451225092043968ull}},
{{13329419223798537020ull, 360980073635174ull}},
{{14352884193780739939ull, 288784058908139ull}},
{{11896568265823452933ull, 462054494253023ull}},
{{16895952242142582993ull, 369643595402418ull}},
{{2448715349488335425ull, 295714876321935ull}},
{{3917944559181336680ull, 473143802115096ull}},
{{17891750906312710636ull, 378515041692076ull}},
{{10624051910308258186ull, 302812033353661ull}},
{{9619785427009392451ull, 484499253365858ull}},
{{15074525971091334607ull, 387599402692686ull}},
{{8370271962131157363ull, 310079522154149ull}},
{{2324388695184120811ull, 496127235446639ull}},
{{5548859770889206972ull, 396901788357311ull}},
{{749739001969455254ull, 317521430685849ull}},
{{8578280032634949053ull, 508034289097358ull}},
{{14241321655591779889ull, 406427431277886ull}},
{{7703708509731513588ull, 325141945022309ull}},
{{1257887171344690771ull, 520227112035695ull}},
{{1006309737075752617ull, 416181689628556ull}},
{{15562443048628243386ull, 332945351702844ull}},
{{13831862433579458449ull, 532712562724551ull}},
{{7376141132121656436ull, 426170050179641ull}},
{{2211564090955414825ull, 340936040143713ull}},
{{18295897804496305013ull, 545497664229940ull}},
{{14636718243597044011ull, 436398131383952ull}},
{{4330676965393814562ull, 349118505107162ull}},
{{10618431959372013623ull, 558589608171459ull}},
{{12184094382239521221ull, 446871686537167ull}},
{{2368577876307796330ull, 357497349229734ull}},
{{5584211115788147387ull, 285997879383787ull}},
{{12624086600002946143ull, 457596607014059ull}},
{{13788618094744267238ull, 366077285611247ull}},
{{3652196846311593144ull, 292861828488998ull}},
{{2154166139356638707ull, 468578925582397ull}},
{{12791379355711041935ull, 374863140465917ull}},
{{2854405855085012902ull, 299890512372734ull}},
{{11945746997619841289ull, 479824819796374ull}},
{{13245946412837783355ull, 383859855837099ull}},
{{14286105945012137007ull, 307087884669679ull}},
{{11789723067793688242ull, 491340615471487ull}},
{{2053080824751129947ull, 393072492377190ull}},
{{1642464659800903957ull, 314457993901752ull}},
{{6317292270423356655ull, 503132790242803ull}},
{{12432531445822505970ull, 402506232194242ull}},
{{2567327527174184130ull, 322004985755394ull}},
{{11486421672962515254ull, 515207977208630ull}},
{{9189137338370012203ull, 412166381766904ull}},
{{11040658685437920086ull, 329733105413523ull}},
{{13975705081958761815ull, 527572968661637ull}},
{{3801866436083188805ull, 422058374929310ull}},
{{3041493148866551044ull, 337646699943448ull}},
{{1177040223444571347ull, 540234719909517ull}},
{{12009678622981388047ull, 432187775927613ull}},
{{16986440527868931084ull, 345750220742090ull}},
{{8731560770880738119ull, 553200353187345ull}},
{{6985248616704590495ull, 442560282549876ull}},
{{1898850078621762073ull, 354048226039901ull}},
{{16276475321865050951ull, 283238580831920ull}},
{{7595616441274529906ull, 453181729331073ull}},
{{13455190782503444571ull, 362545383464858ull}},
{{18142850255486576303ull, 290036306771886ull}},
{{3203118705585149823ull, 464058090835019ull}},
{{6251843779210030181ull, 371246472668015ull}},
{{5001475023368024145ull, 296997178134412ull}},
{{11691708852130748956ull, 475195485015059ull}},
{{13042715896446509488ull, 380156388012047ull}},
{{3055475087673386944ull, 304125110409638ull}},
{{1199411325535508787ull, 486600176655421ull}},
{{15716924319396048322ull, 389280141324336ull}},
{{8884190640774928334ull, 311424113059469ull}},
{{3146658581014154366ull, 498278580895151ull}},
{{17274722123778964785ull, 398622864716120ull}},
{{13819777699023171828ull, 318898291772896ull}},
{{14732946688953254279ull, 510237266836634ull}},
{{15475706165904513746ull, 408189813469307ull}},
{{5001867303239790350ull, 326551850775446ull}},
{{624290055699843915ull, 522482961240714ull}},
{{4188780859301785455ull, 417986368992571ull}},
{{18108419946409069657ull, 334389095194056ull}},
{{3148030211061139188ull, 535022552310491ull}},
{{17275819427816552643ull, 428018041848392ull}},
{{6441957912769421468ull, 342414433478714ull}},
{{17685830289914894996ull, 547863093565942ull}},
{{6769966602448095350ull, 438290474852754ull}},
{{9105322096700386603ull, 350632379882203ull}},
{{10879166539978708242ull, 561011807811525ull}},
{{8703333231982966594ull, 448809446249220ull}},
{{6962666585586373275ull, 359047556999376ull}},
{{1880784453727188297ull, 287238045599501ull}},
{{14077301570189232244ull, 459580872959201ull}},
{{7572492441409475472ull, 367664698367361ull}},
{{2368645138385670055ull, 294131758693889ull}},
{{11168529850900892734ull, 470610813910222ull}},
{{1556126251236893541ull, 376488651128178ull}},
{{8623598630473335479ull, 301190920902542ull}},
{{17487106623499247090ull, 481905473444067ull}},
{{6610987669315577025ull, 385524378755254ull}},
{{8978138950194371943ull, 308419503004203ull}},
{{10675673505569084786ull, 493471204806725ull}},
{{8540538804455267829ull, 394776963845380ull}},
{{6832431043564214263ull, 315821571076304ull}},
{{18310587299186563468ull, 505314513722086ull}},
{{10959121024607340451ull, 404251610977669ull}},
{{12456645634427782684ull, 323401288782135ull}},
{{1483888941374900678ull, 517442062051417ull}},
{{12255157597325651512ull, 413953649641133ull}},
{{17182823707344341856ull, 331162919712906ull}},
{{1667076228557574707ull, 529860671540651ull}},
{{16091056241813701059ull, 423888537232520ull}},
{{12872844993450960847ull, 339110829786016ull}},
{{13217854360037716709ull, 542577327657626ull}},
{{6884934673288263044ull, 434061862126101ull}},
{{1818598923888700112ull, 347249489700881ull}},
{{13977804722447651149ull, 555599183521409ull}},
{{14871592592700031242ull, 444479346817127ull}},
{{4518576444676204347ull, 355583477453702ull}},
{{14682907599966694447ull, 284466781962961ull}},
{{16113954530462890469ull, 455146851140738ull}},
{{1823117180144581406ull, 364117480912591ull}},
{{16215889003083306417ull, 291293984730072ull}},
{{11188027145965648975ull, 466070375568116ull}},
{{5261072902030608857ull, 372856300454493ull}},
{{11587555951108307732ull, 298285040363594ull}},
{{7472043077547561402ull, 477256064581751ull}},
{{2288285647296138798ull, 381804851665401ull}},
{{16588023776804552331ull, 305443881332320ull}},
{{8094093969177732114ull, 488710210131713ull}},
{{13853972804826006338ull, 390968168105370ull}},
{{11083178243860805070ull, 312774534484296ull}},
{{10354387560693467466ull, 500439255174874ull}},
{{11972858863296684296ull, 400351404139899ull}},
{{13267635905379257760ull, 320281123311919ull}},
{{10160171004381081446ull, 512449797299071ull}},
{{4438787988762954834ull, 409959837839257ull}},
{{14619076835236094836ull, 327967870271405ull}},
{{4943778862668200123ull, 524748592434249ull}},
{{7644371904876470421ull, 419798873947399ull}},
{{9804846338643086660ull, 335839099157919ull}},
{{4619707697603207687ull, 537342558652671ull}},
{{6417343340655826ull, 429874046922137ull}},
{{11073180318898255630ull, 343899237537709ull}},
{{6649042066011478039ull, 550238780060335ull}},
{{5319233652809182431ull, 440191024048268ull}},
{{11634084551731166591ull, 352152819238614ull}},
{{12996616456126843596ull, 281722255390891ull}},
{{13415888700319129108ull, 450755608625426ull}},
{{7043362145513392963ull, 360604486900341ull}},
{{1945340901668804047ull, 288483589520273ull}},
{{17869940701637727768ull, 461573743232436ull}},
{{10606603746568271891ull, 369258994585949ull}},
{{12174631811996527836ull, 295407195668759ull}},
{{8411364454968713569ull, 472651513070015ull}},
{{6729091563974970855ull, 378121210456012ull}},
{{16451319695405707653ull, 302496968364809ull}},
{{15254065068423401276ull, 483995149383695ull}},
{{12203252054738721021ull, 387196119506956ull}},
{{6073252829049066493ull, 309756895605565ull}},
{{9717204526478506390ull, 495611032968904ull}},
{{11463112435924715435ull, 396488826375123ull}},
{{16549187578223592994ull, 317191061100098ull}},
{{4342607236706286852ull, 507505697760158ull}},
{{10852783418848850128ull, 406004558208126ull}},
{{4992877920337169779ull, 324803646566501ull}},
{{609907043055651000ull, 519685834506402ull}},
{{11555972078670251770ull, 415748667605121ull}},
{{5555428848194291092ull, 332598934084097ull}},
{{12578034971852776071ull, 532158294534555ull}},
{{10062427977482220857ull, 425726635627644ull}},
{{11739291196727687009ull, 340581308502115ull}},
{{336121841054747598ull, 544930093603385ull}},
{{268897472843798078ull, 435944074882708ull}},
{{7593815607758859109ull, 348755259906166ull}},
{{4771407342930353928ull, 558008415849866ull}},
{{127777059602372819ull, 446406732679893ull}},
{{7480919277165718902ull, 357125386143914ull}},
{{9674084236474485445ull, 285700308915131ull}},
{{8099837148875356065ull, 457120494264210ull}},
{{6479869719100284852ull, 365696395411368ull}},
{{12562593404764048528ull, 292557116329094ull}},
{{9032103003396746675ull, 468091386126551ull}},
{{3536333587975487017ull, 374473108901241ull}},
{{17586462129348030906ull, 299578487120992ull}},
{{13380944147989208158ull, 479325579393588ull}},
{{18083452947875187172ull, 383460463514870ull}},
{{14466762358300149738ull, 306768370811896ull}},
{{15768122143796418934ull, 490829393299034ull}},
{{16303846529779045471ull, 392663514639227ull}},
{{5664379594339415730ull, 314130811711382ull}},
{{12752356165684975491ull, 502609298738211ull}},
{{6512536117806070070ull, 402087438990569ull}},
{{8899377708986766379ull, 321669951192455ull}},
{{14239004334378826207ull, 514671921907928ull}},
{{323157023277329996ull, 411737537526343ull}},
{{7637223248105684643ull, 329390030021074ull}},
{{1151510752743364459ull, 527024048033719ull}},
{{4610557416936601890ull, 421619238426975ull}},
{{3688445933549281512ull, 337295390741580ull}},
{{5901513493678850420ull, 539672625186528ull}},
{{12099908424426900982ull, 431738100149222ull}},
{{2301229110057700139ull, 345390480119378ull}},
{{18439361835059961516ull, 552624768191004ull}},
{{18440838282789879536ull, 442099814552803ull}},
{{3684624182006172659ull, 353679851642243ull}},
{{10326396975088758774ull, 282943881313794ull}},
{{5454188715916283068ull, 452710210102071ull}},
{{674002157991116131ull, 362168168081657ull}},
{{11607248170618623875ull, 289734534465325ull}},
{{124852999280246584ull, 463575255144521ull}},
{{14857277658391838560ull, 370860204115616ull}},
{{8196473311971560524ull, 296688163292493ull}},
{{9425008484412586516ull, 474701061267989ull}},
{{11229355602271979536ull, 379760849014391ull}},
{{5294135667075673305ull, 303808679211513ull}},
{{4781268252579166966ull, 486093886738421ull}},
{{135665787321423249ull, 388875109390737ull}},
{{11176579074082869569ull, 311100087512589ull}},
{{6814480074306860341ull, 497760140020143ull}},
{{12830281688929308919ull, 398208112016114ull}},
{{13953574165885357458ull, 318566489612891ull}},
{{14947021035932751287ull, 509706383380626ull}},
{{8268268014004290707ull, 407765106704501ull}},
{{2925265596461522242ull, 326212085363601ull}},
{{15748471398564166557ull, 521939336581761ull}},
{{8909428304109422922ull, 417551469265409ull}},
{{10816891458029448661ull, 334041175412327ull}},
{{2549631073879476565ull, 534465880659724ull}},
{{5729053673845491575ull, 427572704527779ull}},
{{8272591753818303583ull, 342058163622223ull}},
{{9546797991367375410ull, 547293061795557ull}},
{{258740763610079682ull, 437834449436446ull}},
{{14964387869855705038ull, 350267559549156ull}},
{{16564322962285307415ull, 560428095278650ull}},
{{13251458369828245932ull, 448342476222920ull}},
{{10601166695862596745ull, 358673980978336ull}},
{{4791584541948167073ull, 286939184782669ull}},
{{15045232896600887963ull, 459102695652270ull}},
{{12036186317280710371ull, 367282156521816ull}},
{{5939600239082657973ull, 293825725217453ull}},
{{5814011567790342434ull, 470121160347925ull}},
{{4651209254232273947ull, 376096928278340ull}},
{{3720967403385819158ull, 300877542622672ull}},
{{9642896660159220976ull, 481404068196275ull}},
{{7714317328127376781ull, 385123254557020ull}},
{{6171453862501901424ull, 308098603645616ull}},
{{2495628550519221633ull, 492957765832986ull}},
{{16753898099383018599ull, 394366212666388ull}},
{{2335072035280683910ull, 315492970133111ull}},
{{14804161700674825225ull, 504788752212977ull}},
{{4464631731056039534ull, 403831001770382ull}},
{{14639751829070562596ull, 323064801416305ull}},
{{4976858852803348539ull, 516903682266089ull}},
{{7670835896984589154ull, 413522945812871ull}},
{{2447319902845761000ull, 330818356650297ull}},
{{7605060659295127923ull, 529309370640475ull}},
{{6084048527436102339ull, 423447496512380ull}},
{{4867238821948881871ull, 338757997209904ull}},
{{15166279744602031640ull, 542012795535846ull}},
{{8443674980939714989ull, 433610236428677ull}},
{{17822986428977502960ull, 346888189142941ull}},
{{2691336583170632474ull, 555021102628707ull}},
{{13221115710762236949ull, 444016882102965ull}},
{{10576892568609789559ull, 355213505682372ull}},
{{1082816425404011001ull, 284170804545898ull}},
{{16489901539614058894ull, 454673287273436ull}},
{{9502572416949336792ull, 363738629818749ull}},
{{11291406748301379757ull, 290990903854999ull}},
{{6998204353056476642ull, 465585446167999ull}},
{{9287912297187091636ull, 372468356934399ull}},
{{11119678652491583632ull, 297974685547519ull}},
{{6723439399760802842ull, 476759496876031ull}},
{{1689402705066731951ull, 381407597500825ull}},
{{1351522164053385560ull, 305126078000660ull}},
{{2162435462485416897ull, 488201724801056ull}},
{{16487343628955974810ull, 390561379840844ull}},
{{16879223717906690171ull, 312449103872675ull}},
{{8560013874941152658ull, 499918566196281ull}},
{{3158662285211011803ull, 399934852957025ull}},
{{2526929828168809443ull, 319947882365620ull}},
{{4043087725070095108ull, 511916611784992ull}},
{{14302516624281807056ull, 409533289427993ull}},
{{373966855199714675ull, 327626631542395ull}},
{{598346968319543481ull, 524202610467832ull}},
{{11546724018881365754ull, 419362088374265ull}},
{{9237379215105092603ull, 335489670699412ull}},
{{22411485200506873ull, 536783473119060ull}},
{{17929188160405498ull, 429426778495248ull}},
{{7393040980012145045ull, 343541422796198ull}},
{{8139516753277521749ull, 549666276473917ull}},
{{17579659846847748368ull, 439733021179133ull}},
{{2995681433252467725ull, 351786416943307ull}},
{{8482439107945858684ull, 562858267109291ull}},
{{3096602471614776624ull, 450286613687433ull}},
{{9855979606775641945ull, 360229290949946ull}},
{{4195434870678603233ull, 288183432759957ull}},
{{10402044607827675496ull, 461093492415931ull}},
{{4632286871520230073ull, 368874793932745ull}},
{{3705829497216184059ull, 295099835146196ull}},
{{16997373639771625464ull, 472159736233913ull}},
{{2529852467591569401ull, 377727788987131ull}},
{{16781277233040896814ull, 302182231189704ull}},
{{15781997128639703933ull, 483491569903527ull}},
{{5246900073427942500ull, 386793255922822ull}},
{{15265566502968084969ull, 309434604738257ull}},
{{9667511145781294658ull, 495095367581212ull}},
{{355311287141215080ull, 396076294064970ull}},
{{284249029712972064ull, 316861035251976ull}},
{{11522844891766486272ull, 506977656403161ull}},
{{5528927098671278695ull, 405582125122529ull}},
{{8112490493678933279ull, 324465700098023ull}},
{{9290635975144382923ull, 519145120156837ull}},
{{53811150631685692ull, 415316096125470ull}},
{{43048920505348553ull, 332252876900376ull}},
{{11136924717034288655ull, 531604603040601ull}},
{{5220190958885520601ull, 425283682432481ull}},
{{486803952366506158ull, 340226945945985ull}},
{{778886323786409852ull, 544363113513576ull}},
{{15380504317996769175ull, 435490490810860ull}},
{{12304403454397415340ull, 348392392648688ull}},
{{15997696712293954220ull, 557427828237901ull}},
{{9108808555093253053ull, 445942262590321ull}},
{{3597698029332692119ull, 356753810072257ull}},
{{13946204867691884665ull, 285403048057805ull}},
{{3867183714597463848ull, 456644876892489ull}},
{{6783095786419881402ull, 365315901513991ull}},
{{1737127814393994798ull, 292252721211193ull}},
{{17536799761998032970ull, 467604353937908ull}},
{{2961393365372695406ull, 374083483150327ull}},
{{13437161136523887294ull, 299266786520261ull}},
{{14120760188954399025ull, 478826858432418ull}},
{{228561706937788250ull, 383061486745935ull}},
{{182849365550230600ull, 306449189396748ull}},
{{15049954243848010253ull, 490318703034796ull}},
{{8350614580336497879ull, 392254962427837ull}},
{{17748538108494929273ull, 313803969942269ull}},
{{17329614529366155867ull, 502086351907631ull}},
{{10174342808751014371ull, 401669081526105ull}},
{{8139474247000811496ull, 321335265220884ull}},
{{1955112350975567425ull, 514136424353415ull}},
{{1564089880780453940ull, 411309139482732ull}},
{{12319318348850094121ull, 329047311586185ull}},
{{1264165284450598978ull, 526475698537897ull}},
{{12079378671786210152ull, 421180558830317ull}},
{{2284805307945147475ull, 336944447064254ull}},
{{11034386122196056607ull, 539111115302806ull}},
{{5138160083014934962ull, 431288892242245ull}},
{{4110528066411947970ull, 345031113793796ull}},
{{17644891350484847722ull, 552049782070073ull}},
{{3047866636162147208ull, 441639825656059ull}},
{{6127642123671628089ull, 353311860524847ull}},
{{15970160143163033441ull, 282649488419877ull}},
{{10794860970093212213ull, 452239181471804ull}},
{{12325237590816480093ull, 361791345177443ull}},
{{17238887702137004721ull, 289433076141954ull}},
{{16514173879193476584ull, 463092921827127ull}},
{{5832641473870960621ull, 370474337461702ull}},
{{15734159623322499466ull, 296379469969361ull}},
{{17795957767832178500ull, 474207151950978ull}},
{{3168719770040011830ull, 379365721560783ull}},
{{9913673445515830111ull, 303492577248626ull}},
{{8483179883341507531ull, 485588123597802ull}},
{{17854590350898936994ull, 388470498878241ull}},
{{10594323465977239272ull, 310776399102593ull}},
{{13261568730821672512ull, 497242238564149ull}},
{{14298603799399248333ull, 397793790851319ull}},
{{15128231854261308989ull, 318235032681055ull}},
{{5758426893108542767ull, 509176052289689ull}},
{{8296090329228744537ull, 407340841831751ull}},
{{2947523448641085306ull, 325872673465401ull}},
{{15784083962051467460ull, 521396277544641ull}},
{{8937918354899263645ull, 417117022035713ull}},
{{14529032313403231562ull, 333693617628570ull}},
{{4799707627735618884ull, 533909788205713ull}},
{{11218463731672315753ull, 427127830564570ull}},
{{8974770985337852602ull, 341702264451656ull}},
{{6980935947056743518ull, 546723623122650ull}},
{{5584748757645394814ull, 437378898498120ull}},
{{4467799006116315851ull, 349903118798496ull}},
{{18216524854011836332ull, 559844990077593ull}},
{{3505173438983738096ull, 447875992062075ull}},
{{2804138751186990477ull, 358300793649660ull}},
{{2243311000949592381ull, 286640634919728ull}},
{{18346692860486989103ull, 458625015871564ull}},
{{18366703103131501605ull, 366900012697251ull}},
{{11004013667763290961ull, 293520010157801ull}},
{{10227724238937444892ull, 469632016252482ull}},
{{803481761666135267ull, 375705613001986ull}},
{{15400180668300549506ull, 300564490401588ull}},
{{2504196180829417271ull, 480903184642542ull}},
{{13071403388889264786ull, 384722547714033ull}},
{{17835820340595232475ull, 307778038171226ull}},
{{2711870841758999698ull, 492444861073963ull}},
{{9548194302891020405ull, 393955888859170ull}},
{{7638555442312816324ull, 315164711087336ull}},
{{4842991078216685472ull, 504263537739738ull}},
{{11253090492057169024ull, 403410830191790ull}},
{{9002472393645735219ull, 322728664153432ull}},
{{18093304644575086674ull, 516365862645491ull}},
{{10785294900918159016ull, 413092690116393ull}},
{{16006933550218347859ull, 330474152093114ull}},
{{14543047236123625605ull, 528758643348983ull}},
{{566391344673169514ull, 423006914679187ull}},
{{11521159519964266581ull, 338405531743349ull}},
{{7365808787717095560ull, 541448850789359ull}},
{{9581995844915586771ull, 433159080631487ull}},
{{286899046448648771ull, 346527264505190ull}},
{{459038474317838033ull, 554443623208304ull}},
{{4056579594196180750ull, 443554898566643ull}},
{{10623961304840765246ull, 354843918853314ull}},
{{12188517858614522520ull, 283875135082651ull}},
{{12122930944299415386ull, 454200216132242ull}},
{{2319647125955711662ull, 363360172905794ull}},
{{5545066515506479653ull, 290688138324635ull}},
{{8872106424810367445ull, 465101021319416ull}},
{{3408336325106383633ull, 372080817055533ull}},
{{10105366689568927552ull, 297664653644426ull}},
{{8789889073826463438ull, 476263445831082ull}},
{{18099957703286901720ull, 381010756664865ull}},
{{14479966162629521376ull, 304808605331892ull}},
{{8410550601239592908ull, 487693768531028ull}},
{{14107138110475494973ull, 390155014824822ull}},
{{3907012858896575332ull, 312124011859858ull}},
{{2561871759492610208ull, 499398418975773ull}},
{{9428195037077908813ull, 399518735180618ull}},
{{14921253659146147697ull, 319614988144494ull}},
{{12805959410408105345ull, 511383981031191ull}},
{{6555418713584573953ull, 409107184824953ull}},
{{12623032600351479809ull, 327285747859962ull}},
{{5439456901594726401ull, 523657196575940ull}},
{{4351565521275781121ull, 418925757260752ull}},
{{14549298861246355866ull, 335140605808601ull}},
{{15900180548510348740ull, 536224969293762ull}},
{{5341446809324458345ull, 428979975435010ull}},
{{4273157447459566676ull, 343183980348008ull}},
{{3147703101193396359ull, 549094368556813ull}},
{{9896860110438537734ull, 439275494845450ull}},
{{7917488088350830187ull, 351420395876360ull}},
{{12667980941361328299ull, 562272633402176ull}},
{{6445035938347152316ull, 449818106721741ull}},
{{1466679935935811529ull, 359854485377393ull}},
{{8552041578232469870ull, 287883588301914ull}},
{{2615220080946220823ull, 460613741283063ull}},
{{9470873694240797304ull, 368490993026450ull}},
{{7576698955392637843ull, 294792794421160ull}},
{{12122718328628220550ull, 471668471073856ull}},
{{6008825848160666116ull, 377334776859085ull}},
{{4807060678528532893ull, 301867821487268ull}},
{{4001948270903742306ull, 482988514379629ull}},
{{6890907431464904168ull, 386390811503703ull}},
{{12891423574655743981ull, 309112649202962ull}},
{{5868882460481549076ull, 494580238724740ull}},
{{4695105968385239261ull, 395664190979792ull}},
{{14824131218933922378ull, 316531352783833ull}},
{{1582517061842813866ull, 506450164454134ull}},
{{4955362464216161416ull, 405160131563307ull}},
{{15032336415598660103ull, 324128105250645ull}},
{{5604994191248304548ull, 518604968401033ull}},
{{11862692982482464285ull, 414883974720826ull}},
{{5800805571244061105ull, 331907179776661ull}},
{{1902591284506677121ull, 531051487642658ull}},
{{8900770657089162343ull, 424841190114126ull}},
{{3431267710929419551ull, 339872952091301ull}},
{{16558074781712802252ull, 543796723346081ull}},
{{9557111010628331478ull, 435037378676865ull}},
{{7645688808502665183ull, 348029902941492ull}},
{{15922450908346174616ull, 556847844706387ull}},
{{5359263097193119046ull, 445478275765110ull}},
{{4287410477754495237ull, 356382620612088ull}},
{{10808626011687416836ull, 285106096489670ull}},
{{17293801618699866937ull, 456169754383472ull}},
{{6456343665476072903ull, 364935803506778ull}},
{{12543772561864678969ull, 291948642805422ull}},
{{5312640840015845058ull, 467117828488676ull}},
{{560763857270765723ull, 373694262790941ull}},
{{15206006344784253871ull, 298955410232752ull}},
{{9572214892687164901ull, 478328656372404ull}},
{{11347120728891642244ull, 382662925097923ull}},
{{16456394212597134442ull, 306130340078338ull}},
{{4194137851703953168ull, 489808544125342ull}},
{{14423356725588893504ull, 391846835300273ull}},
{{470638936245383833ull, 313477468240219ull}},
{{8131719927476434780ull, 501563949184350ull}},
{{6505375941981147824ull, 401251159347480ull}},
{{5204300753584918259ull, 321000927477984ull}},
{{15705578835219689861ull, 513601483964774ull}},
{{16253811882917662212ull, 410881187171819ull}},
{{16692398321076040093ull, 328704949737455ull}},
{{8261093240012112533ull, 525927919579929ull}},
{{10298223406751600349ull, 420742335663943ull}},
{{15617276354885100926ull, 336593868531154ull}},
{{13919595723590430512ull, 538550189649847ull}},
{{3756978949388523763ull, 430840151719878ull}},
{{10384280788994639657ull, 344672121375902ull}},
{{1857454003423782158ull, 551475394201444ull}},
{{5175312017480936050ull, 441180315361155ull}},
{{4140249613984748840ull, 352944252288924ull}},
{{7001548505929709395ull, 282355401831139ull}},
{{134431165261804062ull, 451768642929823ull}},
{{7486242561693263896ull, 361414914343858ull}},
{{13367691678838431763ull, 289131931475086ull}},
{{14009609056657670175ull, 462611090360138ull}},
{{139640801100405170ull, 370088872288111ull}},
{{14869107899847965429ull, 296071097830488ull}},
{{1654479751305282747ull, 473713756528782ull}},
{{12391630245269957167ull, 378971005223025ull}},
{{9913304196215965734ull, 303176804178420ull}},
{{15861286713945545174ull, 485082886685472ull}},
{{5310331741672615493ull, 388066309348378ull}},
{{11626963022821913041ull, 310453047478702ull}},
{{3845745577547419573ull, 496724875965924ull}},
{{6765945276779845981ull, 397379900772739ull}},
{{9102105036165787108ull, 317903920618191ull}},
{{7184670428381438727ull, 508646272989106ull}},
{{2058387527963240658ull, 406917018391285ull}},
{{1646710022370592526ull, 325533614713028ull}},
{{17392131294760589335ull, 520853783540844ull}},
{{17603053850550381791ull, 416683026832675ull}},
{{14082443080440305433ull, 333346421466140ull}},
{{4085164854994937077ull, 533354274345825ull}},
{{3268131883995949662ull, 426683419476660ull}},
{{2614505507196759729ull, 341346735581328ull}},
{{493859996772905244ull, 546154776930125ull}},
{{395087997418324195ull, 436923821544100ull}},
{{316070397934659356ull, 349539057235280ull}},
{{505712636695454970ull, 559262491576448ull}},
{{7783267738840184622ull, 447409993261158ull}},
{{13605311820555968344ull, 357927994608926ull}},
{{7194900641702864352ull, 286342395687141ull}},
{{4133143397240762317ull, 458147833099426ull}},
{{18063909976760251146ull, 366518266479540ull}},
{{14451127981408200917ull, 293214613183632ull}},
{{8364409511285480174ull, 469143381093812ull}},
{{17759574053254115109ull, 375314704875049ull}},
{{17897008057345202410ull, 300251763900039ull}},
{{17567166447526592887ull, 480402822240063ull}},
{{2985686713795543340ull, 384322257792051ull}},
{{17145944630004075965ull, 307457806233640ull}},
{{8986767334296969928ull, 491932489973825ull}},
{{7189413867437575942ull, 393545991979060ull}},
{{5751531093950060754ull, 314836793583248ull}},
{{5513100935578186883ull, 503738869733197ull}},
{{15478527192688280476ull, 402991095786557ull}},
{{5004124124666803734ull, 322392876629246ull}},
{{627900969983065329ull, 515828602606794ull}},
{{4191669590728362586ull, 412662882085435ull}},
{{3353335672582690069ull, 330130305668348ull}},
{{1675988261390393787ull, 528208489069357ull}},
{{12408837053338045999ull, 422566791255485ull}},
{{9927069642670436799ull, 338053433004388ull}},
{{12193962613530788556ull, 540885492807021ull}},
{{6065821276082720521ull, 432708394245617ull}},
{{15920703465091907387ull, 346166715396493ull}},
{{3337032655695589880ull, 553866744634390ull}},
{{2669626124556471904ull, 443093395707512ull}},
{{13203747343870908492ull, 354474716566009ull}},
{{14252346689838637117ull, 283579773252807ull}},
{{8046359444774178095ull, 453727637204492ull}},
{{17505134000045073445ull, 362982109763593ull}},
{{2936060755810327787ull, 290385687810875ull}},
{{4697697209296524459ull, 464617100497400ull}},
{{3758157767437219567ull, 371693680397920ull}},
{{3006526213949775653ull, 297354944318336ull}},
{{15878488386545372015ull, 475767910909337ull}},
{{5324093079752476966ull, 380614328727470ull}},
{{4259274463801981573ull, 304491462981976ull}},
{{17882885586308901486ull, 487186340771161ull}},
{{10616959654305210865ull, 389749072616929ull}},
{{12182916538186079015ull, 311799258093543ull}},
{{15803317646355816102ull, 498878812949669ull}},
{{16332002931826563205ull, 399103050359735ull}},
{{13065602345461250564ull, 319282440287788ull}},
{{17215614937996090579ull, 510851904460461ull}},
{{10083143135654962140ull, 408681523568369ull}},
{{11755863323265880035ull, 326945218854695ull}},
{{362637243515856440ull, 523112350167513ull}},
{{7668807424296505798ull, 418489880134010ull}},
{{6135045939437204639ull, 334791904107208ull}},
{{6126724688357617099ull, 535667046571533ull}},
{{12280077380169914325ull, 428533637257226ull}},
{{6134713089394021137ull, 342826909805781ull}},
{{2436843313546613173ull, 548523055689250ull}},
{{1949474650837290538ull, 438818444551400ull}},
{{1559579720669832431ull, 351054755641120ull}},
{{2495327553071731889ull, 561687609025792ull}},
{{13064308486683116481ull, 449350087220633ull}},
{{17830144418830313831ull, 359480069776506ull}},
{{10574766720322340742ull, 287584055821205ull}},
{{16919626752515745187ull, 460134489313928ull}},
{{2467654957786865180ull, 368107591451143ull}},
{{9352821595713312790ull, 294486073160914ull}},
{{3896468108915569495ull, 471177717057463ull}},
{{10495872116616276242ull, 376942173645970ull}},
{{8396697693293020994ull, 301553738916776ull}},
{{6056018679785012944ull, 482485982266842ull}},
{{15912861388053741325ull, 385988785813473ull}},
{{1662242666217262090ull, 308791028650779ull}},
{{10038285895431439991ull, 494065645841246ull}},
{{4341279901603241669ull, 395252516672997ull}},
{{14541070365508324305ull, 316202013338397ull}},
{{8508317325845677595ull, 505923221341436ull}},
{{3117305045934631753ull, 404738577073149ull}},
{{6183192851489615725ull, 323790861658519ull}},
{{17271806191867205807ull, 518065378653630ull}},
{{13817444953493764646ull, 414452302922904ull}},
{{14743304777536922040ull, 331561842338323ull}},
{{1453194755607613325ull, 530498947741318ull}},
{{8541253433969911306ull, 424399158193054ull}},
{{10522351561917839368ull, 339519326554443ull}},
{{13146413684326632666ull, 543230922487109ull}},
{{14206479762203216456ull, 434584737989687ull}},
{{3986486180278752518ull, 347667790391750ull}},
{{6378377888446004029ull, 556268464626800ull}},
{{5102702310756803223ull, 445014771701440ull}},
{{4082161848605442578ull, 356011817361152ull}},
{{14333775923110085032ull, 284809453888921ull}},
{{15555343847492315406ull, 455695126222274ull}},
{{16133623892735762648ull, 364556100977819ull}},
{{16596247928930520441ull, 291644880782255ull}},
{{8107252612579281090ull, 466631809251609ull}},
{{10175150904805335195ull, 373305447401287ull}},
{{761423094360447510ull, 298644357921030ull}},
{{1218276950976716016ull, 477830972673648ull}},
{{8353319190265193459ull, 382264778138918ull}},
{{14061352981695975413ull, 305811822511134ull}},
{{11430118326487829692ull, 489298916017815ull}},
{{9144094661190263754ull, 391439132814252ull}},
{{18383322173177941972ull, 313151306251401ull}},
{{3587873773891334894ull, 501042090002243ull}},
{{10248996648596888561ull, 400833672001794ull}},
{{11888546133619421172ull, 320666937601435ull}},
{{574929740081522260ull, 513067100162297ull}},
{{11527990236290948777ull, 410453680129837ull}},
{{1843694559548938375ull, 328362944103870ull}},
{{2949911295278301401ull, 525380710566192ull}},
{{13427975480448372090ull, 420304568452953ull}},
{{18121078013842518318ull, 336243654762362ull}},
{{14236329563180388017ull, 537989847619780ull}},
{{11389063650544310414ull, 430391878095824ull}},
{{12800599735177358654ull, 344313502476659ull}},
{{9412913132058042877ull, 550901603962655ull}},
{{7530330505646434301ull, 440721283170124ull}},
{{9713613219259057764ull, 352577026536099ull}},
{{11460239390149156535ull, 282061621228879ull}},
{{7268336580012919486ull, 451298593966207ull}},
{{16882715708236066558ull, 361038875172965ull}},
{{13506172566588853246ull, 288831100138372ull}},
{{6852480847574523902ull, 462129760221396ull}},
{{1792635863317708798ull, 369703808177117ull}},
{{12502155134879898008ull, 295763046541693ull}},
{{16314099401065926490ull, 473220874466709ull}},
{{16740628335594651515ull, 378576699573367ull}},
{{6013805038991900566ull, 302861359658694ull}},
{{17000785691870861552ull, 484578175453910ull}},
{{13600628553496689241ull, 387662540363128ull}},
{{18259200472281172039ull, 310130032290502ull}},
{{14457325496682233970ull, 496208051664804ull}},
{{15255209212087697499ull, 396966441331843ull}},
{{1136120925444427030ull, 317573153065475ull}},
{{1817793480711083248ull, 508117044904760ull}},
{{1454234784568866598ull, 406493635923808ull}},
{{8542085457138913925ull, 325194908739046ull}},
{{6288639101938441634ull, 520311853982474ull}},
{{8720260096292663630ull, 416249483185979ull}},
{{10665556891776041227ull, 332999586548783ull}},
{{13375542212099755641ull, 532799338478053ull}},
{{18079131399163625159ull, 426239470782442ull}},
{{7084607489847079481ull, 340991576625954ull}},
{{267325539529596200ull, 545586522601527ull}},
{{11281906875849407929ull, 436469218081221ull}},
{{5336176685937616020ull, 349175374464977ull}},
{{12227231512242095956ull, 558680599143963ull}},
{{17160482839277497411ull, 446944479315170ull}},
{{13728386271421997928ull, 357555583452136ull}},
{{7293360202395688019ull, 286044466761709ull}},
{{601329879607369862ull, 457671146818735ull}},
{{481063903685895889ull, 366136917454988ull}},
{{7763548752432537358ull, 292909533963990ull}},
{{12421678003892059773ull, 468655254342384ull}},
{{13626691217855558141ull, 374924203473907ull}},
{{3522655344800625867ull, 299939362779126ull}},
{{16704294995906732356ull, 479902980446601ull}},
{{9674087181983475562ull, 383922384357281ull}},
{{4049920930844870126ull, 307137907485825ull}},
{{6479873489351792202ull, 491420651977320ull}},
{{5183898791481433762ull, 393136521581856ull}},
{{457770218443236686ull, 314509217265485ull}},
{{732432349509178698ull, 503214747624776ull}},
{{15343341138574984251ull, 402571798099820ull}},
{{12274672910859987401ull, 322057438479856ull}},
{{12260779027892159195ull, 515291901567770ull}},
{{9808623222313727356ull, 412233521254216ull}},
{{4157549763109071561ull, 329786817003373ull}},
{{2962730806232604175ull, 527658907205397ull}},
{{13438231089211814310ull, 422127125764317ull}},
{{3371887241885630801ull, 337701700611454ull}},
{{12773717216500829929ull, 540322720978326ull}},
{{6529624958458753620ull, 432258176782661ull}},
{{1534351152025092573ull, 345806541426129ull}},
{{9833659472723968763ull, 553290466281806ull}},
{{4177578763437264687ull, 442632373025445ull}},
{{3342063010749811749ull, 354105898420356ull}},
{{17431045667567490692ull, 283284718736284ull}},
{{16821626623882254138ull, 453255549978055ull}},
{{13457301299105803311ull, 362604439982444ull}},
{{14455189854026552972ull, 290083551985955ull}},
{{4681559692732933139ull, 464133683177529ull}},
{{7434596568928256834ull, 371306946542023ull}},
{{13326374884626426114ull, 297045557233618ull}},
{{17632851000660371459ull, 475272891573789ull}},
{{17795629615270207490ull, 380218313259031ull}},
{{10547154877474255669ull, 304174650607225ull}},
{{16875447803958809070ull, 486679440971560ull}},
{{13500358243167047256ull, 389343552777248ull}},
{{18178984224017458451ull, 311474842221798ull}},
{{6950281869976471583ull, 498359747554878ull}},
{{12938923125464997913ull, 398687798043902ull}},
{{2972440870888177684ull, 318950238435122ull}},
{{8445254208162994618ull, 510320381496195ull}},
{{6756203366530395694ull, 408256305196956ull}},
{{1715613878482406232ull, 326605044157565ull}},
{{2744982205571849971ull, 522568070652104ull}},
{{5885334579199390300ull, 418054456521683ull}},
{{12086965292843332886ull, 334443565217346ull}},
{{11960446839065511972ull, 535109704347754ull}},
{{13257706285994319901ull, 428087763478203ull}},
{{17984862658279276567ull, 342470210782562ull}},
{{14018384994279201215ull, 547952337252100ull}},
{{11214707995423360972ull, 438361869801680ull}},
{{8971766396338688777ull, 350689495841344ull}},
{{3286779789916171074ull, 561103193346151ull}},
{{17386819090900578152ull, 448882554676920ull}},
{{13909455272720462522ull, 359106043741536ull}},
{{7438215403434459694ull, 287284834993229ull}},
{{833098201269404541ull, 459655735989167ull}},
{{11734525005241254602ull, 367724588791333ull}},
{{16766317633676824328ull, 294179671033066ull}},
{{1000666510689546663ull, 470687473652907ull}},
{{11868579652777368300ull, 376549978922325ull}},
{{9494863722221894640ull, 301239983137860ull}},
{{15191781955555031424ull, 481983973020576ull}},
{{8464076749702114816ull, 385587178416461ull}},
{{3081912585019781529ull, 308469742733169ull}},
{{12309757765515471094ull, 493551588373070ull}},
{{9847806212412376875ull, 394841270698456ull}},
{{4188896155187991177ull, 315873016558765ull}},
{{6702233848300785883ull, 505396826494024ull}},
{{9051135893382539029ull, 404317461195219ull}},
{{10930257529447941547ull, 323453968956175ull}},
{{17488412047116706475ull, 517526350329880ull}},
{{13990729637693365180ull, 414021080263904ull}},
{{14881932524896602467ull, 331216864211123ull}},
{{1674999151383102008ull, 529946982737798ull}},
{{8718696950590302253ull, 423957586190238ull}},
{{14353655189956062449ull, 339166068952190ull}},
{{4519104230220148302ull, 542665710323505ull}},
{{3615283384176118641ull, 434132568258804ull}},
{{6581575522082805236ull, 347306054607043ull}},
{{6841172020590578055ull, 555689687371269ull}},
{{9162286431214372767ull, 444551749897015ull}},
{{7329829144971498214ull, 355641399917612ull}},
{{16931909760202929540ull, 284513119934089ull}},
{{16023009172098956295ull, 455220991894543ull}},
{{1750360893453434067ull, 364176793515635ull}},
{{1400288714762747253ull, 291341434812508ull}},
{{16997857202588036898ull, 466146295700012ull}},
{{6219588132586608872ull, 372917036560010ull}},
{{4975670506069287098ull, 298333629248008ull}},
{{4271723994968949033ull, 477333806796813ull}},
{{10796076825458979873ull, 381867045437450ull}},
{{8636861460367183898ull, 305493636349960ull}},
{{13818978336587494237ull, 488789818159936ull}},
{{7365833854528085067ull, 391031854527949ull}},
{{9582015898364378376ull, 312825483622359ull}},
{{4263178993157274433ull, 500520773795775ull}},
{{3410543194525819546ull, 400416619036620ull}},
{{2728434555620655637ull, 320333295229296ull}},
{{15433541733218779989ull, 512533272366873ull}},
{{1278786942349293021ull, 410026617893499ull}},
{{4712378368621344740ull, 328021294314799ull}},
{{14918503019277972231ull, 524834070903678ull}},
{{866755971196646815ull, 419867256722943ull}},
{{8072102406441138098ull, 335893805378354ull}},
{{1847317406080089988ull, 537430088605367ull}},
{{12545900369089802960ull, 429944070884293ull}},
{{17415417924755663014ull, 343955256707434ull}},
{{16796622235383329854ull, 550328410731895ull}},
{{13437297788306663883ull, 440262728585516ull}},
{{7060489415903420783ull, 352210182868413ull}},
{{13027089162206557273ull, 281768146294730ull}},
{{2396598585820940021ull, 450829034071569ull}},
{{5606627683398662340ull, 360663227257255ull}},
{{4485302146718929872ull, 288530581805804ull}},
{{14555181064234108441ull, 461648930889286ull}},
{{7954796036645376430ull, 369319144711429ull}},
{{10053185644058211467ull, 295455315769143ull}},
{{12395748215751228024ull, 472728505230629ull}},
{{13605947387342892742ull, 378182804184503ull}},
{{18263455539358134840ull, 302546243347602ull}},
{{14464133604005374452ull, 484073989356164ull}},
{{15260655697946209884ull, 387259191484931ull}},
{{8519175743615057584ull, 309807353187945ull}},
{{13630681189784092135ull, 495691765100712ull}},
{{3525847322343453062ull, 396553412080570ull}},
{{2820677857874762449ull, 317242729664456ull}},
{{15581131016825350889ull, 507588367463129ull}},
{{16154253628202191034ull, 406070693970503ull}},
{{1855356458336021858ull, 324856555176403ull}},
{{17725965592305276265ull, 519770488282244ull}},
{{17870121288586131335ull, 415816390625795ull}},
{{14296097030868905068ull, 332653112500636ull}},
{{15495057619906427463ull, 532244980001018ull}},
{{1327999651699411001ull, 425795984000815ull}},
{{1062399721359528800ull, 340636787200652ull}},
{{5389188368917156404ull, 545018859521043ull}},
{{11690048324617545770ull, 436015087616834ull}},
{{13041387474435946939ull, 348812070093467ull}},
{{6108824700129873809ull, 558099312149548ull}},
{{12265757389587719694ull, 446479449719638ull}},
{{17191303541153996401ull, 357183559775710ull}},
{{13753042832923197121ull, 285746847820568ull}},
{{18315519717935205071ull, 457194956512909ull}},
{{18341764589090074380ull, 365755965210327ull}},
{{7294714041788238857ull, 292604772168262ull}},
{{15360891281603092495ull, 468167635469219ull}},
{{15978061840024384319ull, 374534108375375ull}},
{{12782449472019507455ull, 299627286700300ull}},
{{2005175081521660313ull, 479403658720481ull}},
{{16361535324184969543ull, 383522926976384ull}},
{{16778577074089885957ull, 306818341581107ull}},
{{12088328059576176239ull, 490909346529772ull}},
{{2291964818177120345ull, 392727477223818ull}},
{{9212269484025516922ull, 314181981779054ull}},
{{3671584730215096106ull, 502691170846487ull}},
{{14005314228397807855ull, 402152936677189ull}},
{{14893600197460156607ull, 321722349341751ull}},
{{16451062686452429925ull, 514755758946802ull}},
{{5782152519678123293ull, 411804607157442ull}},
{{15693768459968229604ull, 329443685725953ull}},
{{2973936647497705428ull, 527109897161526ull}},
{{17136544576965805635ull, 421687917729220ull}},
{{13709235661572644508ull, 337350334183376ull}},
{{14556079429032410566ull, 539760534693402ull}},
{{4266165913742107807ull, 431808427754722ull}},
{{14480979175219417215ull, 345446742203777ull}},
{{8412171421383426251ull, 552714787526044ull}},
{{10419085951848651324ull, 442171830020835ull}},
{{8335268761478921059ull, 353737464016668ull}},
{{14046912638666957494ull, 282989971213334ull}},
{{11407013777641401020ull, 452783953941335ull}},
{{9125611022113120816ull, 362227163153068ull}},
{{14679186447174317299ull, 289781730522454ull}},
{{12418651871253176710ull, 463650768835927ull}},
{{2556223867518720721ull, 370920615068742ull}},
{{13113025538240707546ull, 296736492054993ull}},
{{17291492046443221751ull, 474778387287989ull}},
{{17522542451896487724ull, 379822709830391ull}},
{{10328685146775279856ull, 303858167864313ull}},
{{12836547420098537447ull, 486173068582901ull}},
{{6579889121336919634ull, 388938454866321ull}},
{{1574562482327625384ull, 311150763893057ull}},
{{6208648786466110938ull, 497841222228891ull}},
{{1277570214430978427ull, 398272977783113ull}},
{{8400753801028603388ull, 318618382226490ull}},
{{13441206081645765421ull, 509789411562384ull}},
{{14442313680058522660ull, 407831529249907ull}},
{{4175153314562997481ull, 326265223399926ull}},
{{17748291747526526940ull, 522024357439881ull}},
{{10509284583279311229ull, 417619485951905ull}},
{{8407427666623448983ull, 334095588761524ull}},
{{2383837822371787403ull, 534552942018439ull}},
{{5596419072639340246ull, 427642353614751ull}},
{{787786443369561873ull, 342113882891801ull}},
{{12328504753617029967ull, 547382212626881ull}},
{{6173454988151713650ull, 437905770101505ull}},
{{4938763990521370920ull, 350324616081204ull}},
{{15280720014318014119ull, 560519385729926ull}},
{{8535227196712500972ull, 448415508583941ull}},
{{3138832942628090454ull, 358732406867153ull}},
{{9889763983586293010ull, 286985925493722ull}},
{{1066227114770427523ull, 459177480789956ull}},
{{15610376950783983311ull, 367341984631964ull}},
{{16177650375369096972ull, 293873587705571ull}},
{{58798897397182893ull, 470197740328915ull}},
{{47039117917746314ull, 376158192263132ull}},
{{11105677738559928021ull, 300926553810505ull}},
{{17769084381695884834ull, 481482486096808ull}},
{{3147221061130976897ull, 385185988877447ull}},
{{13585823293130512487ull, 308148791101957ull}},
{{6979922010041178687ull, 493038065763132ull}},
{{16651984052258673919ull, 394430452610505ull}},
{{13321587241806939135ull, 315544362088404ull}},
{{10246493142665371647ull, 504870979341447ull}},
{{818496884648476671ull, 403896783473158ull}},
{{8033495137202601983ull, 323117426778526ull}},
{{5474894590040342527ull, 516987882845642ull}},
{{15447962116258004991ull, 413590306276513ull}},
{{1290323248780673023ull, 330872245021211ull}},
{{13132563642274807807ull, 529395592033937ull}},
{{3127353284336025599ull, 423516473627150ull}},
{{2501882627468820479ull, 338813178901720ull}},
{{4003012203950112767ull, 542101086242752ull}},
{{14270456207385821183ull, 433680868994201ull}},
{{7727016151166746623ull, 346944695195361ull}},
{{4984528212382973951ull, 555111512312578ull}},
{{11366320199390199807ull, 444089209850062ull}},
{{1714358530028339199ull, 355271367880050ull}},
{{1371486824022671359ull, 284217094304040ull}},
{{2194378918436274175ull, 454747350886464ull}},
{{5444851949490929663ull, 363797880709171ull}},
{{666532744850833407ull, 291038304567337ull}},
{{4755801206503243775ull, 465661287307739ull}},
{{7493989779944505343ull, 372529029846191ull}},
{{2305843009213693951ull, 298023223876953ull}},
{{18446744073709551615ull, 476837158203124ull}},
{{18446744073709551615ull, 381469726562499ull}},
{{18446744073709551615ull, 305175781249999ull}},
{{18446744073709551615ull, 488281249999999ull}},
{{18446744073709551615ull, 390624999999999ull}},
{{18446744073709551615ull, 312499999999999ull}},
{{18446744073709551615ull, 499999999999999ull}},
{{18446744073709551615ull, 399999999999999ull}},
{{18446744073709551615ull, 319999999999999ull}},
{{18446744073709551615ull, 511999999999999ull}},
{{18446744073709551615ull, 409599999999999ull}},
{{18446744073709551615ull, 327679999999999ull}},
{{18446744073709551615ull, 524287999999999ull}},
{{18446744073709551615ull, 419430399999999ull}},
{{18446744073709551615ull, 335544319999999ull}},
{{18446744073709551615ull, 536870911999999ull}},
{{18446744073709551615ull, 429496729599999ull}},
{{18446744073709551615ull, 343597383679999ull}},
{{18446744073709551615ull, 549755813887999ull}},
{{18446744073709551615ull, 439804651110399ull}},
{{18446744073709551615ull, 351843720888319ull}},
{{18446744073709551615ull, 281474976710655ull}},
{{11068046444225730969ull, 450359962737049ull}},
{{12543785970122495098ull, 360287970189639ull}},
{{13724377590839906402ull, 288230376151711ull}},
{{14580306515860029597ull, 461168601842738ull}},
{{596198768462292708ull, 368934881474191ull}},
{{15234354273737475459ull, 295147905179352ull}},
{{9617571579012319442ull, 472236648286964ull}},
{{11383406077951765876ull, 377789318629571ull}},
{{5417376047619502378ull, 302231454903657ull}},
{{12357150490933114128ull, 483570327845851ull}},
{{6196371578004580979ull, 386856262276681ull}},
{{1267748447661754460ull, 309485009821345ull}},
{{2028397516258807136ull, 495176015714152ull}},
{{12690764457232776679ull, 396140812571321ull}},
{{6463262751044311020ull, 316912650057057ull}},
{{14030569216412807955ull, 507060240091291ull}},
{{7535106558388336041ull, 405648192073033ull}},
{{13406782876194489479ull, 324518553658426ull}},
{{14072154972427362520ull, 519229685853482ull}},
{{3879026348458069369ull, 415383748682786ull}},
{{17860616337734096788ull, 332306998946228ull}},
{{6440893251923092922ull, 531691198313966ull}},
{{1463365786796564015ull, 425352958651173ull}},
{{8549390258921071858ull, 340282366920938ull}},
{{9989675599531804650ull, 544451787073501ull}},
{{4302391664883533397ull, 435561429658801ull}},
{{18199308590874468010ull, 348449143727040ull}},
{{10672149671689597200ull, 557518629963265ull}},
{{8537719737351677760ull, 446014903970612ull}},
{{17898222234107073178ull, 356811923176489ull}},
{{18007926602027568865ull, 285449538541191ull}},
{{2987240860050737922ull, 456719261665907ull}},
{{13457839132266321307ull, 365375409332725ull}},
{{10766271305813057046ull, 292300327466180ull}},
{{17226034089300891273ull, 467680523945888ull}},
{{2712780827214982049ull, 374144419156711ull}},
{{16927619920739626932ull, 299315535325368ull}},
{{4948098984731941152ull, 478904856520590ull}},
{{3958479187785552922ull, 383123885216472ull}},
{{14234829794454173307ull, 306499108173177ull}},
{{8018332412159035998ull, 490398573077084ull}},
{{10104014744469139122ull, 392318858461667ull}},
{{704514166091490651ull, 313855086769334ull}},
{{8505920295230205688ull, 502168138830934ull}},
{{10494085050926074874ull, 401734511064747ull}},
{{1016570411257039252ull, 321387608851798ull}},
{{16383907916978904097ull, 514220174162876ull}},
{{9417777518841212954ull, 411376139330301ull}},
{{3844873200331060040ull, 329100911464241ull}},
{{17219843564755427034ull, 526561458342785ull}},
{{13775874851804341627ull, 421249166674228ull}},
{{18399397510927293948ull, 336999333339382ull}},
{{14681640758516029024ull, 539198933343012ull}},
{{4366614977329002573ull, 431359146674410ull}},
{{3493291981863202058ull, 345087317339528ull}},
{{1899918356239212970ull, 552139707743245ull}},
{{1519934684991370376ull, 441711766194596ull}},
{{15973343006960737594ull, 353369412955676ull}},
{{9089325590826679752ull, 282695530364541ull}},
{{7164223315838866956ull, 452312848583266ull}},
{{2042029837929183242ull, 361850278866613ull}},
{{9012321499827167240ull, 289480223093290ull}},
{{14419714399723467584ull, 463168356949264ull}},
{{15225120334520684390ull, 370534685559411ull}},
{{8490747452874637189ull, 296427748447529ull}},
{{2517149480373688533ull, 474284397516047ull}},
{{13081766028524681796ull, 379427518012837ull}},
{{3086715193335924790ull, 303542014410270ull}},
{{4938744309337479665ull, 485667223056432ull}},
{{15019041891695714701ull, 388533778445145ull}},
{{12015233513356571761ull, 310827022756116ull}},
{{11845675991886694171ull, 497323236409786ull}},
{{5787191978767445014ull, 397858589127829ull}},
{{8319102397755866334ull, 318286871302263ull}},
{{9621215021667475812ull, 509258994083621ull}},
{{4007623202592070326ull, 407407195266897ull}},
{{14274145006299387230ull, 325925756213517ull}},
{{8081236751111378276ull, 521481209941628ull}},
{{13843687030372923267ull, 417184967953302ull}},
{{3696251994814517967ull, 333747974362642ull}},
{{9603352006445139071ull, 533996758980227ull}},
{{303983975672290610ull, 427197407184182ull}},
{{11311233624763563458ull, 341757925747345ull}},
{{18097973799621701533ull, 546812681195752ull}},
{{7099681410213540580ull, 437450144956602ull}},
{{16747791572396563433ull, 349960115965281ull}},
{{971024812641129231ull, 559936185544451ull}},
{{15534215109080544677ull, 447948948435560ull}},
{{12427372087264435742ull, 358359158748448ull}},
{{17320595299295369240ull, 286687326998758ull}},
{{5576859590421128845ull, 458699723198014ull}},
{{8150836487078813399ull, 366959778558411ull}},
{{2831320374921140396ull, 293567822846729ull}},
{{11908810229357645280ull, 469708516554766ull}},
{{5837699368744205901ull, 375766813243813ull}},
{{12048857124479185367ull, 300613450595050ull}},
{{831427325457144971ull, 480981520952081ull}},
{{15422537119333357270ull, 384785216761664ull}},
{{16027378510208596139ull, 307828173409331ull}},
{{18265107986849933176ull, 492525077454930ull}},
{{14612086389479946541ull, 394020061963944ull}},
{{15379017926325867556ull, 315216049571155ull}},
{{6159684608411836474ull, 504345679313849ull}},
{{8617096501471379502ull, 403476543451079ull}},
{{10583026015919013925ull, 322781234760863ull}},
{{13243492810728511957ull, 516449975617381ull}},
{{6905445433840899242ull, 413159980493905ull}},
{{5524356347072719393ull, 330527984395124ull}},
{{16217667784800171676ull, 528844775032198ull}},
{{1906087783614406371ull, 423075820025759ull}},
{{5214219041633435420ull, 338460656020607ull}},
{{12032099281355406996ull, 541537049632971ull}},
{{5936330610342415273ull, 433229639706377ull}},
{{15817110932499663188ull, 346583711765101ull}},
{{17928679862515640455ull, 554533938824162ull}},
{{6964246260528691717ull, 443627151059330ull}},
{{5571397008422953374ull, 354901720847464ull}},
{{8146466421480273022ull, 283921376677971ull}},
{{5655648644884616189ull, 454274202684754ull}},
{{8213867730649603275ull, 363419362147803ull}},
{{13949791814003503266ull, 290735489718242ull}},
{{7562271643437963933ull, 465176783549188ull}},
{{13428514944234191793ull, 372141426839350ull}},
{{10742811955387353434ull, 297713141471480ull}},
{{17188499128619765495ull, 476341026354368ull}},
{{2682752858670081426ull, 381072821083495ull}},
{{2146202286936065141ull, 304858256866796ull}},
{{14501970103323435195ull, 487773210986873ull}},
{{533529638433017186ull, 390218568789499ull}},
{{4116172525488324072ull, 312174855031599ull}},
{{13964573670265139162ull, 499479768050558ull}},
{{103612491986380360ull, 399583814440447ull}},
{{11150936437814835258ull, 319667051552357ull}},
{{3084103041536095120ull, 511467282483772ull}},
{{13535328877454607065ull, 409173825987017ull}},
{{3449565472479865006ull, 327339060789614ull}},
{{12898002385451604656ull, 523742497263382ull}},
{{2939704278877463078ull, 418993997810706ull}},
{{17109158682069611755ull, 335195198248564ull}},
{{16306607447085647839ull, 536312317197703ull}},
{{1977239513442787302ull, 429049853758163ull}},
{{8960489240238050488ull, 343239883006530ull}},
{{14336782784380880780ull, 549183812810448ull}},
{{401379783278973655ull, 439347050248359ull}},
{{4010452641365089247ull, 351477640198687ull}},
{{10106073040926053118ull, 562364224317899ull}},
{{11774207247482752818ull, 449891379454319ull}},
{{13108714612728112577ull, 359913103563455ull}},
{{10486971690182490062ull, 287930482850764ull}},
{{5711108260066253130ull, 460688772561223ull}},
{{11947584237536823150ull, 368551018048978ull}},
{{16936765019513279166ull, 294840814439182ull}},
{{12341428772253605373ull, 471745303102692ull}},
{{2494445388319063652ull, 377396242482154ull}},
{{5684905125397161245ull, 301916993985723ull}},
{{5406499385893547669ull, 483067190377157ull}},
{{15393245952940569105ull, 386453752301725ull}},
{{12314596762352455284ull, 309163001841380ull}},
{{1256610746054376838ull, 494660802946209ull}},
{{4694637411585411794ull, 395728642356967ull}},
{{14823756373494060404ull, 316582913885573ull}},
{{1581917309139034708ull, 506532662216918ull}},
{{8644231476795048413ull, 405226129773534ull}},
{{10604733996177949053ull, 324180903818827ull}},
{{2210179134917077193ull, 518689446110124ull}},
{{5457492122675572077ull, 414951556888099ull}},
{{8055342512882367985ull, 331961245510479ull}},
{{1820501576386057807ull, 531137992816767ull}},
{{12524447705334577215ull, 424910394253413ull}},
{{17398255793751482418ull, 339928315402730ull}},
{{9390465196292820253ull, 543885304644369ull}},
{{11201720971776166526ull, 435108243715495ull}},
{{8961376777420933221ull, 348086594972396ull}},
{{6959505214389672507ull, 556938551955834ull}},
{{9256952986253648329ull, 445550841564667ull}},
{{26864759519098016ull, 356440673251734ull}},
{{3710840622357188736ull, 285152538601387ull}},
{{9626693810513412301ull, 456244061762219ull}},
{{11390703863152640164ull, 364995249409775ull}},
{{9112563090522112131ull, 291996199527820ull}},
{{14580100944835379410ull, 467193919244512ull}},
{{4285383126384482882ull, 373755135395610ull}},
{{3428306501107586305ull, 299004108316488ull}},
{{1795941587030227766ull, 478406573306381ull}},
{{16194148528591823505ull, 382725258645104ull}},
{{16644667637615369127ull, 306180206916083ull}},
{{4495375331733128665ull, 489888331065734ull}},
{{7285649080128413255ull, 391910664852587ull}},
{{16896565708328461573ull, 313528531882069ull}},
{{15966458689099807548ull, 501645651011311ull}},
{{9083818136537935715ull, 401316520809049ull}},
{{10956403323972258895ull, 321053216647239ull}},
{{6462198874129883263ull, 513685146635583ull}},
{{12548456728787727257ull, 410948117308466ull}},
{{6349416568288271482ull, 328758493846773ull}},
{{6469717694519324048ull, 526013590154837ull}},
{{16243820599841190208ull, 420810872123869ull}},
{{16684405294614862490ull, 336648697699095ull}},
{{8248304397674228368ull, 538637916318553ull}},
{{13977341147623203341ull, 430910333054842ull}},
{{3803175288614742026ull, 344728266443874ull}},
{{13463778091267407888ull, 551565226310198ull}},
{{18149720102497746957ull, 441252181048158ull}},
{{3451729637772466596ull, 353001744838527ull}},
{{13829430154443704246ull, 282401395870821ull}},
{{14748390617626106148ull, 451842233393314ull}},
{{15488061308842795241ull, 361473786714651ull}},
{{8701100232332325870ull, 289179029371721ull}},
{{6543062742247900745ull, 462686446994754ull}},
{{8923799008540230919ull, 370149157595803ull}},
{{14517736836316005382ull, 296119326076642ull}},
{{8470983679137967319ull, 473790921722628ull}},
{{14155484572794194501ull, 379032737378102ull}},
{{3945690028751534954ull, 303226189902482ull}},
{{10002452860744366251ull, 485161903843971ull}},
{{4312613473853582677ull, 388129523075177ull}},
{{14518137223308597111ull, 310503618460141ull}},
{{15850321927809934732ull, 496805789536226ull}},
{{8990908727506037462ull, 397444631628981ull}},
{{3503378167262919646ull, 317955705303185ull}},
{{5605405067620671435ull, 508729128485096ull}},
{{794975239354626824ull, 406983302788077ull}},
{{11704026635709432429ull, 325586642230461ull}},
{{11347744987651271240ull, 520938627568738ull}},
{{16456893619604837639ull, 416750902054990ull}},
{{13165514895683870111ull, 333400721643992ull}},
{{6307428574126550885ull, 533441154630388ull}},
{{12424640488785061354ull, 426752923704310ull}},
{{9939712391028049083ull, 341402338963448ull}},
{{12214191010902968210ull, 546243742341517ull}},
{{2392655179238553922ull, 436994993873214ull}},
{{5603472958132753460ull, 349595995098571ull}},
{{1586859103528584890ull, 559353592157714ull}},
{{4958836097564778235ull, 447482873726171ull}},
{{277720063309912265ull, 357986298980937ull}},
{{11290222494873660782ull, 286389039184749ull}},
{{6996309547572126281ull, 458222462695599ull}},
{{9286396452799611348ull, 366577970156479ull}},
{{11118465976981599402ull, 293262376125183ull}},
{{14100196748428648720ull, 469219801800293ull}},
{{212110954517188006ull, 375375841440235ull}},
{{169688763613750405ull, 300300673152188ull}},
{{15028897280749641941ull, 480481077043500ull}},
{{12023117824599713552ull, 384384861634800ull}},
{{9618494259679770842ull, 307507889307840ull}},
{{15389590815487633347ull, 492012622892544ull}},
{{16001021467132017001ull, 393610098314035ull}},
{{12800817173705613601ull, 314888078651228ull}},
{{16791958663187071438ull, 503820925841965ull}},
{{13433566930549657150ull, 403056740673572ull}},
{{3368155914955905074ull, 322445392538858ull}},
{{1699700649187537795ull, 515912628062173ull}},
{{8738458148833850882ull, 412730102449738ull}},
{{14369464148550901352ull, 330184081959790ull}},
{{4544398563971890548ull, 528294531135665ull}},
{{3635518851177512438ull, 422635624908532ull}},
{{13976461525167740920ull, 338108499926825ull}},
{{3915594366558833856ull, 540973599882921ull}},
{{17889870752214708378ull, 432778879906336ull}},
{{10622547787029856379ull, 346223103925069ull}},
{{5928030015022039237ull, 553956966280111ull}},
{{1053075197275721066ull, 443165573024089ull}},
{{4531808972562487176ull, 354532458419271ull}},
{{18382842437017631034ull, 283625966735416ull}},
{{3587106196034837392ull, 453801546776667ull}},
{{13937731401053600883ull, 363041237421333ull}},
{{82138676617149737ull, 290432989937067ull}},
{{3820770697329349902ull, 464692783899307ull}},
{{14124663002089210891ull, 371754227119445ull}},
{{11299730401671368713ull, 297403381695556ull}},
{{10700871013190369294ull, 475845410712890ull}},
{{8560696810552295435ull, 380676328570312ull}},
{{17916603892667567318ull, 304541062856249ull}},
{{17598519784042376739ull, 487265700569999ull}},
{{17768164641975811714ull, 389812560455999ull}},
{{17903880528322559695ull, 311850048364799ull}},
{{17578162401090364542ull, 498960077383679ull}},
{{17751878735614201957ull, 399168061906943ull}},
{{3133456544265630596ull, 319334449525555ull}},
{{5013530470825008953ull, 510935119240888ull}},
{{11389522006143827809ull, 408748095392710ull}},
{{9111617604915062247ull, 326998476314168ull}},
{{10889239353122189273ull, 523197562102669ull}},
{{12400740297239661741ull, 418558049682135ull}},
{{9920592237791729393ull, 334846439745708ull}},
{{12183598765724856706ull, 535754303593133ull}},
{{17125576642063706011ull, 428603442874506ull}},
{{10011112498909054485ull, 342882754299605ull}},
{{16017779998254487177ull, 548612406879368ull}},
{{1746177554377858772ull, 438889925503495ull}},
{{1396942043502287017ull, 351111940402796ull}},
{{13303153713829390198ull, 561779104644473ull}},
{{18021220600547332804ull, 449423283715578ull}},
{{3348930036212135274ull, 359538626972463ull}},
{{10057841658453528865ull, 287630901577970ull}},
{{16092546653525646185ull, 460209442524752ull}},
{{5495339693336696301ull, 368167554019802ull}},
{{15464318198895088011ull, 294534043215841ull}},
{{17364211488748320171ull, 471254469145346ull}},
{{10202020376256745813ull, 377003575316277ull}},
{{782918671521576004ull, 301602860253022ull}},
{{4942018689176431930ull, 482564576404835ull}},
{{3953614951341145544ull, 386051661123868ull}},
{{10541589590556737082ull, 308841328899094ull}},
{{5798496900665048361ull, 494146126238551ull}},
{{949448705790128366ull, 395316900990841ull}},
{{15516954223599743985ull, 316253520792672ull}},
{{10069731498791949084ull, 506005633268276ull}},
{{4366436384291648944ull, 404804506614621ull}},
{{18250544366400960448ull, 323843605291696ull}},
{{3375429283048164454ull, 518149768466715ull}},
{{2700343426438531563ull, 414519814773372ull}},
{{13228321185376556220ull, 331615851818697ull}},
{{6407918637634848660ull, 530585362909916ull}},
{{1436986095365968605ull, 424468290327933ull}},
{{8528286505776595530ull, 339574632262346ull}},
{{6266560779758732202ull, 543319411619754ull}},
{{8702597438548896085ull, 434655529295803ull}},
{{14340775580322937514ull, 347724423436642ull}},
{{8187845669549058730ull, 556359077498628ull}},
{{13928974165123067630ull, 445087261998902ull}},
{{3764481702614633458ull, 356069809599122ull}},
{{14079631806317437736ull, 284855847679297ull}},
{{7770015631140259084ull, 455769356286876ull}},
{{2526663690170296944ull, 364615485029501ull}},
{{16778726211103878848ull, 291692388023600ull}},
{{8399217864056654541ull, 466707820837761ull}},
{{3030025476503413310ull, 373366256670209ull}},
{{6113369195944640971ull, 298693005336167ull}},
{{13470739528253335877ull, 477908808537867ull}},
{{3397893993118848055ull, 382327046830294ull}},
{{6407664009236988767ull, 305861637464235ull}},
{{10252262414779182028ull, 489378619942776ull}},
{{4512461117081435299ull, 391502895954221ull}},
{{18367364152632789532ull, 313202316763376ull}},
{{3562340941019090989ull, 501123706821403ull}},
{{10228570382299093437ull, 400898965457122ull}},
{{804158676355454103ull, 320719172365698ull}},
{{16044049141136367858ull, 513150675785116ull}},
{{9145890498167183963ull, 410520540628093ull}},
{{14695410028017567817ull, 328416432502474ull}},
{{12444609600602377538ull, 525466292003959ull}},
{{13645036495223812353ull, 420373033603167ull}},
{{3537331566695229236ull, 336298426882534ull}},
{{13038428136196187425ull, 538077483012054ull}},
{{14120091323698860263ull, 430461986409643ull}},
{{228026614733357241ull, 344369589127715ull}},
{{364842583573371585ull, 550991342604344ull}},
{{3981222881600607591ull, 440793074083475ull}},
{{3184978305280486073ull, 352634459266780ull}},
{{2547982644224388858ull, 282107567413424ull}},
{{11455469860242842820ull, 451372107861478ull}},
{{16543073517678094902ull, 361097686289182ull}},
{{5855761184658655275ull, 288878149031346ull}},
{{1990520265970027794ull, 462205038450154ull}},
{{5281765027517932559ull, 369764030760123ull}},
{{11604109651498166693ull, 295811224608098ull}},
{{14877226627655156386ull, 473297959372957ull}},
{{4523083672640304462ull, 378638367498366ull}},
{{18375862197079884863ull, 302910693998692ull}},
{{14643984256360174488ull, 484657110397908ull}},
{{647140960862408621ull, 387725688318327ull}},
{{11585759212915657866ull, 310180550654661ull}},
{{11158517111181231939ull, 496288881047458ull}},
{{16305511318428806198ull, 397031104837966ull}},
{{9355060240001134635ull, 317624883870373ull}},
{{11278747569259905093ull, 508199814192597ull}},
{{1644300425924103428ull, 406559851354078ull}},
{{8694137970223103389ull, 325247881083262ull}},
{{17599969567098875745ull, 520396609733219ull}},
{{17769324468421010919ull, 416317287786575ull}},
{{14215459574736808735ull, 333053830229260ull}},
{{4297991245869342361ull, 532886128366817ull}},
{{14506439440921204858ull, 426308902693453ull}},
{{537105108511232917ull, 341047122154763ull}},
{{15616763432585613960ull, 545675395447620ull}},
{{12493410746068491168ull, 436540316358096ull}},
{{6305379782112882611ull, 349232253086477ull}},
{{13777956466122522501ull, 558771604938363ull}},
{{18401062802381838647ull, 447017283950690ull}},
{{14720850241905470918ull, 357613827160552ull}},
{{4397982564040556088ull, 286091061728442ull}},
{{10726120917206800064ull, 457745698765507ull}},
{{1202199104281619405ull, 366196559012406ull}},
{{15719154542392936816ull, 292957247209924ull}},
{{14082600823602967937ull, 468731595535879ull}},
{{14955429473624284673ull, 374985276428703ull}},
{{896297134673696768ull, 299988221142963ull}},
{{16191470674445556122ull, 479981153828740ull}},
{{12953176539556444898ull, 383984923062992ull}},
{{2983843602161335272ull, 307187938450394ull}},
{{12152847392941957082ull, 491500701520630ull}},
{{9722277914353565665ull, 393200561216504ull}},
{{11467171146224762855ull, 314560448973203ull}},
{{14658125019217710245ull, 503296718357125ull}},
{{11726500015374168196ull, 402637374685700ull}},
{{9381200012299334557ull, 322109899748560ull}},
{{15009920019678935291ull, 515375839597696ull}},
{{8318587201001237910ull, 412300671678157ull}},
{{17722916205026721297ull, 329840537342525ull}},
{{9909921854333202460ull, 527744859748041ull}},
{{4238588668724651645ull, 422195887798433ull}},
{{10769568564463541962ull, 337756710238746ull}},
{{9852612073657846493ull, 540410736381994ull}},
{{11571438473668187518ull, 432328589105595ull}},
{{9257150778934550014ull, 345862871284476ull}},
{{7432743616811459376ull, 553380594055162ull}},
{{17014241337674898471ull, 442704475244129ull}},
{{17300741884881829100ull, 354163580195303ull}},
{{2772547063679732310ull, 283330864156243ull}},
{{746726487145661373ull, 453329382649989ull}},
{{4286730004458439422ull, 362663506119991ull}},
{{18186779262534392830ull, 290130804895992ull}},
{{14341451561087387235ull, 464209287833588ull}},
{{405114804644178819ull, 371367430266871ull}},
{{15081487102682984348ull, 297093944213496ull}},
{{16751681734808954310ull, 475350310741594ull}},
{{17090694202589073771ull, 380280248593275ull}},
{{13672555362071259017ull, 304224198874620ull}},
{{3429344505604462811ull, 486758718199393ull}},
{{10122173233967390895ull, 389406974559514ull}},
{{11787087401915823039ull, 311525579647611ull}},
{{11480642213581496217ull, 498440927436178ull}},
{{16563211400349017620ull, 398752741948942ull}},
{{5871871490795393449ull, 319002193559154ull}},
{{16773692014756450166ull, 510403509694646ull}},
{{9729604797063249809ull, 408322807755717ull}},
{{404986208166779201ull, 326658246204574ull}},
{{8026675562550667368ull, 522653193927318ull}},
{{13800038079524354541ull, 418122555141854ull}},
{{14729379278361393956ull, 334498044113483ull}},
{{1430913956926768390ull, 535196870581574ull}},
{{4834079980283325035ull, 428157496465259ull}},
{{7556612798968570351ull, 342525997172207ull}},
{{15779929293091622885ull, 548041595475531ull}},
{{8934594619731387985ull, 438433276380425ull}},
{{7147675695785110388ull, 350746621104340ull}},
{{11436281113256176621ull, 561194593766944ull}},
{{12838373705346851620ull, 448955675013555ull}},
{{10270698964277481296ull, 359164540010844ull}},
{{11905907986163895360ull, 287331632008675ull}},
{{602708704152680960ull, 459730611213881ull}},
{{15239562222289786061ull, 367784488971104ull}},
{{15880998592573739172ull, 294227591176883ull}},
{{3273504859666520736ull, 470764145883014ull}},
{{6308152702475126912ull, 376611316706411ull}},
{{1357173347238191206ull, 301289053365129ull}},
{{9550174985064926576ull, 482062485384206ull}},
{{3950791173310030938ull, 385649988307365ull}},
{{3160632938648024750ull, 308519990645892ull}},
{{8746361516578749924ull, 493631985033427ull}},
{{18065135657488730908ull, 394905588026741ull}},
{{10762759711249074403ull, 315924470421393ull}},
{{13531066723256608723ull, 505479152674229ull}},
{{14514202193347197301ull, 404383322139383ull}},
{{543315310452026871ull, 323506657711507ull}},
{{4558653311465153318ull, 517610652338411ull}},
{{18404317908139763947ull, 414088521870728ull}},
{{3655407882286080188ull, 331270817496583ull}},
{{2159303796915817977ull, 530033307994533ull}},
{{9106140667016475028ull, 424026646395626ull}},
{{3595563718871269699ull, 339221317116501ull}},
{{16820948394419762489ull, 542754107386401ull}},
{{9767409900793899668ull, 434203285909121ull}},
{{4124579105893209411ull, 347362628727297ull}},
{{10288675384171045381ull, 555780205963675ull}},
{{8230940307336836305ull, 444624164770940ull}},
{{6584752245869469044ull, 355699331816752ull}},
{{16335848240921306204ull, 284559465453401ull}},
{{311915482280717665ull, 455295144725443ull}},
{{7628230015308394778ull, 364236115780354ull}},
{{9791932826988626146ull, 291388892624283ull}},
{{11977743708439891510ull, 466222228198853ull}},
{{16960892596235733854ull, 372977782559082ull}},
{{6190016447504766437ull, 298382226047266ull}},
{{2525328686523805653ull, 477411561675626ull}},
{{16777658208186685815ull, 381929249340500ull}},
{{13422126566549348652ull, 305543399472400ull}},
{{3028658432769406228ull, 488869439155841ull}},
{{17180322005183166275ull, 391095551324672ull}},
{{6365559974662712373ull, 312876441059738ull}},
{{6495547144718429474ull, 500602305695581ull}},
{{1507088901032833256ull, 400481844556465ull}},
{{1205671120826266605ull, 320385475645172ull}},
{{5618422608063936891ull, 512616761032275ull}},
{{4494738086451149513ull, 410093408825820ull}},
{{3595790469160919610ull, 328074727060656ull}},
{{16821311194883202346ull, 524919563297049ull}},
{{17146397770648472200ull, 419935650637639ull}},
{{17406467031260688083ull, 335948520510111ull}},
{{2024905546823728671ull, 537517632816179ull}},
{{5309273252200893260ull, 430014106252943ull}},
{{11626116231244535254ull, 344011285002354ull}},
{{7533739525765525438ull, 550418056003767ull}},
{{17095038064838151320ull, 440334444803013ull}},
{{2607984007644790086ull, 352267555842411ull}},
{{16843782465083473361ull, 281814044673928ull}},
{{4813959055682095439ull, 450902471478286ull}},
{{161818429803766028ull, 360721977182629ull}},
{{3818803558584923146ull, 288577581746103ull}},
{{2420736878993966710ull, 461724130793765ull}},
{{1936589503195173368ull, 369379304635012ull}},
{{12617318046781869664ull, 295503443708009ull}},
{{9119662430625260493ull, 472805509932815ull}},
{{7295729944500208394ull, 378244407946252ull}},
{{16904630399825897685ull, 302595526357001ull}},
{{1221966936528064034ull, 484152842171203ull}},
{{8356271178706271873ull, 387322273736962ull}},
{{17753063387190748468ull, 309857818989569ull}},
{{17336854975279466580ull, 495772510383311ull}},
{{10180135165481662941ull, 396618008306649ull}},
{{11833456947127240676ull, 317294406645319ull}},
{{7865484671177854112ull, 507671050632511ull}},
{{2603038922200372966ull, 406136840506009ull}},
{{5771779952502208696ull, 324909472404807ull}},
{{12924196738745444237ull, 519855155847691ull}},
{{6650008576254445066ull, 415884124678153ull}},
{{12698704490487376699ull, 332707299742522ull}},
{{5560531925812161426ull, 532331679588036ull}},
{{759076725907818818ull, 425865343670429ull}},
{{4296610195468165377ull, 340692274936343ull}},
{{3185227498007154281ull, 545107639898149ull}},
{{6237530813147633748ull, 436086111918519ull}},
{{8679373465260017321ull, 348868889534815ull}},
{{13886997544416027714ull, 558190223255704ull}},
{{14798946850274732495ull, 446552178604563ull}},
{{771111035994055026ull, 357241742883651ull}},
{{15374284087762885313ull, 285793394306920ull}},
{{6152110466711064886ull, 457269430891073ull}},
{{12300386002852672555ull, 365815544712858ull}},
{{17219006431765958690ull, 292652435770286ull}},
{{1724968587632161642ull, 468243897232459ull}},
{{5069323684847639637ull, 374595117785967ull}},
{{15123505392103842679ull, 299676094228773ull}},
{{2061515738914686348ull, 479481750766038ull}},
{{9027910220615569724ull, 383585400612830ull}},
{{7222328176492455779ull, 306868320490264ull}},
{{487678638162198278ull, 490989312784423ull}},
{{7768840540013579269ull, 392791450227538ull}},
{{13593770061494684061ull, 314233160182030ull}},
{{3303288024681942882ull, 502773056291249ull}},
{{6331979234487464629ull, 402218445032999ull}},
{{8754932202331882026ull, 321774756026399ull}},
{{2939845079505280272ull, 514839609642239ull}},
{{6041224878346134541ull, 411871687713791ull}},
{{1143631087934997310ull, 329497350171033ull}},
{{16587204999663636988ull, 527195760273652ull}},
{{5891066370247088944ull, 421756608218922ull}},
{{15780899540423402125ull, 337405286575137ull}},
{{10492044005709802107ull, 539848458520220ull}},
{{8393635204567841686ull, 431878766816176ull}},
{{3025559348912363025ull, 345503013452941ull}},
{{15908941402485511810ull, 552804821524705ull}},
{{12727153121988409448ull, 442243857219764ull}},
{{13871071312332637882ull, 353795085775811ull}},
{{7407508235124199982ull, 283036068620649ull}},
{{783966731972989002ull, 452857709793039ull}},
{{4316522200320301525ull, 362286167834431ull}},
{{18210613019223882512ull, 289828934267544ull}},
{{18068934386532481051ull, 463726294828071ull}},
{{10765798694484074517ull, 370981035862457ull}},
{{1233941326103438967ull, 296784828689966ull}},
{{13042352565991233317ull, 474855725903945ull}},
{{10433882052792986654ull, 379884580723156ull}},
{{4657756827492479000ull, 303907664578525ull}},
{{7452410923987966400ull, 486252263325640ull}},
{{5961928739190373120ull, 389001810660512ull}},
{{15837589435578029465ull, 311201448528409ull}},
{{14272096652699116175ull, 497922317645455ull}},
{{11417677322159292940ull, 398337854116364ull}},
{{12823490672469344675ull, 318670283293091ull}},
{{13138887446467130834ull, 509872453268946ull}},
{{6821761142431794344ull, 407897962615157ull}},
{{16525455358171166445ull, 326318370092125ull}},
{{7993984499364314696ull, 522109392147401ull}},
{{2705838784749541434ull, 417687513717921ull}},
{{16922066286767274440ull, 334150010974336ull}},
{{1249864355634266841ull, 534640017558939ull}},
{{4689240299249323796ull, 427712014047151ull}},
{{62043424657548713ull, 342169611237721ull}},
{{11167315923677808911ull, 547471377980353ull}},
{{16312550368426067775ull, 437977102384282ull}},
{{5671342665257033574ull, 350381681907426ull}},
{{1695450634927433072ull, 560610691051882ull}},
{{12424406952167677427ull, 448488552841505ull}},
{{9939525561734141942ull, 358790842273204ull}},
{{11640969264129223876ull, 287032673818563ull}},
{{14936202007864847879ull, 459252278109701ull}},
{{8259612791549967980ull, 367401822487761ull}},
{{2918341418498064061ull, 293921457990209ull}},
{{12048043899080723144ull, 470274332784334ull}},
{{13327783934006488838ull, 376219466227467ull}},
{{3283529517721370424ull, 300975572981974ull}},
{{12632344857838013325ull, 481560916771158ull}},
{{17484573515754231307ull, 385248733416926ull}},
{{10298309997861474722ull, 308198986733541ull}},
{{9098598367094538909ull, 493118378773666ull}},
{{3589529878933720804ull, 394494703018933ull}},
{{10250321532630797289ull, 315595762415146ull}},
{{9021816822725455017ull, 504953219864234ull}},
{{10906802272922274337ull, 403962575891387ull}},
{{1346744188853998823ull, 323170060713110ull}},
{{2154790702166398117ull, 517072097140976ull}},
{{16481227820700759786ull, 413657677712780ull}},
{{13184982256560607829ull, 330926142170224ull}},
{{10027925166271241557ull, 529481827472359ull}},
{{11711688947758903569ull, 423585461977887ull}},
{{1990653528723302208ull, 338868369582310ull}},
{{3185045645957283534ull, 542189391331696ull}},
{{17305431775733468120ull, 433751513065356ull}},
{{10154996605844864172ull, 347001210452285ull}},
{{16247994569351782676ull, 555201936723656ull}},
{{9309046840739515818ull, 444161549378925ull}},
{{7447237472591612654ull, 355329239503140ull}},
{{5957789978073290123ull, 284263391602512ull}},
{{13221812779659174521ull, 454821426564019ull}},
{{14266799038469249940ull, 363857141251215ull}},
{{11413439230775399952ull, 291085713000972ull}},
{{3504107510272998630ull, 465737140801556ull}},
{{17560681267186040197ull, 372589712641244ull}},
{{17737893828490742480ull, 298071770112995ull}},
{{9933886051875636353ull, 476914832180793ull}},
{{15325806470984329729ull, 381531865744634ull}},
{{15949993991529374106ull, 305225492595707ull}},
{{10762595127479357277ull, 488360788153132ull}},
{{1231378472499665175ull, 390688630522506ull}},
{{15742498036967373433ull, 312550904418004ull}},
{{14119950414922066523ull, 500081447068807ull}},
{{3917262702453832572ull, 400065157655046ull}},
{{17891205420930707350ull, 320052126124036ull}},
{{2800486970295759499ull, 512083401798459ull}},
{{5929738390978517922ull, 409666721438767ull}},
{{15811837157008545307ull, 327733377151013ull}},
{{3162846562762210552ull, 524373403441622ull}},
{{13598323694435499411ull, 419498722753297ull}},
{{3499961326064578883ull, 335598978202638ull}},
{{1910589306961415889ull, 536958365124221ull}},
{{16285866704536774004ull, 429566692099376ull}},
{{9339344548887508880ull, 343653353679501ull}},
{{7564253648736193562ull, 549845365887202ull}},
{{17119449363214685819ull, 439876292709761ull}},
{{10006210675829838332ull, 351901034167809ull}},
{{11694317355405780989ull, 281520827334247ull}},
{{3953512509681608289ull, 450433323734796ull}},
{{17920205266712927924ull, 360346658987836ull}},
{{10646815398628432016ull, 288277327190269ull}},
{{5966858193579760256ull, 461243723504431ull}},
{{1084137740121897882ull, 368994978803545ull}},
{{867310192097518305ull, 295195983042836ull}},
{{12455742751581760258ull, 472313572868537ull}},
{{2585896571781587560ull, 377850858294830ull}},
{{2068717257425270048ull, 302280686635864ull}},
{{10688645241364252724ull, 483649098617382ull}},
{{1172218563607581532ull, 386919278893906ull}},
{{15695170109853706519ull, 309535423115124ull}},
{{14044225731540199461ull, 495256676984199ull}},
{{14924729399974069892ull, 396205341587359ull}},
{{15629132334721166236ull, 316964273269887ull}},
{{10249216476586224686ull, 507142837231820ull}},
{{8199373181268979748ull, 405714269785456ull}},
{{2870149730273273475ull, 324571415828365ull}},
{{4592239568437237561ull, 519314265325384ull}},
{{7363140469491700372ull, 415451412260307ull}},
{{16958558819819091267ull, 332361129808245ull}},
{{8686950038000994412ull, 531777807693193ull}},
{{14328257659884616176ull, 425422246154554ull}},
{{15151954942649603264ull, 340337796923643ull}},
{{2107035019787903283ull, 544540475077830ull}},
{{1685628015830322626ull, 435632380062264ull}},
{{5037851227406168424ull, 348505904049811ull}},
{{681864334366048832ull, 557609446479698ull}},
{{7924189096976659712ull, 446087557183758ull}},
{{13718048907065148416ull, 356870045747006ull}},
{{7285090310910208409ull, 285496036597605ull}},
{{11656144497456333455ull, 456793658556168ull}},
{{16703613227448887411ull, 365434926844934ull}},
{{17052239396701020252ull, 292347941475947ull}},
{{12526187775753991110ull, 467756706361516ull}},
{{6331601405861282565ull, 374205365089213ull}},
{{12443978754172846698ull, 299364292071370ull}},
{{1463621932967003101ull, 478982867314193ull}},
{{8549595175857423127ull, 383186293851354ull}},
{{10529024955427848825ull, 306549035081083ull}},
{{13157091113942647797ull, 490478456129733ull}},
{{17904370520637938884ull, 392382764903786ull}},
{{10634147601768440784ull, 313906211923029ull}},
{{5946589718603774285ull, 502249939076847ull}},
{{15825318219108750397ull, 401799951261477ull}},
{{5281556945803179671ull, 321439961009182ull}},
{{12139839928026997798ull, 514303937614691ull}},
{{6022523127679687915ull, 411443150091753ull}},
{{12196716131627570978ull, 329154520073402ull}},
{{4757350551636472273ull, 526647232117444ull}},
{{7495229256051088141ull, 421317785693955ull}},
{{5996183404840870513ull, 337054228555164ull}},
{{16972591077229213467ull, 539286765688262ull}},
{{6199375232299550127ull, 431429412550610ull}},
{{4959500185839640102ull, 345143530040488ull}},
{{4245851482601513840ull, 552229648064781ull}},
{{18154076445048852365ull, 441783718451824ull}},
{{18212609970780992215ull, 353426974761459ull}},
{{18259436791366704095ull, 282741579809167ull}},
{{14457703607219085259ull, 452386527694668ull}},
{{498116441549537238ull, 361909222155735ull}},
{{398493153239629790ull, 289527377724588ull}},
{{15394984304151048957ull, 463243804359340ull}},
{{12315987443320839166ull, 370595043487472ull}},
{{2474092325172850686ull, 296476034789978ull}},
{{269198905534650775ull, 474361655663965ull}},
{{215359124427720620ull, 379489324531172ull}},
{{11240333743767907465ull, 303591459624937ull}},
{{3227138731061010652ull, 485746335399900ull}},
{{2581710984848808522ull, 388597068319920ull}},
{{2065368787879046817ull, 310877654655936ull}},
{{14372636504832205877ull, 497404247449497ull}},
{{4119411574381944055ull, 397923397959598ull}},
{{10674226888989375891ull, 318338718367678ull}},
{{13389414207641091102ull, 509341949388285ull}},
{{10711531366112872882ull, 407473559510628ull}},
{{15947922722374118952ull, 325978847608502ull}},
{{10759281096830949030ull, 521566156173604ull}},
{{12296773692206669547ull, 417252924938883ull}},
{{17216116583249156284ull, 333802339951106ull}},
{{1720344830005277792ull, 534083743921771ull}},
{{16133671122971863527ull, 427266995137416ull}},
{{9217588083635580498ull, 341813596109933ull}},
{{11058792119075018474ull, 546901753775893ull}},
{{16225731324743835425ull, 437521403020714ull}},
{{16669933874536978663ull, 350017122416571ull}},
{{846452496065793599ull, 560027395866515ull}},
{{677161996852634879ull, 448021916693212ull}},
{{11609776041707838873ull, 358417533354569ull}},
{{12977169648108181421ull, 286734026683655ull}},
{{2316727363263538659ull, 458774442693849ull}},
{{5542730705352741250ull, 367019554155079ull}},
{{8123533379024103323ull, 293615643324063ull}},
{{9308304591696654994ull, 469785029318501ull}},
{{3757294858615413672ull, 375828023454801ull}},
{{17763231145859972230ull, 300662418763840ull}},
{{9974425759666403953ull, 481059870022145ull}},
{{7979540607733123162ull, 384847896017716ull}},
{{2694283671444588206ull, 307878316814173ull}},
{{621505059569430807ull, 492605306902677ull}},
{{11565250491881275615ull, 394084245522141ull}},
{{5562851578763110169ull, 315267396417713ull}},
{{5211213711279065947ull, 504427834268341ull}},
{{479622154281342435ull, 403542267414673ull}},
{{7762395352908894594ull, 322833813931738ull}},
{{8730483749912321028ull, 516534102290781ull}},
{{3295038185187946499ull, 413227281832625ull}},
{{2636030548150357199ull, 330581825466100ull}},
{{4217648877040571519ull, 528930920745760ull}},
{{3374119101632457215ull, 423144736596608ull}},
{{10077992910789786418ull, 338515789277286ull}},
{{8746091027779837623ull, 541625262843658ull}},
{{14375570451707690745ull, 433300210274926ull}},
{{7811107546624242272ull, 346640168219941ull}},
{{5119074445114966990ull, 554624269151906ull}},
{{405910741350063268ull, 443699415321525ull}},
{{324728593080050615ull, 354959532257220ull}},
{{259782874464040492ull, 283967625805776ull}},
{{11483699043368195756ull, 454348201289241ull}},
{{5497610419952646282ull, 363478561031393ull}},
{{11776785965445937672ull, 290782848825114ull}},
{{7774811100487769306ull, 465252558120183ull}},
{{13598546509874036091ull, 372202046496146ull}},
{{7189488393157318549ull, 297761637196917ull}},
{{15192530243793620002ull, 476418619515067ull}},
{{4775326565551075355ull, 381134895612054ull}},
{{7509610067182770607ull, 304907916489643ull}},
{{8326027292750522649ull, 487852666383429ull}},
{{10350170648942328442ull, 390282133106743ull}},
{{15658834148637683400ull, 312225706485394ull}},
{{13986088193594562471ull, 499561130376631ull}},
{{7499521740133739653ull, 399648904301305ull}},
{{5999617392106991723ull, 319719123441044ull}},
{{16978085456855007403ull, 511550597505670ull}},
{{13582468365484005922ull, 409240478004536ull}},
{{7176625877645294415ull, 327392382403629ull}},
{{414554960006740094ull, 523827811845807ull}},
{{11399690412231123045ull, 419062249476645ull}},
{{9119752329784898436ull, 335249799581316ull}},
{{7212906098172016851ull, 536399679330106ull}},
{{2080976063795703157ull, 429119743464085ull}},
{{1664780851036562526ull, 343295794771268ull}},
{{17421044620626141334ull, 549273271634028ull}},
{{2868789252275182098ull, 439418617307223ull}},
{{9673729031303966325ull, 351534893845778ull}},
{{11788617635344435796ull, 562455830153245ull}},
{{9430894108275548637ull, 449964664122596ull}},
{{3855366471878528586ull, 359971731298077ull}},
{{14152339621728553839ull, 287977385038461ull}},
{{15265045765281865496ull, 460763816061538ull}},
{{1143990167999761427ull, 368611052849231ull}},
{{15672587393367450434ull, 294888842279384ull}},
{{14008093385162189725ull, 471822147647015ull}},
{{11206474708129751780ull, 377457718117612ull}},
{{1586482137019980778ull, 301966174494090ull}},
{{2538371419231969244ull, 483145879190544ull}},
{{5720045950127485719ull, 386516703352435ull}},
{{4576036760101988575ull, 309213362681948ull}},
{{3632310001421271397ull, 494741380291117ull}},
{{13973894445362748087ull, 395793104232893ull}},
{{111069112064467500ull, 316634483386315ull}},
{{177710579303148000ull, 506615173418104ull}},
{{3831517278184428723ull, 405292138734483ull}},
{{10443911452031363625ull, 324233710987586ull}},
{{9331560693766361154ull, 518773937580138ull}},
{{14843946184496909569ull, 415019150064110ull}},
{{11875156947597527655ull, 332015320051288ull}},
{{15310902301414133926ull, 531224512082061ull}},
{{8559373026389396817ull, 424979609665649ull}},
{{10536847235853427777ull, 339983687732519ull}},
{{5790909133139753474ull, 543973900372031ull}},
{{943378491769892456ull, 435179120297625ull}},
{{754702793415913964ull, 348143296238100ull}},
{{1207524469465462343ull, 557029273980960ull}},
{{966019575572369875ull, 445623419184768ull}},
{{8151513289941716546ull, 356498735347814ull}},
{{10210559446695283560ull, 285198988278251ull}},
{{8958197485228633050ull, 456318381245202ull}},
{{18234604432408637409ull, 365054704996161ull}},
{{10898334731184999604ull, 292043763996929ull}},
{{6369289125670268397ull, 467270022395087ull}},
{{16163477744761945687ull, 373816017916069ull}},
{{16620131010551466873ull, 299052814332855ull}},
{{8145465543172795381ull, 478484502932569ull}},
{{10205721249280146628ull, 382787602346055ull}},
{{8164576999424117302ull, 306230081876844ull}},
{{1995276754852856714ull, 489968131002951ull}},
{{16353616662849926664ull, 391974504802360ull}},
{{13082893330279941331ull, 313579603841888ull}},
{{17243280513705995807ull, 501727366147021ull}},
{{10105275596222886322ull, 401381892917617ull}},
{{705522847494488411ull, 321105514334094ull}},
{{8507534185475002105ull, 513768822934550ull}},
{{6806027348380001684ull, 411015058347640ull}},
{{5444821878704001347ull, 328812046678112ull}},
{{12401063820668312478ull, 526099274684979ull}},
{{13610199871276560306ull, 420879419747983ull}},
{{18266857526505068891ull, 336703535798386ull}},
{{3401530339214737964ull, 538725657277419ull}},
{{6410573086113700694ull, 430980525821935ull}},
{{5128458468890960555ull, 344784420657548ull}},
{{4516184735483626565ull, 551655073052077ull}},
{{14680994232612632222ull, 441324058441661ull}},
{{8055446571348195454ull, 353059246753329ull}},
{{10133706071820466686ull, 282447397402663ull}},
{{12524580900170836375ull, 451915835844261ull}},
{{6330315905394758777ull, 361532668675409ull}},
{{8753601539057717345ull, 289226134940327ull}},
{{17695111277234258075ull, 462761815904523ull}},
{{3088042577561675490ull, 370209452723619ull}},
{{6159782876791250715ull, 296167562178895ull}},
{{9855652602866001145ull, 473868099486232ull}},
{{505824452808980269ull, 379094479588986ull}},
{{15162054821214825508ull, 303275583671188ull}},
{{2123194825492258874ull, 485240933873902ull}},
{{12766602304619538069ull, 388192747099121ull}},
{{6523933028953720132ull, 310554197679297ull}},
{{14127641661067862534ull, 496886716286875ull}},
{{11302113328854290027ull, 397509373029500ull}},
{{9041690663083432022ull, 318007498423600ull}},
{{14466705060933491235ull, 508811997477760ull}},
{{11573364048746792988ull, 407049597982208ull}},
{{16637388868481255037ull, 325639678385766ull}},
{{794380486376635797ull, 521023485417227ull}},
{{11703550833327039607ull, 416818788333781ull}},
{{5673491851919721362ull, 333455030667025ull}},
{{9077586963071554180ull, 533528049067240ull}},
{{7262069570457243344ull, 426822439253792ull}},
{{16877702100591525644ull, 341457951403033ull}},
{{4868230472494979092ull, 546332722244854ull}},
{{7583933192737893597ull, 437066177795883ull}},
{{13445844183674135524ull, 349652942236706ull}},
{{14134653064394796192ull, 559444707578730ull}},
{{11307722451515836953ull, 447555766062984ull}},
{{12735526775954579886ull, 358044612850387ull}},
{{2809723791279843262ull, 286435690280310ull}},
{{4495558066047749220ull, 458297104448496ull}},
{{18353841711805840668ull, 366637683558796ull}},
{{10993724554702762211ull, 293310146847037ull}},
{{2832564028556778246ull, 469296234955260ull}},
{{2266051222845422597ull, 375436987964208ull}},
{{9191538607760158724ull, 300349590371366ull}},
{{7327764142932433312ull, 480559344594186ull}},
{{2172862499604036326ull, 384447475675349ull}},
{{5427638814425139384ull, 307557980540279ull}},
{{16062919732564043661ull, 492092768864446ull}},
{{9160986971309324605ull, 393674215091557ull}},
{{18396836021273190654ull, 314939372073245ull}},
{{10988193560327553430ull, 503902995317193ull}},
{{16169252477745863391ull, 403122396253754ull}},
{{16624750796938601036ull, 322497917003003ull}},
{{4463508386650299718ull, 515996667204806ull}},
{{18328201968287881067ull, 412797333763844ull}},
{{18351910389372215177ull, 330237867011075ull}},
{{10916312549285992667ull, 528380587217721ull}},
{{5043701224686883811ull, 422704469774177ull}},
{{15103007423975238018ull, 338163575819341ull}},
{{16786114248876560183ull, 541061721310946ull}},
{{9739542584359337823ull, 432849377048757ull}},
{{412936438003649612ull, 346279501639006ull}},
{{11728744745031570349ull, 554047202622409ull}},
{{13072344610767166602ull, 443237762097927ull}},
{{3079178059129912635ull, 354590209678342ull}},
{{13531388891529661078ull, 283672167742673ull}},
{{17960873411705547401ull, 453875468388277ull}},
{{6990001099880617274ull, 363100374710622ull}},
{{16660047324130224789ull, 290480299768497ull}},
{{11898680459640718370ull, 464768479629596ull}},
{{5829595552970664373ull, 371814783703677ull}},
{{15731722886602262468ull, 297451826962941ull}},
{{17792058989079799302ull, 475922923140706ull}},
{{10544298376521929118ull, 380738338512565ull}},
{{8435438701217543295ull, 304590670810052ull}},
{{17186050736689979595ull, 487345073296083ull}},
{{2680794145126252706ull, 389876058636867ull}},
{{13212681760326733135ull, 311900846909493ull}},
{{17450942001780862692ull, 499041355055189ull}},
{{17650102416166600477ull, 399233084044151ull}},
{{10430733118191370058ull, 319386467235321ull}},
{{9310475359622371447ull, 511018347576514ull}},
{{11137729102439807481ull, 408814678061211ull}},
{{5220834467209935661ull, 327051742448969ull}},
{{15732032777019717705ull, 523282787918350ull}},
{{12585626221615774164ull, 418626230334680ull}},
{{10068500977292619331ull, 334900984267744ull}},
{{5041555119442459960ull, 535841574828391ull}},
{{343895280812057645ull, 428673259862713ull}},
{{7653813854133466762ull, 342938607890170ull}},
{{12246102166613546820ull, 548701772624272ull}},
{{2418184103807016809ull, 438961418099418ull}},
{{9313244912529434094ull, 351169134479534ull}},
{{3833145415821363581ull, 561870615167255ull}},
{{3066516332657090864ull, 449496492133804ull}},
{{6142561880867583015ull, 359597193707043ull}},
{{12292747134177887058ull, 287677754965634ull}},
{{8600348970458888324ull, 460284407945015ull}},
{{6880279176367110659ull, 368227526356012ull}},
{{16572269785319419497ull, 294582021084809ull}},
{{15447585212285340225ull, 471331233735695ull}},
{{12358068169828272180ull, 377064986988556ull}},
{{6197105721120707421ull, 301651989590845ull}},
{{9915369153793131873ull, 482643183345352ull}},
{{553597693550684852ull, 386114546676282ull}},
{{11510924599066278851ull, 308891637341025ull}},
{{18417479358506046162ull, 494226619745640ull}},
{{14733983486804836930ull, 395381295796512ull}},
{{4408489159960048897ull, 316305036637210ull}},
{{7053582655936078236ull, 506088058619536ull}},
{{1953517310006952266ull, 404870446895629ull}},
{{5252162662747472136ull, 323896357516503ull}},
{{4714111445654045094ull, 518234172026405ull}},
{{3771289156523236075ull, 414587337621124ull}},
{{6706380139960499183ull, 331669870096899ull}},
{{18108905853420619340ull, 530671792155038ull}},
{{3419078238510764502ull, 424537433724031ull}},
{{17492657849776252894ull, 339629946979224ull}},
{{16920206115416273662ull, 543407915166759ull}},
{{17225513707074929252ull, 434726332133407ull}},
{{6401713336176122755ull, 347781065706726ull}},
{{2864043708397975763ull, 556449705130762ull}},
{{13359281410944111580ull, 445159764104609ull}},
{{14376773943497199587ull, 356127811283687ull}},
{{4122721525313939023ull, 284902249026950ull}},
{{6596354440502302437ull, 455843598443120ull}},
{{5277083552401841949ull, 364674878754496ull}},
{{532318027179563236ull, 291739903003597ull}},
{{4541057658229211502ull, 466783844805755ull}},
{{3632846126583369201ull, 373427075844604ull}},
{{6595625716008605684ull, 298741660675683ull}},
{{6863652330871858772ull, 477986657081093ull}},
{{12869619494181307664ull, 382389325664874ull}},
{{13985044410086956454ull, 305911460531899ull}},
{{11308024611913399357ull, 489458336851039ull}},
{{12735768504272629809ull, 391566669480831ull}},
{{6499265988676193524ull, 313253335584665ull}},
{{10398825581881909638ull, 501205336935464ull}},
{{12008409280247438034ull, 400964269548371ull}},
{{5917378609456040104ull, 320771415638697ull}},
{{13157154589871574489ull, 513234265021915ull}},
{{10525723671897259591ull, 410587412017532ull}},
{{1041881308033987027ull, 328469929614026ull}},
{{12735056537080110212ull, 525551887382441ull}},
{{6498696414922177847ull, 420441509905953ull}},
{{12577654761421562924ull, 336353207924762ull}},
{{5366852359306859385ull, 538165132679620ull}},
{{4293481887445487508ull, 430532106143696ull}},
{{18192180768924031299ull, 344425684914956ull}},
{{3282047527085077817ull, 551081095863931ull}},
{{17383033280635703546ull, 440864876691144ull}},
{{17595775439250473160ull, 352691901352915ull}},
{{14076620351400378528ull, 282153521082332ull}},
{{7765197303272964352ull, 451445633731732ull}},
{{17280204286844102451ull, 361156506985385ull}},
{{13824163429475281961ull, 288925205588308ull}},
{{18429312672418540814ull, 462280328941293ull}},
{{3675403693709101682ull, 369824263153035ull}},
{{2940322954967281345ull, 295859410522428ull}},
{{1015167913205739830ull, 473375056835885ull}},
{{812134330564591864ull, 378700045468708ull}},
{{8028405093935494137ull, 302960036374966ull}},
{{5466750520812969973ull, 484736058199946ull}},
{{684051601908465655ull, 387788846559957ull}},
{{11615287725752503494ull, 310231077247965ull}},
{{137716287494453974ull, 496369723596745ull}},
{{110173029995563179ull, 397095778877396ull}},
{{14845533682964091836ull, 317676623101916ull}},
{{16374156263258726292ull, 508282596963066ull}},
{{9409976195865070710ull, 406626077570453ull}},
{{14906678586175877214ull, 325300862056362ull}},
{{9093290478913762251ull, 520481379290180ull}},
{{7274632383131009800ull, 416385103432144ull}},
{{9509054721246718163ull, 333108082745715ull}},
{{15214487553994749062ull, 532972932393144ull}},
{{15860938857937709572ull, 426378345914515ull}},
{{12688751086350167658ull, 341102676731612ull}},
{{5544606479192626960ull, 545764282770580ull}},
{{4435685183354101568ull, 436611426216464ull}},
{{7237896961425191577ull, 349289140973171ull}},
{{4201937508796485878ull, 558862625557074ull}},
{{7050898821779099025ull, 447090100445659ull}},
{{9330067872165189543ull, 357672080356527ull}},
{{85356668248330988ull, 286137664285222ull}},
{{3825919483939239905ull, 457820262856355ull}},
{{3060735587151391924ull, 366256210285084ull}},
{{6137937284463023862ull, 293004968228067ull}},
{{13510048469882748503ull, 468807949164907ull}},
{{3429341146422378156ull, 375046359331926ull}},
{{17500868176105543817ull, 300037087465540ull}},
{{9554645008059318492ull, 480059339944865ull}},
{{7643716006447454793ull, 384047471955892ull}},
{{17183019249383694804ull, 307237977564713ull}},
{{5356737910562449748ull, 491580764103542ull}},
{{15353436772675690768ull, 393264611282833ull}},
{{1214702973914821645ull, 314611689026267ull}},
{{5632873573005624955ull, 503378702442027ull}},
{{15574345302630230933ull, 402702961953621ull}},
{{8770127427362274423ull, 322162369562897ull}},
{{17721552698521549401ull, 515459791300635ull}},
{{14177242158817239521ull, 412367833040508ull}},
{{273747282828060647ull, 329894266432407ull}},
{{4127344467266807358ull, 527830826291851ull}},
{{18059270832781087179ull, 422264661033480ull}},
{{14447416666224869743ull, 337811728826784ull}},
{{12047820221734060620ull, 540498766122855ull}},
{{9638256177387248496ull, 432399012898284ull}},
{{11399953756651709120ull, 345919210318627ull}},
{{3482530751675093299ull, 553470736509804ull}},
{{6475373416081984963ull, 442776589207843ull}},
{{12558996362349408616ull, 354221271366274ull}},
{{13736545904621437216ull, 283377017093019ull}},
{{10910427003168568577ull, 453403227348831ull}},
{{5038992787792944538ull, 362722581879065ull}},
{{4031194230234355630ull, 290178065503252ull}},
{{10139259583116879332ull, 464284904805203ull}},
{{15490105295977324112ull, 371427923844162ull}},
{{5013386607298038643ull, 297142339075330ull}},
{{8021418571676861829ull, 475427742520528ull}},
{{13795832486825310110ull, 380342194016422ull}},
{{3657968359976427441ull, 304273755213138ull}},
{{2163400561220373583ull, 486838008341021ull}},
{{16488115707943940159ull, 389470406672816ull}},
{{9501143751613241804ull, 311576325338253ull}},
{{11512481187839276563ull, 498522120541205ull}},
{{9209984950271421251ull, 398817696432964ull}},
{{11057336774959047324ull, 319054157146371ull}},
{{10313041210450655072ull, 510486651434194ull}},
{{11939781783102434380ull, 408389321147355ull}},
{{9551825426481947504ull, 326711456917884ull}},
{{4214874238145385037ull, 522738331068615ull}},
{{3371899390516308030ull, 418190664854892ull}},
{{13765565956638777393ull, 334552531883913ull}},
{{18335556715880133507ull, 535284051014261ull}},
{{10979096557962196482ull, 428227240811409ull}},
{{12472626061111667509ull, 342581792649127ull}},
{{5198806438811026721ull, 548130868238604ull}},
{{7848393965790731700ull, 438504694590883ull}},
{{13657412802116406006ull, 350803755672706ull}},
{{14473162853902428964ull, 561286009076330ull}},
{{11578530283121943171ull, 449028807261064ull}},
{{12952173041239464860ull, 359223045808851ull}},
{{6672389618249661565ull, 287378436647081ull}},
{{3297125759715637858ull, 459805498635330ull}},
{{2637700607772510286ull, 367844398908264ull}},
{{5799509300959918552ull, 294275519126611ull}},
{{1900517252052049037ull, 470840830602578ull}},
{{8899111431125459876ull, 376672664482062ull}},
{{18187335589126098870ull, 301338131585649ull}},
{{18031690498376027223ull, 482141010537039ull}},
{{18114701213442732101ull, 385712808429631ull}},
{{10802412156012275358ull, 308570246743705ull}},
{{17283859449619640573ull, 493712394789928ull}},
{{2759041115469981489ull, 394969915831943ull}},
{{9585930521859805837ull, 315975932665554ull}},
{{4269442390749958370ull, 505561492264887ull}},
{{14483600356825697666ull, 404449193811909ull}},
{{15276229100202468456ull, 323559355049527ull}},
{{9684571301356308236ull, 517694968079244ull}},
{{11437005855826956912ull, 414155974463395ull}},
{{9149604684661565530ull, 331324779570716ull}},
{{7260669865974684201ull, 530119647313146ull}},
{{2119187078037837038ull, 424095717850517ull}},
{{12763396106656000600ull, 339276574280413ull}},
{{16732084955907690637ull, 542842518848661ull}},
{{9696319149984242186ull, 434274015078929ull}},
{{11446404134729304072ull, 347419212063143ull}},
{{14624897800824976192ull, 555870739301029ull}},
{{15389267055401891277ull, 444696591440823ull}},
{{1243367200095782052ull, 355757273152659ull}},
{{4684042574818535965ull, 284605818522127ull}},
{{11183816934451567867ull, 455369309635403ull}},
{{16325751177045074940ull, 364295447708322ull}},
{{5681903312152239305ull, 291436358166658ull}},
{{5401696484701672566ull, 466298173066653ull}},
{{11700054817245158699ull, 373038538453322ull}},
{{1981346224312306313ull, 298430830762658ull}},
{{17927549217867331393ull, 477489329220252ull}},
{{6963341744810044468ull, 381991463376202ull}},
{{16638719840073766544ull, 305593170700961ull}},
{{796510040924654208ull, 488949073121539ull}},
{{4326556847481633690ull, 391159258497231ull}},
{{18218640736952948244ull, 312927406797784ull}},
{{18081778734898986222ull, 500683850876455ull}},
{{14465422987919188977ull, 400547080701164ull}},
{{15261687205077261505ull, 320437664560931ull}},
{{17040001898639797762ull, 512700263297490ull}},
{{13632001518911838209ull, 410160210637992ull}},
{{3526903585645649921ull, 328128168510394ull}},
{{13021743366516860520ull, 525005069616630ull}},
{{10417394693213488416ull, 420004055693304ull}},
{{12023264569312701056ull, 336003244554643ull}},
{{15547874496158411367ull, 537605191287429ull}},
{{16127648411668639416ull, 430084153029943ull}},
{{1834072285109180563ull, 344067322423955ull}},
{{2934515656174688902ull, 550507715878328ull}},
{{9726310154423571768ull, 440406172702662ull}},
{{402350494055036768ull, 352324938162130ull}},
{{321880395244029414ull, 281859950529704ull}},
{{7893706261874267709ull, 450975920847526ull}},
{{2625616194757503844ull, 360780736678021ull}},
{{16857888214773644368ull, 288624589342416ull}},
{{1147179440444458727ull, 461799342947867ull}},
{{11985789996581297951ull, 369439474358293ull}},
{{16967329626748859007ull, 295551579486634ull}},
{{16079680958572443442ull, 472882527178615ull}},
{{12863744766857954753ull, 378306021742892ull}},
{{2912298184002543156ull, 302644817394314ull}},
{{12038374723887889697ull, 484231707830902ull}},
{{2252002149626491111ull, 387385366264722ull}},
{{12869648163926923858ull, 309908293011777ull}},
{{5834041803315436880ull, 495853268818844ull}},
{{8356582257394259827ull, 396682615055075ull}},
{{6685265805915407862ull, 317346092044060ull}},
{{10696425289464652579ull, 507753747270496ull}},
{{4867791416829811740ull, 406202997816397ull}},
{{14962279577689580362ull, 324962398253117ull}},
{{9182252065335687286ull, 519939837204988ull}},
{{14724499281752370475ull, 415951869763990ull}},
{{11779599425401896380ull, 332761495811192ull}},
{{4089963821675392916ull, 532418393297908ull}},
{{10650668686824134979ull, 425934714638326ull}},
{{4831186134717397660ull, 340747771710661ull}},
{{351200186064015609ull, 545196434737058ull}},
{{7659657778335033134ull, 436157147789646ull}},
{{2438377407926116184ull, 348925718231717ull}},
{{7590752667423696218ull, 558281149170747ull}},
{{17140648578164687944ull, 446624919336597ull}},
{{6333821233047929708ull, 357299935469278ull}},
{{12445754615922164413ull, 285839948375422ull}},
{{5155812126507821768ull, 457343917400676ull}},
{{435300886464347091ull, 365875133920541ull}},
{{15105635968139118966ull, 292700107136432ull}},
{{9411622290054949053ull, 468320171418292ull}},
{{150600202560138596ull, 374656137134634ull}},
{{3809828976790021200ull, 299724909707707ull}},
{{9785075177605944243ull, 479559855532331ull}},
{{4138711327342845071ull, 383647884425865ull}},
{{3310969061874276057ull, 306918307540692ull}},
{{8986899313740752014ull, 491069292065107ull}},
{{18257565895218332581ull, 392855433652085ull}},
{{14606052716174666065ull, 314284346921668ull}},
{{1233591457428003764ull, 502854955074670ull}},
{{986873165942403011ull, 402283964059736ull}},
{{15546893791721563702ull, 321827171247788ull}},
{{2738937178303039984ull, 514923473996462ull}},
{{13259196186868162957ull, 411938779197169ull}},
{{14296705764236440689ull, 329551023357735ull}},
{{4427985149068753486ull, 527281637372377ull}},
{{14610434563480733758ull, 421825309897901ull}},
{{7998998836042676683ull, 337460247918321ull}},
{{5419700508184462047ull, 539936396669314ull}},
{{8025109221289479961ull, 431949117335451ull}},
{{2730738562289673645ull, 345559293868361ull}},
{{15437228143889208802ull, 552894870189377ull}},
{{4971084885627546395ull, 442315896151502ull}},
{{15044914352727768086ull, 353852716921201ull}},
{{8346582667440304145ull, 283082173536961ull}},
{{5975834638420665987ull, 452931477659138ull}},
{{12159365340220353436ull, 362345182127310ull}},
{{9727492272176282748ull, 289876145701848ull}},
{{11874638820740142074ull, 463801833122957ull}},
{{2121013427108293013ull, 371041466498366ull}},
{{16454206000654275703ull, 296833173198692ull}},
{{11569334342079199833ull, 474933077117908ull}},
{{16634165103147180512ull, 379946461694326ull}},
{{9617983267775834087ull, 303957169355461ull}},
{{8010075598957513892ull, 486331470968738ull}},
{{13786758108649831760ull, 389065176774990ull}},
{{11029406486919865408ull, 311252141419992ull}},
{{2889655120104143360ull, 498003426271988ull}},
{{9690421725567135335ull, 398402741017590ull}},
{{7752337380453708268ull, 318722192814072ull}},
{{16093088623467843552ull, 509955508502515ull}},
{{12874470898774274841ull, 407964406802012ull}},
{{2920879089535599226ull, 326371525441610ull}},
{{4673406543256958763ull, 522194440706576ull}},
{{49376419863656687ull, 417755552565261ull}},
{{14796896394858566642ull, 334204442052208ull}},
{{1538941343322244689ull, 534727107283534ull}},
{{4920501889399706074ull, 427781685826827ull}},
{{15004447955745495829ull, 342225348661461ull}},
{{16628419099708972680ull, 547560557858338ull}},
{{2234688835541447174ull, 438048446286671ull}},
{{16545146327400799032ull, 350438757029336ull}},
{{646792420647906189ull, 560702011246939ull}},
{{4206782751260235274ull, 448561608997551ull}},
{{18122821459975829512ull, 358849287198040ull}},
{{14498257167980663610ull, 287079429758432ull}},
{{8439816209801420483ull, 459327087613492ull}},
{{17819899412066867356ull, 367461670090793ull}},
{{3187873085427762915ull, 293969336072635ull}},
{{5100596936684420664ull, 470350937716216ull}},
{{391128734605626208ull, 376280750172973ull}},
{{7691600617168321613ull, 301024600138378ull}},
{{8617212172727404258ull, 481639360221405ull}},
{{6893769738181923406ull, 385311488177124ull}},
{{9204364605287449048ull, 308249190541699ull}},
{{3658936924234187507ull, 493198704866719ull}},
{{6616498354129260329ull, 394558963893375ull}},
{{5293198683303408263ull, 315647171114700ull}},
{{8469117893285453221ull, 505035473783520ull}},
{{6775294314628362577ull, 404028379026816ull}},
{{1730886636960779738ull, 323222703221453ull}},
{{17526813878104888874ull, 517156325154324ull}},
{{17710799917225821422ull, 413725060123459ull}},
{{17857988748522567461ull, 330980048098767ull}},
{{13815386738668466645ull, 529568076958028ull}},
{{18431007020418593962ull, 423654461566422ull}},
{{7366107986851054523ull, 338923569253138ull}},
{{8096423964219776915ull, 542277710805021ull}},
{{2787790356633911208ull, 433822168644017ull}},
{{13298278729532859936ull, 347057734915213ull}},
{{17587897152510665575ull, 555292375864341ull}},
{{10380968907266622137ull, 444233900691473ull}},
{{15683472755297118356ull, 355387120553178ull}},
{{1478731760011963715ull, 284309696442543ull}},
{{17123366074986783237ull, 454895514308068ull}},
{{2630646415763695620ull, 363916411446455ull}},
{{2104517132610956496ull, 291133129157164ull}},
{{10745925041661351040ull, 465813006651462ull}},
{{1218042403845260185ull, 372650405321170ull}},
{{974433923076208148ull, 298120324256936ull}},
{{12627140721147664007ull, 476992518811097ull}},
{{2723014947434310559ull, 381594015048878ull}},
{{9557109587431269094ull, 305275212039102ull}},
{{533980080922389257ull, 488440339262564ull}},
{{4116532879479821729ull, 390752271410051ull}},
{{18050621562551498676ull, 312601817128040ull}},
{{10434250426372846266ull, 500162907404865ull}},
{{8347400341098277012ull, 400130325923892ull}},
{{17745966717104352579ull, 320104260739113ull}},
{{6257453858915502188ull, 512166817182582ull}},
{{16074009531358132720ull, 409733453746065ull}},
{{12859207625086506176ull, 327786762996852ull}},
{{5817336941170768589ull, 524458820794964ull}},
{{8343218367678525194ull, 419567056635971ull}},
{{2985225879400909832ull, 335653645308777ull}},
{{8465710221783366055ull, 537045832494043ull}},
{{14151265806910513490ull, 429636665995234ull}},
{{15010361460270321115ull, 343709332796187ull}},
{{9259183077464872492ull, 549934932473900ull}},
{{7407346461971897993ull, 439947945979120ull}},
{{5925877169577518395ull, 351958356783296ull}},
{{1051352920920104392ull, 281566685426637ull}},
{{5371513488214077351ull, 450506696682619ull}},
{{7986559605313172204ull, 360405357346095ull}},
{{6389247684250537763ull, 288324285876876ull}},
{{2844098665317039775ull, 461318857403002ull}},
{{13343325376479362790ull, 369055085922401ull}},
{{6985311486441579908ull, 295244068737921ull}},
{{3797800748822707207ull, 472390509980674ull}},
{{6727589413800076089ull, 377912407984539ull}},
{{9071420345781971194ull, 302329926387631ull}},
{{7135574923767333265ull, 483727882220210ull}},
{{5708459939013866612ull, 386982305776168ull}},
{{11945465580694913936ull, 309585844620934ull}},
{{8044698484886131328ull, 495337351393495ull}},
{{6435758787908905062ull, 396269881114796ull}},
{{1459258215585213726ull, 317015904891837ull}},
{{6024161959678252286ull, 507225447826939ull}},
{{8508678382484512152ull, 405780358261551ull}},
{{3117593891245699398ull, 324624286609241ull}},
{{16056196670218850007ull, 519398858574785ull}},
{{12844957336175080005ull, 415519086859828ull}},
{{17654663498423884651ull, 332415269487862ull}},
{{13490066338510574148ull, 531864431180580ull}},
{{10792053070808459319ull, 425491544944464ull}},
{{12322991271388677778ull, 340393235955571ull}},
{{12338088404738063799ull, 544629177528914ull}},
{{13559819538532361362ull, 435703342023131ull}},
{{7158506816083978766ull, 348562673618505ull}},
{{11453610905734366026ull, 557700277789608ull}},
{{16541586354071313467ull, 446160222231686ull}},
{{9543920268515140451ull, 356928177785349ull}},
{{11324485029554022684ull, 285542542228279ull}},
{{7051129603060705325ull, 456868067565247ull}},
{{16708950126674295229ull, 365494454052197ull}},
{{5988462471855615537ull, 292395563241758ull}},
{{5892191140227074536ull, 467832901186813ull}},
{{12092450541665480275ull, 374266320949450ull}},
{{9673960433332384220ull, 299413056759560ull}},
{{15478336693331814752ull, 479060890815296ull}},
{{8693320539923541478ull, 383248712652237ull}},
{{18022702876164564152ull, 306598970121789ull}},
{{17768278157637571674ull, 490558352194863ull}},
{{3146576081884326370ull, 392446681755891ull}},
{{17274656124475102389ull, 313957345404712ull}},
{{12882054540192522529ull, 502331752647540ull}},
{{10305643632154018023ull, 401865402118032ull}},
{{865817276239393772ull, 321492321694426ull}},
{{12453354086208761005ull, 514387714711081ull}},
{{6273334454225098481ull, 411510171768865ull}},
{{5018667563380078785ull, 329208137415092ull}},
{{11719216916150036379ull, 526733019864147ull}},
{{1996675903436208457ull, 421386415891318ull}},
{{8976038352232787412ull, 337109132713054ull}},
{{3293614919346728889ull, 539374612340887ull}},
{{13702938379703114081ull, 431499689872709ull}},
{{14651699518504401588ull, 345199751898167ull}},
{{8685323970639401248ull, 552319603037068ull}},
{{14326956805995341645ull, 441855682429654ull}},
{{15150914259538183639ull, 353484545943723ull}},
{{1052684963404815941ull, 282787636754979ull}},
{{9062993570931526153ull, 452460218807966ull}},
{{3561046042003310599ull, 361968175046373ull}},
{{10227534463086469126ull, 289574540037098ull}},
{{12674706326196440278ull, 463319264059357ull}},
{{2761067431473331576ull, 370655411247486ull}},
{{16966249204146306553ull, 296524328997988ull}},
{{5009905838182628546ull, 474438926396782ull}},
{{15075971114771833807ull, 379551141117425ull}},
{{12060776891817467045ull, 303640912893940ull}},
{{850498953198395657ull, 485825460630305ull}},
{{680399162558716525ull, 388660368504244ull}},
{{4233668144788883543ull, 310928294803395ull}},
{{6773869031662213670ull, 497485271685432ull}},
{{16487141669555501905ull, 397988217348345ull}},
{{13189713335644401524ull, 318390573878676ull}},
{{13724843707547221792ull, 509424918205882ull}},
{{3601177336553956787ull, 407539934564706ull}},
{{17638337128210806723ull, 326031947651764ull}},
{{17153292960911559787ull, 521651116242823ull}},
{{2654587924503516860ull, 417320892994259ull}},
{{5813019154344723811ull, 333856714395407ull}},
{{12990179461693468421ull, 534170743032651ull}},
{{6702794754612864414ull, 427336594426121ull}},
{{1672886988948381208ull, 341869275540897ull}},
{{6365967997059320256ull, 546990840865435ull}},
{{5092774397647456204ull, 437592672692348ull}},
{{11452917147601785610ull, 350074138153878ull}},
{{14635318621420946653ull, 560118621046205ull}},
{{11708254897136757322ull, 448094896836964ull}},
{{13055952732451316181ull, 358475917469571ull}},
{{6755413371219142621ull, 286780733975657ull}},
{{14498010208692538518ull, 458849174361051ull}},
{{7909059352212120491ull, 367079339488841ull}},
{{2637898667027786069ull, 293663471591073ull}},
{{531289052502547388ull, 469861554545717ull}},
{{11493077686227768880ull, 375889243636573ull}},
{{16573159778466035750ull, 300711394909258ull}},
{{4380962757094195261ull, 481138231854814ull}},
{{7194119020417266532ull, 384910585483851ull}},
{{2065946401591902903ull, 307928468387081ull}},
{{14373560686772775614ull, 492685549419329ull}},
{{15188197364160130814ull, 394148439535463ull}},
{{1082511447102373682ull, 315318751628371ull}},
{{12800064759589528861ull, 504510002605393ull}},
{{17618749437155443735ull, 403608002084314ull}},
{{17784348364466265311ull, 322886401667451ull}},
{{2629515679952652235ull, 516618242667923ull}},
{{9482310173445942435ull, 413294594134338ull}},
{{14964545768240574594ull, 330635675307470ull}},
{{5496529155475367735ull, 529017080491953ull}},
{{11775920953864114834ull, 423213664393562ull}},
{{2042039133607471221ull, 338570931514850ull}},
{{3267262613771953953ull, 541713490423760ull}},
{{2613810091017563163ull, 433370792339008ull}},
{{9469745702297871176ull, 346696633871206ull}},
{{7772895494192773236ull, 554714614193930ull}},
{{6218316395354218589ull, 443771691355144ull}},
{{8664001931025285194ull, 355017353084115ull}},
{{6931201544820228155ull, 284013882467292ull}},
{{14779271286454275372ull, 454422211947667ull}},
{{4444719399679599651ull, 363537769558134ull}},
{{7245124334485590044ull, 290830215646507ull}},
{{15281547749918854394ull, 465328345034411ull}},
{{8535889385193173192ull, 372262676027529ull}},
{{10518060322896448876ull, 297810140822023ull}},
{{13139547701892407879ull, 476496225315237ull}},
{{3132940532030105657ull, 381196980252190ull}},
{{2506352425624084526ull, 304957584201752ull}},
{{7699512695740445564ull, 487932134722803ull}},
{{13538307786076177098ull, 390345707778242ull}},
{{3451948599377121032ull, 312276566222594ull}},
{{12901815388487214297ull, 499642505956150ull}},
{{10321452310789771438ull, 399714004764920ull}},
{{8257161848631817150ull, 319771203811936ull}},
{{5832761328327086794ull, 511633926099098ull}},
{{12044906692145490082ull, 409307140879278ull}},
{{17014622983200212712ull, 327445712703422ull}},
{{12466001514152699046ull, 523913140325476ull}},
{{6283452396580248914ull, 419130512260381ull}},
{{1337413102522288808ull, 335304409808305ull}},
{{2139860964035662092ull, 536487055693288ull}},
{{9090586400712350320ull, 429189644554630ull}},
{{7272469120569880256ull, 343351715643704ull}},
{{567904148686077440ull, 549362745029927ull}},
{{11522369763174592922ull, 439490196023941ull}},
{{5528546995797764014ull, 351592156819153ull}},
{{5156326378534512100ull, 562547450910645ull}},
{{4125061102827609680ull, 450037960728516ull}},
{{18057444141229729036ull, 360030368582812ull}},
{{7067257683499962583ull, 288024294866250ull}},
{{11307612293599940133ull, 460838871786000ull}},
{{9046089834879952106ull, 368671097428800ull}},
{{7236871867903961685ull, 294936877943040ull}},
{{11578994988646338696ull, 471899004708864ull}},
{{12952544805658981280ull, 377519203767091ull}},
{{6672687029785274700ull, 302015363013673ull}},
{{6986950432914529198ull, 483224580821877ull}},
{{16657606790557354328ull, 386579664657501ull}},
{{9636736617703973139ull, 309263731726001ull}},
{{8040080958842536376ull, 494821970761602ull}},
{{17500111211299760070ull, 395857576609281ull}},
{{10310740154297897733ull, 316686061287425ull}},
{{16497184246876636373ull, 506697698059880ull}},
{{13197747397501309098ull, 405358158447904ull}},
{{14247546732742957602ull, 324286526758323ull}},
{{659981883937270224ull, 518858442813318ull}},
{{7906683136633636826ull, 415086754250654ull}},
{{10014695324048819784ull, 332069403400523ull}},
{{12334163703736201331ull, 531311045440837ull}},
{{2488633333505140418ull, 425048836352670ull}},
{{1990906666804112334ull, 340039069082136ull}},
{{14253497111112310705ull, 544062510531417ull}},
{{4024100059406027917ull, 435250008425134ull}},
{{6908628862266732657ull, 348200006740107ull}},
{{14743154994368682575ull, 557120010784171ull}},
{{8105175180753035737ull, 445696008627337ull}},
{{17552186588828159559ull, 356556806901869ull}},
{{17731098085804437970ull, 285245445521495ull}},
{{9923012863577549136ull, 456392712834393ull}},
{{15317107920345859955ull, 365114170267514ull}},
{{15943035151018598287ull, 292091336214011ull}},
{{18130158612145936614ull, 467346137942418ull}},
{{3436080445491018321ull, 373876910353935ull}},
{{2748864356392814657ull, 299101528283148ull}},
{{708834155486593128ull, 478562445253037ull}},
{{11635113768615005472ull, 382849956202429ull}},
{{12997439829633914701ull, 306279964961943ull}},
{{17106554912672353198ull, 490047943939109ull}},
{{17374592744879792882ull, 392038355151287ull}},
{{6520976566420013659ull, 313630684121030ull}},
{{10433562506272021855ull, 501809094593648ull}},
{{15725547634501438130ull, 401447275674918ull}},
{{1512391663375419534ull, 321157820539935ull}},
{{2419826661400671255ull, 513852512863896ull}},
{{16693256588088178297ull, 411082010291116ull}},
{{9665256455728632314ull, 328865608232893ull}},
{{11775061514423901380ull, 526184973172629ull}},
{{13109398026281031427ull, 420947978538103ull}},
{{17866216050508645788ull, 336758382830482ull}},
{{13828550421846191968ull, 538813412528772ull}},
{{3684142707993132928ull, 431050730023018ull}},
{{10326011795878326989ull, 344840584018414ull}},
{{5453572429179592213ull, 551744934429463ull}},
{{11741555572827494416ull, 441395947543570ull}},
{{9393244458261995533ull, 353116758034856ull}},
{{3825246751867686103ull, 282493406427885ull}},
{{6120394802988297765ull, 451989450284616ull}},
{{1206967027648727889ull, 361591560227693ull}},
{{8344271251602802957ull, 289273248182154ull}},
{{2282787558338753763ull, 462837197091447ull}},
{{12894276490896733980ull, 370269757673157ull}},
{{2936723563233566537ull, 296215806138526ull}},
{{15766804145399437429ull, 473945289821641ull}},
{{8924094501577639620ull, 379156231857313ull}},
{{14517973230745932342ull, 303324985485850ull}},
{{4782013095483940132ull, 485319976777361ull}},
{{136261661645241782ull, 388255981421889ull}},
{{3798358144058103749ull, 310604785137511ull}},
{{17145419474718696968ull, 496967656220017ull}},
{{6337637950291136928ull, 397574124976014ull}},
{{8759459174974819866ull, 318059299980811ull}},
{{6636437050475891139ull, 508894879969298ull}},
{{12687847269864533557ull, 407115903975438ull}},
{{17528975445375447492ull, 325692723180350ull}},
{{9599616638891164372ull, 521108357088561ull}},
{{3990344496371021174ull, 416886685670849ull}},
{{6881624411838727263ull, 333509348536679ull}},
{{18389296688425784267ull, 533614957658686ull}},
{{11022088535998717090ull, 426891966126949ull}},
{{12507019643540883995ull, 341513572901559ull}},
{{8943184985439683423ull, 546421716642495ull}},
{{7154547988351746738ull, 437137373313996ull}},
{{2034289575939487067ull, 349709898651197ull}},
{{6944212136245089631ull, 559535837841915ull}},
{{5555369708996071705ull, 447628670273532ull}},
{{15512342211422588333ull, 358102936218825ull}},
{{12409873769138070667ull, 286482348975060ull}},
{{1409053956911361451ull, 458371758360097ull}},
{{12195289609754820130ull, 366697406688077ull}},
{{2377534058320035458ull, 293357925350462ull}},
{{7493403308053967056ull, 469372680560739ull}},
{{9684071461185083968ull, 375498144448591ull}},
{{4057908354206156851ull, 300398515558873ull}},
{{2803304551987940638ull, 480637624894197ull}},
{{13310690085816083480ull, 384510099915357ull}},
{{3269854439169046138ull, 307608079932286ull}},
{{16299813546896204790ull, 492172927891657ull}},
{{5661153208033143186ull, 393738342313326ull}},
{{839573751684604225ull, 314990673850661ull}},
{{12411364446921097730ull, 503985078161057ull}},
{{2550393928053057538ull, 403188062528846ull}},
{{16797710401410087323ull, 322550450023076ull}},
{{1050894939062767455ull, 516080720036923ull}},
{{8219413580734034610ull, 412864576029538ull}},
{{13954228494071048334ull, 330291660823630ull}},
{{3880021516804125719ull, 528466657317809ull}},
{{6793366028185210898ull, 422773325854247ull}},
{{16502739266773899688ull, 338218660683397ull}},
{{11646987567870598209ull, 541149857093436ull}},
{{5628241239554568244ull, 432919885674749ull}},
{{8191941806385564918ull, 346335908539799ull}},
{{2039060445991172899ull, 554137453663679ull}},
{{5320597171534848643ull, 443309962930943ull}},
{{11635175366711699560ull, 354647970344754ull}},
{{12997489108111269971ull, 283718376275803ull}},
{{17106633758236121631ull, 453949402041285ull}},
{{13685307006588897305ull, 363159521633028ull}},
{{18326943234754938490ull, 290527617306422ull}},
{{14565713916640260292ull, 464844187690276ull}},
{{7963222318570297910ull, 371875350152221ull}},
{{2681229040114328005ull, 297500280121777ull}},
{{7979315278924835131ull, 476000448194843ull}},
{{13762149852623688751ull, 380800358555874ull}},
{{14699068696840861324ull, 304640286844699ull}},
{{12450463470719647150ull, 487424458951519ull}},
{{13649719591317628043ull, 389939567161215ull}},
{{10919775673054102434ull, 311951653728972ull}},
{{2714245817918922602ull, 499122645966356ull}},
{{16928791913302779374ull, 399298116773084ull}},
{{17232382345384133823ull, 319438493418467ull}},
{{12814416493646972824ull, 511101589469548ull}},
{{17630230824401398905ull, 408881271575638ull}},
{{3036138215295388154ull, 327105017260511ull}},
{{15925867588698352017ull, 523368027616817ull}},
{{5361996441474860967ull, 418694422093454ull}},
{{7978945967921799097ull, 334955537674763ull}},
{{9076964733932968232ull, 535928860279621ull}},
{{3572222972404464262ull, 428743088223697ull}},
{{13925824822149302379ull, 342994470578957ull}},
{{7523924456471242514ull, 548791152926332ull}},
{{17087186009402724981ull, 439032922341065ull}},
{{13669748807522179985ull, 351226337872852ull}},
{{7114202833067846683ull, 561962140596564ull}},
{{9380711081196187670ull, 449569712477251ull}},
{{3815220050215039812ull, 359655769981801ull}},
{{17809571299139673143ull, 287724615985440ull}},
{{10048570004913925412ull, 460359385576705ull}},
{{8038856003931140330ull, 368287508461364ull}},
{{10120433617886822587ull, 294630006769091ull}},
{{8813996159135095493ull, 471408010830546ull}},
{{3361848112566166071ull, 377126408664437ull}},
{{13757524934278663826ull, 301701126931549ull}},
{{10943993450620131153ull, 482721803090479ull}},
{{12444543575238015245ull, 386177442472383ull}},
{{17334332489674232843ull, 308941953977906ull}},
{{1909490280285400286ull, 494307126364651ull}},
{{16284987483195961522ull, 395445701091720ull}},
{{13027989986556769217ull, 316356560873376ull}},
{{13466086349007010101ull, 506170497397402ull}},
{{3394171449721787435ull, 404936397917922ull}},
{{13783383604003160917ull, 323949118334337ull}},
{{7296018507437416175ull, 518318589334940ull}},
{{5836814805949932940ull, 414654871467952ull}},
{{15737498288985677321ull, 331723897174361ull}},
{{17801299632893263068ull, 530758235478978ull}},
{{3172993262088879485ull, 424606588383183ull}},
{{9917092239154924234ull, 339685270706546ull}},
{{8488649953164058129ull, 543496433130474ull}},
{{10480268777273156826ull, 434797146504379ull}},
{{12073563836560435784ull, 347837717203503ull}},
{{15628353323754786931ull, 556540347525605ull}},
{{12502682659003829545ull, 445232278020484ull}},
{{13691494941944973959ull, 356185822416387ull}},
{{3574498324072158521ull, 284948657933110ull}},
{{5719197318515453634ull, 455917852692976ull}},
{{886009040070452584ull, 364734282154381ull}},
{{15466202491024003360ull, 291787425723504ull}},
{{13677877541412674406ull, 466859881157607ull}},
{{3563604403646318878ull, 373487904926086ull}},
{{17608278781884696395ull, 298790323940868ull}},
{{6037153162564052294ull, 478064518305390ull}},
{{4829722530051241835ull, 382451614644312ull}},
{{14931824468266724437ull, 305961291715449ull}},
{{12822872705001028130ull, 489538066744719ull}},
{{13947646978742732827ull, 391630453395775ull}},
{{11158117582994186262ull, 313304362716620ull}},
{{17852988132790698019ull, 501286980346592ull}},
{{6903692876748737769ull, 401029584277274ull}},
{{9212303116140900538ull, 320823667421819ull}},
{{3671638541599709892ull, 513317867874911ull}},
{{17694706092247409206ull, 410654294299928ull}},
{{3087718429572196395ull, 328523435439943ull}},
{{1251000672573603909ull, 525637496703909ull}},
{{4690149352800793451ull, 420509997363127ull}},
{{14820165926466365730ull, 336407997890501ull}},
{{16333567852862364522ull, 538252796624802ull}},
{{5688156652806070971ull, 430602237299842ull}},
{{15618571766470587746ull, 344481789839873ull}},
{{2853621937901478455ull, 551170863743798ull}},
{{9661595179805003410ull, 440936690995038ull}},
{{15107973773327823375ull, 352749352796030ull}},
{{12086379018662258700ull, 282199482236824ull}},
{{8270159985633882950ull, 451519171578919ull}},
{{10305476803249016683ull, 361215337263135ull}},
{{8244381442599213346ull, 288972269810508ull}},
{{9501661493416831031ull, 462355631696813ull}},
{{14980026824217285471ull, 369884505357450ull}},
{{11984021459373828377ull, 295907604285960ull}},
{{727690261288573788ull, 473452166857537ull}},
{{11650198653256590000ull, 378761733486029ull}},
{{13009507737347182323ull, 303009386788823ull}},
{{17125863565013581394ull, 484815018862117ull}},
{{6321993222527044468ull, 387852015089694ull}},
{{8746943392763545898ull, 310281612071755ull}},
{{13995109428421673437ull, 496450579314808ull}},
{{128041098511607780ull, 397160463451847ull}},
{{11170479323035017193ull, 317728370761477ull}},
{{3115371657888386217ull, 508365393218364ull}},
{{6181646141052619296ull, 406692314574691ull}},
{{1255968098100185114ull, 325353851659753ull}},
{{16766944215927937475ull, 520566162655604ull}},
{{17102904187484260303ull, 416452930124483ull}},
{{2614276905761677273ull, 333162344099587ull}},
{{7872191863960593960ull, 533059750559339ull}},
{{9987102305910385491ull, 426447800447471ull}},
{{4300333029986398070ull, 341158240357977ull}},
{{10569881662720147235ull, 545853184572763ull}},
{{15834602959659938434ull, 436682547658210ull}},
{{12667682367727950747ull, 349346038126568ull}},
{{16578942973622810873ull, 558953661002509ull}},
{{16952503193640159021ull, 447162928802007ull}},
{{6183304925428306571ull, 357730343041606ull}},
{{1257295125600734933ull, 286184274433285ull}},
{{2011672200961175893ull, 457894839093256ull}},
{{16366733019736582007ull, 366315871274604ull}},
{{16782735230531175929ull, 293052697019683ull}},
{{4716283480398419548ull, 468884315231494ull}},
{{7462375599060645961ull, 375107452185195ull}},
{{5969900479248516769ull, 300085961748156ull}},
{{2173143137313806184ull, 480137538797050ull}},
{{1738514509851044947ull, 384110031037640ull}},
{{1390811607880835958ull, 307288024830112ull}},
{{5914647387351247856ull, 491660839728179ull}},
{{8421066724622908608ull, 393328671782543ull}},
{{14115551009182147532ull, 314662937426034ull}},
{{11516835170465705083ull, 503460699881655ull}},
{{9213468136372564066ull, 402768559905324ull}},
{{11060123323839961576ull, 322214847924259ull}},
{{6628150873918207552ull, 515543756678815ull}},
{{5302520699134566042ull, 412435005343052ull}},
{{15310063003533383803ull, 329948004274441ull}},
{{17117403176169593438ull, 527916806839106ull}},
{{10004573726193764427ull, 422333445471285ull}},
{{8003658980955011542ull, 337866756377028ull}},
{{9116505554786108144ull, 540586810203245ull}},
{{7293204443828886515ull, 432469448162596ull}},
{{2145214740321198889ull, 345975558530077ull}},
{{7121692399255828545ull, 553560893648123ull}},
{{13076051548888483483ull, 442848714918498ull}},
{{17839538868594607432ull, 354278971934798ull}},
{{3203584650649954976ull, 283423177547839ull}},
{{12504433070523748609ull, 453477084076542ull}},
{{2624848826935178240ull, 362781667261234ull}},
{{5789227876290052915ull, 290225333808987ull}},
{{12952113416805994988ull, 464360534094379ull}},
{{14051039548186706314ull, 371488427275503ull}},
{{172785194323634081ull, 297190741820403ull}},
{{15033851569885455823ull, 475505186912644ull}},
{{15716430070650274982ull, 380404149530115ull}},
{{12573144056520219985ull, 304323319624092ull}},
{{5359635231464710684ull, 486917311398548ull}},
{{11666405814655589193ull, 389533849118838ull}},
{{16711822281208292001ull, 311627079295070ull}},
{{8292171576223715586ull, 498603326872113ull}},
{{14012434890462793115ull, 398882661497690ull}},
{{11209947912370234492ull, 319106129198152ull}},
{{3178521400824733895ull, 510569806717044ull}},
{{6232165935401697439ull, 408455845373635ull}},
{{4985732748321357951ull, 326764676298908ull}},
{{4287823582572262398ull, 522823482078253ull}},
{{10808956495541630565ull, 418258785662602ull}},
{{1268467566949483806ull, 334607028530082ull}},
{{5718896921861084412ull, 535371245648131ull}},
{{885768722746957207ull, 428296996518505ull}},
{{708614978197565765ull, 342637597214804ull}},
{{8512481594599925871ull, 548220155543686ull}},
{{3120636460938030374ull, 438576124434949ull}},
{{6185857983492334622ull, 350860899547959ull}},
{{17276070403071556042ull, 561377439276734ull}},
{{17510205137199155157ull, 449101951421387ull}},
{{6629466480275503479ull, 359281561137110ull}},
{{5303573184220402783ull, 287425248909688ull}},
{{4796368280010734130ull, 459880398255501ull}},
{{147745809266676980ull, 367904318604401ull}},
{{14875591906380982877ull, 294323454883520ull}},
{{5354202976500020988ull, 470917527813633ull}},
{{11662060010683837436ull, 376734022250906ull}},
{{5640299193805159626ull, 301387217800725ull}},
{{9024478710088255402ull, 482219548481160ull}},
{{7219582968070604321ull, 385775638784928ull}},
{{13154364003940304103ull, 308620511027942ull}},
{{6289587147336845273ull, 493792817644708ull}},
{{12410367347353296864ull, 395034254115766ull}},
{{6238945063140727168ull, 316027403292613ull}},
{{6292963286283253146ull, 505643845268181ull}},
{{1345021814284692194ull, 404515076214545ull}},
{{1076017451427753755ull, 323612060971636ull}},
{{12789674366510136978ull, 517779297554617ull}},
{{2853041863724288936ull, 414223438043694ull}},
{{5971782305721341472ull, 331378750434955ull}},
{{9554851689154146355ull, 530206000695928ull}},
{{15022578980807137730ull, 424164800556742ull}},
{{4639365555161889538ull, 339331840445394ull}},
{{14801682517742843907ull, 542930944712630ull}},
{{11841346014194275126ull, 434344755770104ull}},
{{13162425626097330424ull, 347475804616083ull}},
{{17370532187013818355ull, 555961287385733ull}},
{{2828379305385323714ull, 444769029908587ull}},
{{13330749888533989941ull, 355815223926869ull}},
{{14353948725569102276ull, 284652179141495ull}},
{{4519573887201012025ull, 455443486626393ull}},
{{10994356739244630267ull, 364354789301114ull}},
{{12484834206137614536ull, 291483831440891ull}},
{{12597037100336362612ull, 466374130305426ull}},
{{6388280865527179766ull, 373099304244341ull}},
{{1421275877679833490ull, 298479443395473ull}},
{{17031436663255374877ull, 477567109432756ull}},
{{9935800515862389578ull, 382053687546205ull}},
{{7948640412689911662ull, 305642950036964ull}},
{{1649778216078127691ull, 489028720059143ull}},
{{8698520202346322799ull, 391222976047314ull}},
{{10648164976618968562ull, 312978380837851ull}},
{{9658366333106529053ull, 500765409340562ull}},
{{347995437001402596ull, 400612327472450ull}},
{{278396349601122077ull, 320489861977960ull}},
{{445434159361795323ull, 512783779164736ull}},
{{15113742586457077551ull, 410227023331788ull}},
{{1022947624939931071ull, 328181618665431ull}},
{{12704762644129620684ull, 525090589864689ull}},
{{13853158930045606870ull, 420072471891751ull}},
{{7393178329294575173ull, 336057977513401ull}},
{{4450387697387499631ull, 537692764021442ull}},
{{14628356602135730674ull, 430154211217153ull}},
{{634638837482853569ull, 344123368973723ull}},
{{15772817398940207004ull, 550597390357956ull}},
{{8928905104410255280ull, 440477912286365ull}},
{{7143124083528204224ull, 352382329829092ull}},
{{16782545711048294349ull, 281905863863273ull}},
{{4715980249225809019ull, 451049382181238ull}},
{{11151481828864467862ull, 360839505744990ull}},
{{8921185463091574289ull, 288671604595992ull}},
{{17963245555688429186ull, 461874567353587ull}},
{{6991898815066922702ull, 369499653882870ull}},
{{5593519052053538162ull, 295599723106296ull}},
{{1570932853801840413ull, 472959556970074ull}},
{{4946095097783382653ull, 378367645576059ull}},
{{7646224892968616446ull, 302694116460847ull}},
{{15923308643491696637ull, 484310586337355ull}},
{{12738646914793357309ull, 387448469069884ull}},
{{13880266346576596171ull, 309958775255907ull}},
{{7451030895554912580ull, 495934040409452ull}},
{{17028871160669661034ull, 396747232327561ull}},
{{9933748113793818504ull, 317397785862049ull}},
{{4825950537844378637ull, 507836457379279ull}},
{{7550109245017413232ull, 406269165903423ull}},
{{13418785025497751232ull, 325015332722738ull}},
{{17780707226054491649ull, 520024532356381ull}},
{{10535216966101682996ull, 416019625885105ull}},
{{8428173572881346396ull, 332815700708084ull}},
{{2417031272384423265ull, 532505121132935ull}},
{{1933625017907538612ull, 426004096906348ull}},
{{8925597643809851536ull, 340803277525078ull}},
{{10591607415353852134ull, 545285244040125ull}},
{{8473285932283081707ull, 436228195232100ull}},
{{6778628745826465366ull, 348982556185680ull}},
{{10845805993322344586ull, 558372089897088ull}},
{{16055342424141696315ull, 446697671917670ull}},
{{12844273939313357052ull, 357358137534136ull}},
{{6586070336708775318ull, 285886510027309ull}},
{{17916410168217861156ull, 457418416043694ull}},
{{18022476949316199248ull, 365934732834955ull}},
{{14417981559452959398ull, 292747786267964ull}},
{{12000724050899004067ull, 468396458028743ull}},
{{16979276870203023900ull, 374717166422994ull}},
{{17272770310904329443ull, 299773733138395ull}},
{{9189688423737375494ull, 479637973021433ull}},
{{14730448368473721041ull, 383710378417146ull}},
{{8095009880037066510ull, 306968302733717ull}},
{{16641364622801216739ull, 491149284373947ull}},
{{5934394068757152745ull, 392919427499158ull}},
{{12126212884489542842ull, 314335541999326ull}},
{{12023242985699447901ull, 502936867198922ull}},
{{2239896759075737674ull, 402349493759138ull}},
{{9170615036744410786ull, 321879595007310ull}},
{{14672984058791057258ull, 515007352011696ull}},
{{8049038432290935483ull, 412005881609357ull}},
{{17507277190058479356ull, 329604705287485ull}},
{{9564899430384015353ull, 527367528459977ull}},
{{273221914823391636ull, 421894022767982ull}},
{{11286623976084444279ull, 337515218214385ull}},
{{18058598361735110846ull, 540024349143016ull}},
{{10757529874646178353ull, 432019479314413ull}},
{{15984721529200763329ull, 345615583451530ull}},
{{7128810373011669711ull, 552984933522449ull}},
{{9392397113151246092ull, 442387946817959ull}},
{{11203266505262907196ull, 353910357454367ull}},
{{1583915574726505111ull, 283128285963494ull}},
{{9912962549046228824ull, 453005257541590ull}},
{{7930370039236983059ull, 362404206033272ull}},
{{17412342475615317417ull, 289923364826617ull}},
{{13102352702016866574ull, 463877383722588ull}},
{{17860579791097313906ull, 371101906978070ull}},
{{14288463832877851124ull, 296881525582456ull}},
{{15482844503120741153ull, 475010440931930ull}},
{{12386275602496592922ull, 380008352745544ull}},
{{13598369296739184661ull, 304006682196435ull}},
{{3310646801073143842ull, 486410691514297ull}},
{{13716563885084246043ull, 389128553211437ull}},
{{3594553478583576188ull, 311302842569150ull}},
{{5751285565733721901ull, 498084548110640ull}},
{{4601028452586977521ull, 398467638488512ull}},
{{14748869206295312986ull, 318774110790809ull}},
{{12530144285846769808ull, 510038577265295ull}},
{{10024115428677415846ull, 408030861812236ull}},
{{4329943528200022354ull, 326424689449789ull}},
{{14306607274603856413ull, 522279503119662ull}},
{{4066588190199264484ull, 417823602495730ull}},
{{3253270552159411587ull, 334258881996584ull}},
{{12583930512938879186ull, 534814211194534ull}},
{{13756493225093013672ull, 427851368955627ull}},
{{3626496950590590291ull, 342281095164502ull}},
{{9491743935686854789ull, 547649752263203ull}},
{{14972092778033304477ull, 438119801810562ull}},
{{4598976592942822935ull, 350495841448450ull}},
{{7358362548708516697ull, 560793346317520ull}},
{{5886690038966813358ull, 448634677054016ull}},
{{1020003216431540363ull, 358907741643213ull}},
{{8194700202629052936ull, 287126193314570ull}},
{{13111520324206484699ull, 459401909303312ull}},
{{3110518629881367112ull, 367521527442650ull}},
{{2488414903905093690ull, 294017221954120ull}},
{{3981463846248149904ull, 470427555126592ull}},
{{14253217521224250893ull, 376342044101273ull}},
{{334527572753669744ull, 301073635281019ull}},
{{7913941745889692238ull, 481717816449630ull}},
{{6331153396711753790ull, 385374253159704ull}},
{{8754271532111313355ull, 308299402527763ull}},
{{10317485636636191046ull, 493279044044421ull}},
{{4564639694567042513ull, 394623235235537ull}},
{{14719758199879364980ull, 315698588188429ull}},
{{12483566675581252999ull, 505117741101487ull}},
{{2608155710981181752ull, 404094192881190ull}},
{{2086524568784945402ull, 323275354304952ull}},
{{7027788124797822966ull, 517240566887923ull}},
{{13000928129322079019ull, 413792453510338ull}},
{{17779440132941483862ull, 331033962808270ull}},
{{10000360138996822563ull, 529654340493233ull}},
{{15378985740681278697ull, 423723472394586ull}},
{{8613839777803112634ull, 338978777915669ull}},
{{2714097200259249246ull, 542366044665071ull}},
{{16928673019175040689ull, 433892835732056ull}},
{{9853589600598122228ull, 347114268585645ull}},
{{15765743360956995565ull, 555382829737032ull}},
{{5233897059281775806ull, 444306263789626ull}},
{{497768832683510321ull, 355445011031701ull}},
{{15155610325114449550ull, 284356008825360ull}},
{{5802232446473567664ull, 454969614120577ull}},
{{15709832401404585100ull, 363975691296461ull}},
{{8878517106381757757ull, 291180553037169ull}},
{{3137580925985081442ull, 465888884859471ull}},
{{17267459999755706446ull, 372711107887576ull}},
{{10124619185062654834ull, 298168886310061ull}},
{{8820693066616427088ull, 477070218096098ull}},
{{14435252082776962317ull, 381656174476878ull}},
{{480155221995838884ull, 305324939581503ull}},
{{15525643614160983507ull, 488519903330404ull}},
{{16109863706070697129ull, 390815922664323ull}},
{{1819844520630826733ull, 312652738131459ull}},
{{10290448862493143420ull, 500244381010334ull}},
{{11921707904736425059ull, 400195504808267ull}},
{{2158668694305319401ull, 320156403846614ull}},
{{10832567540372331688ull, 512250246154582ull}},
{{1287356402814044704ull, 409800196923666ull}},
{{15787280381218877056ull, 327840157538932ull}},
{{10502253350982561997ull, 524544252062292ull}},
{{1023105051302228951ull, 419635401649834ull}},
{{4507832855783693484ull, 335708321319867ull}},
{{10901881383995819897ull, 537133314111787ull}},
{{1342807477712835271ull, 429706651289430ull}},
{{1074245982170268217ull, 343765321031544ull}},
{{9097491200956249794ull, 550024513650470ull}},
{{7277992960764999835ull, 440019610920376ull}},
{{2133045553870089545ull, 352015688736301ull}},
{{16463831702063712928ull, 281612550989040ull}},
{{7895386649592389070ull, 450580081582465ull}},
{{6316309319673911256ull, 360464065265972ull}},
{{16121093899964859974ull, 288371252212777ull}},
{{11036354980976134666ull, 461394003540444ull}},
{{12518432799522818056ull, 369115202832355ull}},
{{10014746239618254445ull, 295292162265884ull}},
{{4955547539163476142ull, 472467459625415ull}},
{{3964438031330780914ull, 377973967700332ull}},
{{14239596869290355700ull, 302379174160265ull}},
{{4336610917155017505ull, 483806678656425ull}},
{{3469288733724014004ull, 387045342925140ull}},
{{2775430986979211203ull, 309636274340112ull}},
{{8130038393908648248ull, 495418038944179ull}},
{{10193379529868828922ull, 396334431155343ull}},
{{15533401253378883784ull, 317067544924274ull}},
{{13785395561180483085ull, 507308071878839ull}},
{{14717665263686296791ull, 405846457503071ull}},
{{8084783396207127109ull, 324677166002457ull}},
{{16625002248673313698ull, 519483465603931ull}},
{{9610652984196740635ull, 415586772483145ull}},
{{7688522387357392508ull, 332469417986516ull}},
{{4922938190288007367ull, 531951068778426ull}},
{{249001737488495570ull, 425560855022741ull}},
{{14956596648958437749ull, 340448684018192ull}},
{{9173159379365859106ull, 544717894429108ull}},
{{14717225132976507931ull, 435774315543286ull}},
{{8084431291639296022ull, 348619452434629ull}},
{{1867043622397142665ull, 557791123895407ull}},
{{12561681342143445102ull, 446232899116325ull}},
{{10049345073714756081ull, 356986319293060ull}},
{{8039476058971804865ull, 285589055434448ull}},
{{9173812879612977461ull, 456942488695117ull}},
{{18407096747916112938ull, 365553990956093ull}},
{{3657630954107159381ull, 292443192764875ull}},
{{5852209526571455010ull, 467909108423800ull}},
{{4681767621257164008ull, 374327286739040ull}},
{{3745414097005731206ull, 299461829391232ull}},
{{9682011369951080253ull, 479138927025971ull}},
{{4056260281218953879ull, 383311141620777ull}},
{{14313054669200894073ull, 306648913296621ull}},
{{15522189841237609870ull, 490638261274594ull}},
{{16107100687731998219ull, 392510609019675ull}},
{{12885680550185598575ull, 314008487215740ull}},
{{2170344806587406105ull, 502413579545185ull}},
{{1736275845269924884ull, 401930863636148ull}},
{{8767718305699760553ull, 321544690908918ull}},
{{10339000474377706563ull, 514471505454269ull}},
{{11960549194244075573ull, 411577204363415ull}},
{{9568439355395260458ull, 329261763490732ull}},
{{552107709664775441ull, 526818821585172ull}},
{{11509732611957551322ull, 421455057268137ull}},
{{1829088460082220411ull, 337164045814510ull}},
{{2926541536131552659ull, 539462473303216ull}},
{{17098628487872883420ull, 431569978642572ull}},
{{6300205160814486089ull, 345255982914058ull}},
{{6390979442561267420ull, 552409572662493ull}},
{{12491481183532834582ull, 441927658129994ull}},
{{13682533761568177989ull, 353542126503995ull}},
{{10946027009254542391ull, 282833701203196ull}},
{{10134945585323447179ull, 452533921925114ull}},
{{11797305283000668067ull, 362027137540091ull}},
{{5748495411658624130ull, 289621710032073ull}},
{{5508243843911888285ull, 463394736051317ull}},
{{15474641519355241598ull, 370715788841053ull}},
{{1311666771258462308ull, 296572631072843ull}},
{{16856062092981180986ull, 474516209716548ull}},
{{2416803230159213819ull, 379612967773239ull}},
{{5622791398869281379ull, 303690374218591ull}},
{{1617768608707029560ull, 485904598749746ull}},
{{16051610145933264940ull, 388723678999796ull}},
{{9151939302004701629ull, 310978943199837ull}},
{{18332451697949432930ull, 497566309119739ull}},
{{18355310173101456667ull, 398053047295791ull}},
{{10994899323739255010ull, 318442437836633ull}},
{{13902490103240897694ull, 509507900538613ull}},
{{53945638366987185ull, 407606320430891ull}},
{{14800551769661231041ull, 326085056344712ull}},
{{8923487572490328373ull, 521736090151540ull}},
{{7138790057992262698ull, 417388872121232ull}},
{{16779078490619541128ull, 333911097696985ull}},
{{8399781511281714189ull, 534257756315177ull}},
{{17787871653251102321ull, 427406205052141ull}},
{{10540948507858971533ull, 341924964041713ull}},
{{13176168797832444131ull, 547079942466741ull}},
{{6851586223524044981ull, 437663953973393ull}},
{{12859966608303056631ull, 350131163178714ull}},
{{9507900129059159641ull, 560209861085943ull}},
{{14985017732731148359ull, 448167888868754ull}},
{{15677363000926829010ull, 358534311095003ull}},
{{1473843956515732238ull, 286827448876003ull}},
{{17115545589392812875ull, 458923918201604ull}},
{{17381785286256160623ull, 367139134561283ull}},
{{2837381784779197529ull, 293711307649027ull}},
{{8229159670388626369ull, 469938092238443ull}},
{{13962025365794721742ull, 375950473790754ull}},
{{14858969107377687716ull, 300760379032603ull}},
{{1638257683352838407ull, 481216606452166ull}},
{{16068001405649912019ull, 384973285161732ull}},
{{5475703495036108968ull, 307978628129386ull}},
{{1382427962573953703ull, 492765805007018ull}},
{{8484639999542983609ull, 394212644005614ull}},
{{10477060814376297210ull, 315370115204491ull}},
{{9384599673518254890ull, 504592184327186ull}},
{{3818330924072693589ull, 403673747461749ull}},
{{6744013554000065194ull, 322938997969399ull}},
{{18169119315883924958ull, 516702396751038ull}},
{{3467249008481408996ull, 413361917400831ull}},
{{17531194465752768490ull, 330689533920664ull}},
{{16981864700978698614ull, 529103254273063ull}},
{{2517445316557227922ull, 423282603418451ull}},
{{16771351512213423630ull, 338626082734760ull}},
{{8387418345831926192ull, 541801732375617ull}},
{{17777981120891271923ull, 433441385900493ull}},
{{3154338452487286569ull, 346753108720395ull}},
{{5046941523979658511ull, 554804973952632ull}},
{{15105599663409457778ull, 443843979162105ull}},
{{12084479730727566222ull, 355075183329684ull}},
{{13356932599323963301ull, 284060146663747ull}},
{{6613696899950699989ull, 454496234661996ull}},
{{1601608705218649668ull, 363596987729597ull}},
{{12349333408400650704ull, 290877590183677ull}},
{{5001538194473399834ull, 465404144293884ull}},
{{7690579370320630190ull, 372323315435107ull}},
{{17220509940482235122ull, 297858652348085ull}},
{{9106071831062024579ull, 476573843756937ull}},
{{18352903909075350633ull, 381259075005549ull}},
{{18371671942002190829ull, 305007260004439ull}},
{{18326628662977774357ull, 488011616007103ull}},
{{3593256486156488516ull, 390409292805683ull}},
{{10253302818409011459ull, 312327434244546ull}},
{{9026586879970597689ull, 499723894791274ull}},
{{10910618318718388474ull, 399779115833019ull}},
{{12417843469716621102ull, 319823292666415ull}},
{{1421805477837042148ull, 511717268266265ull}},
{{1137444382269633718ull, 409373814613012ull}},
{{11978001950041437944ull, 327499051690409ull}},
{{8096756675840569741ull, 523998482704655ull}},
{{6477405340672455793ull, 419198786163724ull}},
{{8871273087279874958ull, 335359028930979ull}},
{{3125990495422068963ull, 536574446289567ull}},
{{13568838840563386140ull, 429259557031653ull}},
{{18233768701934529558ull, 343407645625322ull}},
{{14416634664127606000ull, 549452233000516ull}},
{{7843958916560174477ull, 439561786400413ull}},
{{13653864762731960228ull, 351649429120330ull}},
{{3399439546661584749ull, 562639086592529ull}},
{{6408900452071178122ull, 450111269274023ull}},
{{12505817991140763144ull, 360089015419218ull}},
{{17383352022396431162ull, 288071212335374ull}},
{{16745316791608558889ull, 460913939736599ull}},
{{17085602248028757434ull, 368731151789279ull}},
{{17357830613164916271ull, 294984921431423ull}},
{{5636436092612404094ull, 471975874290278ull}},
{{11887846503573743922ull, 377580699432222ull}},
{{2131579573375174491ull, 302064559545778ull}},
{{18167922576367920478ull, 483303295273244ull}},
{{18223686875836246706ull, 386642636218595ull}},
{{14578949500668997365ull, 309314108974876ull}},
{{15947621571586575137ull, 494902574359802ull}},
{{5379399627785439463ull, 395922059487842ull}},
{{15371566146454082540ull, 316737647590273ull}},
{{2458412945875070125ull, 506780236144438ull}},
{{9345427986183876747ull, 405424188915550ull}},
{{7476342388947101397ull, 324339351132440ull}},
{{11962147822315362236ull, 518942961811904ull}},
{{13259067072594200112ull, 415154369449523ull}},
{{17985951287559180736ull, 332123495559618ull}},
{{6641429171643227238ull, 531397592895390ull}},
{{5313143337314581790ull, 425118074316312ull}},
{{15318561114077396402ull, 340094459453049ull}},
{{13441651338298103274ull, 544151135124879ull}},
{{14442669885380392942ull, 435320908099903ull}},
{{486089464078583384ull, 348256726479923ull}},
{{15535138401493374707ull, 557210762367876ull}},
{{8738761906452789443ull, 445768609894301ull}},
{{3301660710420321231ull, 356614887915441ull}},
{{17398723827303898277ull, 285291910332352ull}},
{{13080562864718595951ull, 456467056531764ull}},
{{14153799106516787084ull, 365173645225411ull}},
{{7633690470471519344ull, 292138916180329ull}},
{{1145858308528699981ull, 467422265888527ull}},
{{11984733091048690954ull, 373937812710821ull}},
{{5898437658097042440ull, 299150250168657ull}},
{{13126849067697178228ull, 478640400269851ull}},
{{6812130439415832259ull, 382912320215881ull}},
{{1760355536790755484ull, 306329856172705ull}},
{{2816568858865208774ull, 490127769876328ull}},
{{9631952716575987666ull, 392102215901062ull}},
{{326864543776969486ull, 313681772720850ull}},
{{522983270043151178ull, 501890836353360ull}},
{{418386616034520942ull, 401512669082688ull}},
{{7713406922311437400ull, 321210135266150ull}},
{{12341451075698299841ull, 513936216425840ull}},
{{9873160860558639872ull, 411148973140672ull}},
{{519831058963091251ull, 328919178512538ull}},
{{15589124953308587295ull, 526270685620060ull}},
{{12471299962646869836ull, 421016548496048ull}},
{{17355737599601316515ull, 336813238796838ull}},
{{5633087270910644485ull, 538901182074942ull}},
{{15574516260954246558ull, 431120945659953ull}},
{{1391566564537666277ull, 344896756527963ull}},
{{16983901762227907336ull, 551834810444740ull}},
{{13587121409782325868ull, 441467848355792ull}},
{{3490999498342040048ull, 353174278684634ull}},
{{6482148413415542362ull, 282539422947707ull}},
{{14060786276206778102ull, 452063076716331ull}},
{{7559280206223512158ull, 361650461373065ull}},
{{6047424164978809727ull, 289320369098452ull}},
{{13365227478708005886ull, 462912590557523ull}},
{{18070879612450225355ull, 370330072446018ull}},
{{3388657245734449315ull, 296264057956815ull}},
{{5421851593175118904ull, 474022492730904ull}},
{{8026830089282005446ull, 379217994184723ull}},
{{13800161700909425003ull, 303374395347778ull}},
{{18390909906713169682ull, 485399032556445ull}},
{{14712727925370535745ull, 388319226045156ull}},
{{8080833525554518273ull, 310655380836125ull}},
{{12929333640887229237ull, 497048609337800ull}},
{{10343466912709783390ull, 397638887470240ull}},
{{8274773530167826712ull, 318111109976192ull}},
{{16928986463010433062ull, 508977775961907ull}},
{{6164491540924525803ull, 407182220769526ull}},
{{1242244417997710319ull, 325745776615621ull}},
{{13055637513022067481ull, 521193242584993ull}},
{{17823207639901474631ull, 416954594067994ull}},
{{17947914926663090028ull, 333563675254395ull}},
{{10269919808951392429ull, 533701880407033ull}},
{{15594633476644934589ull, 426961504325626ull}},
{{8786357966574037348ull, 341569203460501ull}},
{{6679475117034639111ull, 546510725536802ull}},
{{16411626537853442258ull, 437208580429441ull}},
{{9439952415540843483ull, 349766864343553ull}},
{{11414575050123439250ull, 559626982949685ull}},
{{9131660040098751400ull, 447701586359748ull}},
{{14684025661562821766ull, 358161269087798ull}},
{{679174085024526443ull, 286529015270239ull}},
{{8465376165523062956ull, 458446424432382ull}},
{{17840347376644181335ull, 366757139545905ull}},
{{14272277901315345068ull, 293405711636724ull}},
{{11767598197878821139ull, 469449138618759ull}},
{{13103427373044967234ull, 375559310895007ull}},
{{3104044268952153141ull, 300447448716006ull}},
{{16034517274549175995ull, 480715917945609ull}},
{{16516962634381251119ull, 384572734356487ull}},
{{5834872478021180249ull, 307658187485190ull}},
{{9335795964833888398ull, 492253099976304ull}},
{{11157985586609021042ull, 393802479981043ull}},
{{16305086098771037480ull, 315041983984834ull}},
{{15020091313807928998ull, 504067174375735ull}},
{{12016073051046343199ull, 403253739500588ull}},
{{16991556070320895205ull, 322602991600470ull}},
{{8739745638803880713ull, 516164786560753ull}},
{{14370494140526925216ull, 412931829248602ull}},
{{4117697682937719527ull, 330345463398882ull}},
{{10277665107442261566ull, 528552741438211ull}},
{{4532783271211898930ull, 422842193150569ull}},
{{7315575431711429467ull, 338273754520455ull}},
{{11704920690738287147ull, 541238007232728ull}},
{{16742634182074450364ull, 432990405786182ull}},
{{6015409716175739645ull, 346392324628946ull}},
{{2245957916397362785ull, 554227719406314ull}},
{{5486115147859800551ull, 443382175525051ull}},
{{699543303545930118ull, 354705740420041ull}},
{{15317029901804385387ull, 283764592336032ull}},
{{9749852583919375327ull, 454023347737652ull}},
{{421184437651679615ull, 363218678190122ull}},
{{11404993994347074661ull, 290574942552097ull}},
{{3490595131987678166ull, 464919908083356ull}},
{{17549871364557783825ull, 371935926466684ull}},
{{17729245906388137383ull, 297548741173347ull}},
{{13609398191253378521ull, 476077985877356ull}},
{{7198169738260792493ull, 380862388701885ull}},
{{5758535790608633995ull, 304689910961508ull}},
{{5524308450231904068ull, 487503857538413ull}},
{{11798144389669343901ull, 390003086030730ull}},
{{9438515511735475121ull, 312002468824584ull}},
{{4033578374551029224ull, 499203950119335ull}},
{{3226862699640823379ull, 399363160095468ull}},
{{9960187789196479349ull, 319490528076374ull}},
{{4868254018488635990ull, 511184844922199ull}},
{{7583952029532819115ull, 408947875937759ull}},
{{9756510438368165615ull, 327158300750207ull}},
{{853021442421423692ull, 523453281200332ull}},
{{11750463598162869923ull, 418762624960265ull}},
{{9400370878530295938ull, 335010099968212ull}},
{{283198146680832208ull, 536016159949140ull}},
{{226558517344665767ull, 428812927959312ull}},
{{11249293258101463583ull, 343050342367449ull}},
{{6930822768736610763ull, 548880547787919ull}},
{{9234007029731198934ull, 439104438230335ull}},
{{7387205623784959147ull, 351283550584268ull}},
{{8130180183314024312ull, 562053680934829ull}},
{{10193492961393129773ull, 449642944747863ull}},
{{15533491998598324465ull, 359714355798290ull}},
{{12426793598878659572ull, 287771484638632ull}},
{{5125474499238214022ull, 460434375421812ull}},
{{15168426043616302187ull, 368347500337449ull}},
{{15824089649634952073ull, 294678000269959ull}},
{{14250496995190192347ull, 471484800431935ull}},
{{11400397596152153878ull, 377187840345548ull}},
{{16499015706405543748ull, 301750272276438ull}},
{{4262332241797408058ull, 482800435642302ull}},
{{14477912237663657416ull, 386240348513841ull}},
{{7892980975389015610ull, 308992278811073ull}},
{{8939420745880514653ull, 494387646097717ull}},
{{18219583040930142692ull, 395510116878173ull}},
{{3507619988518383184ull, 316408093502539ull}},
{{12990889611113233740ull, 506252949604062ull}},
{{3014014059406766346ull, 405002359683250ull}},
{{2411211247525413077ull, 324001887746600ull}},
{{3857937996040660923ull, 518403020394560ull}},
{{3086350396832528738ull, 414722416315648ull}},
{{9847777946949843637ull, 331777933052518ull}},
{{12067095900377839496ull, 530844692884029ull}},
{{13343025535044181920ull, 424675754307223ull}},
{{18053118057519166182ull, 339740603445778ull}},
{{6748896003579203953ull, 543584965513246ull}},
{{1709767988121452839ull, 434867972410597ull}},
{{12435860834722893241ull, 347894377928477ull}},
{{5139982076588987892ull, 556631004685564ull}},
{{7801334476013100637ull, 445304803748451ull}},
{{2551718766068570186ull, 356243842998761ull}},
{{16798770271822497442ull, 284995074399008ull}},
{{4741939546464533968ull, 455992119038414ull}},
{{7482900451913537497ull, 364793695230731ull}},
{{2296971546788919675ull, 291834956184585ull}},
{{3675154474862271480ull, 466935929895336ull}},
{{17697518838857458476ull, 373548743916268ull}},
{{3089968626860235811ull, 298838995133015ull}},
{{4943949802976377299ull, 478142392212824ull}},
{{7644508657123012162ull, 382513913770259ull}},
{{9804955740440320053ull, 306011131016207ull}},
{{930533925736870792ull, 489617809625932ull}},
{{11812473584815227603ull, 391694247700745ull}},
{{9449978867852182082ull, 313355398160596ull}},
{{7741268559079670686ull, 501368637056954ull}},
{{9882363662005646872ull, 401094909645563ull}},
{{15284588559088338144ull, 320875927716450ull}},
{{6008597620831789414ull, 513401484346321ull}},
{{1117529281923521208ull, 410721187477057ull}},
{{11962069869764547936ull, 328576949981645ull}},
{{692567717913725082ull, 525723119970633ull}},
{{7932751803814800712ull, 420578495976506ull}},
{{2656852628309930246ull, 336462796781205ull}},
{{4250964205295888394ull, 538340474849928ull}},
{{10779468993720531361ull, 430672379879942ull}},
{{1244877565492604443ull, 344537903903954ull}},
{{9370501734271987755ull, 551260646246326ull}},
{{3807052572675679881ull, 441008516997061ull}},
{{17803037317108185197ull, 352806813597648ull}},
{{3174383409460817188ull, 282245450878119ull}},
{{12457711084621128148ull, 451592721404990ull}},
{{9966168867696902518ull, 361274177123992ull}},
{{594237464673701368ull, 289019341699194ull}},
{{8329477572961742835ull, 462430946718710ull}},
{{6663582058369394268ull, 369944757374968ull}},
{{12709563276179336061ull, 295955805899974ull}},
{{9267254797661206728ull, 473529289439959ull}},
{{11103152652870875705ull, 378823431551967ull}},
{{1503824492812879918ull, 303058745241574ull}},
{{9784816817984428515ull, 484893992386518ull}},
{{15206551083871363459ull, 387915193909214ull}},
{{15854589681839001090ull, 310332155127371ull}},
{{17988645861458581098ull, 496531448203794ull}},
{{18080265503908775201ull, 397225158563035ull}},
{{14464212403127020161ull, 317780126850428ull}},
{{1006646956551770319ull, 508448202960686ull}},
{{15562712824209057548ull, 406758562368548ull}},
{{1382123815141515068ull, 325406849894839ull}},
{{9590095733710244756ull, 520650959831742ull}},
{{293378957484375158ull, 416520767865394ull}},
{{3924051980729410450ull, 333216614292315ull}},
{{6278483169167056720ull, 533146582867704ull}},
{{8712135350075555699ull, 426517266294163ull}},
{{14348405909544265206ull, 341213813035330ull}},
{{4510705381561272713ull, 545942100856529ull}},
{{7297913119990928494ull, 436753680685223ull}},
{{13217028125476563441ull, 349402944548178ull}},
{{17457896186020591183ull, 559044711277085ull}},
{{13966316948816472946ull, 447235769021668ull}},
{{105007114827447387ull, 357788615217335ull}},
{{84005691861957910ull, 286230892173868ull}},
{{14891804365946773949ull, 457969427478188ull}},
{{845397048531688189ull, 366375541982551ull}},
{{15433712897792991844ull, 293100433586040ull}},
{{6247196562759235335ull, 468960693737665ull}},
{{4997757250207388268ull, 375168554990132ull}},
{{15066252244391641584ull, 300134843992105ull}},
{{5659259517317074918ull, 480215750387369ull}},
{{8216756428595570258ull, 384172600309895ull}},
{{6573405142876456206ull, 307338080247916ull}},
{{3138750599118509284ull, 491740928396666ull}},
{{17268395738262448720ull, 393392742717332ull}},
{{6436018961126138329ull, 314714194173866ull}},
{{2918932708318000681ull, 503542710678186ull}},
{{17092541425622041837ull, 402834168542548ull}},
{{2605986696271902500ull, 322267334834039ull}},
{{11548276343518864647ull, 515627735734462ull}},
{{1859923445331271071ull, 412502188587570ull}},
{{1487938756265016857ull, 330001750870056ull}},
{{13448748454249757941ull, 528002801392089ull}},
{{14448347578141716676ull, 422402241113671ull}},
{{7869329247771463017ull, 337921792890937ull}},
{{16280275611176251151ull, 540674868625499ull}},
{{16713569303682911244ull, 432539894900399ull}},
{{17060204257688239318ull, 346031915920319ull}},
{{16228280368075451940ull, 553651065472511ull}},
{{9293275479718451229ull, 442920852378009ull}},
{{11123969198516671306ull, 354336681902407ull}},
{{1520477729329516398ull, 283469345521926ull}},
{{13500810811152957207ull, 453550952835081ull}},
{{7111299834180455442ull, 362840762268065ull}},
{{5689039867344364354ull, 290272609814452ull}},
{{12791812602492893290ull, 464436175703123ull}},
{{17612147711478135278ull, 371548940562498ull}},
{{3021671724956777253ull, 297239152449999ull}},
{{12213372389414664251ull, 475582643919998ull}},
{{17149395541015552047ull, 380466115135998ull}},
{{2651469988586710668ull, 304372892108799ull}},
{{11621049611222557716ull, 486996627374078ull}},
{{16675537318461866819ull, 389597301899262ull}},
{{5961732225285672808ull, 311677841519410ull}},
{{9538771560457076494ull, 498684546431056ull}},
{{3941668433623750872ull, 398947637144845ull}},
{{3153334746899000697ull, 319158109715876ull}},
{{16113382039264132086ull, 510652975545401ull}},
{{9201356816669395345ull, 408522380436321ull}},
{{3671736638593605953ull, 326817904349057ull}},
{{9564127436491679848ull, 522908646958491ull}},
{{3961953134451433555ull, 418326917566793ull}},
{{10548260137044967490ull, 334661534053434ull}},
{{5809169775046217015ull, 535458454485495ull}},
{{4647335820036973612ull, 428366763588396ull}},
{{28519841287668566ull, 342693410870717ull}},
{{3734980560802180030ull, 548309457393147ull}},
{{14056030892867474993ull, 438647565914517ull}},
{{3866127084810159348ull, 350918052731614ull}},
{{13564500965180075604ull, 561468884370582ull}},
{{3472903142660239837ull, 449175107496466ull}},
{{17535717773095833162ull, 359340085997172ull}},
{{6649876588992845883ull, 287472068797738ull}},
{{6950453727646643090ull, 459955310076381ull}},
{{1871014167375404149ull, 367964248061105ull}},
{{1496811333900323319ull, 294371398448884ull}},
{{9773595763724337957ull, 470994237518214ull}},
{{11508225425721380689ull, 376795390014571ull}},
{{5517231525835194228ull, 301436312011657ull}},
{{12516919256078221088ull, 482298099218651ull}},
{{6324186590120666547ull, 385838479374921ull}},
{{1370000457354622914ull, 308670783499937ull}},
{{5881349546509306986ull, 493873253599899ull}},
{{8394428451949355912ull, 395098602879919ull}},
{{10404891576301395053ull, 316078882303935ull}},
{{16647826522082232085ull, 505726211686296ull}},
{{9628912402923875344ull, 404580969349037ull}},
{{324432292855279629ull, 323664775479230ull}},
{{519091668568447407ull, 517863640766768ull}},
{{7793970964338578572ull, 414290912613414ull}},
{{9924525586212773180ull, 331432730090731ull}},
{{8500543308456616443ull, 530292368145170ull}},
{{6800434646765293154ull, 424233894516136ull}},
{{1750998902670324200ull, 339387115612909ull}},
{{10180295873756339367ull, 543019384980654ull}},
{{11833585513746981816ull, 434415507984523ull}},
{{16845566040481406099ull, 347532406387618ull}},
{{4816812776318787820ull, 556051850220190ull}},
{{3853450221055030256ull, 444841480176152ull}},
{{14150806621069755174ull, 355873184140921ull}},
{{7631296482113893816ull, 284698547312737ull}},
{{15899423186124140429ull, 455517675700379ull}},
{{16408887363641222667ull, 364414140560303ull}},
{{2059063446687247164ull, 291531312448243ull}},
{{18051896773667236755ull, 466450099917188ull}},
{{3373470974708058434ull, 373160079933751ull}},
{{17456172038734088040ull, 298528063947000ull}},
{{9483131188264989248ull, 477644902315201ull}},
{{3897156135870081075ull, 382115921852161ull}},
{{17875120167663706153ull, 305692737481728ull}},
{{6464099379810467906ull, 489108379970766ull}},
{{1481930689106464001ull, 391286703976613ull}},
{{8564242180768991847ull, 313029363181290ull}},
{{13702787489230386956ull, 500846981090064ull}},
{{14651578806126219888ull, 400677584872051ull}},
{{8031914230159065587ull, 320542067897641ull}},
{{5472365138770684293ull, 512867308636226ull}},
{{688543296274637111ull, 410293846908981ull}},
{{15308229895987350982ull, 328235077527184ull}},
{{13425121389354030601ull, 525176124043495ull}},
{{10740097111483224481ull, 420140899234796ull}},
{{4902728874444669262ull, 336112719387837ull}},
{{11533715013853381142ull, 537780351020539ull}},
{{12916320825824615237ull, 430224280816431ull}},
{{6643707845917781866ull, 344179424653145ull}},
{{10629932553468450986ull, 550687079445032ull}},
{{1125248413290940142ull, 440549663556026ull}},
{{15657593989600393407ull, 352439730844820ull}},
{{12526075191680314725ull, 281951784675856ull}},
{{12663022677204682914ull, 451122855481370ull}},
{{10130418141763746331ull, 360898284385096ull}},
{{4414985698669086742ull, 288718627508077ull}},
{{10753325932612449110ull, 461949804012923ull}},
{{15981358375573779934ull, 369559843210338ull}},
{{1717040256233292978ull, 295647874568271ull}},
{{13815310854198999734ull, 473036599309233ull}},
{{18430946312843020434ull, 378429279447386ull}},
{{11055408235532506024ull, 302743423557909ull}},
{{6620606732626278669ull, 484389477692655ull}},
{{5296485386101022935ull, 387511582154124ull}},
{{7926537123622728671ull, 310009265723299ull}},
{{1614412953570634904ull, 496014825157279ull}},
{{4980879177598418247ull, 396811860125823ull}},
{{11363400971562555244ull, 317449488100658ull}},
{{14492092739758178067ull, 507919180961053ull}},
{{525627747580811484ull, 406335344768843ull}},
{{7799199827548469833ull, 325068275815074ull}},
{{1410673279851820764ull, 520109241304119ull}},
{{4817887438623366934ull, 416087393043295ull}},
{{3854309950898693547ull, 332869914434636ull}},
{{17234942365663640646ull, 532591863095417ull}},
{{6409256263047091870ull, 426073490476334ull}},
{{8816753825179583819ull, 340858792381067ull}},
{{17796154935029244434ull, 545374067809707ull}},
{{6858226318539574901ull, 436299254247766ull}},
{{1797232240089749597ull, 349039403398213ull}},
{{17632966843111240649ull, 558463045437140ull}},
{{14106373474488992519ull, 446770436349712ull}},
{{3906401150107373369ull, 357416349079770ull}},
{{3125120920085898695ull, 285933079263816ull}},
{{16068239916363168882ull, 457492926822105ull}},
{{12854591933090535105ull, 365994341457684ull}},
{{13973022361214338407ull, 292795473166147ull}},
{{7599440518975300159ull, 468472757065836ull}},
{{2390203600438329804ull, 374778205652669ull}},
{{5601511695092574166ull, 299822564522135ull}},
{{8962418712148118666ull, 479716103235416ull}},
{{3480586154976584610ull, 383772882588333ull}},
{{10163166553465088334ull, 307018306070666ull}},
{{8882368856060320688ull, 491229289713066ull}},
{{3416546270106346227ull, 392983431770453ull}},
{{10111934645568897628ull, 314386745416362ull}},
{{1421700173942594913ull, 503018792666180ull}},
{{1137360139154075930ull, 402415034132944ull}},
{{4599236926065171067ull, 321932027306355ull}},
{{7358779081704273708ull, 515091243690168ull}},
{{13265720894847239612ull, 412072994952134ull}},
{{14301925530619702013ull, 329658395961707ull}},
{{8125685590023881928ull, 527453433538732ull}},
{{17568594916244836512ull, 421962746830985ull}},
{{14054875932995869210ull, 337570197464788ull}},
{{351708604341928797ull, 540112315943662ull}},
{{11349413327699274007ull, 432089852754929ull}},
{{12768879476901329529ull, 345671882203943ull}},
{{16740858348300216923ull, 553075011526309ull}},
{{17082035493382083861ull, 442460009221047ull}},
{{6286930765221846443ull, 353968007376838ull}},
{{12408242241661297800ull, 283174405901470ull}},
{{1406443512948524865ull, 453079049442353ull}},
{{8503852439842640538ull, 362463239553882ull}},
{{17871128396099843400ull, 289970591643105ull}},
{{10147061360050197824ull, 463952946628969ull}},
{{11806997902782068583ull, 371162357303175ull}},
{{9445598322225654866ull, 296929885842540ull}},
{{15112957315561047786ull, 475087817348064ull}},
{{15779714667190748552ull, 380070253878451ull}},
{{8934422919010688518ull, 304056203102761ull}},
{{6916379040933280983ull, 486489924964418ull}},
{{12911800862230445433ull, 389191939971534ull}},
{{14018789504526266669ull, 311353551977227ull}},
{{7672667948274385378ull, 498165683163564ull}},
{{9827483173361418626ull, 398532546530851ull}},
{{4172637723947224577ull, 318826037224681ull}},
{{17744266802541290293ull, 510121659559489ull}},
{{17884762256774942558ull, 408097327647591ull}},
{{10618460990678043723ull, 326477862118073ull}},
{{13300188770342959634ull, 522364579388917ull}},
{{3261453386790547061ull, 417891663511134ull}},
{{6298511524174347972ull, 334313330808907ull}},
{{13766967253420867078ull, 534901329294251ull}},
{{7324224987994783339ull, 427921063435401ull}},
{{2170031175653916348ull, 342336850748321ull}},
{{14540096325271997127ull, 547738961197313ull}},
{{564030615991866732ull, 438191168957851ull}},
{{15208619751761134678ull, 350552935166280ull}},
{{5887047529108263869ull, 560884696266049ull}},
{{8398986838028521418ull, 448707757012839ull}},
{{10408538285164727458ull, 358966205610271ull}},
{{4637481813389871643ull, 287172964488217ull}},
{{11109319716165704952ull, 459476743181147ull}},
{{1508758143448743315ull, 367581394544918ull}},
{{8585704144242815299ull, 294065115635934ull}},
{{2669080186562773508ull, 470504185017495ull}},
{{2135264149250218807ull, 376403348013996ull}},
{{16465606578367816338ull, 301122678411196ull}},
{{519528822195133879ull, 481796285457915ull}},
{{415623057756107103ull, 385437028366332ull}},
{{11400544890430616652ull, 308349622693065ull}},
{{18240871824688986643ull, 493359396308904ull}},
{{18282046274493099638ull, 394687517047123ull}},
{{3557590575368748740ull, 315750013637699ull}},
{{13070842550073818631ull, 505200021820318ull}},
{{17835371669542875551ull, 404160017456254ull}},
{{17957646150376210764ull, 323328013965003ull}},
{{6596140952150475284ull, 517324822344006ull}},
{{1587563946978469904ull, 413859857875205ull}},
{{1270051157582775923ull, 331087886300164ull}},
{{9410779481616262123ull, 529740618080262ull}},
{{149925955809189052ull, 423792494464210ull}},
{{119940764647351242ull, 339033995571368ull}},
{{14949300482403403280ull, 542454392914188ull}},
{{891393941696991654ull, 433963514331351ull}},
{{15470510412325234616ull, 347170811465080ull}},
{{6306072586010823770ull, 555473298344129ull}},
{{8734206883550569339ull, 444378638675303ull}},
{{14366063136324276117ull, 355502910940242ull}},
{{4114152879575600247ull, 284402328752194ull}},
{{13961342236804781043ull, 455043726003510ull}},
{{11169073789443824834ull, 364034980802808ull}},
{{16313956661038880514ull, 291227984642246ull}},
{{276888954468836560ull, 465964775427595ull}},
{{221511163575069248ull, 372771820342076ull}},
{{14934604189827696691ull, 298217456273660ull}},
{{5448622630014763089ull, 477147930037857ull}},
{{15426944548237541441ull, 381718344030285ull}},
{{12341555638590033153ull, 305374675224228ull}},
{{16057140207002142722ull, 488599480358765ull}},
{{12845712165601714177ull, 390879584287012ull}},
{{2897872102997550695ull, 312703667429610ull}},
{{4636595364796081113ull, 500325867887376ull}},
{{19927477094954567ull, 400260694309901ull}},
{{14773337240643604946ull, 320208555447920ull}},
{{5190595511320216298ull, 512333688716673ull}},
{{11531174038539993685ull, 409866950973338ull}},
{{16603636860315815594ull, 327893560778670ull}},
{{8119074902795753335ull, 524629697245873ull}},
{{13873957551720423314ull, 419703757796698ull}},
{{31119597150607682ull, 335763006237359ull}},
{{7428488984924792937ull, 537220809979774ull}},
{{9632140002681744673ull, 429776647983819ull}},
{{11395060816887306061ull, 343821318387055ull}},
{{18232097307019689699ull, 550114109419288ull}},
{{3517631401390020789ull, 440091287535431ull}},
{{17571500380079657924ull, 352073030028344ull}},
{{17746549118805636662ull, 281658424022675ull}},
{{9947734516379467044ull, 450653478436281ull}},
{{4268838798361663312ull, 360522782749025ull}},
{{3415071038689330649ull, 288418226199220ull}},
{{5464113661902929039ull, 461469161918752ull}},
{{15439337373748074201ull, 369175329535001ull}},
{{8662121084256549038ull, 295340263628001ull}},
{{6480696105326657814ull, 472544421804802ull}},
{{16252603328487057221ull, 378035537443841ull}},
{{9312733848047735453ull, 302428429955073ull}},
{{11211025342134466402ull, 483885487928117ull}},
{{1590122644223752475ull, 387108390342494ull}},
{{4961446930120912303ull, 309686712273995ull}},
{{7938315088193459686ull, 495498739638392ull}},
{{17418698514780498718ull, 396398991710713ull}},
{{2866912367598668005ull, 317119193368571ull}},
{{15655106232383599778ull, 507390709389713ull}},
{{1456038541681148852ull, 405912567511771ull}},
{{15922226092312560375ull, 324730054009416ull}},
{{18096864118216275953ull, 519568086415066ull}},
{{10788142479831110439ull, 415654469132053ull}},
{{16009211613348708998ull, 332523575305642ull}},
{{10857343322390293104ull, 532037720489028ull}},
{{16064572287396055129ull, 425630176391222ull}},
{{5472960200433023457ull, 340504141112978ull}},
{{5067387505950927208ull, 544806625780765ull}},
{{4053910004760741767ull, 435845300624612ull}},
{{14311174448034324383ull, 348676240499689ull}},
{{11829832672629188043ull, 557881984799503ull}},
{{16842563767587171081ull, 446305587839602ull}},
{{6095353384585916218ull, 357044470271682ull}},
{{15944329151894463944ull, 285635576217345ull}},
{{7064182569321590695ull, 457016921947753ull}},
{{13030043684941093202ull, 365613537558202ull}},
{{3045337318469053915ull, 292490830046562ull}},
{{8561888524292396588ull, 467985328074499ull}},
{{10538859634175827593ull, 374388262459599ull}},
{{12120436522082572398ull, 299510609967679ull}},
{{8324651991106384867ull, 479216975948287ull}},
{{17727768037110838863ull, 383373580758629ull}},
{{17871563244430581414ull, 306698864606903ull}},
{{6458408302637468323ull, 490718183371046ull}},
{{1477377827368064335ull, 392574546696837ull}},
{{12249948706120182437ull, 314059637357469ull}},
{{8531871485566560931ull, 502495419771951ull}},
{{3136148373711338421ull, 401996335817561ull}},
{{17266313957936712030ull, 321597068654048ull}},
{{5490009444247277309ull, 514555309846478ull}},
{{11770705184881642493ull, 411644247877182ull}},
{{2037866518421493348ull, 329315398301746ull}},
{{14328632873700120327ull, 526904637282793ull}},
{{394859854734365292ull, 421523709826235ull}},
{{315887883787492233ull, 337218967860988ull}},
{{15262815873027628866ull, 539550348577580ull}},
{{12210252698422103093ull, 431640278862064ull}},
{{13457550973479592797ull, 345312223089651ull}},
{{14153383928083527830ull, 552499556943442ull}},
{{3944009512983001617ull, 441999645554754ull}},
{{6844556425128311617ull, 353599716443803ull}},
{{12854342769586469940ull, 282879773155042ull}},
{{5809553172370710611ull, 452607637048068ull}},
{{12026340167380389135ull, 362086109638454ull}},
{{13310420948646221631ull, 289668887710763ull}},
{{17607324703092044287ull, 463470220337221ull}},
{{10396510947731725107ull, 370776176269777ull}},
{{938511128701559439ull, 296620941015822ull}},
{{5190966620664405426ull, 474593505625315ull}},
{{4152773296531524340ull, 379674804500252ull}},
{{14390265081450950442ull, 303739843600201ull}},
{{15645726500837700061ull, 485983749760322ull}},
{{5137883571186339402ull, 388786999808258ull}},
{{11489004486432892168ull, 311029599846606ull}},
{{11003709548808806823ull, 497647359754570ull}},
{{8802967639047045458ull, 398117887803656ull}},
{{3353025296495726043ull, 318494310242925ull}},
{{5364840474393161669ull, 509590896388680ull}},
{{4291872379514529335ull, 407672717110944ull}},
{{7122846718353533791ull, 326138173688755ull}},
{{11396554749365654066ull, 521821077902008ull}},
{{16495941428976343899ull, 417456862321606ull}},
{{9507404328439164796ull, 333965489857285ull}},
{{15211846925502663674ull, 534344783771656ull}},
{{8480128725660220616ull, 427475827017325ull}},
{{6784102980528176493ull, 341980661613860ull}},
{{10854564768845082389ull, 547169058582176ull}},
{{4994303000334155588ull, 437735246865741ull}},
{{306093585525414147ull, 350188197492593ull}},
{{15247144995808303928ull, 560301115988148ull}},
{{1129669552420912173ull, 448240892790519ull}},
{{4593084456678640061ull, 358592714232415ull}},
{{3674467565342912049ull, 286874171385932ull}},
{{9568496919290569602ull, 458998674217491ull}},
{{3965448720690545358ull, 367198939373993ull}},
{{10551056606036256933ull, 293759151499194ull}},
{{5813644125432280123ull, 470014642398711ull}},
{{961566485603913775ull, 376011713918969ull}},
{{4458602003225041343ull, 300809371135175ull}},
{{7133763205160066150ull, 481294993816280ull}},
{{5707010564128052920ull, 385035995053024ull}},
{{8254957266044352659ull, 308028796042419ull}},
{{2139885181445233285ull, 492846073667871ull}},
{{16469303404123827921ull, 394276858934296ull}},
{{9486093908557152013ull, 315421487147437ull}},
{{420354994723801929ull, 504674379435900ull}},
{{336283995779041543ull, 403739503548720ull}},
{{269027196623233234ull, 322991602838976ull}},
{{11498489958822904144ull, 516786564542361ull}},
{{5509443152316412992ull, 413429251633889ull}},
{{8096903336595040717ull, 330743401307111ull}},
{{5576347709068244501ull, 529189442091378ull}},
{{11839775796738416247ull, 423351553673102ull}},
{{2093123007906912351ull, 338681242938482ull}},
{{7038345627392970085ull, 541889988701571ull}},
{{1941327687172465745ull, 433511990961257ull}},
{{12621108593963703565ull, 346809592769005ull}},
{{1747029676632374089ull, 554895348430409ull}},
{{5086972556047809594ull, 443916278744327ull}},
{{15137624489063978645ull, 355133022995461ull}},
{{8420750776509272593ull, 284106418396369ull}},
{{2405154798189105179ull, 454570269434191ull}},
{{16681519097518925436ull, 363656215547352ull}},
{{5966517648531319702ull, 290924972437882ull}},
{{13235777052392021847ull, 465479955900611ull}},
{{6899272827171707154ull, 372383964720489ull}},
{{9208767076479276047ull, 297907171776391ull}},
{{7355329692883021028ull, 476651474842226ull}},
{{2194914939564506499ull, 381321179873781ull}},
{{16513327210619246492ull, 305056943899024ull}},
{{15353277092765063418ull, 488091110238439ull}},
{{15971970488953961058ull, 390472888190751ull}},
{{9088227576421258523ull, 312378310552601ull}},
{{7162466492790192990ull, 499805296884162ull}},
{{16798019638457885362ull, 399844237507329ull}},
{{17127764525508218613ull, 319875390005863ull}},
{{5268330352361687841ull, 511800624009382ull}},
{{15282710726115081243ull, 409440499207505ull}},
{{12226168580892064994ull, 327552399366004ull}},
{{8493823285201573021ull, 524083838985607ull}},
{{17863105072386989386ull, 419267071188485ull}},
{{14290484057909591509ull, 335413656950788ull}},
{{728681604203884475ull, 536661851121262ull}},
{{11650991727588838550ull, 429329480897009ull}},
{{13010142196812981163ull, 343463584717607ull}},
{{6058832255933128568ull, 549541735548172ull}},
{{15915112248972233824ull, 439633388438537ull}},
{{5353392169693966413ull, 351706710750830ull}},
{{8565427471510346261ull, 562730737201328ull}},
{{14231039606692097655ull, 450184589761062ull}},
{{4006134055869857477ull, 360147671808850ull}},
{{3204907244695885982ull, 288118137447080ull}},
{{5127851591513417571ull, 460989019915328ull}},
{{11480978902694554703ull, 368791215932262ull}},
{{1806085492671823116ull, 295032972745810ull}},
{{2889736788274916986ull, 472052756393296ull}},
{{17069184689587574882ull, 377642205114636ull}},
{{9965998936928149582ull, 302113764091709ull}},
{{4877551854859308362ull, 483382022546735ull}},
{{3902041483887446689ull, 386705618037388ull}},
{{10500330816593777998ull, 309364494429910ull}},
{{16800529306550044797ull, 494983191087856ull}},
{{9751074630498125514ull, 395986552870285ull}},
{{7800859704398500411ull, 316789242296228ull}},
{{8792026712295690335ull, 506862787673965ull}},
{{7033621369836552268ull, 405490230139172ull}},
{{16694943540094972784ull, 324392184111337ull}},
{{11954514405184315162ull, 519027494578140ull}},
{{9563611524147452129ull, 415221995662512ull}},
{{272191589834141057ull, 332177596530010ull}},
{{435506543734625691ull, 531484154448016ull}},
{{15105800493955341846ull, 425187323558412ull}},
{{4705942765680452830ull, 340149858846730ull}},
{{7529508425088724528ull, 544239774154768ull}},
{{13402304369554800269ull, 435391819323814ull}},
{{14411192310385750538ull, 348313455459051ull}},
{{15679210067133380215ull, 557301528734482ull}},
{{5164670424222883526ull, 445841222987586ull}},
{{442387524636396497ull, 356672978390069ull}},
{{4043258834451027521ull, 285338382712055ull}},
{{6469214135121644034ull, 456541412339288ull}},
{{12554068937581135873ull, 365233129871430ull}},
{{10043255150064908699ull, 292186503897144ull}},
{{5001161795878122948ull, 467498406235431ull}},
{{311580621960588035ull, 373998724988345ull}},
{{249264497568470428ull, 299198979990676ull}},
{{11466869640335283655ull, 478718367985081ull}},
{{5484146897526316601ull, 382974694388065ull}},
{{4387317518021053280ull, 306379755510452ull}},
{{10709056843575595572ull, 490207608816723ull}},
{{15945943104344297104ull, 392166087053378ull}},
{{1688708039249706714ull, 313732869642703ull}},
{{17459328121767172035ull, 501972591428324ull}},
{{17656811312155647951ull, 401578073142659ull}},
{{17814797864466428684ull, 321262458514127ull}},
{{13746281324178644602ull, 514019933622604ull}},
{{14686373874084826004ull, 411215946898083ull}},
{{681052655042129834ull, 328972757518467ull}},
{{4779033062809318058ull, 526356412029547ull}},
{{14891272894473185416ull, 421085129623637ull}},
{{4534320686094727686ull, 336868103698910ull}},
{{7254913097751564298ull, 538988965918256ull}},
{{2114581663459341115ull, 431191172734605ull}},
{{1691665330767472892ull, 344952938187684ull}},
{{10085362158711777274ull, 551924701100294ull}},
{{11757638541711332142ull, 441539760880235ull}},
{{9406110833369065714ull, 353231808704188ull}},
{{14903586296179073217ull, 282585446963350ull}},
{{5398994000176965532ull, 452136715141361ull}},
{{629846385399662102ull, 361709372113089ull}},
{{4193225923061640005ull, 289367497690471ull}},
{{17777207921124354978ull, 462987996304753ull}},
{{3153719892673753012ull, 370390397043803ull}},
{{9901673543622823056ull, 296312317635042ull}},
{{1085282410828875597ull, 474099708216068ull}},
{{8246923558146921124ull, 379279766572854ull}},
{{10286887661259447222ull, 303423813258283ull}},
{{12769671443273205233ull, 485478101213253ull}},
{{17594434784102384833ull, 388382480970602ull}},
{{6696850197798087220ull, 310705984776482ull}},
{{14404309131218849875ull, 497129575642371ull}},
{{7834098490233169577ull, 397703660513897ull}},
{{17335325236412266631ull, 318162928411117ull}},
{{12979125119291985317ull, 509060685457788ull}},
{{17761997724917408900ull, 407248548366230ull}},
{{14209598179933927120ull, 325798838692984ull}},
{{11667310643668552422ull, 521278141908775ull}},
{{9333848514934841938ull, 417022513527020ull}},
{{7467078811947873550ull, 333618010821616ull}},
{{4568628469632777034ull, 533788817314586ull}},
{{18412298034673862920ull, 427031053851668ull}},
{{3661791983513359366ull, 341624843081335ull}},
{{5858867173621374986ull, 546599748930136ull}},
{{997744924155189666ull, 437279799144109ull}},
{{4487544754066062056ull, 349823839315287ull}},
{{10869420421247609613ull, 559718142904459ull}},
{{12384885151739998013ull, 447774514323567ull}},
{{2529210491908177764ull, 358219611458854ull}},
{{5712717208268452534ull, 286575689167083ull}},
{{5450998718487613732ull, 458521102667333ull}},
{{11739496604273911632ull, 366816882133866ull}},
{{5702248468677218982ull, 293453505707093ull}},
{{5434248735141640049ull, 469525609131349ull}},
{{8036747802855222362ull, 375620487305079ull}},
{{10118747057026088213ull, 300496389844063ull}},
{{12500646476499830818ull, 480794223750501ull}},
{{6311168366457954331ull, 384635379000401ull}},
{{1359585878424453141ull, 307708303200321ull}},
{{13243383849704855996ull, 492333285120513ull}},
{{17973404709247705443ull, 393866628096410ull}},
{{14378723767398164354ull, 315093302477128ull}},
{{869865139385601028ull, 504149283963406ull}},
{{15453287370476122115ull, 403319427170724ull}},
{{16051978711122808015ull, 322655541736579ull}},
{{14615119493570761855ull, 516248866778527ull}},
{{4313397965372788838ull, 412999093422822ull}},
{{14518764816523962040ull, 330399274738257ull}},
{{8472628447470697971ull, 528638839581212ull}},
{{17846149202202289346ull, 422911071664969ull}},
{{17966268176503741800ull, 338328857331975ull}},
{{10299285008696435264ull, 541326171731161ull}},
{{4550079192215237888ull, 433060937384929ull}},
{{7329412168514100634ull, 346448749907943ull}},
{{8037710654880650691ull, 554317999852709ull}},
{{10119517338646430876ull, 443454399882167ull}},
{{716916241433324054ull, 354763519905734ull}},
{{4262881807888569566ull, 283810815924587ull}},
{{10509959707363621630ull, 454097305479339ull}},
{{12097316580632807627ull, 363277844383471ull}},
{{5988504449764335778ull, 290622275506777ull}},
{{13270955934364847569ull, 464995640810843ull}},
{{17995462376975698701ull, 371996512648674ull}},
{{18085718716322469284ull, 297597210118939ull}},
{{17869103501890219885ull, 476155536190303ull}},
{{3227236357286444938ull, 380924428952243ull}},
{{9960486715312976597ull, 304739543161794ull}},
{{4868732300275031586ull, 487583269058871ull}},
{{205637025478114945ull, 390066615247097ull}},
{{11232556064608222926ull, 312053292197677ull}},
{{3214694444405515389ull, 499285267516284ull}},
{{6261104370266322634ull, 399428214013027ull}},
{{16076929940438789077ull, 319542571210421ull}},
{{18344390275218241877ull, 511268113936674ull}},
{{18364861034916503825ull, 409014491149339ull}},
{{18381237642675113383ull, 327211592919471ull}},
{{3584538525086809150ull, 523538548671155ull}},
{{2867630820069447320ull, 418830838936924ull}},
{{5983453470797468179ull, 335064671149539ull}},
{{16952223182759769734ull, 536103473839262ull}},
{{6183080916723995140ull, 428882779071410ull}},
{{4946464733379196112ull, 343106223257128ull}},
{{4224994758664803457ull, 548969957211405ull}},
{{3379995806931842765ull, 439175965769124ull}},
{{6393345460287384535ull, 351340772615299ull}},
{{17608050365943635903ull, 562145236184478ull}},
{{3018393848529177753ull, 449716188947583ull}},
{{9793412708307162849ull, 359772951158066ull}},
{{4145381351903819956ull, 287818360926453ull}},
{{2943261348304201606ull, 460509377482325ull}},
{{2354609078643361285ull, 368407501985860ull}},
{{1883687262914689028ull, 294726001588688ull}},
{{17771294879631143737ull, 471561602541900ull}},
{{14217035903704914990ull, 377249282033520ull}},
{{11373628722963931992ull, 301799425626816ull}},
{{10819108327258470541ull, 482879081002906ull}},
{{4965937847064866109ull, 386303264802325ull}},
{{3972750277651892887ull, 309042611841860ull}},
{{6356400444243028620ull, 494468178946976ull}},
{{1395771540652512573ull, 395574543157581ull}},
{{15874012491489651351ull, 316459634526064ull}},
{{14330373542157711192ull, 506335415241703ull}},
{{396252389500437984ull, 405068332193363ull}},
{{7695699541084171033ull, 324054665754690ull}},
{{12313119265734673654ull, 518487465207504ull}},
{{13539844227329649246ull, 414789972166003ull}},
{{18210573011347540043ull, 331831977732802ull}},
{{14379521559188422777ull, 530931164372484ull}},
{{15192966062092648544ull, 424744931497987ull}},
{{4775675220190298189ull, 339795945198390ull}},
{{7641080352304477103ull, 543673512317424ull}},
{{9802213096585492005ull, 434938809853939ull}},
{{11531119292010303927ull, 347951047883151ull}},
{{11071093237732665638ull, 556721676613042ull}},
{{1478176960702311864ull, 445377341290434ull}},
{{4871890383303759814ull, 356301873032347ull}},
{{14965558750868738821ull, 285041498425877ull}},
{{9187498742422340821ull, 456066397481404ull}},
{{11039347808679782980ull, 364853117985123ull}},
{{16210175876427647030ull, 291882494388098ull}},
{{3800188513832773309ull, 467011991020958ull}},
{{10418848440550039293ull, 373609592816766ull}},
{{4645729937698121111ull, 298887674253413ull}},
{{3743819085575083455ull, 478220278805461ull}},
{{17752450527427708057ull, 382576223044368ull}},
{{3133913977716435476ull, 306060978435495ull}},
{{5014262364346296762ull, 489697565496792ull}},
{{15079456335702768379ull, 391758052397433ull}},
{{995518624336483733ull, 313406441917947ull}},
{{5282178613680284297ull, 501450307068715ull}},
{{4225742890944227438ull, 401160245654972ull}},
{{14448640756981112920ull, 320928196523977ull}},
{{8360429952202139379ull, 513485114438364ull}},
{{10377692776503621826ull, 410788091550691ull}},
{{4612805406460987138ull, 328630473240553ull}},
{{3691139835595669097ull, 525808757184885ull}},
{{2952911868476535278ull, 420647005747908ull}},
{{9741027124265048868ull, 336517604598326ull}},
{{8206945769340257543ull, 538428167357322ull}},
{{17633603059697937004ull, 430742533885857ull}},
{{6728184818274528957ull, 344594027108686ull}},
{{3386398079755425685ull, 551350443373898ull}},
{{10087816093288161194ull, 441080354699118ull}},
{{15448950504114349602ull, 352864283759294ull}},
{{16048509218033390004ull, 282291427007435ull}},
{{7230870675143872391ull, 451666283211897ull}},
{{16852742984340828883ull, 361333026569517ull}},
{{6103496757988842460ull, 289066421255614ull}},
{{17144292442265968582ull, 462506274008982ull}},
{{6336736324328954219ull, 370005019207186ull}},
{{1380040244721253052ull, 296004015365749ull}},
{{9586762021037825530ull, 473606424585198ull}},
{{15048107246314081070ull, 378885139668158ull}},
{{970439352825533886ull, 303108111734527ull}},
{{5242051779262764542ull, 484972978775243ull}},
{{11572339052894032280ull, 387978383020194ull}},
{{12947220057057136147ull, 310382706416155ull}},
{{2268808017581866219ull, 496612330265849ull}},
{{5504395228807403299ull, 397289864212679ull}},
{{8092864997787832962ull, 317831891370143ull}},
{{9259235181718622416ull, 508531026192229ull}},
{{11096736960116808256ull, 406824820953783ull}},
{{16256087197577267251ull, 325459856763026ull}},
{{184297812930255340ull, 520735770820843ull}},
{{7526135879828024918ull, 416588616656674ull}},
{{9710257518604330258ull, 333270893325339ull}},
{{4468365585541197443ull, 533233429320543ull}},
{{10953390097916778601ull, 426586743456434ull}},
{{12452060893075333204ull, 341269394765147ull}},
{{5165902169952891833ull, 546031031624236ull}},
{{443372921220403143ull, 436824825299389ull}},
{{4044047151718232838ull, 349459860239511ull}},
{{17538521886974903510ull, 559135776383217ull}},
{{6652119880096102162ull, 447308621106574ull}},
{{9011044718818792053ull, 357846896885259ull}},
{{10898184589796943965ull, 286277517508207ull}},
{{2679700084707469052ull, 458044028013132ull}},
{{13211806511991706211ull, 366435222410505ull}},
{{10569445209593364969ull, 293148177928404ull}},
{{5843065891123652980ull, 469037084685447ull}},
{{15742499157124653354ull, 375229667748357ull}},
{{5215301696215902037ull, 300183734198686ull}},
{{965785084461622612ull, 480293974717898ull}},
{{8151325697053118736ull, 384235179774318ull}},
{{13899758187126315635ull, 307388143819454ull}},
{{11171566655176374047ull, 491821030111127ull}},
{{1558555694657278591ull, 393456824088902ull}},
{{12314890999951553842ull, 314765459271121ull}},
{{12325127970438665502ull, 503624734833794ull}},
{{13549451191092842725ull, 402899787867035ull}},
{{10839560952874274180ull, 322319830293628ull}},
{{13653948709856928364ull, 515711728469805ull}},
{{10923158967885542691ull, 412569382775844ull}},
{{12427875989050344476ull, 330055506220675ull}},
{{1437857508770999546ull, 528088809953081ull}},
{{15907681265984440930ull, 422471047962464ull}},
{{16415493827529463067ull, 337976838369971ull}},
{{439348420853768645ull, 540762941391955ull}},
{{351478736683014916ull, 432610353113564ull}},
{{3970531804088322256ull, 346088282490851ull}},
{{17420897330767046579ull, 553741251985361ull}},
{{10247369049871726940ull, 442993001588289ull}},
{{11887244054639291875ull, 354394401270631ull}},
{{5820446428969523177ull, 283515521016505ull}},
{{9312714286351237083ull, 453624833626408ull}},
{{14828869058564810313ull, 362899866901126ull}},
{{8173746432109937927ull, 290319893520901ull}},
{{5699296661892080037ull, 464511829633442ull}},
{{15627483773739394999ull, 371609463706753ull}},
{{1433940574765785030ull, 297287570965403ull}},
{{17051700178592897340ull, 475660113544644ull}},
{{17330708957616228195ull, 380528090835715ull}},
{{13864567166092982556ull, 304422472668572ull}},
{{7425912206781130798ull, 487075956269716ull}},
{{2251380950682994315ull, 389660765015773ull}},
{{9179802390030216098ull, 311728612012618ull}},
{{10998335009306435434ull, 498765779220189ull}},
{{12488016822187058670ull, 399012623376151ull}},
{{6301064643007736613ull, 319210098700921ull}},
{{2703005799328557935ull, 510736157921474ull}},
{{5851753454204756671ull, 408588926337179ull}},
{{8370751578105715660ull, 326871141069743ull}},
{{9703853710227234733ull, 522993825711589ull}},
{{11452431782923698109ull, 418395060569271ull}},
{{5472596611597048164ull, 334716048455417ull}},
{{12445503393297187386ull, 535545677528667ull}},
{{2577705085153929262ull, 428436542022934ull}},
{{5751512882865053733ull, 342749233618347ull}},
{{12891769427325996296ull, 548398773789355ull}},
{{10313415541860797037ull, 438719019031484ull}},
{{11940081248230547953ull, 350975215225187ull}},
{{4346734738201235432ull, 561560344360300ull}},
{{3477387790560988345ull, 449248275488240ull}},
{{2781910232448790676ull, 359398620390592ull}},
{{13293574630184763510ull, 287518896312473ull}},
{{17580370593553711294ull, 460030234099957ull}},
{{6685598845359148388ull, 368024187279966ull}},
{{1659130261545408387ull, 294419349823973ull}},
{{17412003677440294713ull, 471070959718356ull}},
{{10240254127210325447ull, 376856767774685ull}},
{{8192203301768260358ull, 301485414219748ull}},
{{9418176468087306249ull, 482376662751597ull}},
{{155843544986024353ull, 385901330201278ull}},
{{7503372465472640129ull, 308721064161022ull}},
{{15694744759498134529ull, 493953702657635ull}},
{{12555795807598507623ull, 395162962126108ull}},
{{17423334275562626745ull, 316130369700886ull}},
{{2051893137706830530ull, 505808591521419ull}},
{{5330863324907374747ull, 404646873217135ull}},
{{4264690659925899798ull, 323717498573708ull}},
{{3134156241139529353ull, 517947997717933ull}},
{{9886022622395444129ull, 414358398174346ull}},
{{4219469283174444980ull, 331486718539477ull}},
{{10440499667821022291ull, 530378749663163ull}},
{{15731097363740638479ull, 424302999730530ull}},
{{12584877890992510783ull, 339442399784424ull}},
{{9067758181362286284ull, 543107839655079ull}},
{{10943555359831739350ull, 434486271724063ull}},
{{16133541917349212126ull, 347589017379250ull}},
{{7366922994049187787ull, 556142427806801ull}},
{{2204189580497439906ull, 444913942245441ull}},
{{16520746923365593218ull, 355931153796352ull}},
{{5837899909208653928ull, 284744923037082ull}},
{{13029988669475756608ull, 455591876859331ull}},
{{6734642120838694963ull, 364473501487465ull}},
{{5387713696670955970ull, 291578801189972ull}},
{{12309690729415439876ull, 466526081903955ull}},
{{9847752583532351900ull, 373220865523164ull}},
{{11567550881567791843ull, 298576692418531ull}},
{{11129383781024646303ull, 477722707869650ull}},
{{8903507024819717043ull, 382178166295720ull}},
{{7122805619855773634ull, 305742533036576ull}},
{{4017791362285417168ull, 489188052858522ull}},
{{14282279534054064704ull, 391350442286817ull}},
{{4047125997759431117ull, 313080353829454ull}},
{{13854099225898910434ull, 500928566127126ull}},
{{7393930565977218024ull, 400742852901701ull}},
{{2225795638039864096ull, 320594282321361ull}},
{{14629319465089513523ull, 512950851714177ull}},
{{4324757942587790172ull, 410360681371342ull}},
{{14527852798295963107ull, 328288545097073ull}},
{{1108471588822079032ull, 525261672155318ull}},
{{8265474900541483872ull, 420209337724254ull}},
{{10301728735175097421ull, 336167470179403ull}},
{{12793417161538245550ull, 537867952287045ull}},
{{10234733729230596440ull, 430294361829636ull}},
{{4498438168642566829ull, 344235489463709ull}},
{{14576198699311927573ull, 550776783141934ull}},
{{15350307774191452381ull, 440621426513547ull}},
{{4901548589869341258ull, 352497141210838ull}},
{{11299936501379293653ull, 281997712968670ull}},
{{18079898402206869845ull, 451196340749872ull}},
{{7085221092281675230ull, 360957072599898ull}},
{{13046874503309160830ull, 288765658079918ull}},
{{17185650390552747005ull, 462025052927869ull}},
{{17437869127184107927ull, 369620042342295ull}},
{{13950295301747286342ull, 295696033873836ull}},
{{14941774853311837501ull, 473113654198138ull}},
{{885373438423739031ull, 378490923358511ull}},
{{15465694009706632517ull, 302792738686808ull}},
{{2609017527079150089ull, 484468381898894ull}},
{{5776562836405230394ull, 387574705519115ull}},
{{4621250269124184315ull, 310059764415292ull}},
{{11083349245340605228ull, 496095623064467ull}},
{{1487981766788663536ull, 396876498451574ull}},
{{4879734228172841152ull, 317501198761259ull}},
{{15186272394560366489ull, 508001918018014ull}},
{{15838366730390203515ull, 406401534414411ull}},
{{8981344569570252488ull, 325121227531529ull}},
{{3302104867086673012ull, 520193964050447ull}},
{{13709730337895069379ull, 416155171240357ull}},
{{3589086640832234857ull, 332924136992286ull}},
{{16810585069557306741ull, 532678619187657ull}},
{{6069770426162024746ull, 426142895350126ull}},
{{1166467526187709474ull, 340914316280101ull}},
{{12934394486126066128ull, 545462906048161ull}},
{{6658166774158942579ull, 436370324838529ull}},
{{9015882234069064386ull, 349096259870823ull}},
{{10736062759768592695ull, 558554015793317ull}},
{{1210152578331053510ull, 446843212634654ull}},
{{4657470877406753131ull, 357474570107723ull}},
{{11104674331409223151ull, 285979656086178ull}},
{{14078130115512846719ull, 457567449737885ull}},
{{11262504092410277375ull, 366053959790308ull}},
{{16388700903412042546ull, 292843167832246ull}},
{{396479742265895812ull, 468549068531595ull}},
{{317183793812716649ull, 374839254825276ull}},
{{15011142294017814612ull, 299871403860220ull}},
{{5571083596718951764ull, 479794246176353ull}},
{{11835564506858982057ull, 383835396941082ull}},
{{2089753976003364999ull, 307068317552866ull}},
{{14411652805831114969ull, 491309308084585ull}},
{{11529322244664891975ull, 393047446467668ull}},
{{16602155425215734226ull, 314437957174134ull}},
{{15495402236119443793ull, 503100731478615ull}},
{{12396321788895555034ull, 402480585182892ull}},
{{2538359801632623381ull, 321984468146314ull}},
{{11440073312096018056ull, 515175149034102ull}},
{{1773361020192993798ull, 412140119227282ull}},
{{12486735260380126008ull, 329712095381825ull}},
{{1532032342898649997ull, 527539352610921ull}},
{{15983021133286561290ull, 422031482088736ull}},
{{9097068091887338709ull, 337625185670989ull}},
{{3487262502794010965ull, 540200297073583ull}},
{{10168507631719029418ull, 432160237658866ull}},
{{4445457290633313211ull, 345728190127093ull}},
{{3423382850271390815ull, 553165104203349ull}},
{{6428055094959022975ull, 442532083362679ull}},
{{8831792890709128703ull, 354025666690143ull}},
{{14444131942051123609ull, 283220533352114ull}},
{{12042564663056066805ull, 453152853363383ull}},
{{17012749359928674090ull, 362522282690706ull}},
{{9920850673201028949ull, 290017826152565ull}},
{{15873361077121646319ull, 464028521844104ull}},
{{16388037676439227378ull, 371222817475283ull}},
{{2042383696925650933ull, 296978253980227ull}},
{{6957162729822951816ull, 475165206368363ull}},
{{12944427813342182099ull, 380132165094690ull}},
{{10355542250673745679ull, 304105732075752ull}},
{{1811472342110351794ull, 486569171321204ull}},
{{5138526688430191758ull, 389255337056963ull}},
{{11489518980227974053ull, 311404269645570ull}},
{{18383230368364758485ull, 498246831432912ull}},
{{7327886665207986142ull, 398597465146330ull}},
{{5862309332166388913ull, 318877972117064ull}},
{{16758392560950042908ull, 510204755387302ull}},
{{6028016419276213680ull, 408163804309842ull}},
{{15890459579646701913ull, 326531043447873ull}},
{{3288642438983261122ull, 522449669516598ull}},
{{10009611580670429544ull, 417959735613278ull}},
{{15386386894020164282ull, 334367788490622ull}},
{{9860823771464621558ull, 534988461584996ull}},
{{4199310202429786923ull, 427990769267997ull}},
{{14427494606169560508ull, 342392615414397ull}},
{{8326596110903655521ull, 547828184663036ull}},
{{2971928073981014093ull, 438262547730429ull}},
{{6066891273926721598ull, 350610038184343ull}},
{{6017677223540844233ull, 560976061094949ull}},
{{8503490593574585710ull, 448780848875959ull}},
{{10492141289601578891ull, 359024679100767ull}},
{{1015015402197442466ull, 287219743280614ull}},
{{9002722272999728593ull, 459551589248982ull}},
{{18270224262625513844ull, 367641271399185ull}},
{{14616179410100411075ull, 294113017119348ull}},
{{1249794167709195781ull, 470580827390958ull}},
{{8378532963651177271ull, 376464661912766ull}},
{{3013477556179031493ull, 301171729530213ull}},
{{1132215275144540067ull, 481874767248341ull}},
{{15663167479083273346ull, 385499813798672ull}},
{{5151836353782798030ull, 308399851038938ull}},
{{4553589351310566526ull, 493439761662301ull}},
{{18400266740016094513ull, 394751809329840ull}},
{{14720213392012875610ull, 315801447463872ull}},
{{8794946168252959684ull, 505282315942196ull}},
{{3346608119860457424ull, 404225852753757ull}},
{{13745332940114096909ull, 323380682203005ull}},
{{3545788630473003438ull, 517409091524809ull}},
{{6525979719120313074ull, 413927273219847ull}},
{{16288830219521981428ull, 331141818575877ull}},
{{11304733092267528993ull, 529826909721404ull}},
{{12733135288555933517ull, 423861527777123ull}},
{{17565205860328567460ull, 339089222221698ull}},
{{5968236488074245998ull, 542542755554718ull}},
{{12153286819943217444ull, 434034204443774ull}},
{{13411978270696484279ull, 347227363555019ull}},
{{10391118788888643876ull, 555563781688031ull}},
{{4623546216369004778ull, 444451025350425ull}},
{{3698836973095203822ull, 355560820280340ull}},
{{2959069578476163058ull, 284448656224272ull}},
{{8423860140303771216ull, 455117849958835ull}},
{{6739088112243016972ull, 364094279967068ull}},
{{12769968119278234224ull, 291275423973654ull}},
{{9363902546619443790ull, 466040678357847ull}},
{{112424407811734385ull, 372832542686278ull}},
{{7468637155733208154ull, 298266034149022ull}},
{{15639168263915043371ull, 477225654638435ull}},
{{12511334611132034696ull, 381780523710748ull}},
{{17387765318389448403ull, 305424418968598ull}},
{{5684331620971655507ull, 488679070349758ull}},
{{11926162926261145052ull, 390943256279806ull}},
{{5851581526267005718ull, 312754605023845ull}},
{{9362530442027209149ull, 500407368038152ull}},
{{111326724137946673ull, 400325894430522ull}},
{{11157107823536088308ull, 320260715544417ull}},
{{3093977258690100000ull, 512417144871068ull}},
{{9853879436435900646ull, 409933715896854ull}},
{{11572452363890630840ull, 327946972717483ull}},
{{14826574967483099021ull, 524715156347973ull}},
{{793213529760748247ull, 419772125078379ull}},
{{4323919638550508921ull, 335817700062703ull}},
{{3228922606938903950ull, 537308320100325ull}},
{{2583138085551123160ull, 429846656080260ull}},
{{2066510468440898528ull, 343877324864208ull}},
{{18063812008473078938ull, 550203719782732ull}},
{{7072351977294642504ull, 440162975826186ull}},
{{1968532767093803680ull, 352130380660949ull}},
{{5264175028416953267ull, 281704304528759ull}},
{{15801377674950945874ull, 450726887246014ull}},
{{16330450954702667022ull, 360581509796811ull}},
{{9375011949020223294ull, 288465207837449ull}},
{{3931972674206626302ull, 461544332539919ull}},
{{6834926954107211365ull, 369235466031935ull}},
{{5467941563285769092ull, 295388372825548ull}},
{{5059357686515320224ull, 472621396520877ull}},
{{15115532593437987148ull, 378097117216701ull}},
{{8403077260008479395ull, 302477693773361ull}},
{{6066225986529746386ull, 483964310037378ull}},
{{12231678418707617755ull, 387171448029902ull}},
{{2406645105482273558ull, 309737158423922ull}},
{{7539980983513548016ull, 495579453478275ull}},
{{6031984786810838413ull, 396463562782620ull}},
{{4825587829448670730ull, 317170850226096ull}},
{{342242897634052522ull, 507473360361754ull}},
{{3963143132849152341ull, 405978688289403ull}},
{{10549212135763142519ull, 324782950631522ull}},
{{2121344158253386738ull, 519652721010436ull}},
{{16454470585570350683ull, 415722176808348ull}},
{{2095530024230549577ull, 332577741446679ull}},
{{10731545668252699969ull, 532124386314686ull}},
{{4895887719860249652ull, 425699509051749ull}},
{{7606058990630110045ull, 340559607241399ull}},
{{1101647940782445102ull, 544895371586239ull}},
{{4570667167367866405ull, 435916297268991ull}},
{{18413928992861934417ull, 348733037815192ull}},
{{14704891129611453774ull, 557972860504308ull}},
{{695866459463432050ull, 446378288403447ull}},
{{11624739611796476609ull, 357102630722757ull}},
{{1921094059953360641ull, 285682104578206ull}},
{{14141796940151107995ull, 457091367325129ull}},
{{15002786366862796719ull, 365673093860103ull}},
{{934182649264506406ull, 292538475088083ull}},
{{16252087497790851542ull, 468061560140932ull}},
{{5622972368748860587ull, 374449248112746ull}},
{{809029080257178147ull, 299559398490197ull}},
{{4983795343153395358ull, 479295037584315ull}},
{{3987036274522716286ull, 383436030067452ull}},
{{14257675463843903999ull, 306748824053961ull}},
{{15433583112666425752ull, 490798118486338ull}},
{{1278820045907409632ull, 392638494789071ull}},
{{15780451295693568998ull, 314110795831256ull}},
{{17870024443625889751ull, 502577273330010ull}},
{{14296019554900711801ull, 402061818664008ull}},
{{368769199694838471ull, 321649454931207ull}},
{{4279379534253651877ull, 514639127889931ull}},
{{18180898886370562794ull, 411711302311944ull}},
{{18234067923838360558ull, 329369041849555ull}},
{{10727764604431825278ull, 526990466959289ull}},
{{12271560498287370545ull, 421592373567431ull}},
{{6127899583887986113ull, 337273898853945ull}},
{{9804639334220777781ull, 539638238166312ull}},
{{465013837892801578ull, 431710590533050ull}},
{{372011070314241262ull, 345368472426440ull}},
{{595217712502786020ull, 552589555882304ull}},
{{4165522984744139139ull, 442071644705843ull}},
{{10711116017279131958ull, 353657315764674ull}},
{{12258241628565215889ull, 282925852611739ull}},
{{8545140161478614454ull, 452681364178783ull}},
{{14214809758666712209ull, 362145091343026ull}},
{{7682498992191459444ull, 289716073074421ull}},
{{4913300758022514464ull, 463545716919074ull}},
{{7619989421159921895ull, 370836573535259ull}},
{{9785340351669847839ull, 296669258828207ull}},
{{899149303704115249ull, 474670814125132ull}},
{{11787365887189023169ull, 379736651300105ull}},
{{9429892709751218535ull, 303789321040084ull}},
{{4019781891376218687ull, 486062913664135ull}},
{{3215825513100974949ull, 388850330931308ull}},
{{9951358039964600606ull, 311080264745046ull}},
{{8543475234459540323ull, 497728423592074ull}},
{{10524129002309542582ull, 398182738873659ull}},
{{12108652016589544388ull, 318546191098927ull}},
{{4616447967575629729ull, 509673905758284ull}},
{{7382507188802414106ull, 407739124606627ull}},
{{16974052195267662255ull, 326191299685301ull}},
{{1333041809234887345ull, 521906079496483ull}},
{{8445131076871730522ull, 417524863597186ull}},
{{3066756046755474095ull, 334019890877749ull}},
{{12285507304292579198ull, 534431825404398ull}},
{{17207103472917884005ull, 427545460323518ull}},
{{2697636334108576234ull, 342036368258815ull}},
{{4316218134573721975ull, 547258189214104ull}},
{{7142323322400887903ull, 437806551371283ull}},
{{13092556287404530969ull, 350245241097026ull}},
{{13569392430363428904ull, 560392385755242ull}},
{{3476816314806922477ull, 448313908604194ull}},
{{6470801866587448304ull, 358651126883355ull}},
{{5176641493269958643ull, 286920901506684ull}},
{{15661324018715754476ull, 459073442410694ull}},
{{16218408029714513904ull, 367258753928555ull}},
{{12974726423771611123ull, 293807003142844ull}},
{{9691515833808846828ull, 470091205028551ull}},
{{4063863852305167139ull, 376072964022841ull}},
{{18008486340811775004ull, 300858371218272ull}},
{{14056182886331198714ull, 481373393949236ull}},
{{7555597494323048648ull, 385098715159389ull}},
{{9733826810200349241ull, 308078972127511ull}},
{{8195425266836738140ull, 492926355404018ull}},
{{13935037842953211158ull, 394341084323214ull}},
{{14837379089104479250ull, 315472867458571ull}},
{{16361108913083346153ull, 504756587933714ull}},
{{16778235945208587246ull, 403805270346971ull}},
{{9733239941424959473ull, 323044216277577ull}},
{{815788647312293865ull, 516870746044124ull}},
{{4341979732591745415ull, 413496596835299ull}},
{{7162932600815306655ull, 330797277468239ull}},
{{392645717078759679ull, 529275643949183ull}},
{{7692814203146828389ull, 423420515159346ull}},
{{2464902547775552388ull, 338736412127477ull}},
{{7633192891182794144ull, 541978259403963ull}},
{{13485251942430055962ull, 433582607523170ull}},
{{10788201553944044769ull, 346866086018536ull}},
{{9882424856826650985ull, 554985737629658ull}},
{{15284637514945141434ull, 443988590103726ull}},
{{8538361197214202824ull, 355190872082981ull}},
{{3141340143029451936ull, 284152697666385ull}},
{{5026144228847123098ull, 454644316266216ull}},
{{331566568335788155ull, 363715453012973ull}},
{{7643950884152451170ull, 290972362410378ull}},
{{8540972599902011550ull, 465555779856605ull}},
{{6832778079921609240ull, 372444623885284ull}},
{{9155571278679197715ull, 297955699108227ull}},
{{18338262860628626667ull, 476729118573163ull}},
{{3602563844277170364ull, 381383294858531ull}},
{{17639446334389377584ull, 305106635886824ull}},
{{17155067690797273165ull, 488170617418919ull}},
{{17413402967379728855ull, 390536493935135ull}},
{{13930722373903783084ull, 312429195148108ull}},
{{153062909794590995ull, 499886712236974ull}},
{{3811799142577583119ull, 399909369789579ull}},
{{6738788128803976819ull, 319927495831663ull}},
{{7092712191344452587ull, 511883993330661ull}},
{{1984820938333651746ull, 409507194664529ull}},
{{5277205565408831720ull, 327605755731623ull}},
{{4754180089912220429ull, 524169209170597ull}},
{{14871390516155507313ull, 419335367336477ull}},
{{4518414783440585204ull, 335468293869182ull}},
{{10918812468246846650ull, 536749270190691ull}},
{{5045701159855566996ull, 429399416152553ull}},
{{11415258557368274243ull, 343519532922042ull}},
{{3507018432821597497ull, 549631252675268ull}},
{{10184312375741098644ull, 439705002140214ull}},
{{11836798715334789238ull, 351764001712171ull}},
{{11560180315051842135ull, 562822402739474ull}},
{{12937493066783384031ull, 450257922191579ull}},
{{14039343268168617548ull, 360206337753263ull}},
{{163428170309163069ull, 288165070202611ull}},
{{11329531516720391880ull, 461064112324177ull}},
{{1684927583892492857ull, 368851289859342ull}},
{{12415988511339725255ull, 295081031887473ull}},
{{16176232803401650086ull, 472129651019957ull}},
{{5562288613237499422ull, 377703720815966ull}},
{{760482075848089214ull, 302162976652773ull}},
{{15974166580324584036ull, 483460762644436ull}},
{{9089984449517756906ull, 386768610115549ull}},
{{10961336374356115848ull, 309414888092439ull}},
{{6470091754744054387ull, 495063820947903ull}},
{{12554771033279064156ull, 396051056758322ull}},
{{2665119197139430678ull, 316840845406658ull}},
{{574841900681178762ull, 506945352650653ull}},
{{7838571150028763656ull, 405556282120522ull}},
{{17338903364248741894ull, 324445025696417ull}},
{{12984850123830345738ull, 519112041114268ull}},
{{17766577728548097237ull, 415289632891414ull}},
{{17902610997580388113ull, 332231706313131ull}},
{{2818735892935248718ull, 531570730101011ull}},
{{17012383973315840267ull, 425256584080808ull}},
{{2541860734426941244ull, 340205267264647ull}},
{{7756325989825016314ull, 544328427623435ull}},
{{6205060791860013051ull, 435462742098748ull}},
{{12342746262971831087ull, 348370193678998ull}},
{{16059045206013019417ull, 557392309886397ull}},
{{5468538535326594887ull, 445913847909118ull}},
{{11753528457745096556ull, 356731078327294ull}},
{{13092171580937987568ull, 285384862661835ull}},
{{2500730455791228493ull, 456615780258937ull}},
{{13068630808858713764ull, 365292624207149ull}},
{{14144253461828881334ull, 292234099365719ull}},
{{11562759094700479165ull, 467574558985151ull}},
{{5560858461018473009ull, 374059647188121ull}},
{{759337954072868084ull, 299247717750497ull}},
{{4904289541258499257ull, 478796348400795ull}},
{{3923431633006799406ull, 383037078720636ull}},
{{17896140565373080817ull, 306429662976508ull}},
{{6497732016145467369ull, 490287460762414ull}},
{{8887534427658284218ull, 392229968609931ull}},
{{3420678727384717051ull, 313783974887945ull}},
{{5473085963815547282ull, 502054359820712ull}},
{{15446515215278168795ull, 401643487856569ull}},
{{16046560986964445359ull, 321314790285255ull}},
{{7227753505433560959ull, 514103664456409ull}},
{{9471551619088759090ull, 411282931565127ull}},
{{198543665787186626ull, 329026345252102ull}},
{{4007018680001408925ull, 526442152403363ull}},
{{10584312573484947786ull, 421153721922690ull}},
{{8467450058787958229ull, 336922977538152ull}},
{{17237268908802643490ull, 539076764061043ull}},
{{2721768682816383822ull, 431261411248835ull}},
{{2177414946253107058ull, 345009128999068ull}},
{{18241259172972612585ull, 552014606398508ull}},
{{3524960894152359098ull, 441611685118807ull}},
{{13888015159547618248ull, 353289348095045ull}},
{{11110412127638094599ull, 282631478476036ull}},
{{10397961774737130712ull, 452210365561658ull}},
{{15697067049273525216ull, 361768292449326ull}},
{{8868304824676909849ull, 289414633959461ull}},
{{6810590089999235112ull, 463063414335138ull}},
{{12827169701483208736ull, 370450731468110ull}},
{{10261735761186566989ull, 296360585174488ull}},
{{12729428403156596859ull, 474176936279181ull}},
{{6494193907783367164ull, 379341549023345ull}},
{{5195355126226693731ull, 303473239218676ull}},
{{933870572478889324ull, 485557182749882ull}},
{{11815142902208842429ull, 388445746199905ull}},
{{9452114321767073943ull, 310756596959924ull}},
{{4055336470601587339ull, 497210555135879ull}},
{{6933617991223180194ull, 397768444108703ull}},
{{12925592022462364802ull, 318214755286962ull}},
{{5923551976972142390ull, 509143608459140ull}},
{{4738841581577713912ull, 407314886767312ull}},
{{14859119709487902099ull, 325851909413849ull}},
{{12706545090954912390ull, 521363055062159ull}},
{{13854584887505840235ull, 417090444049727ull}},
{{3704970280520851541ull, 333672355239782ull}},
{{9617301263575272790ull, 533875768383651ull}},
{{4004492196118307908ull, 427100614706921ull}},
{{17960989015862287619ull, 341680491765536ull}},
{{2912140722186287929ull, 546688786824859ull}},
{{6019061392490940666ull, 437351029459887ull}},
{{15883295558218483503ull, 349880823567909ull}},
{{14345226448923842635ull, 559809317708655ull}},
{{11476181159139074108ull, 447847454166924ull}},
{{12870293742053169609ull, 358277963333539ull}},
{{13985583808384446011ull, 286622370666831ull}},
{{14998236463931292971ull, 458595793066930ull}},
{{11998589171145034376ull, 366876634453544ull}},
{{13288220151657937824ull, 293501307562835ull}},
{{2814408168943148903ull, 469602092100537ull}},
{{13319572979380250092ull, 375681673680429ull}},
{{14345007198246110397ull, 300545338944343ull}},
{{815918628742314696ull, 480872542310950ull}},
{{652734902993851757ull, 384698033848760ull}},
{{522187922395081405ull, 307758427079008ull}},
{{15592895934799771541ull, 492413483326412ull}},
{{5095619118355996587ull, 393930786661130ull}},
{{4076495294684797269ull, 315144629328904ull}},
{{13901090100979496277ull, 504231406926246ull}},
{{7431523266041686699ull, 403385125540997ull}},
{{17013265057059080328ull, 322708100432797ull}},
{{12463828832326887233ull, 516332960692476ull}},
{{6281714251119599463ull, 413066368553981ull}},
{{1336022586153769247ull, 330453094843185ull}},
{{2137636137846030796ull, 528724951749096ull}},
{{16467504169244465929ull, 422979961399276ull}},
{{9484654520653662420ull, 338383969119421ull}},
{{7796749603562039226ull, 541414350591074ull}},
{{9926748497591541704ull, 433131480472859ull}},
{{11630747612815143686ull, 346505184378287ull}},
{{3851800921536588606ull, 554408295005260ull}},
{{3081440737229270884ull, 443526636004208ull}},
{{9843850219267237354ull, 354821308803366ull}},
{{4185731360671879560ull, 283857047042693ull}},
{{3007821362333096973ull, 454171275268309ull}},
{{6095605904608387901ull, 363337020214647ull}},
{{15944531167912441290ull, 290669616171717ull}},
{{10753854609692264772ull, 465071385874748ull}},
{{15981781317237632464ull, 372057108699798ull}},
{{1717378609564375002ull, 297645686959839ull}},
{{10126503404786820649ull, 476233099135742ull}},
{{722505094345635873ull, 380986479308594ull}},
{{4267352890218419021ull, 304789183446875ull}},
{{6827764624349470435ull, 487662693515000ull}},
{{5462211699479576348ull, 390130154812000ull}},
{{4369769359583661078ull, 312104123849600ull}},
{{6991630975333857725ull, 499366598159360ull}},
{{5593304780267086180ull, 399493278527488ull}},
{{11853341453697489590ull, 319594622821990ull}},
{{518602252206431729ull, 511351396515185ull}},
{{414881801765145383ull, 409081117212148ull}},
{{7710603070895936953ull, 327264893769718ull}},
{{8647616098691588801ull, 523623830031549ull}},
{{10607441693695181364ull, 418899064025239ull}},
{{12175302169698055414ull, 335119251220191ull}},
{{12101785842033068017ull, 536190801952306ull}},
{{5992079858884544090ull, 428952641561845ull}},
{{4793663887107635272ull, 343162113249476ull}},
{{291164589888395789ull, 549059381199162ull}},
{{11300978116136447601ull, 439247504959329ull}},
{{12730131307651068404ull, 351398003967463ull}},
{{16678861277499799123ull, 562236806347941ull}},
{{9653740207257928975ull, 449789445078353ull}},
{{15101689795290163826ull, 359831556062682ull}},
{{4702654206748310415ull, 287865244850146ull}},
{{145549101313476017ull, 460584391760234ull}},
{{3805788095792691137ull, 368467513408187ull}},
{{14112676920859883879ull, 294774010726549ull}},
{{11512236629150083237ull, 471638417162479ull}},
{{12899138118061976913ull, 377310733729983ull}},
{{17698008123933402177ull, 301848586983986ull}},
{{2491371295100071220ull, 482957739174379ull}},
{{5682445850821967299ull, 386366191339503ull}},
{{11924654310141394486ull, 309092953071602ull}},
{{4322051637258589885ull, 494548724914564ull}},
{{7146990124548782231ull, 395638979931651ull}},
{{2028243284897115462ull, 316511183945321ull}},
{{14313235700061115708ull, 506417894312513ull}},
{{382542115823161597ull, 405134315450011ull}},
{{15063428951626170570ull, 324107452360008ull}},
{{1965393434150410974ull, 518571923776014ull}},
{{5261663562062239102ull, 414857539020811ull}},
{{519982034907880958ull, 331886031216649ull}},
{{8210668885336430180ull, 531017649946638ull}},
{{13947232737752964790ull, 424814119957310ull}},
{{11157786190202371832ull, 339851295965848ull}},
{{14163109089581884608ull, 543762073545357ull}},
{{3951789642181687040ull, 435009658836286ull}},
{{17918826972712990925ull, 348007727069028ull}},
{{6534030267889323541ull, 556812363310446ull}},
{{1537875399569548509ull, 445449890648357ull}},
{{12298346763881369777ull, 356359912518685ull}},
{{9838677411105095822ull, 285087930014948ull}},
{{12052535043026242992ull, 456140688023917ull}},
{{2263330404937173747ull, 364912550419134ull}},
{{5500013138691649320ull, 291930040335307ull}},
{{12489369836648549236ull, 467088064536491ull}},
{{6302147054576929066ull, 373670451629193ull}},
{{12420415273145363899ull, 298936361303354ull}},
{{8804617992806851269ull, 478298178085367ull}},
{{18111740838471211985ull, 382638542468293ull}},
{{3421346226551238618ull, 306110833974635ull}},
{{5474153962481981789ull, 489777334359416ull}},
{{689974355243675108ull, 391821867487533ull}},
{{7930677113678760733ull, 313457493990026ull}},
{{5310385752402196526ull, 501531990384042ull}},
{{15316355046147488190ull, 401225592307233ull}},
{{1185037592692259583ull, 320980473845787ull}},
{{5585408963049525656ull, 513568758153259ull}},
{{8157675985181530848ull, 410855006522607ull}},
{{17594187232370955648ull, 328684005218085ull}},
{{9703955498083977421ull, 525894408348937ull}},
{{384466768983361290ull, 420715526679150ull}},
{{307573415186689032ull, 336572421343320ull}},
{{492117464298702451ull, 538515874149312ull}},
{{11461740415664692931ull, 430812699319449ull}},
{{12858741147273664668ull, 344650159455559ull}},
{{9505939391412132499ull, 551440255128895ull}},
{{7604751513129705999ull, 441152204103116ull}},
{{2394452395761854476ull, 352921763282493ull}},
{{9294259546093304227ull, 282337410625994ull}},
{{3802768829523555794ull, 451739857001591ull}},
{{17799610322586485928ull, 361391885601272ull}},
{{6860990628585368096ull, 289113508481018ull}},
{{7288236190994678630ull, 462581613569629ull}},
{{9519937767537653227ull, 370065290855703ull}},
{{14994647843513943228ull, 296052232684562ull}},
{{9234041290654667873ull, 473683572295300ull}},
{{7387233032523734298ull, 378946857836240ull}},
{{5909786426018987438ull, 303157486268992ull}},
{{13145007096372290225ull, 485051978030387ull}},
{{3137308047614011533ull, 388041582424310ull}},
{{2509846438091209226ull, 310433265939448ull}},
{{326405486204024439ull, 496693225503117ull}},
{{11329170833188950521ull, 397354580402493ull}},
{{16442034296034981063ull, 317883664321994ull}},
{{15239208429430238732ull, 508613862915191ull}},
{{8502017928802280662ull, 406891090332153ull}},
{{14180311972525645176ull, 325512872265722ull}},
{{7931103897073390989ull, 520820595625156ull}},
{{2655534302916802468ull, 416656476500125ull}},
{{2124427442333441974ull, 333325181200100ull}},
{{3399083907733507159ull, 533320289920160ull}},
{{2719267126186805727ull, 426656231936128ull}},
{{9554111330433265228ull, 341324985548902ull}},
{{529182869725583072ull, 546119976878244ull}},
{{4112695110522376781ull, 436895981502595ull}},
{{3290156088417901425ull, 349516785202076ull}},
{{16332296185694373249ull, 559226856323321ull}},
{{9376488133813588276ull, 447381485058657ull}},
{{122492877567049975ull, 357905188046926ull}},
{{14855389561021281272ull, 286324150437540ull}},
{{5321879223924498420ull, 458118640700065ull}},
{{4257503379139598736ull, 366494912560052ull}},
{{14474049147537409958ull, 293195930048041ull}},
{{15779781006576035287ull, 469113488076866ull}},
{{8934475990518917906ull, 375290790461493ull}},
{{14526278421898954971ull, 300232632369194ull}},
{{12173999030812596985ull, 480372211790711ull}},
{{6049850409908167265ull, 384297769432569ull}},
{{8529229142668444135ull, 307438215546055ull}},
{{13646766628269510616ull, 491901144873688ull}},
{{18296110932099429139ull, 393520915898950ull}},
{{14636888745679543311ull, 314816732719160ull}},
{{4972277919377717682ull, 503706772350657ull}},
{{15045868779727905115ull, 402965417880525ull}},
{{12036695023782324092ull, 322372334304420ull}},
{{811967964342166932ull, 515795734887073ull}},
{{8028272000957554192ull, 412636587909658ull}},
{{13801315230249864000ull, 330109270327726ull}},
{{14703406738915961753ull, 528174832524362ull}},
{{4384027761648948756ull, 422539866019490ull}},
{{3507222209319159005ull, 338031892815592ull}},
{{9300904349652564731ull, 540851028504947ull}},
{{62025850238231138ull, 432680822803958ull}},
{{7428318309674405557ull, 346144658243166ull}},
{{4506611665995228245ull, 553831453189066ull}},
{{18362684591763823889ull, 443065162551252ull}},
{{7311450043927238465ull, 354452130041002ull}},
{{16917206479367521741ull, 283561704032801ull}},
{{1242088663794662524ull, 453698726452483ull}},
{{8372368560519550665ull, 362958981161986ull}},
{{3008546033673730209ull, 290367184929589ull}},
{{12192371283361788981ull, 464587495887342ull}},
{{2375199397205610538ull, 371669996709874ull}},
{{5589508332506398754ull, 297335997367899ull}},
{{16321910961494058653ull, 475737595788638ull}},
{{1989482324969515952ull, 380590076630911ull}},
{{16348981118943254055ull, 304472061304728ull}},
{{4022276901857744549ull, 487155298087566ull}},
{{17975216780453836932ull, 389724238470052ull}},
{{7001475794879248899ull, 311779390776042ull}},
{{14891710086548708561ull, 498847025241667ull}},
{{4534670439755146203ull, 399077620193334ull}},
{{7317085166546027285ull, 319262096154667ull}},
{{15396685081215553980ull, 510819353847467ull}},
{{4938650435488622537ull, 408655483077974ull}},
{{7640269163132808353ull, 326924386462379ull}},
{{1156384216786762396ull, 523079018339807ull}},
{{11993153817655140886ull, 418463214671845ull}},
{{9594523054124112709ull, 334770571737476ull}},
{{7972539257114759688ull, 535632914779962ull}},
{{17446077849917538720ull, 428506331823969ull}},
{{17646211094675941299ull, 342805065459175ull}},
{{9787193677771954462ull, 548488104734681ull}},
{{4140406127475653247ull, 438790483787745ull}},
{{3312324901980522597ull, 351032387030196ull}},
{{16367766287394567125ull, 561651819248313ull}},
{{2026166585689922731ull, 449321455398651ull}},
{{16378328527519579477ull, 359457164318920ull}},
{{13102662822015663582ull, 287565731455136ull}},
{{13585562885741241085ull, 460105170328218ull}},
{{18247147938076813514ull, 368084136262574ull}},
{{18287067165203361134ull, 294467309010059ull}},
{{18191261020099646846ull, 471147694416095ull}},
{{14553008816079717476ull, 376918155532876ull}},
{{7953058238121863658ull, 301534524426301ull}},
{{5346195551511161206ull, 482455239082082ull}},
{{15345002885434659935ull, 385964191265665ull}},
{{12276002308347727948ull, 308771353012532ull}},
{{4884208434388723424ull, 494034164820052ull}},
{{14975413191736709708ull, 395227331856041ull}},
{{8290981738647457443ull, 316181865484833ull}},
{{9576221967094021587ull, 505890984775733ull}},
{{15039675203159037916ull, 404712787820586ull}},
{{8342391347785320009ull, 323770230256469ull}},
{{2279779712230781045ull, 518032368410351ull}},
{{16581219028752266129ull, 414425894728280ull}},
{{13264975223001812903ull, 331540715782624ull}},
{{10155913912577169676ull, 530465145252199ull}},
{{11814079944803646064ull, 424372116201759ull}},
{{13140612770584827174ull, 339497692961407ull}},
{{6267585173968082186ull, 543196308738252ull}},
{{16082114583400196718ull, 434557046990601ull}},
{{9176342851978247051ull, 347645637592481ull}},
{{7303450933681374636ull, 556233020147970ull}},
{{5842760746945099709ull, 444986416118376ull}},
{{984859782814169444ull, 355989132894701ull}},
{{15545283085218976848ull, 284791306315760ull}},
{{6425708862640811340ull, 455666090105217ull}},
{{16208613534338380042ull, 364532872084173ull}},
{{1898844383244973064ull, 291626297667339ull}},
{{10416848642675777549ull, 466602076267742ull}},
{{954781284656801392ull, 373281661014194ull}},
{{4453173842467351437ull, 298625328811355ull}},
{{7125078147947762300ull, 477800526098168ull}},
{{13078760147842030486ull, 382240420878534ull}},
{{14152356933015534712ull, 305792336702827ull}},
{{7886375833857214247ull, 489267738724524ull}},
{{9998449481827681720ull, 391414190979619ull}},
{{11688108400204055699ull, 313131352783695ull}},
{{254229366616937503ull, 501010164453913ull}},
{{7582081122777370649ull, 400808131563130ull}},
{{6065664898221896519ull, 320646505250504ull}},
{{17083761466638855077ull, 513034408400806ull}},
{{9977660358569173738ull, 410427526720645ull}},
{{7982128286855338991ull, 328342021376516ull}},
{{5392707629484721739ull, 525347234202426ull}},
{{624817288845867068ull, 420277787361941ull}},
{{15257249090044334947ull, 336222229889552ull}},
{{9654203285103294623ull, 537955567823284ull}},
{{11412711442824546021ull, 430364454258627ull}},
{{1751471524775816170ull, 344291563406902ull}},
{{6491703254383216196ull, 550866501451043ull}},
{{12572060232990393603ull, 440693201160834ull}},
{{13746997001134225206ull, 352554560928667ull}},
{{3618899971423559518ull, 282043648742934ull}},
{{13168937583761515876ull, 451269837988694ull}},
{{14224498881751123024ull, 361015870390955ull}},
{{11379599105400898419ull, 288812696312764ull}},
{{7139312124415706501ull, 462100314100423ull}},
{{13090147329016385847ull, 369680251280338ull}},
{{17850815492696929324ull, 295744201024270ull}},
{{10114560714605535302ull, 473190721638833ull}},
{{15470346201168248888ull, 378552577311066ull}},
{{8686928146192688787ull, 302842061848853ull}},
{{10209736219166391737ull, 484547298958165ull}},
{{8167788975333113389ull, 387637839166532ull}},
{{17602277624492221681ull, 310110271333225ull}},
{{9716900125478003074ull, 496176434133161ull}},
{{4084171285640492136ull, 396941147306529ull}},
{{6956685843254304032ull, 317552917845223ull}},
{{7441348534464976128ull, 508084668552357ull}},
{{17021125271797711872ull, 406467734841885ull}},
{{13616900217438169497ull, 325174187873508ull}},
{{18097691533159160873ull, 520278700597613ull}},
{{3410106782301597729ull, 416222960478091ull}},
{{17485480684808919476ull, 332978368382472ull}},
{{13219373836726629868ull, 532765389411956ull}},
{{6886150254639393571ull, 426212311529565ull}},
{{5508920203711514857ull, 340969849223652ull}},
{{12503621140680334095ull, 545551758757843ull}},
{{17381594542028087922ull, 436441407006274ull}},
{{17594624448364380661ull, 349153125605019ull}},
{{17083352673157278088ull, 558645000968031ull}},
{{9977333323783912147ull, 446916000774425ull}},
{{7981866659027129718ull, 357532800619540ull}},
{{6385493327221703774ull, 286026240495632ull}},
{{13906138138296636362ull, 457641984793011ull}},
{{7435561695895398766ull, 366113587834409ull}},
{{9637798171458229336ull, 292890870267527ull}},
{{663081815365525645ull, 468625392428044ull}},
{{4219814267034330839ull, 374900313942435ull}},
{{3375851413627464671ull, 299920251153948ull}},
{{1712013447062033151ull, 479872401846317ull}},
{{12437657201875357490ull, 383897921477053ull}},
{{17328823390984106639ull, 307118337181642ull}},
{{12968722166606929329ull, 491389339490628ull}},
{{17753675362769364110ull, 393111471592502ull}},
{{6824242660731670641ull, 314489177274002ull}},
{{14608137071912583349ull, 503182683638403ull}},
{{618463213304335710ull, 402546146910723ull}},
{{7873468200127289214ull, 322036917528578ull}},
{{8908200305461752420ull, 515259068045725ull}},
{{7126560244369401936ull, 412207254436580ull}},
{{5701248195495521549ull, 329765803549264ull}},
{{16500694742276655124ull, 527625285678822ull}},
{{5821858164337503453ull, 422100228543058ull}},
{{12036184160953823409ull, 337680182834446ull}},
{{11879197028042296808ull, 540288292535114ull}},
{{13192706437175747769ull, 432230634028091ull}},
{{6864816334998687892ull, 345784507222473ull}},
{{7294357321255990305ull, 553255211555957ull}},
{{16903532301230523213ull, 442604169244765ull}},
{{13522825840984418570ull, 354083335395812ull}},
{{3439563043303714210ull, 283266668316650ull}},
{{5503300869285942736ull, 453226669306640ull}},
{{4402640695428754189ull, 362581335445312ull}},
{{14590159000568734320ull, 290065068356249ull}},
{{12276207956684243943ull, 464104109369999ull}},
{{13510315180089305478ull, 371283287495999ull}},
{{14497600958813354705ull, 297026629996799ull}},
{{12128115089875636559ull, 475242607994879ull}},
{{13391840886642419571ull, 380194086395903ull}},
{{18092170338797756303ull, 304155269116722ull}},
{{14190077283108768792ull, 486648430586756ull}},
{{7662713011745104710ull, 389318744469405ull}},
{{6130170409396083768ull, 311454995575524ull}},
{{17186970284517554676ull, 498327992920838ull}},
{{2681529783388312771ull, 398662394336671ull}},
{{16902619085678291509ull, 318929915469336ull}},
{{1218748833891894153ull, 510287864750939ull}},
{{4664347881855425645ull, 408230291800751ull}},
{{42129490742430193ull, 326584233440601ull}},
{{11135453629413619279ull, 522534773504961ull}},
{{5219014088788985100ull, 418027818803969ull}},
{{7864560085773098403ull, 334422255043175ull}},
{{12583296137236957445ull, 535075608069080ull}},
{{10066636909789565956ull, 428060486455264ull}},
{{11742658342573563088ull, 342448389164211ull}},
{{11409555718633880294ull, 547917422662738ull}},
{{16506342204390924882ull, 438333938130190ull}},
{{13205073763512739905ull, 350667150504152ull}},
{{6370722762652742556ull, 561067440806644ull}},
{{8785927024864104368ull, 448853952645315ull}},
{{7028741619891283494ull, 359083162116252ull}},
{{16691039740138757765ull, 287266529693001ull}},
{{880221881028640162ull, 459626447508803ull}},
{{8082875134306732776ull, 367701158007042ull}},
{{17534346551671117190ull, 294160926405633ull}},
{{5918861594222325565ull, 470657482249014ull}},
{{8424438090119770775ull, 376525985799211ull}},
{{3050201657353906297ull, 301220788639369ull}},
{{12259020281250070722ull, 481953261822990ull}},
{{9807216225000056577ull, 385562609458392ull}},
{{467075350516224615ull, 308450087566714ull}},
{{8126018190309780031ull, 493520140106742ull}},
{{17568860996473554994ull, 394816112085393ull}},
{{2987042352953113026ull, 315852889668315ull}},
{{4779267764724980842ull, 505364623469304ull}},
{{7512763026521894996ull, 404291698775443ull}},
{{13388908050701336643ull, 323433359020354ull}},
{{10354206436896407660ull, 517493374432567ull}},
{{904667520033305482ull, 413994699546054ull}},
{{4413082830768554708ull, 331195759636843ull}},
{{3371583714487777211ull, 529913215418949ull}},
{{6386615786332132092ull, 423930572335159ull}},
{{8798641443807615996ull, 339144457868127ull}},
{{17767175124834095918ull, 542631132589003ull}},
{{3145693655641545764ull, 434104906071203ull}},
{{9895252553997057258ull, 347283924856962ull}},
{{1075008827427650320ull, 555654279771140ull}},
{{860007061942120256ull, 444523423816912ull}},
{{11756052093779427174ull, 355618739053529ull}},
{{13094190489765452062ull, 284494991242823ull}},
{{17261355968882812977ull, 455191985988517ull}},
{{6430387145622429735ull, 364153588790814ull}},
{{8833658531239854111ull, 291322871032651ull}},
{{6755156020499945932ull, 466116593652242ull}},
{{16472171260625687715ull, 372893274921793ull}},
{{2109690564274819202ull, 298314619937435ull}},
{{3375504902839710724ull, 477303391899896ull}},
{{17457799181239409872ull, 381842713519916ull}},
{{10276890530249617574ull, 305474170815933ull}},
{{12753676033657477796ull, 488758673305493ull}},
{{17581638456409802883ull, 391006938644394ull}},
{{17754659579869752629ull, 312805550915515ull}},
{{9960711254082052591ull, 500488881464825ull}},
{{7968569003265642073ull, 400391105171860ull}},
{{6374855202612513658ull, 320312884137488ull}},
{{6510419509438111530ull, 512500614619981ull}},
{{1518986792808578901ull, 410000491695985ull}},
{{1215189434246863121ull, 328000393356788ull}},
{{16701698353762622286ull, 524800629370860ull}},
{{13361358683010097829ull, 419840503496688ull}},
{{18067784575891898909ull, 335872402797350ull}},
{{10461711247717486639ull, 537395844475761ull}},
{{4680020183432078988ull, 429916675580609ull}},
{{7433364961487573514ull, 343933340464487ull}},
{{15582732753122027945ull, 550293344743179ull}},
{{16155535017239532679ull, 440234675794543ull}},
{{1856381569565895174ull, 352187740635635ull}},
{{1485105255652716139ull, 281750192508508ull}},
{{17133563668011987115ull, 450800308013612ull}},
{{6328153304925769046ull, 360640246410890ull}},
{{5062522643940615237ull, 288512197128712ull}},
{{11789385045046894702ull, 461619515405939ull}},
{{13120856850779426085ull, 369295612324751ull}},
{{6807336665881630544ull, 295436489859801ull}},
{{3513041035926788225ull, 472698383775682ull}},
{{13878479272967161550ull, 378158707020545ull}},
{{11102783418373729240ull, 302526965616436ull}},
{{10385755839914146137ull, 484043144986298ull}},
{{15687302301415137556ull, 387234515989038ull}},
{{1481795396906379075ull, 309787612791231ull}},
{{13438919079275937490ull, 495660180465969ull}},
{{14440484078162660315ull, 396528144372775ull}},
{{11552387262530128252ull, 317222515498220ull}},
{{37075546338653588ull, 507556024797153ull}},
{{7408358066554743516ull, 406044819837722ull}},
{{16994732897469525783ull, 324835855870177ull}},
{{12434177376983599960ull, 519737369392284ull}},
{{13636690716328790291ull, 415789895513827ull}},
{{3530654943579211586ull, 332631916411062ull}},
{{9338396724468648861ull, 532211066257699ull}},
{{11160066194316829412ull, 425768853006159ull}},
{{12617401770195373853ull, 340615082404927ull}},
{{5430447573344956872ull, 544984131847884ull}},
{{8033706873417875821ull, 435987305478307ull}},
{{17495011942960031626ull, 348789844382645ull}},
{{9545275035026498986ull, 558063751012233ull}},
{{15014917657505019835ull, 446451000809786ull}},
{{8322585311262105545ull, 357160800647829ull}},
{{10347417063751594759ull, 285728640518263ull}},
{{12866518487260641291ull, 457165824829221ull}},
{{6603865975066602710ull, 365732659863377ull}},
{{16351139224279013137ull, 292586127890701ull}},
{{336381055653048758ull, 468137804625123ull}},
{{7647802474006259652ull, 374510243700098ull}},
{{13496939608688828368ull, 299608194960078ull}},
{{17905754559160215066ull, 479373111936125ull}},
{{14324603647328172053ull, 383498489548900ull}},
{{11459682917862537642ull, 306798791639120ull}},
{{18335492668580060228ull, 490878066622592ull}},
{{7289696505380227536ull, 392702453298074ull}},
{{9521106019046092352ull, 314161962638459ull}},
{{4165723186248016794ull, 502659140221535ull}},
{{3332578548998413435ull, 402127312177228ull}},
{{10044760468682551394ull, 321701849741782ull}},
{{1314221490924440938ull, 514722959586852ull}},
{{12119423636965283720ull, 411778367669481ull}},
{{6006190094830316653ull, 329422694135585ull}},
{{9609904151728506645ull, 527076310616936ull}},
{{3998574506640894992ull, 421661048493549ull}},
{{6888208420054626317ull, 337328838794839ull}},
{{18399831101571222754ull, 539726142071742ull}},
{{7341167251773157557ull, 431780913657394ull}},
{{9562282616160436368ull, 345424730925915ull}},
{{15299652185856698190ull, 552679569481464ull}},
{{15929070563427268875ull, 442143655585171ull}},
{{9053907635999904777ull, 353714924468137ull}},
{{18311172553025654791ull, 282971939574509ull}},
{{18229829640615316696ull, 452755103319215ull}},
{{14583863712492253357ull, 362204082655372ull}},
{{4288393340509982039ull, 289763266124298ull}},
{{3172080530074060939ull, 463621225798877ull}},
{{13605710868284979721ull, 370896980639101ull}},
{{7195219879886073453ull, 296717584511281ull}},
{{4133654178333896879ull, 474748135218050ull}},
{{3306923342667117503ull, 379798508174440ull}},
{{2645538674133694003ull, 303838806539552ull}},
{{7922210693355820728ull, 486142090463283ull}},
{{13716466184168477228ull, 388913672370626ull}},
{{7283824132592871459ull, 311130937896501ull}},
{{4275420982664773689ull, 497809500634402ull}},
{{14488383230357549921ull, 398247600507521ull}},
{{7901357769544129613ull, 318598080406017ull}},
{{16331521246012517705ull, 509756928649627ull}},
{{5686519367326193517ull, 407805542919702ull}},
{{15617261938086685783ull, 326244434335761ull}},
{{17608921471454876607ull, 521991094937218ull}},
{{3019090732938170316ull, 417592875949775ull}},
{{2415272586350536253ull, 334074300759820ull}},
{{3864436138160858005ull, 534518881215712ull}},
{{14159595354754417373ull, 427615104972569ull}},
{{15017025098545444222ull, 342092083978055ull}},
{{5580496083963159139ull, 547347334364889ull}},
{{8153745681912437634ull, 437877867491911ull}},
{{2833647730788039784ull, 350302293993529ull}},
{{11912533998744684301ull, 560483670389646ull}},
{{5840678384253837118ull, 448386936311717ull}},
{{15740589151628800664ull, 358709549049373ull}},
{{1524424877077309561ull, 286967639239499ull}},
{{9817777432807515945ull, 459148222783198ull}},
{{15232919575729833402ull, 367318578226558ull}},
{{1118289216358135752ull, 293854862581247ull}},
{{5478611560914927527ull, 470167780129995ull}},
{{4382889248731942021ull, 376134224103996ull}},
{{18263706657953194910ull, 300907379283196ull}},
{{3396488949531739593ull, 481451806853115ull}},
{{2717191159625391675ull, 385161445482492ull}},
{{13241799371926044309ull, 308129156385993ull}},
{{17497530180339760572ull, 493006650217589ull}},
{{17687372959013718781ull, 394405320174071ull}},
{{10460549552469064701ull, 315524256139257ull}},
{{1979484024982862229ull, 504838809822812ull}},
{{12651633664212020753ull, 403871047858249ull}},
{{13810655746111526925ull, 323096838286599ull}},
{{11029002749552712111ull, 516954941258559ull}},
{{12512551014384080012ull, 413563953006847ull}},
{{2631343182023443363ull, 330851162405478ull}},
{{520800276495599058ull, 529361859848765ull}},
{{416640221196479247ull, 423489487879012ull}},
{{11401358621182914367ull, 338791590303209ull}},
{{7174127349666932018ull, 542066544485135ull}},
{{5739301879733545614ull, 433653235588108ull}},
{{11970139133270657137ull, 346922588470486ull}},
{{11773524983749230774ull, 555076141552778ull}},
{{16797517616483205265ull, 444060913242222ull}},
{{6059316463702743566ull, 355248730593778ull}},
{{12226150800446015499ull, 284198984475022ull}},
{{4804446021745983506ull, 454718375160036ull}},
{{154208002654876481ull, 363774700128029ull}},
{{3812715216865811508ull, 291019760102423ull}},
{{2410995532243388090ull, 465631616163877ull}},
{{12996842870020441442ull, 372505292931101ull}},
{{6708125481274442830ull, 298004234344881ull}},
{{3354303140555287882ull, 476806774951810ull}},
{{2683442512444230305ull, 381445419961448ull}},
{{9525451639439204891ull, 305156335969158ull}},
{{11551373808360817502ull, 488250137550653ull}},
{{16619796676172474648ull, 390600110040522ull}},
{{5917139711454159072ull, 312480088032418ull}},
{{5778074723584744192ull, 499968140851869ull}},
{{8311808593609705677ull, 399974512681495ull}},
{{6649446874887764541ull, 319979610145196ull}},
{{3260417370336602620ull, 511967376232314ull}},
{{6297682711011192419ull, 409573900985851ull}},
{{1348797354067043612ull, 327659120788681ull}},
{{13226122210733000749ull, 524254593261889ull}},
{{14270246583328310922ull, 419403674609511ull}},
{{7726848451920738415ull, 335522939687609ull}},
{{1294911078847450494ull, 536836703500175ull}},
{{1035928863077960395ull, 429469362800140ull}},
{{828743090462368316ull, 343575490240112ull}},
{{5015337759481699629ull, 549720784384179ull}},
{{7701619022327270026ull, 439776627507343ull}},
{{13539992847345636667ull, 351821302005874ull}},
{{10595942111527287699ull, 562914083209399ull}},
{{12166102503963740482ull, 450331266567519ull}},
{{13422230817912902709ull, 360265013254015ull}},
{{10737784654330322167ull, 288212010603212ull}},
{{2423060187960874174ull, 461139216965140ull}},
{{1938448150368699339ull, 368911373572112ull}},
{{12618804964520690441ull, 295129098857689ull}},
{{9122041499007373736ull, 472206558172303ull}},
{{14676330828689719635ull, 377765246537842ull}},
{{4362367033467955062ull, 302212197230274ull}},
{{14358484883032548746ull, 483539515568438ull}},
{{418741462200308027ull, 386831612454751ull}},
{{15092388428727887714ull, 309465289963800ull}},
{{5701077412255068727ull, 495144463942081ull}},
{{871513115062144658ull, 396115571153665ull}},
{{697210492049715726ull, 316892456922932ull}},
{{4804885602021455486ull, 507027931076691ull}},
{{154559666875254065ull, 405622344861353ull}},
{{7502345362984023899ull, 324497875889082ull}},
{{15693101395516348561ull, 519196601422531ull}},
{{8865132301671168526ull, 415357281138025ull}},
{{7092105841336934820ull, 332285824910420ull}},
{{11347369346139095713ull, 531657319856672ull}},
{{1699197847427455924ull, 425325855885338ull}},
{{8738055907425785385ull, 340260684708270ull}},
{{13980889451881256617ull, 544417095533232ull}},
{{3806013932021184647ull, 435533676426586ull}},
{{17802206404584589010ull, 348426941141268ull}},
{{6347437358883880478ull, 557483105826030ull}},
{{5077949887107104382ull, 445986484660824ull}},
{{7751708724427593829ull, 356789187728659ull}},
{{9890715794283985386ull, 285431350182927ull}},
{{1067750011886735325ull, 456690160292684ull}},
{{4543548824251298583ull, 365352128234147ull}},
{{14702885503626769836ull, 292281702587317ull}},
{{8767221546835190445ull, 467650724139708ull}},
{{14392474866951973003ull, 374120579311766ull}},
{{7824631078819668079ull, 299296463449413ull}},
{{8830060911369558603ull, 478874341519061ull}},
{{3374699914353736559ull, 383099473215249ull}},
{{6389108746224899570ull, 306479578572199ull}},
{{17601271623443659959ull, 490367325715518ull}},
{{3012970854529196998ull, 392293860572415ull}},
{{2410376683623357598ull, 313835088457932ull}},
{{7545951508539282481ull, 502136141532691ull}},
{{2347412392089515661ull, 401708913226153ull}},
{{9256627543155433175ull, 321367130580922ull}},
{{53208810081051788ull, 514187408929476ull}},
{{14799962307032482723ull, 411349927143580ull}},
{{11839969845625986178ull, 329079941714864ull}},
{{7875905308775846916ull, 526527906743783ull}},
{{13679421876504498179ull, 421222325395026ull}},
{{7254188686461688220ull, 336977860316021ull}},
{{4228004268854880506ull, 539164576505634ull}},
{{7071752229825814728ull, 431331661204507ull}},
{{16725448228086382752ull, 345065328963605ull}},
{{8313973091228660787ull, 552104526341769ull}},
{{10340527287724838953ull, 441683621073415ull}},
{{8272421830179871162ull, 353346896858732ull}},
{{17685983908369627899ull, 282677517486985ull}},
{{9850830179681853023ull, 452284027979177ull}},
{{501966514261661772ull, 361827222383342ull}},
{{11469619655635060387ull, 289461777906673ull}},
{{14662042634274186296ull, 463138844650677ull}},
{{4350936477935528391ull, 370511075720542ull}},
{{14548795626574153682ull, 296408860576433ull}},
{{1141980114067183952ull, 474254176922294ull}},
{{4602932905995657485ull, 379403341537835ull}},
{{3682346324796525988ull, 303522673230268ull}},
{{2202405304932531258ull, 485636277168429ull}},
{{5451273058687935329ull, 388509021734743ull}},
{{11739716076434168910ull, 310807217387794ull}},
{{7715499278068939286ull, 497291547820471ull}},
{{2483050607713241106ull, 397833238256377ull}},
{{13054486930396323854ull, 318266590605101ull}},
{{13508481459150297520ull, 509226544968162ull}},
{{3428087537836417370ull, 407381235974530ull}},
{{2742470030269133896ull, 325904988779624ull}},
{{11766649677914434880ull, 521447982047398ull}},
{{16792017371815368550ull, 417158385637918ull}},
{{2365567453226563870ull, 333726708510335ull}},
{{3784907925162502193ull, 533962733616536ull}},
{{17785321599097643047ull, 427170186893228ull}},
{{3160210835052383468ull, 341736149514583ull}},
{{1366988521341903226ull, 546777839223333ull}},
{{8472288446557343227ull, 437422271378666ull}},
{{3088481942503964258ull, 349937817102933ull}},
{{1252222293264432490ull, 559900507364693ull}},
{{8380475464095366639ull, 447920405891754ull}},
{{10393729186018203634ull, 358336324713403ull}},
{{15693680978298383553ull, 286669059770722ull}},
{{10352494306309772393ull, 458670495633156ull}},
{{4592646630305907591ull, 366936396506525ull}},
{{3674117304244726073ull, 293549117205220ull}},
{{5878587686791561717ull, 469678587528352ull}},
{{15770916593658980343ull, 375742870022681ull}},
{{8927384460185273951ull, 300594296018145ull}},
{{14283815136296438322ull, 480950873629032ull}},
{{4048354479553330011ull, 384760698903226ull}},
{{17996078842610305302ull, 307808559122580ull}},
{{10346982074466936867ull, 492493694596129ull}},
{{11966934474315459817ull, 393994955676903ull}},
{{16952245208936188500ull, 315195964541522ull}},
{{12366197075330260307ull, 504313543266436ull}},
{{6203608845522297922ull, 403450834613149ull}},
{{8652235891159748661ull, 322760667690519ull}},
{{2775530981629866888ull, 516417068304831ull}},
{{16977820044271534803ull, 413133654643864ull}},
{{17271604850159138166ull, 330506923715091ull}},
{{1809126057061248803ull, 528811077944147ull}},
{{12515347289874730012ull, 423048862355317ull}},
{{2633580202415963363ull, 338439089884254ull}},
{{11592425953349362027ull, 541502543814806ull}},
{{5584591947937579299ull, 433202035051845ull}},
{{4467673558350063439ull, 346561628041476ull}},
{{18216324137585832472ull, 554498604866361ull}},
{{10883710495326755654ull, 443598883893089ull}},
{{12396317211003314846ull, 354879107114471ull}},
{{6227704954060741554ull, 283903285691577ull}},
{{13653676741239096810ull, 454245257106523ull}},
{{18301639022475098094ull, 363396205685218ull}},
{{3573264773754347506ull, 290716964548175ull}},
{{5717223638006956009ull, 465147143277080ull}},
{{4573778910405564807ull, 372117714621664ull}},
{{7348371943066362169ull, 297694171697331ull}},
{{4378697479422358824ull, 476310674715730ull}},
{{3502957983537887059ull, 381048539772584ull}},
{{6491715201572219970ull, 304838831818067ull}},
{{14076093137257462276ull, 487742130908907ull}},
{{3882176880322149174ull, 390193704727126ull}},
{{17863136763225360632ull, 312154963781700ull}},
{{10134274747451025396ull, 499447942050721ull}},
{{4418070983218909993ull, 399558353640577ull}},
{{14602503230800858964ull, 319646682912461ull}},
{{15985307539797553697ull, 511434692659938ull}},
{{1720199587612311988ull, 409147754127951ull}},
{{16133554929057490883ull, 327318203302360ull}},
{{7366943812782433797ull, 523709125283777ull}},
{{16961601494451678007ull, 418967300227021ull}},
{{9879932380819432082ull, 335173840181617ull}},
{{1050496550343450039ull, 536278144290588ull}},
{{8219094869758580678ull, 429022515432470ull}},
{{6575275895806864542ull, 343218012345976ull}},
{{3141743803807162621ull, 549148819753562ull}},
{{13581441487271461066ull, 439319055802849ull}},
{{14554502004559079176ull, 351455244642279ull}},
{{12219156763068795713ull, 562328391427647ull}},
{{2396627780971215924ull, 449862713142118ull}},
{{9295999854260793385ull, 359890170513694ull}},
{{11126148698150545031ull, 287912136410955ull}},
{{17801837917040872050ull, 460659418257528ull}},
{{3173423889406966671ull, 368527534606023ull}},
{{9917436741009393983ull, 294822027684818ull}},
{{12178549970873120049ull, 471715244295709ull}},
{{13432188791440406363ull, 377372195436567ull}},
{{3367053403668504444ull, 301897756349254ull}},
{{12765983075353427757ull, 483036410158806ull}},
{{6523437645540831882ull, 386429128127045ull}},
{{5218750116432665505ull, 309143302501636ull}},
{{971302556808444163ull, 494629284002618ull}},
{{8155739674930575976ull, 395703427202094ull}},
{{10213940554686371104ull, 316562741761675ull}},
{{16342304887498193767ull, 506500386818680ull}},
{{13073843909998555014ull, 405200309454944ull}},
{{14148423942740754334ull, 324160247563955ull}},
{{4190734234675655319ull, 518656396102329ull}},
{{7041936202482434578ull, 414925116881863ull}},
{{13012246591469768309ull, 331940093505490ull}},
{{2372850472642077678ull, 531104149608785ull}},
{{1898280378113662142ull, 424883319687028ull}},
{{8897321931974750360ull, 339906655749622ull}},
{{17925063905901510900ull, 543850649199395ull}},
{{14340051124721208720ull, 435080519359516ull}},
{{7782692085035056653ull, 348064415487613ull}},
{{8762958521314180321ull, 556903064780181ull}},
{{3321018002309433934ull, 445522451824145ull}},
{{2656814401847547147ull, 356417961459316ull}},
{{16882846780445679010ull, 285134369167452ull}},
{{12255159589745445124ull, 456214990667924ull}},
{{13493476486538266422ull, 364971992534339ull}},
{{14484130003972523461ull, 291977594027471ull}},
{{15795910376872216891ull, 467164150443954ull}},
{{16326077116239683836ull, 373731320355163ull}},
{{1992815248766016099ull, 298985056284131ull}},
{{14256550842251356728ull, 478376090054609ull}},
{{15094589488542995706ull, 382700872043687ull}},
{{4696973961350575918ull, 306160697634950ull}},
{{7515158338160921469ull, 489857116215920ull}},
{{6012126670528737175ull, 391885692972736ull}},
{{1120352521681079417ull, 313508554378189ull}},
{{9171261664173547714ull, 501613687005102ull}},
{{18405055775564569141ull, 401290949604081ull}},
{{11034695805709744989ull, 321032759683265ull}},
{{17655513289135591983ull, 513652415493224ull}},
{{17813759446050383910ull, 410921932394579ull}},
{{17940356371582217451ull, 328737545915663ull}},
{{6568477306080085982ull, 525980073465062ull}},
{{16322828289089799755ull, 420784058772049ull}},
{{16747611446013750127ull, 336627247017639ull}},
{{15728131869396269235ull, 538603595228223ull}},
{{1514459051291284418ull, 430882876182579ull}},
{{4900916055774937857ull, 344706300946063ull}},
{{4152116874497990249ull, 551530081513701ull}},
{{18079088758566033492ull, 441224065210960ull}},
{{14463271006852826793ull, 352979252168768ull}},
{{502570361256530465ull, 282383401735015ull}},
{{804112578010448744ull, 451813442776024ull}},
{{4332638877150269319ull, 361450754220819ull}},
{{7155459916462125778ull, 289160603376655ull}},
{{11448735866339401245ull, 462656965402648ull}},
{{16537686322555341642ull, 370125572322118ull}},
{{2162102613818542344ull, 296100457857695ull}},
{{3459364182109667751ull, 473760732572312ull}},
{{13835537789913465170ull, 379008586057849ull}},
{{14757779046672682459ull, 303206868846279ull}},
{{12544400030450560966ull, 485130990154047ull}},
{{2656822394876628126ull, 388104792123238ull}},
{{9504155545385123147ull, 310483833698590ull}},
{{15206648872616197036ull, 496774133917744ull}},
{{15854667912834867952ull, 397419307134195ull}},
{{12683734330267894361ull, 317935445707356ull}},
{{12915277298944810332ull, 508696713131770ull}},
{{10332221839155848265ull, 406957370505416ull}},
{{4576428656582768289ull, 325565896404333ull}},
{{3632937035790518939ull, 520905434246933ull}},
{{10285047258116235798ull, 416724347397546ull}},
{{4538688991751078315ull, 333379477918037ull}},
{{10951251201543635627ull, 533407164668859ull}},
{{12450349775976818825ull, 426725731735087ull}},
{{2581582191297634414ull, 341380585388070ull}},
{{4130531506076215062ull, 546208936620912ull}},
{{14372471649086703019ull, 436967149296729ull}},
{{15187326134011272738ull, 349573719437383ull}},
{{2163628925966574443ull, 559317951099814ull}},
{{5420251955515169877ull, 447454360879851ull}},
{{646852749670225578ull, 357963488703881ull}},
{{15274877458703821755ull, 286370790963104ull}},
{{13371757489700383839ull, 458193265540967ull}},
{{3318708362276486425ull, 366554612432774ull}},
{{6344315504563099463ull, 293243689946219ull}},
{{17529602436784779788ull, 469189903913950ull}},
{{14023681949427823830ull, 375351923131160ull}},
{{11218945559542259064ull, 300281538504928ull}},
{{14260964080525704179ull, 480450461607885ull}},
{{11408771264420563343ull, 384360369286308ull}},
{{16505714641020271321ull, 307488295429046ull}},
{{583701722439061852ull, 491981272686475ull}},
{{466961377951249481ull, 393585018149180ull}},
{{373569102360999585ull, 314868014519344ull}},
{{7976408193261419982ull, 503788823230950ull}},
{{6381126554609135986ull, 403031058584760ull}},
{{5104901243687308789ull, 322424846867808ull}},
{{4478493175157783739ull, 515879754988493ull}},
{{10961492169610047637ull, 412703803990794ull}},
{{12458542550429948433ull, 330163043192635ull}},
{{1486924006978365877ull, 528260869108217ull}},
{{12257585649808423671ull, 422608695286573ull}},
{{17184766149330559583ull, 338086956229258ull}},
{{5359532950477433394ull, 540939129966814ull}},
{{7976975175123857038ull, 432751303973451ull}},
{{2692231325357175307ull, 346201043178761ull}},
{{15375616564797211462ull, 553921669086017ull}},
{{4921795622353948523ull, 443137335268814ull}},
{{7626785312625069141ull, 354509868215051ull}},
{{2412079435358144990ull, 283607894572041ull}},
{{14927373540798762954ull, 453772631315265ull}},
{{11941898832639010363ull, 363018105052212ull}},
{{2174821436627387644ull, 290414484041770ull}},
{{3479714298603820230ull, 464663174466832ull}},
{{13851817883108787154ull, 371730539573465ull}},
{{11081454306487029723ull, 297384431658772ull}},
{{2972931631411606264ull, 475815090654036ull}},
{{17135740564096926304ull, 380652072523228ull}},
{{2640546007051810074ull, 304521658018583ull}},
{{535524796540985795ull, 487234652829733ull}},
{{7807117466716609282ull, 389787722263786ull}},
{{2556345158631377102ull, 311830177811029ull}},
{{11468849883294024011ull, 498928284497646ull}},
{{5485731091893308885ull, 399142627598117ull}},
{{15456631317740378078ull, 319314102078493ull}},
{{2594517219933142985ull, 510902563325590ull}},
{{2075613775946514388ull, 408722050660472ull}},
{{12728537464982942480ull, 326977640528377ull}},
{{5608264685005066675ull, 523164224845404ull}},
{{8175960562745963663ull, 418531379876323ull}},
{{13919466079680591577ull, 334825103901058ull}},
{{135052839037484584ull, 535720166241694ull}},
{{3797391085971897991ull, 428576132993355ull}},
{{3037912868777518392ull, 342860906394684ull}},
{{12239358219527850075ull, 548577450231494ull}},
{{13480835390364190383ull, 438861960185195ull}},
{{10784668312291352306ull, 351089568148156ull}},
{{9876771670182343044ull, 561743309037050ull}},
{{7901417336145874435ull, 449394647229640ull}},
{{6321133868916699548ull, 359515717783712ull}},
{{16124953539359090608ull, 287612574226969ull}},
{{14731879218748814003ull, 460180118763151ull}},
{{8096154560257140879ull, 368144095010521ull}},
{{2787574833463802380ull, 294515276008417ull}},
{{8149468548283994132ull, 471224441613467ull}},
{{17587621282852926275ull, 376979553290773ull}},
{{3002050582056610050ull, 301583642632619ull}},
{{12181978560774396727ull, 482533828212190ull}},
{{9745582848619517381ull, 386027062569752ull}},
{{417768649411793259ull, 308821650055802ull}},
{{4357778653800779537ull, 494114640089283ull}},
{{10864920552524444276ull, 395291712071426ull}},
{{5002587627277645098ull, 316233369657141ull}},
{{625442574160411510ull, 505973391451426ull}},
{{15257749318295970501ull, 404778713161140ull}},
{{12206199454636776400ull, 323822970528912ull}},
{{4772523868451200948ull, 518116752846260ull}},
{{3818019094760960759ull, 414493402277008ull}},
{{10433112905292589253ull, 331594721821606ull}},
{{9314283018984322159ull, 530551554914570ull}},
{{7451426415187457727ull, 424441243931656ull}},
{{2271792317408055858ull, 339552995145325ull}},
{{3634867707852889374ull, 543284792232520ull}},
{{2907894166282311499ull, 434627833786016ull}},
{{17083710591993490492ull, 347702267028812ull}},
{{12576541688221943494ull, 556323627246100ull}},
{{10061233350577554795ull, 445058901796880ull}},
{{8048986680462043836ull, 356047121437504ull}},
{{10128538159111545392ull, 284837697150003ull}},
{{12516312239836562304ull, 455740315440005ull}},
{{10013049791869249843ull, 364592252352004ull}},
{{11699788648237310198ull, 291673801881603ull}},
{{15030313022437785994ull, 466678083010565ull}},
{{12024250417950228795ull, 373342466408452ull}},
{{2240702704876362389ull, 298673973126762ull}},
{{7274473142544090146ull, 477878357002819ull}},
{{9508927328777182440ull, 382302685602255ull}},
{{7607141863021745952ull, 305842148481804ull}},
{{1103380536609062554ull, 489347437570887ull}},
{{11950750873512981013ull, 391477950056709ull}},
{{13249949513552295133ull, 313182360045367ull}},
{{6442523962716030921ull, 501091776072588ull}},
{{12532716799656645383ull, 400873420858070ull}},
{{10026173439725316306ull, 320698736686456ull}},
{{8663179874076685444ull, 513117978698330ull}},
{{6930543899261348355ull, 410494382958664ull}},
{{9233783934150989007ull, 328395506366931ull}},
{{7395356665157761765ull, 525432810187090ull}},
{{5916285332126209412ull, 420346248149672ull}},
{{15801074709926698499ull, 336276998519737ull}},
{{10524324276915076306ull, 538043197631580ull}},
{{8419459421532061045ull, 430434558105264ull}},
{{10424916351967559159ull, 344347646484211ull}},
{{9301168533664274008ull, 550956234374738ull}},
{{14819632456415239853ull, 440764987499790ull}},
{{11855705965132191882ull, 352611989999832ull}},
{{2105867142621932859ull, 282089591999866ull}},
{{14437433872420823545ull, 451343347199785ull}},
{{11549947097936658836ull, 361074677759828ull}},
{{16618655307833147715ull, 288859742207862ull}},
{{11832453233565395051ull, 462175587532580ull}},
{{9465962586852316041ull, 369740470026064ull}},
{{11262118884223763156ull, 295792376020851ull}},
{{10640692585274200403ull, 473267801633362ull}},
{{1133856438735539676ull, 378614241306690ull}},
{{907085150988431741ull, 302891393045352ull}},
{{5140685056323401109ull, 484626228872563ull}},
{{11491245674542541533ull, 387700983098050ull}},
{{9192996539634033226ull, 310160786478440ull}},
{{14708794463414453163ull, 496257258365504ull}},
{{15456384385473472853ull, 397005806692403ull}},
{{1297061064153047313ull, 317604645353923ull}},
{{16832692961612516994ull, 508167432566276ull}},
{{9776805554548103272ull, 406533946053021ull}},
{{4132095628896572294ull, 325227156842417ull}},
{{10300701820976425994ull, 520363450947867ull}},
{{861863827297320149ull, 416290760758294ull}},
{{4378839876579766442ull, 333032608606635ull}},
{{7006143802527626308ull, 532852173770616ull}},
{{1915566227280190723ull, 426281739016493ull}},
{{8911150611307973225ull, 341025391213194ull}},
{{3189794533867026190ull, 545640625941111ull}},
{{17309230886061262245ull, 436512500752888ull}},
{{2779338264623278826ull, 349210000602311ull}},
{{15514987667622977092ull, 558736000963697ull}},
{{5033292504614561027ull, 446988800770958ull}},
{{11405331633175469468ull, 357591040616766ull}},
{{5434916491798465251ull, 286072832493413ull}},
{{5006517572135634078ull, 457716531989461ull}},
{{315865242966596939ull, 366173225591569ull}},
{{3942041009115187875ull, 292938580473255ull}},
{{6307265614584300600ull, 468701728757208ull}},
{{12424510121151261126ull, 374961383005766ull}},
{{6250259282179098578ull, 299969106404613ull}},
{{6311066036744647401ull, 479950570247381ull}},
{{1359504014653807598ull, 383960456197905ull}},
{{1087603211723046078ull, 307168364958324ull}},
{{9118862768240694372ull, 491469383933318ull}},
{{14673787844076376144ull, 393175507146654ull}},
{{15428379090003011238ull, 314540405717323ull}},
{{2549313655553356042ull, 503264649147718ull}},
{{9418148553926505480ull, 402611719318174ull}},
{{11223867657883114707ull, 322089375454539ull}},
{{6890141808387252562ull, 515343000727263ull}},
{{12890811076193622696ull, 412274400581810ull}},
{{10312648860954898156ull, 329819520465448ull}},
{{12810889362785926727ull, 527711232744717ull}},
{{2870013860744920735ull, 422168986195774ull}},
{{5985359903337846911ull, 337735188956619ull}},
{{16955273474824375705ull, 540376302330590ull}},
{{13564218779859500564ull, 432301041864472ull}},
{{3472677394403779805ull, 345840833491578ull}},
{{1866935016304137365ull, 553345333586525ull}},
{{1493548013043309892ull, 442676266869220ull}},
{{1194838410434647913ull, 354141013495376ull}},
{{15713265987315359623ull, 283312810796300ull}},
{{6694481505995023781ull, 453300497274081ull}},
{{1666236390054108702ull, 362640397819265ull}},
{{1332989112043286961ull, 290112318255412ull}},
{{5822131394011169462ull, 464179709208659ull}},
{{8347053929950845892ull, 371343767366927ull}},
{{17745689588186407683ull, 297075013893541ull}},
{{2567661637904880031ull, 475320022229667ull}},
{{13122175754549634995ull, 380256017783733ull}},
{{17876438233123528642ull, 304204814226986ull}},
{{2776859469804273565ull, 486727702763179ull}},
{{5910836390585329175ull, 389382162210543ull}},
{{12107366741952083986ull, 311505729768434ull}},
{{8303740342897603409ull, 498409167629495ull}},
{{6642992274318082727ull, 398727334103596ull}},
{{1625045004712555858ull, 318981867282877ull}},
{{6289420822281999697ull, 510370987652603ull}},
{{12410234287309420404ull, 408296790122082ull}},
{{2549489800363715677ull, 326637432097666ull}},
{{15147230124807676052ull, 522619891356265ull}},
{{12117784099846140842ull, 418095913085012ull}},
{{2315529650393092027ull, 334476730468010ull}},
{{3704847440628947243ull, 535162768748816ull}},
{{17721273211470799087ull, 428130214999052ull}},
{{6798320939692818623ull, 342504171999242ull}},
{{14566662318250420121ull, 548006675198787ull}},
{{4274632225116515450ull, 438405340159030ull}},
{{3419705780093212360ull, 350724272127224ull}},
{{12850226877632960423ull, 561158835403558ull}},
{{17658879131590188985ull, 448927068322846ull}},
{{10437754490530240864ull, 359141654658277ull}},
{{971505962940372045ull, 287313323726622ull}},
{{5243758355446505596ull, 459701317962595ull}},
{{4195006684357204476ull, 367761054370076ull}},
{{18113400606453404874ull, 294208843496060ull}},
{{10534696896615896182ull, 470734149593697ull}},
{{1049059887808896299ull, 376587319674958ull}},
{{8217945539730937686ull, 301269855739966ull}},
{{5770015234085679651ull, 482031769183946ull}},
{{926663372526633398ull, 385625415347157ull}},
{{11809377142247037688ull, 308500332277725ull}},
{{448259353885708685ull, 493600531644361ull}},
{{15116002742076208240ull, 394880425315488ull}},
{{1024755749435235623ull, 315904340252391ull}},
{{12707655643322107966ull, 505446944403825ull}},
{{10166124514657686373ull, 404357555523060ull}},
{{8132899611726149098ull, 323486044418448ull}},
{{9323290564019928234ull, 517577671069517ull}},
{{79934821732121941ull, 414062136855614ull}},
{{3753296672127607876ull, 331249709484491ull}},
{{17073321119629903571ull, 529999535175185ull}},
{{13658656895703922857ull, 423999628140148ull}},
{{18305623146046958932ull, 339199702512118ull}},
{{7152904145223672352ull, 542719524019390ull}},
{{5722323316178937881ull, 434175619215512ull}},
{{15645905097168881275ull, 347340495372409ull}},
{{13965401711244479070ull, 555744792595855ull}},
{{11172321368995583256ull, 444595834076684ull}},
{{12627205909938376928ull, 355676667261347ull}},
{{2723067098466880896ull, 284541333809078ull}},
{{667558542805099110ull, 455266134094525ull}},
{{534046834244079288ull, 364212907275620ull}},
{{427237467395263430ull, 291370325820496ull}},
{{11751626392058152458ull, 466192521312793ull}},
{{16779998743130342613ull, 372954017050234ull}},
{{17113347809246184414ull, 298363213640187ull}},
{{12623961235826253769ull, 477381141824300ull}},
{{10099168988661003015ull, 381904913459440ull}},
{{8079335190928802412ull, 305523930767552ull}},
{{16616285120227994183ull, 488838289228083ull}},
{{2224981651956664377ull, 391070631382467ull}},
{{12848031765791062471ull, 312856505105973ull}},
{{16867502010523789630ull, 500570408169557ull}},
{{6115303978935211058ull, 400456326535646ull}},
{{1202894368406258523ull, 320365061228517ull}},
{{5613979804191923960ull, 512584097965627ull}},
{{15559230287579270138ull, 410067278372501ull}},
{{8758035415321505787ull, 328053822698001ull}},
{{6634159035030588613ull, 524886116316802ull}},
{{16375373672250201860ull, 419908893053441ull}},
{{9410950123058251165ull, 335927114442753ull}},
{{11368171382151291540ull, 537483383108405ull}},
{{9094537105721033232ull, 429986706486724ull}},
{{10964978499318736909ull, 343989365189379ull}},
{{6475919154684248085ull, 550382984303007ull}},
{{16248781767973129437ull, 440306387442405ull}},
{{12999025414378503550ull, 352245109953924ull}},
{{14088569146244713163ull, 281796087963139ull}},
{{11473664189765810091ull, 450873740741023ull}},
{{16557628981296468719ull, 360698992592818ull}},
{{2178056740811444006ull, 288559194074255ull}},
{{3484890785298310410ull, 461694710518808ull}},
{{10166610257722468974ull, 369355768415046ull}},
{{4443939391436064856ull, 295484614732037ull}},
{{10799651841039614093ull, 472775383571259ull}},
{{12329070287573601597ull, 378220306857007ull}},
{{2484558600575060631ull, 302576245485606ull}},
{{15043340205145827980ull, 484121992776969ull}},
{{15724020978858572707ull, 387297594221575ull}},
{{12579216783086858166ull, 309838075377260ull}},
{{1680002779229421449ull, 495740920603617ull}},
{{12412048667609268129ull, 396592736482893ull}},
{{17308336563571235150ull, 317274189186314ull}},
{{16625292057488245270ull, 507638702698103ull}},
{{2232187201764865246ull, 406110962158483ull}},
{{9164447390895712843ull, 324888769726786ull}},
{{7284418195949319903ull, 519822031562858ull}},
{{13206232186243276569ull, 415857625250286ull}},
{{6875636934252710932ull, 332686100200229ull}},
{{18379716724288158138ull, 532297760320366ull}},
{{11014424564688616187ull, 425838208256293ull}},
{{16190237281234713596ull, 340670566605034ull}},
{{14836333205749810784ull, 545072906568055ull}},
{{11869066564599848627ull, 436058325254444ull}},
{{13184602066421789225ull, 348846660203555ull}},
{{2648619232565311144ull, 558154656325689ull}},
{{5808244200794159238ull, 446523725060551ull}},
{{957246545893417067ull, 357218980048441ull}},
{{15523192495682374946ull, 285775184038752ull}},
{{10079712734124158622ull, 457240294462004ull}},
{{11753119002041237221ull, 365792235569603ull}},
{{16781192831116810423ull, 292633788455682ull}},
{{12092513270819255384ull, 468214061529092ull}},
{{2295312987171583661ull, 374571249223274ull}},
{{5525599204479177252ull, 299656999378619ull}},
{{16219656356650504249ull, 479451199005790ull}},
{{12975725085320403399ull, 383560959204632ull}},
{{3001882438772502073ull, 306848767363706ull}},
{{15871058346261734287ull, 490958027781929ull}},
{{16386195491751297752ull, 392766422225543ull}},
{{2040909949175307232ull, 314213137780435ull}},
{{3265455918680491572ull, 502741020448696ull}},
{{17369759993912034550ull, 402192816358956ull}},
{{10206459180387717317ull, 321754253087165ull}},
{{16330334688620347707ull, 514806804939464ull}},
{{16753616565638188489ull, 411845443951571ull}},
{{9713544437768640468ull, 329476355161257ull}},
{{784275841462183456ull, 527162168258012ull}},
{{11695467117395477734ull, 421729734606409ull}},
{{13045722508658292511ull, 337383787685127ull}},
{{6115760754885626724ull, 539814060296204ull}},
{{8581957418650411703ull, 431851248236963ull}},
{{14244263564404150008ull, 345480998589570ull}},
{{4344077629337088398ull, 552769597743313ull}},
{{10853959732953491364ull, 442215678194650ull}},
{{8683167786362793091ull, 353772542555720ull}},
{{6946534229090234473ull, 283018034044576ull}},
{{3735757137060554511ull, 452828854471322ull}},
{{14056652153874174578ull, 362263083577057ull}},
{{3866624093615519016ull, 289810466861646ull}},
{{17254644994010561396ull, 463696746978633ull}},
{{2735669550982718147ull, 370957397582907ull}},
{{13256582085011905487ull, 296765918066325ull}},
{{2763787262309497163ull, 474825468906121ull}},
{{16968425068815239023ull, 379860375124896ull}},
{{9885391240310280895ull, 303888300099917ull}},
{{1059230725528808140ull, 486221280159868ull}},
{{8226082209906867158ull, 388977024127894ull}},
{{10270214582667404050ull, 311181619302315ull}},
{{16432343332267846480ull, 497890590883704ull}},
{{16835223480556187507ull, 398312472706963ull}},
{{2400132340219219036ull, 318649978165571ull}},
{{14908258188576481427ull, 509839965064913ull}},
{{858560106635454172ull, 407871972051931ull}},
{{15444243344276004631ull, 326297577641544ull}},
{{13642742906615876440ull, 522076124226471ull}},
{{7224845510550790828ull, 417660899381177ull}},
{{16847922852666363632ull, 334128719504941ull}},
{{1131234861072809549ull, 534605951207907ull}},
{{11973034333083978609ull, 427684760966325ull}},
{{9578427466467182887ull, 342147808773060ull}},
{{15325483946347492620ull, 547436494036896ull}},
{{8571038342336083772ull, 437949195229517ull}},
{{17924877118094597987ull, 350359356183613ull}},
{{6543710500499894841ull, 560574969893782ull}},
{{16303014844625646842ull, 448459975915025ull}},
{{13042411875700517474ull, 358767980732020ull}},
{{10433929500560413979ull, 287014384585616ull}},
{{9315589571412841720ull, 459223015336986ull}},
{{3763122842388363053ull, 367378412269589ull}},
{{6699847088652600765ull, 293902729815671ull}},
{{3341057712360340578ull, 470244367705074ull}},
{{6362194984630182786ull, 376195494164059ull}},
{{8779104802446056552ull, 300956395331247ull}},
{{17735916498655600806ull, 481530232529995ull}},
{{14188733198924480645ull, 385224186023996ull}},
{{7661637744397674193ull, 308179348819197ull}},
{{15947969205778189032ull, 493086958110715ull}},
{{12758375364622551225ull, 394469566488572ull}},
{{2828002662214220334ull, 315575653190858ull}},
{{835455444800842211ull, 504921045105373ull}},
{{8047061985324494415ull, 403936836084298ull}},
{{13816347217743416178ull, 323149468867438ull}},
{{18416806733647555563ull, 517039150187901ull}},
{{11044096572176134127ull, 413631320150321ull}},
{{5145928442998996978ull, 330905056120257ull}},
{{11922834323540305489ull, 529448089792411ull}},
{{5848918644090334068ull, 423558471833929ull}},
{{8368483730014177577ull, 338846777467143ull}},
{{9700225153280773800ull, 542154843947429ull}},
{{11449528937366529363ull, 433723875157943ull}},
{{16538320779377044137ull, 346979100126354ull}},
{{15393266802777539650ull, 555166560202167ull}},
{{4935915812738211074ull, 444133248161734ull}},
{{7638081464932479182ull, 355306598529387ull}},
{{17178511616171714315ull, 284245278823509ull}},
{{16417572141649011935ull, 454792446117615ull}},
{{13134057713319209548ull, 363833956894092ull}},
{{3128548541171546992ull, 291067165515274ull}},
{{12384375295358295833ull, 465707464824438ull}},
{{17286197865770457313ull, 372565971859550ull}},
{{13828958292616365850ull, 298052777487640ull}},
{{3679589194476633745ull, 476884443980225ull}},
{{2943671355581306996ull, 381507555184180ull}},
{{2354937084465045596ull, 305206044147344ull}},
{{11146596964627893601ull, 488329670635750ull}},
{{8917277571702314881ull, 390663736508600ull}},
{{7133822057361851905ull, 312530989206880ull}},
{{11414115291778963048ull, 500049582731008ull}},
{{16509989862906991084ull, 400039666184806ull}},
{{9518643075583682544ull, 320031732947845ull}},
{{15229828920933892071ull, 512050772716552ull}},
{{4805165507263293010ull, 409640618173242ull}},
{{14912178850036365378ull, 327712494538593ull}},
{{1723393271606722665ull, 524339991261750ull}},
{{1378714617285378132ull, 419471993009400ull}},
{{1102971693828302506ull, 335577594407520ull}},
{{1764754710125284009ull, 536924151052032ull}},
{{12479850212325958177ull, 429539320841625ull}},
{{9983880169860766542ull, 343631456673300ull}},
{{15974208271777226467ull, 549810330677280ull}},
{{12779366617421781173ull, 439848264541824ull}},
{{13912842108679335262ull, 351878611633459ull}},
{{14819622501685378532ull, 281502889306767ull}},
{{8954000743728964359ull, 450404622890828ull}},
{{14541898224466992134ull, 360323698312662ull}},
{{4254820950089773061ull, 288258958650130ull}},
{{6807713520143636897ull, 461214333840208ull}},
{{12824868445598730164ull, 368971467072166ull}},
{{6570545941737073808ull, 295177173657733ull}},
{{6823524692037407770ull, 472283477852373ull}},
{{12837517383113746862ull, 377826782281898ull}},
{{17648711535974818136ull, 302261425825518ull}},
{{6101845569108247079ull, 483618281320830ull}},
{{4881476455286597663ull, 386894625056664ull}},
{{7594529978971188453ull, 309515700045331ull}},
{{4772550336870080879ull, 495225120072530ull}},
{{3818040269496064703ull, 396180096058024ull}},
{{6743781030338762086ull, 316944076846419ull}},
{{18168747278025839984ull, 507110522954270ull}},
{{14534997822420671987ull, 405688418363416ull}},
{{7938649443194627266ull, 324550734690733ull}},
{{9012490294369493303ull, 519281175505173ull}},
{{14588689864979415289ull, 415424940404138ull}},
{{602905447757801261ull, 332339952323311ull}},
{{12032695160638212988ull, 531743923717297ull}},
{{2247458499026749744ull, 425395138973838ull}},
{{9176664428705220442ull, 340316111179070ull}},
{{14682663085928352707ull, 544505777886512ull}},
{{4367432839258861519ull, 435604622309210ull}},
{{3493946271407089215ull, 348483697847368ull}},
{{1900965219509432421ull, 557573916555789ull}},
{{5210120990349456260ull, 446059133244631ull}},
{{478747977537654685ull, 356847306595705ull}},
{{382998382030123748ull, 285477845276564ull}},
{{7991495040732018643ull, 456764552442502ull}},
{{17461242476811345884ull, 365411641954001ull}},
{{10279645166707166384ull, 292329313563201ull}},
{{9068734637247645568ull, 467726901701122ull}},
{{18323034154023847424ull, 374181521360897ull}},
{{7279729693735257293ull, 299345217088718ull}},
{{7958218695234501345ull, 478952347341949ull}},
{{10055923770929511399ull, 383161877873559ull}},
{{11734087831485519443ull, 306529502298847ull}},
{{4017145271409189816ull, 490447203678156ull}},
{{17971111476094993145ull, 392357762942524ull}},
{{18066237995617904839ull, 313886210354019ull}},
{{17837934348762916774ull, 502217936566431ull}},
{{10580998664268423096ull, 401774349253145ull}},
{{8464798931414738476ull, 321419479402516ull}},
{{6164980660779760916ull, 514271167044026ull}},
{{1242635713881898410ull, 411416933635221ull}},
{{15751503830073160020ull, 329133546908176ull}},
{{17823708498633235386ull, 526613675053082ull}},
{{6880269169422767663ull, 421290940042466ull}},
{{1814866520796303807ull, 337032752033973ull}},
{{17661181692241727384ull, 539252403254356ull}},
{{10439596539051471584ull, 431401922603485ull}},
{{8351677231241177267ull, 345121538082788ull}},
{{9673334755243973304ull, 552194460932461ull}},
{{4049318989453268320ull, 441755568745969ull}},
{{6928804006304524979ull, 353404454996775ull}},
{{5543043205043619983ull, 282723563997420ull}},
{{8868869128069791974ull, 452357702395872ull}},
{{18163141746681564548ull, 361886161916697ull}},
{{7151815767861430992ull, 289508929533358ull}},
{{7753556413836379265ull, 463214287253373ull}},
{{13581542760552924058ull, 370571429802698ull}},
{{18243931837926159893ull, 296457143842158ull}},
{{7054198052230393889ull, 474331430147454ull}},
{{9332707256526225435ull, 379465144117963ull}},
{{14844863434704800994ull, 303572115294370ull}},
{{5305037421818129975ull, 485715384470993ull}},
{{11622727566938324626ull, 388572307576794ull}},
{{12987530868292570024ull, 310857846061435ull}},
{{2333305315558560423ull, 497372553698297ull}},
{{12934690696672579308ull, 397898042958637ull}},
{{2969054927854242800ull, 318318434366910ull}},
{{4750487884566788480ull, 509309494987056ull}},
{{111041492911520460ull, 407447595989645ull}},
{{88833194329216368ull, 325958076791716ull}},
{{11210179555152477159ull, 521532922866745ull}},
{{8968143644121981727ull, 417226338293396ull}},
{{3485166100555675058ull, 333781070634717ull}},
{{9265614575630990417ull, 534049713015547ull}},
{{33794031020971687ull, 427239770412438ull}},
{{7405732854300597996ull, 341791816329950ull}},
{{11849172566880956794ull, 546866906127920ull}},
{{9479338053504765435ull, 437493524902336ull}},
{{3894121628061902025ull, 349994819921869ull}},
{{13609292234382863886ull, 559991711874990ull}},
{{10887433787506291109ull, 447993369499992ull}},
{{1331249400521212241ull, 358394695599994ull}},
{{4754348335158880116ull, 286715756479995ull}},
{{7606957336254208185ull, 458745210367992ull}},
{{17153612313229097518ull, 366996168294393ull}},
{{2654843406357547044ull, 293596934635515ull}},
{{4247749450172075271ull, 469755095416824ull}},
{{7087548374879570540ull, 375804076333459ull}},
{{9359387514645566755ull, 300643261066767ull}},
{{217624764465265516ull, 481029217706828ull}},
{{7552797441056033059ull, 384823374165462ull}},
{{17110284397070557417ull, 307858699332369ull}},
{{16308408591087160897ull, 492573918931791ull}},
{{9357378058127818395ull, 394059135145433ull}},
{{14864600075986075362ull, 315247308116346ull}},
{{16404662492093899933ull, 504395692986154ull}},
{{16813078808417030270ull, 403516554388923ull}},
{{2382416602507893246ull, 322813243511139ull}},
{{11190564193496449840ull, 516501189617822ull}},
{{1573753725313339226ull, 413200951694258ull}},
{{8637700609734492027ull, 330560761355406ull}},
{{6441623346091366597ull, 528897218168650ull}},
{{5153298676873093277ull, 423117774534920ull}},
{{4122638941498474622ull, 338494219627936ull}},
{{17664268750623290365ull, 541590751404697ull}},
{{6752717371014811645ull, 433272601123758ull}},
{{12780871526295669963ull, 346618080899006ull}},
{{13070696812589251294ull, 554588929438410ull}},
{{10456557450071401035ull, 443671143550728ull}},
{{15743943589540941474ull, 354936914840582ull}},
{{5216457242148932533ull, 283949531872466ull}},
{{967633957954471407ull, 454319250995946ull}},
{{15531502425331218418ull, 363455400796756ull}},
{{8735853125523064411ull, 290764320637405ull}},
{{13977365000836903058ull, 465222913019848ull}},
{{113845556443791477ull, 372178330415879ull}},
{{3780425259896943505ull, 297742664332703ull}},
{{2359331601093199284ull, 476388262932325ull}},
{{1887465280874559427ull, 381110610345860ull}},
{{1509972224699647542ull, 304888488276688ull}},
{{17173350818487077360ull, 487821581242700ull}},
{{13738680654789661888ull, 390257264994160ull}},
{{10990944523831729510ull, 312205811995328ull}},
{{13896162423388856894ull, 499529299192525ull}},
{{11116929938711085515ull, 399623439354020ull}},
{{8893543950968868412ull, 319698751483216ull}},
{{6850972692066368813ull, 511518002373146ull}},
{{1791429338911184727ull, 409214401898517ull}},
{{12501189915354678751ull, 327371521518813ull}},
{{16312555049825575679ull, 523794434430101ull}},
{{9360695225118550220ull, 419035547544081ull}},
{{3799207365352929852ull, 335228438035265ull}},
{{6078731784564687764ull, 536365500856424ull}},
{{8552334242393660534ull, 429092400685139ull}},
{{10531216208656838751ull, 343273920548111ull}},
{{9471248304367121355ull, 549238272876978ull}},
{{14955696272977517730ull, 439390618301582ull}},
{{4585859388898193538ull, 351512494641266ull}},
{{18405421466462840630ull, 562419991426025ull}},
{{14724337173170272504ull, 449935993140820ull}},
{{11779469738536218003ull, 359948794512656ull}},
{{5734226976087064079ull, 287959035610125ull}},
{{9174763161739302527ull, 460734456976200ull}},
{{7339810529391442021ull, 368587565580960ull}},
{{5871848423513153617ull, 294870052464768ull}},
{{5705608662879135464ull, 471792083943629ull}},
{{8253835745045218695ull, 377433667154903ull}},
{{13981766225519995602ull, 301946933723922ull}},
{{7613430701864351671ull, 483115093958276ull}},
{{2401395746749571013ull, 386492075166621ull}},
{{16678511856367298103ull, 309193660133296ull}},
{{860177266994304703ull, 494709856213275ull}},
{{688141813595443762ull, 395767884970620ull}},
{{550513450876355010ull, 316614307976496ull}},
{{11948867965627898986ull, 506582892762393ull}},
{{16937792001986139835ull, 405266314209914ull}},
{{17239582416330822191ull, 324213051367931ull}},
{{1757890162935943243ull, 518740882188691ull}},
{{16163707389316395887ull, 414992705750952ull}},
{{5552268281969296063ull, 331994164600762ull}},
{{12572978065892784025ull, 531190663361219ull}},
{{13747731267456137543ull, 424952530688975ull}},
{{10998185013964910034ull, 339962024551180ull}},
{{17597096022343856055ull, 543939239281888ull}},
{{3009630373649353875ull, 435151391425511ull}},
{{17165099557887124392ull, 348121113140408ull}},
{{5328066404167937089ull, 556993781024654ull}},
{{7951801938076259994ull, 445595024819723ull}},
{{13740139179944828642ull, 356476019855778ull}},
{{18370808973439683560ull, 285180815884622ull}},
{{14635899098535852403ull, 456289305415396ull}},
{{8019370464086771599ull, 365031444332317ull}},
{{17483542815495148249ull, 292025155465853ull}},
{{5837575616340775259ull, 467240248745366ull}},
{{980711678330709884ull, 373792198996293ull}},
{{8163266972148388553ull, 299033759197034ull}},
{{1993180711211690716ull, 478454014715255ull}},
{{1594544568969352573ull, 382763211772204ull}},
{{4964984469917392381ull, 306210569417763ull}},
{{4254626337125917487ull, 489936911068421ull}},
{{18161096328668375283ull, 391949528854736ull}},
{{10839528248192789903ull, 313559623083789ull}},
{{6275198752882732875ull, 501695396934063ull}},
{{12398856631790006946ull, 401356317547250ull}},
{{9919085305432005557ull, 321085054037800ull}},
{{15870536488691208892ull, 513736086460480ull}},
{{12696429190952967113ull, 410988869168384ull}},
{{13846492167504284014ull, 328791095334707ull}},
{{7396992209039213129ull, 526065752535532ull}},
{{16985640211457101473ull, 420852602028425ull}},
{{13588512169165681178ull, 336682081622740ull}},
{{3294875396955538270ull, 538691330596385ull}},
{{2635900317564430616ull, 430953064477108ull}},
{{9487417883535365139ull, 344762451581686ull}},
{{7801170984172763576ull, 551619922530698ull}},
{{13619634416822031507ull, 441295938024558ull}},
{{18274405162941445852ull, 353036750419646ull}},
{{10930175315611246358ull, 282429400335717ull}},
{{2730885246010352881ull, 451887040537148ull}},
{{9563405826292102951ull, 361509632429718ull}},
{{15029422290517503007ull, 289207705943774ull}},
{{12979029220602273842ull, 462732329510039ull}},
{{14072572191223729397ull, 370185863608031ull}},
{{7568708938237073194ull, 296148690886425ull}},
{{12109934301179317111ull, 473837905418280ull}},
{{9687947440943453688ull, 379070324334624ull}},
{{11439706767496673274ull, 303256259467699ull}},
{{7235484383768946269ull, 485210015148319ull}},
{{9477736321757067338ull, 388168012118655ull}},
{{7582189057405653870ull, 310534409694924ull}},
{{1063456047623315223ull, 496855055511879ull}},
{{4540113652840562502ull, 397484044409503ull}},
{{11010788551756270648ull, 317987235527602ull}},
{{2859866423842391744ull, 508779576844164ull}},
{{5977241953815823718ull, 407023661475331ull}},
{{1092444748310748651ull, 325618929180265ull}},
{{1747911597297197842ull, 520990286688424ull}},
{{5087678092579668597ull, 416792229350739ull}},
{{7759491288805645201ull, 333433783480591ull}},
{{5036488432605211675ull, 533494053568946ull}},
{{339841931342259017ull, 426795242855157ull}},
{{11339919989299538183ull, 341436194284125ull}},
{{18143871982879261093ull, 546297910854600ull}},
{{14515097586303408874ull, 437038328683680ull}},
{{11612078069042727099ull, 349630662946944ull}},
{{7511278466242632389ull, 559409060715111ull}},
{{2319673958252195588ull, 447527248572089ull}},
{{5545087981343666794ull, 358021798857671ull}},
{{746721570333023112ull, 286417439086137ull}},
{{4884103327274747302ull, 458267902537819ull}},
{{7596631476561708165ull, 366614322030255ull}},
{{6077305181249366532ull, 293291457624204ull}},
{{17102385919482807098ull, 469266332198726ull}},
{{9992559920844335355ull, 375413065758981ull}},
{{4304699121933557960ull, 300330452607185ull}},
{{6887518595093692737ull, 480528724171496ull}},
{{1820666061333043866ull, 384422979337197ull}},
{{12524579293292166063ull, 307538383469757ull}},
{{5281931610299824408ull, 492061413551612ull}},
{{15293591732465590496ull, 393649130841289ull}},
{{15924222200714382720ull, 314919304673031ull}},
{{18100057891659191705ull, 503870887476850ull}},
{{14480046313327353364ull, 403096709981480ull}},
{{11584037050661882691ull, 322477367985184ull}},
{{7466412836833281337ull, 515963788776295ull}},
{{5973130269466625069ull, 412771031021036ull}},
{{1089155400831389732ull, 330216824816829ull}},
{{9121346270814044218ull, 528346919706926ull}},
{{3607728201909325051ull, 422677535765541ull}},
{{17643577820495101334ull, 338142028612432ull}},
{{13472329253824520841ull, 541027245779892ull}},
{{3399165773575796026ull, 432821796623914ull}},
{{6408681433602547144ull, 346257437299131ull}},
{{2875192664280254785ull, 554011899678610ull}},
{{2300154131424203828ull, 443209519742888ull}},
{{9218820934623183708ull, 354567615794310ull}},
{{7375056747698546967ull, 283654092635448ull}},
{{8110741981575764824ull, 453846548216717ull}},
{{17556640029486342828ull, 363077238573373ull}},
{{2977265579363343293ull, 290461790858699ull}},
{{12142322556465169916ull, 464738865373918ull}},
{{17092555674655956579ull, 371791092299134ull}},
{{17363393354466675586ull, 297432873839307ull}},
{{13024034108179039645ull, 475892598142892ull}},
{{3040529657059411070ull, 380714078514314ull}},
{{6121772540389439179ull, 304571262811451ull}},
{{2416138435139282040ull, 487314020498322ull}},
{{13000957192337156602ull, 389851216398657ull}},
{{3022068124385904635ull, 311880973118926ull}},
{{15903355443243178386ull, 499009556990281ull}},
{{9033335539852632385ull, 399207645592225ull}},
{{7226668431882105908ull, 319366116473780ull}},
{{11562669491011369453ull, 510985786358048ull}},
{{16628833222292916209ull, 408788629086438ull}},
{{2235020133608601997ull, 327030903269151ull}},
{{14644078657999494166ull, 523249445230641ull}},
{{8025914111657685009ull, 418599556184513ull}},
{{13799428918809968654ull, 334879644947610ull}},
{{3632342196386398230ull, 535807431916177ull}}
};

static const int exponents_binary80[] = { -65,
  -62,
  -59,
  -55,
  -52,
  -49,
  -45,
  -42,
  -39,
  -35,
  -32,
  -29,
  -25,
  -22,
  -19,
  -15,
  -12,
  -9,
  -6,
  -2,
  1,
  4,
  8,
  11,
  14,
  18,
  21,
  24,
  28,
  31,
  34,
  38,
  41,
  44,
  48,
  51,
  54,
  58,
  61,
  64,
  68,
  71,
  74,
  78,
  81,
  84,
  87,
  91,
  94,
  97,
  101,
  104,
  107,
  111,
  114,
  117,
  121,
  124,
  127,
  131,
  134,
  137,
  141,
  144,
  147,
  151,
  154,
  157,
  161,
  164,
  167,
  171,
  174,
  177,
  181,
  184,
  187,
  190,
  194,
  197,
  200,
  204,
  207,
  210,
  214,
  217,
  220,
  224,
  227,
  230,
  234,
  237,
  240,
  244,
  247,
  250,
  254,
  257,
  260,
  264,
  267,
  270,
  274,
  277,
  280,
  283,
  287,
  290,
  293,
  297,
  300,
  303,
  307,
  310,
  313,
  317,
  320,
  323,
  327,
  330,
  333,
  337,
  340,
  343,
  347,
  350,
  353,
  357,
  360,
  363,
  367,
  370,
  373,
  377,
  380,
  383,
  386,
  390,
  393,
  396,
  400,
  403,
  406,
  410,
  413,
  416,
  420,
  423,
  426,
  430,
  433,
  436,
  440,
  443,
  446,
  450,
  453,
  456,
  460,
  463,
  466,
  470,
  473,
  476,
  479,
  483,
  486,
  489,
  493,
  496,
  499,
  503,
  506,
  509,
  513,
  516,
  519,
  523,
  526,
  529,
  533,
  536,
  539,
  543,
  546,
  549,
  553,
  556,
  559,
  563,
  566,
  569,
  572,
  576,
  579,
  582,
  586,
  589,
  592,
  596,
  599,
  602,
  606,
  609,
  612,
  616,
  619,
  622,
  626,
  629,
  632,
  636,
  639,
  642,
  646,
  649,
  652,
  656,
  659,
  662,
  666,
  669,
  672,
  675,
  679,
  682,
  685,
  689,
  692,
  695,
  699,
  702,
  705,
  709,
  712,
  715,
  719,
  722,
  725,
  729,
  732,
  735,
  739,
  742,
  745,
  749,
  752,
  755,
  759,
  762,
  765,
  768,
  772,
  775,
  778,
  782,
  785,
  788,
  792,
  795,
  798,
  802,
  805,
  808,
  812,
  815,
  818,
  822,
  825,
  828,
  832,
  835,
  838,
  842,
  845,
  848,
  852,
  855,
  858,
  862,
  865,
  868,
  871,
  875,
  878,
  881,
  885,
  888,
  891,
  895,
  898,
  901,
  905,
  908,
  911,
  915,
  918,
  921,
  925,
  928,
  931,
  935,
  938,
  941,
  945,
  948,
  951,
  955,
  958,
  961,
  964,
  968,
  971,
  974,
  978,
  981,
  984,
  988,
  991,
  994,
  998,
  1001,
  1004,
  1008,
  1011,
  1014,
  1018,
  1021,
  1024,
  1028,
  1031,
  1034,
  1038,
  1041,
  1044,
  1048,
  1051,
  1054,
  1058,
  1061,
  1064,
  1067,
  1071,
  1074,
  1077,
  1081,
  1084,
  1087,
  1091,
  1094,
  1097,
  1101,
  1104,
  1107,
  1111,
  1114,
  1117,
  1121,
  1124,
  1127,
  1131,
  1134,
  1137,
  1141,
  1144,
  1147,
  1151,
  1154,
  1157,
  1160,
  1164,
  1167,
  1170,
  1174,
  1177,
  1180,
  1184,
  1187,
  1190,
  1194,
  1197,
  1200,
  1204,
  1207,
  1210,
  1214,
  1217,
  1220,
  1224,
  1227,
  1230,
  1234,
  1237,
  1240,
  1244,
  1247,
  1250,
  1253,
  1257,
  1260,
  1263,
  1267,
  1270,
  1273,
  1277,
  1280,
  1283,
  1287,
  1290,
  1293,
  1297,
  1300,
  1303,
  1307,
  1310,
  1313,
  1317,
  1320,
  1323,
  1327,
  1330,
  1333,
  1337,
  1340,
  1343,
  1347,
  1350,
  1353,
  1356,
  1360,
  1363,
  1366,
  1370,
  1373,
  1376,
  1380,
  1383,
  1386,
  1390,
  1393,
  1396,
  1400,
  1403,
  1406,
  1410,
  1413,
  1416,
  1420,
  1423,
  1426,
  1430,
  1433,
  1436,
  1440,
  1443,
  1446,
  1449,
  1453,
  1456,
  1459,
  1463,
  1466,
  1469,
  1473,
  1476,
  1479,
  1483,
  1486,
  1489,
  1493,
  1496,
  1499,
  1503,
  1506,
  1509,
  1513,
  1516,
  1519,
  1523,
  1526,
  1529,
  1533,
  1536,
  1539,
  1543,
  1546,
  1549,
  1552,
  1556,
  1559,
  1562,
  1566,
  1569,
  1572,
  1576,
  1579,
  1582,
  1586,
  1589,
  1592,
  1596,
  1599,
  1602,
  1606,
  1609,
  1612,
  1616,
  1619,
  1622,
  1626,
  1629,
  1632,
  1636,
  1639,
  1642,
  1645,
  1649,
  1652,
  1655,
  1659,
  1662,
  1665,
  1669,
  1672,
  1675,
  1679,
  1682,
  1685,
  1689,
  1692,
  1695,
  1699,
  1702,
  1705,
  1709,
  1712,
  1715,
  1719,
  1722,
  1725,
  1729,
  1732,
  1735,
  1738,
  1742,
  1745,
  1748,
  1752,
  1755,
  1758,
  1762,
  1765,
  1768,
  1772,
  1775,
  1778,
  1782,
  1785,
  1788,
  1792,
  1795,
  1798,
  1802,
  1805,
  1808,
  1812,
  1815,
  1818,
  1822,
  1825,
  1828,
  1832,
  1835,
  1838,
  1841,
  1845,
  1848,
  1851,
  1855,
  1858,
  1861,
  1865,
  1868,
  1871,
  1875,
  1878,
  1881,
  1885,
  1888,
  1891,
  1895,
  1898,
  1901,
  1905,
  1908,
  1911,
  1915,
  1918,
  1921,
  1925,
  1928,
  1931,
  1934,
  1938,
  1941,
  1944,
  1948,
  1951,
  1954,
  1958,
  1961,
  1964,
  1968,
  1971,
  1974,
  1978,
  1981,
  1984,
  1988,
  1991,
  1994,
  1998,
  2001,
  2004,
  2008,
  2011,
  2014,
  2018,
  2021,
  2024,
  2028,
  2031,
  2034,
  2037,
  2041,
  2044,
  2047,
  2051,
  2054,
  2057,
  2061,
  2064,
  2067,
  2071,
  2074,
  2077,
  2081,
  2084,
  2087,
  2091,
  2094,
  2097,
  2101,
  2104,
  2107,
  2111,
  2114,
  2117,
  2121,
  2124,
  2127,
  2130,
  2134,
  2137,
  2140,
  2144,
  2147,
  2150,
  2154,
  2157,
  2160,
  2164,
  2167,
  2170,
  2174,
  2177,
  2180,
  2184,
  2187,
  2190,
  2194,
  2197,
  2200,
  2204,
  2207,
  2210,
  2214,
  2217,
  2220,
  2223,
  2227,
  2230,
  2233,
  2237,
  2240,
  2243,
  2247,
  2250,
  2253,
  2257,
  2260,
  2263,
  2267,
  2270,
  2273,
  2277,
  2280,
  2283,
  2287,
  2290,
  2293,
  2297,
  2300,
  2303,
  2307,
  2310,
  2313,
  2317,
  2320,
  2323,
  2326,
  2330,
  2333,
  2336,
  2340,
  2343,
  2346,
  2350,
  2353,
  2356,
  2360,
  2363,
  2366,
  2370,
  2373,
  2376,
  2380,
  2383,
  2386,
  2390,
  2393,
  2396,
  2400,
  2403,
  2406,
  2410,
  2413,
  2416,
  2419,
  2423,
  2426,
  2429,
  2433,
  2436,
  2439,
  2443,
  2446,
  2449,
  2453,
  2456,
  2459,
  2463,
  2466,
  2469,
  2473,
  2476,
  2479,
  2483,
  2486,
  2489,
  2493,
  2496,
  2499,
  2503,
  2506,
  2509,
  2513,
  2516,
  2519,
  2522,
  2526,
  2529,
  2532,
  2536,
  2539,
  2542,
  2546,
  2549,
  2552,
  2556,
  2559,
  2562,
  2566,
  2569,
  2572,
  2576,
  2579,
  2582,
  2586,
  2589,
  2592,
  2596,
  2599,
  2602,
  2606,
  2609,
  2612,
  2615,
  2619,
  2622,
  2625,
  2629,
  2632,
  2635,
  2639,
  2642,
  2645,
  2649,
  2652,
  2655,
  2659,
  2662,
  2665,
  2669,
  2672,
  2675,
  2679,
  2682,
  2685,
  2689,
  2692,
  2695,
  2699,
  2702,
  2705,
  2708,
  2712,
  2715,
  2718,
  2722,
  2725,
  2728,
  2732,
  2735,
  2738,
  2742,
  2745,
  2748,
  2752,
  2755,
  2758,
  2762,
  2765,
  2768,
  2772,
  2775,
  2778,
  2782,
  2785,
  2788,
  2792,
  2795,
  2798,
  2802,
  2805,
  2808,
  2811,
  2815,
  2818,
  2821,
  2825,
  2828,
  2831,
  2835,
  2838,
  2841,
  2845,
  2848,
  2851,
  2855,
  2858,
  2861,
  2865,
  2868,
  2871,
  2875,
  2878,
  2881,
  2885,
  2888,
  2891,
  2895,
  2898,
  2901,
  2904,
  2908,
  2911,
  2914,
  2918,
  2921,
  2924,
  2928,
  2931,
  2934,
  2938,
  2941,
  2944,
  2948,
  2951,
  2954,
  2958,
  2961,
  2964,
  2968,
  2971,
  2974,
  2978,
  2981,
  2984,
  2988,
  2991,
  2994,
  2998,
  3001,
  3004,
  3007,
  3011,
  3014,
  3017,
  3021,
  3024,
  3027,
  3031,
  3034,
  3037,
  3041,
  3044,
  3047,
  3051,
  3054,
  3057,
  3061,
  3064,
  3067,
  3071,
  3074,
  3077,
  3081,
  3084,
  3087,
  3091,
  3094,
  3097,
  3100,
  3104,
  3107,
  3110,
  3114,
  3117,
  3120,
  3124,
  3127,
  3130,
  3134,
  3137,
  3140,
  3144,
  3147,
  3150,
  3154,
  3157,
  3160,
  3164,
  3167,
  3170,
  3174,
  3177,
  3180,
  3184,
  3187,
  3190,
  3193,
  3197,
  3200,
  3203,
  3207,
  3210,
  3213,
  3217,
  3220,
  3223,
  3227,
  3230,
  3233,
  3237,
  3240,
  3243,
  3247,
  3250,
  3253,
  3257,
  3260,
  3263,
  3267,
  3270,
  3273,
  3277,
  3280,
  3283,
  3287,
  3290,
  3293,
  3296,
  3300,
  3303,
  3306,
  3310,
  3313,
  3316,
  3320,
  3323,
  3326,
  3330,
  3333,
  3336,
  3340,
  3343,
  3346,
  3350,
  3353,
  3356,
  3360,
  3363,
  3366,
  3370,
  3373,
  3376,
  3380,
  3383,
  3386,
  3389,
  3393,
  3396,
  3399,
  3403,
  3406,
  3409,
  3413,
  3416,
  3419,
  3423,
  3426,
  3429,
  3433,
  3436,
  3439,
  3443,
  3446,
  3449,
  3453,
  3456,
  3459,
  3463,
  3466,
  3469,
  3473,
  3476,
  3479,
  3483,
  3486,
  3489,
  3492,
  3496,
  3499,
  3502,
  3506,
  3509,
  3512,
  3516,
  3519,
  3522,
  3526,
  3529,
  3532,
  3536,
  3539,
  3542,
  3546,
  3549,
  3552,
  3556,
  3559,
  3562,
  3566,
  3569,
  3572,
  3576,
  3579,
  3582,
  3585,
  3589,
  3592,
  3595,
  3599,
  3602,
  3605,
  3609,
  3612,
  3615,
  3619,
  3622,
  3625,
  3629,
  3632,
  3635,
  3639,
  3642,
  3645,
  3649,
  3652,
  3655,
  3659,
  3662,
  3665,
  3669,
  3672,
  3675,
  3679,
  3682,
  3685,
  3688,
  3692,
  3695,
  3698,
  3702,
  3705,
  3708,
  3712,
  3715,
  3718,
  3722,
  3725,
  3728,
  3732,
  3735,
  3738,
  3742,
  3745,
  3748,
  3752,
  3755,
  3758,
  3762,
  3765,
  3768,
  3772,
  3775,
  3778,
  3781,
  3785,
  3788,
  3791,
  3795,
  3798,
  3801,
  3805,
  3808,
  3811,
  3815,
  3818,
  3821,
  3825,
  3828,
  3831,
  3835,
  3838,
  3841,
  3845,
  3848,
  3851,
  3855,
  3858,
  3861,
  3865,
  3868,
  3871,
  3874,
  3878,
  3881,
  3884,
  3888,
  3891,
  3894,
  3898,
  3901,
  3904,
  3908,
  3911,
  3914,
  3918,
  3921,
  3924,
  3928,
  3931,
  3934,
  3938,
  3941,
  3944,
  3948,
  3951,
  3954,
  3958,
  3961,
  3964,
  3968,
  3971,
  3974,
  3977,
  3981,
  3984,
  3987,
  3991,
  3994,
  3997,
  4001,
  4004,
  4007,
  4011,
  4014,
  4017,
  4021,
  4024,
  4027,
  4031,
  4034,
  4037,
  4041,
  4044,
  4047,
  4051,
  4054,
  4057,
  4061,
  4064,
  4067,
  4070,
  4074,
  4077,
  4080,
  4084,
  4087,
  4090,
  4094,
  4097,
  4100,
  4104,
  4107,
  4110,
  4114,
  4117,
  4120,
  4124,
  4127,
  4130,
  4134,
  4137,
  4140,
  4144,
  4147,
  4150,
  4154,
  4157,
  4160,
  4164,
  4167,
  4170,
  4173,
  4177,
  4180,
  4183,
  4187,
  4190,
  4193,
  4197,
  4200,
  4203,
  4207,
  4210,
  4213,
  4217,
  4220,
  4223,
  4227,
  4230,
  4233,
  4237,
  4240,
  4243,
  4247,
  4250,
  4253,
  4257,
  4260,
  4263,
  4266,
  4270,
  4273,
  4276,
  4280,
  4283,
  4286,
  4290,
  4293,
  4296,
  4300,
  4303,
  4306,
  4310,
  4313,
  4316,
  4320,
  4323,
  4326,
  4330,
  4333,
  4336,
  4340,
  4343,
  4346,
  4350,
  4353,
  4356,
  4359,
  4363,
  4366,
  4369,
  4373,
  4376,
  4379,
  4383,
  4386,
  4389,
  4393,
  4396,
  4399,
  4403,
  4406,
  4409,
  4413,
  4416,
  4419,
  4423,
  4426,
  4429,
  4433,
  4436,
  4439,
  4443,
  4446,
  4449,
  4453,
  4456,
  4459,
  4462,
  4466,
  4469,
  4472,
  4476,
  4479,
  4482,
  4486,
  4489,
  4492,
  4496,
  4499,
  4502,
  4506,
  4509,
  4512,
  4516,
  4519,
  4522,
  4526,
  4529,
  4532,
  4536,
  4539,
  4542,
  4546,
  4549,
  4552,
  4555,
  4559,
  4562,
  4565,
  4569,
  4572,
  4575,
  4579,
  4582,
  4585,
  4589,
  4592,
  4595,
  4599,
  4602,
  4605,
  4609,
  4612,
  4615,
  4619,
  4622,
  4625,
  4629,
  4632,
  4635,
  4639,
  4642,
  4645,
  4649,
  4652,
  4655,
  4658,
  4662,
  4665,
  4668,
  4672,
  4675,
  4678,
  4682,
  4685,
  4688,
  4692,
  4695,
  4698,
  4702,
  4705,
  4708,
  4712,
  4715,
  4718,
  4722,
  4725,
  4728,
  4732,
  4735,
  4738,
  4742,
  4745,
  4748,
  4751,
  4755,
  4758,
  4761,
  4765,
  4768,
  4771,
  4775,
  4778,
  4781,
  4785,
  4788,
  4791,
  4795,
  4798,
  4801,
  4805,
  4808,
  4811,
  4815,
  4818,
  4821,
  4825,
  4828,
  4831,
  4835,
  4838,
  4841,
  4844,
  4848,
  4851,
  4854,
  4858,
  4861,
  4864,
  4868,
  4871,
  4874,
  4878,
  4881,
  4884,
  4888,
  4891,
  4894,
  4898,
  4901,
  4904,
  4908,
  4911,
  4914,
  4918,
  4921,
  4924,
  4928,
  4931,
  4934,
  4938,
  4941,
  4944,
  4947,
  4951,
  4954,
  4957,
  4961,
  4964,
  4967,
  4971,
  4974,
  4977,
  4981,
  4984,
  4987,
  4991,
  4994,
  4997,
  5001,
  5004,
  5007,
  5011,
  5014,
  5017,
  5021,
  5024,
  5027,
  5031,
  5034,
  5037,
  5040,
  5044,
  5047,
  5050,
  5054,
  5057,
  5060,
  5064,
  5067,
  5070,
  5074,
  5077,
  5080,
  5084,
  5087,
  5090,
  5094,
  5097,
  5100,
  5104,
  5107,
  5110,
  5114,
  5117,
  5120,
  5124,
  5127,
  5130,
  5134,
  5137,
  5140,
  5143,
  5147,
  5150,
  5153,
  5157,
  5160,
  5163,
  5167,
  5170,
  5173,
  5177,
  5180,
  5183,
  5187,
  5190,
  5193,
  5197,
  5200,
  5203,
  5207,
  5210,
  5213,
  5217,
  5220,
  5223,
  5227,
  5230,
  5233,
  5236,
  5240,
  5243,
  5246,
  5250,
  5253,
  5256,
  5260,
  5263,
  5266,
  5270,
  5273,
  5276,
  5280,
  5283,
  5286,
  5290,
  5293,
  5296,
  5300,
  5303,
  5306,
  5310,
  5313,
  5316,
  5320,
  5323,
  5326,
  5329,
  5333,
  5336,
  5339,
  5343,
  5346,
  5349,
  5353,
  5356,
  5359,
  5363,
  5366,
  5369,
  5373,
  5376,
  5379,
  5383,
  5386,
  5389,
  5393,
  5396,
  5399,
  5403,
  5406,
  5409,
  5413,
  5416,
  5419,
  5423,
  5426,
  5429,
  5432,
  5436,
  5439,
  5442,
  5446,
  5449,
  5452,
  5456,
  5459,
  5462,
  5466,
  5469,
  5472,
  5476,
  5479,
  5482,
  5486,
  5489,
  5492,
  5496,
  5499,
  5502,
  5506,
  5509,
  5512,
  5516,
  5519,
  5522,
  5525,
  5529,
  5532,
  5535,
  5539,
  5542,
  5545,
  5549,
  5552,
  5555,
  5559,
  5562,
  5565,
  5569,
  5572,
  5575,
  5579,
  5582,
  5585,
  5589,
  5592,
  5595,
  5599,
  5602,
  5605,
  5609,
  5612,
  5615,
  5619,
  5622,
  5625,
  5628,
  5632,
  5635,
  5638,
  5642,
  5645,
  5648,
  5652,
  5655,
  5658,
  5662,
  5665,
  5668,
  5672,
  5675,
  5678,
  5682,
  5685,
  5688,
  5692,
  5695,
  5698,
  5702,
  5705,
  5708,
  5712,
  5715,
  5718,
  5721,
  5725,
  5728,
  5731,
  5735,
  5738,
  5741,
  5745,
  5748,
  5751,
  5755,
  5758,
  5761,
  5765,
  5768,
  5771,
  5775,
  5778,
  5781,
  5785,
  5788,
  5791,
  5795,
  5798,
  5801,
  5805,
  5808,
  5811,
  5815,
  5818,
  5821,
  5824,
  5828,
  5831,
  5834,
  5838,
  5841,
  5844,
  5848,
  5851,
  5854,
  5858,
  5861,
  5864,
  5868,
  5871,
  5874,
  5878,
  5881,
  5884,
  5888,
  5891,
  5894,
  5898,
  5901,
  5904,
  5908,
  5911,
  5914,
  5917,
  5921,
  5924,
  5927,
  5931,
  5934,
  5937,
  5941,
  5944,
  5947,
  5951,
  5954,
  5957,
  5961,
  5964,
  5967,
  5971,
  5974,
  5977,
  5981,
  5984,
  5987,
  5991,
  5994,
  5997,
  6001,
  6004,
  6007,
  6010,
  6014,
  6017,
  6020,
  6024,
  6027,
  6030,
  6034,
  6037,
  6040,
  6044,
  6047,
  6050,
  6054,
  6057,
  6060,
  6064,
  6067,
  6070,
  6074,
  6077,
  6080,
  6084,
  6087,
  6090,
  6094,
  6097,
  6100,
  6104,
  6107,
  6110,
  6113,
  6117,
  6120,
  6123,
  6127,
  6130,
  6133,
  6137,
  6140,
  6143,
  6147,
  6150,
  6153,
  6157,
  6160,
  6163,
  6167,
  6170,
  6173,
  6177,
  6180,
  6183,
  6187,
  6190,
  6193,
  6197,
  6200,
  6203,
  6206,
  6210,
  6213,
  6216,
  6220,
  6223,
  6226,
  6230,
  6233,
  6236,
  6240,
  6243,
  6246,
  6250,
  6253,
  6256,
  6260,
  6263,
  6266,
  6270,
  6273,
  6276,
  6280,
  6283,
  6286,
  6290,
  6293,
  6296,
  6300,
  6303,
  6306,
  6309,
  6313,
  6316,
  6319,
  6323,
  6326,
  6329,
  6333,
  6336,
  6339,
  6343,
  6346,
  6349,
  6353,
  6356,
  6359,
  6363,
  6366,
  6369,
  6373,
  6376,
  6379,
  6383,
  6386,
  6389,
  6393,
  6396,
  6399,
  6402,
  6406,
  6409,
  6412,
  6416,
  6419,
  6422,
  6426,
  6429,
  6432,
  6436,
  6439,
  6442,
  6446,
  6449,
  6452,
  6456,
  6459,
  6462,
  6466,
  6469,
  6472,
  6476,
  6479,
  6482,
  6486,
  6489,
  6492,
  6495,
  6499,
  6502,
  6505,
  6509,
  6512,
  6515,
  6519,
  6522,
  6525,
  6529,
  6532,
  6535,
  6539,
  6542,
  6545,
  6549,
  6552,
  6555,
  6559,
  6562,
  6565,
  6569,
  6572,
  6575,
  6579,
  6582,
  6585,
  6589,
  6592,
  6595,
  6598,
  6602,
  6605,
  6608,
  6612,
  6615,
  6618,
  6622,
  6625,
  6628,
  6632,
  6635,
  6638,
  6642,
  6645,
  6648,
  6652,
  6655,
  6658,
  6662,
  6665,
  6668,
  6672,
  6675,
  6678,
  6682,
  6685,
  6688,
  6691,
  6695,
  6698,
  6701,
  6705,
  6708,
  6711,
  6715,
  6718,
  6721,
  6725,
  6728,
  6731,
  6735,
  6738,
  6741,
  6745,
  6748,
  6751,
  6755,
  6758,
  6761,
  6765,
  6768,
  6771,
  6775,
  6778,
  6781,
  6785,
  6788,
  6791,
  6794,
  6798,
  6801,
  6804,
  6808,
  6811,
  6814,
  6818,
  6821,
  6824,
  6828,
  6831,
  6834,
  6838,
  6841,
  6844,
  6848,
  6851,
  6854,
  6858,
  6861,
  6864,
  6868,
  6871,
  6874,
  6878,
  6881,
  6884,
  6887,
  6891,
  6894,
  6897,
  6901,
  6904,
  6907,
  6911,
  6914,
  6917,
  6921,
  6924,
  6927,
  6931,
  6934,
  6937,
  6941,
  6944,
  6947,
  6951,
  6954,
  6957,
  6961,
  6964,
  6967,
  6971,
  6974,
  6977,
  6980,
  6984,
  6987,
  6990,
  6994,
  6997,
  7000,
  7004,
  7007,
  7010,
  7014,
  7017,
  7020,
  7024,
  7027,
  7030,
  7034,
  7037,
  7040,
  7044,
  7047,
  7050,
  7054,
  7057,
  7060,
  7064,
  7067,
  7070,
  7074,
  7077,
  7080,
  7083,
  7087,
  7090,
  7093,
  7097,
  7100,
  7103,
  7107,
  7110,
  7113,
  7117,
  7120,
  7123,
  7127,
  7130,
  7133,
  7137,
  7140,
  7143,
  7147,
  7150,
  7153,
  7157,
  7160,
  7163,
  7167,
  7170,
  7173,
  7176,
  7180,
  7183,
  7186,
  7190,
  7193,
  7196,
  7200,
  7203,
  7206,
  7210,
  7213,
  7216,
  7220,
  7223,
  7226,
  7230,
  7233,
  7236,
  7240,
  7243,
  7246,
  7250,
  7253,
  7256,
  7260,
  7263,
  7266,
  7270,
  7273,
  7276,
  7279,
  7283,
  7286,
  7289,
  7293,
  7296,
  7299,
  7303,
  7306,
  7309,
  7313,
  7316,
  7319,
  7323,
  7326,
  7329,
  7333,
  7336,
  7339,
  7343,
  7346,
  7349,
  7353,
  7356,
  7359,
  7363,
  7366,
  7369,
  7372,
  7376,
  7379,
  7382,
  7386,
  7389,
  7392,
  7396,
  7399,
  7402,
  7406,
  7409,
  7412,
  7416,
  7419,
  7422,
  7426,
  7429,
  7432,
  7436,
  7439,
  7442,
  7446,
  7449,
  7452,
  7456,
  7459,
  7462,
  7465,
  7469,
  7472,
  7475,
  7479,
  7482,
  7485,
  7489,
  7492,
  7495,
  7499,
  7502,
  7505,
  7509,
  7512,
  7515,
  7519,
  7522,
  7525,
  7529,
  7532,
  7535,
  7539,
  7542,
  7545,
  7549,
  7552,
  7555,
  7559,
  7562,
  7565,
  7568,
  7572,
  7575,
  7578,
  7582,
  7585,
  7588,
  7592,
  7595,
  7598,
  7602,
  7605,
  7608,
  7612,
  7615,
  7618,
  7622,
  7625,
  7628,
  7632,
  7635,
  7638,
  7642,
  7645,
  7648,
  7652,
  7655,
  7658,
  7661,
  7665,
  7668,
  7671,
  7675,
  7678,
  7681,
  7685,
  7688,
  7691,
  7695,
  7698,
  7701,
  7705,
  7708,
  7711,
  7715,
  7718,
  7721,
  7725,
  7728,
  7731,
  7735,
  7738,
  7741,
  7745,
  7748,
  7751,
  7755,
  7758,
  7761,
  7764,
  7768,
  7771,
  7774,
  7778,
  7781,
  7784,
  7788,
  7791,
  7794,
  7798,
  7801,
  7804,
  7808,
  7811,
  7814,
  7818,
  7821,
  7824,
  7828,
  7831,
  7834,
  7838,
  7841,
  7844,
  7848,
  7851,
  7854,
  7857,
  7861,
  7864,
  7867,
  7871,
  7874,
  7877,
  7881,
  7884,
  7887,
  7891,
  7894,
  7897,
  7901,
  7904,
  7907,
  7911,
  7914,
  7917,
  7921,
  7924,
  7927,
  7931,
  7934,
  7937,
  7941,
  7944,
  7947,
  7951,
  7954,
  7957,
  7960,
  7964,
  7967,
  7970,
  7974,
  7977,
  7980,
  7984,
  7987,
  7990,
  7994,
  7997,
  8000,
  8004,
  8007,
  8010,
  8014,
  8017,
  8020,
  8024,
  8027,
  8030,
  8034,
  8037,
  8040,
  8044,
  8047,
  8050,
  8053,
  8057,
  8060,
  8063,
  8067,
  8070,
  8073,
  8077,
  8080,
  8083,
  8087,
  8090,
  8093,
  8097,
  8100,
  8103,
  8107,
  8110,
  8113,
  8117,
  8120,
  8123,
  8127,
  8130,
  8133,
  8137,
  8140,
  8143,
  8146,
  8150,
  8153,
  8156,
  8160,
  8163,
  8166,
  8170,
  8173,
  8176,
  8180,
  8183,
  8186,
  8190,
  8193,
  8196,
  8200,
  8203,
  8206,
  8210,
  8213,
  8216,
  8220,
  8223,
  8226,
  8230,
  8233,
  8236,
  8240,
  8243,
  8246,
  8249,
  8253,
  8256,
  8259,
  8263,
  8266,
  8269,
  8273,
  8276,
  8279,
  8283,
  8286,
  8289,
  8293,
  8296,
  8299,
  8303,
  8306,
  8309,
  8313,
  8316,
  8319,
  8323,
  8326,
  8329,
  8333,
  8336,
  8339,
  8342,
  8346,
  8349,
  8352,
  8356,
  8359,
  8362,
  8366,
  8369,
  8372,
  8376,
  8379,
  8382,
  8386,
  8389,
  8392,
  8396,
  8399,
  8402,
  8406,
  8409,
  8412,
  8416,
  8419,
  8422,
  8426,
  8429,
  8432,
  8436,
  8439,
  8442,
  8445,
  8449,
  8452,
  8455,
  8459,
  8462,
  8465,
  8469,
  8472,
  8475,
  8479,
  8482,
  8485,
  8489,
  8492,
  8495,
  8499,
  8502,
  8505,
  8509,
  8512,
  8515,
  8519,
  8522,
  8525,
  8529,
  8532,
  8535,
  8538,
  8542,
  8545,
  8548,
  8552,
  8555,
  8558,
  8562,
  8565,
  8568,
  8572,
  8575,
  8578,
  8582,
  8585,
  8588,
  8592,
  8595,
  8598,
  8602,
  8605,
  8608,
  8612,
  8615,
  8618,
  8622,
  8625,
  8628,
  8631,
  8635,
  8638,
  8641,
  8645,
  8648,
  8651,
  8655,
  8658,
  8661,
  8665,
  8668,
  8671,
  8675,
  8678,
  8681,
  8685,
  8688,
  8691,
  8695,
  8698,
  8701,
  8705,
  8708,
  8711,
  8715,
  8718,
  8721,
  8725,
  8728,
  8731,
  8734,
  8738,
  8741,
  8744,
  8748,
  8751,
  8754,
  8758,
  8761,
  8764,
  8768,
  8771,
  8774,
  8778,
  8781,
  8784,
  8788,
  8791,
  8794,
  8798,
  8801,
  8804,
  8808,
  8811,
  8814,
  8818,
  8821,
  8824,
  8827,
  8831,
  8834,
  8837,
  8841,
  8844,
  8847,
  8851,
  8854,
  8857,
  8861,
  8864,
  8867,
  8871,
  8874,
  8877,
  8881,
  8884,
  8887,
  8891,
  8894,
  8897,
  8901,
  8904,
  8907,
  8911,
  8914,
  8917,
  8921,
  8924,
  8927,
  8930,
  8934,
  8937,
  8940,
  8944,
  8947,
  8950,
  8954,
  8957,
  8960,
  8964,
  8967,
  8970,
  8974,
  8977,
  8980,
  8984,
  8987,
  8990,
  8994,
  8997,
  9000,
  9004,
  9007,
  9010,
  9014,
  9017,
  9020,
  9023,
  9027,
  9030,
  9033,
  9037,
  9040,
  9043,
  9047,
  9050,
  9053,
  9057,
  9060,
  9063,
  9067,
  9070,
  9073,
  9077,
  9080,
  9083,
  9087,
  9090,
  9093,
  9097,
  9100,
  9103,
  9107,
  9110,
  9113,
  9116,
  9120,
  9123,
  9126,
  9130,
  9133,
  9136,
  9140,
  9143,
  9146,
  9150,
  9153,
  9156,
  9160,
  9163,
  9166,
  9170,
  9173,
  9176,
  9180,
  9183,
  9186,
  9190,
  9193,
  9196,
  9200,
  9203,
  9206,
  9210,
  9213,
  9216,
  9219,
  9223,
  9226,
  9229,
  9233,
  9236,
  9239,
  9243,
  9246,
  9249,
  9253,
  9256,
  9259,
  9263,
  9266,
  9269,
  9273,
  9276,
  9279,
  9283,
  9286,
  9289,
  9293,
  9296,
  9299,
  9303,
  9306,
  9309,
  9312,
  9316,
  9319,
  9322,
  9326,
  9329,
  9332,
  9336,
  9339,
  9342,
  9346,
  9349,
  9352,
  9356,
  9359,
  9362,
  9366,
  9369,
  9372,
  9376,
  9379,
  9382,
  9386,
  9389,
  9392,
  9396,
  9399,
  9402,
  9406,
  9409,
  9412,
  9415,
  9419,
  9422,
  9425,
  9429,
  9432,
  9435,
  9439,
  9442,
  9445,
  9449,
  9452,
  9455,
  9459,
  9462,
  9465,
  9469,
  9472,
  9475,
  9479,
  9482,
  9485,
  9489,
  9492,
  9495,
  9499,
  9502,
  9505,
  9508,
  9512,
  9515,
  9518,
  9522,
  9525,
  9528,
  9532,
  9535,
  9538,
  9542,
  9545,
  9548,
  9552,
  9555,
  9558,
  9562,
  9565,
  9568,
  9572,
  9575,
  9578,
  9582,
  9585,
  9588,
  9592,
  9595,
  9598,
  9601,
  9605,
  9608,
  9611,
  9615,
  9618,
  9621,
  9625,
  9628,
  9631,
  9635,
  9638,
  9641,
  9645,
  9648,
  9651,
  9655,
  9658,
  9661,
  9665,
  9668,
  9671,
  9675,
  9678,
  9681,
  9685,
  9688,
  9691,
  9695,
  9698,
  9701,
  9704,
  9708,
  9711,
  9714,
  9718,
  9721,
  9724,
  9728,
  9731,
  9734,
  9738,
  9741,
  9744,
  9748,
  9751,
  9754,
  9758,
  9761,
  9764,
  9768,
  9771,
  9774,
  9778,
  9781,
  9784,
  9788,
  9791,
  9794,
  9797,
  9801,
  9804,
  9807,
  9811,
  9814,
  9817,
  9821,
  9824,
  9827,
  9831,
  9834,
  9837,
  9841,
  9844,
  9847,
  9851,
  9854,
  9857,
  9861,
  9864,
  9867,
  9871,
  9874,
  9877,
  9881,
  9884,
  9887,
  9891,
  9894,
  9897,
  9900,
  9904,
  9907,
  9910,
  9914,
  9917,
  9920,
  9924,
  9927,
  9930,
  9934,
  9937,
  9940,
  9944,
  9947,
  9950,
  9954,
  9957,
  9960,
  9964,
  9967,
  9970,
  9974,
  9977,
  9980,
  9984,
  9987,
  9990,
  9993,
  9997,
  10000,
  10003,
  10007,
  10010,
  10013,
  10017,
  10020,
  10023,
  10027,
  10030,
  10033,
  10037,
  10040,
  10043,
  10047,
  10050,
  10053,
  10057,
  10060,
  10063,
  10067,
  10070,
  10073,
  10077,
  10080,
  10083,
  10087,
  10090,
  10093,
  10096,
  10100,
  10103,
  10106,
  10110,
  10113,
  10116,
  10120,
  10123,
  10126,
  10130,
  10133,
  10136,
  10140,
  10143,
  10146,
  10150,
  10153,
  10156,
  10160,
  10163,
  10166,
  10170,
  10173,
  10176,
  10180,
  10183,
  10186,
  10189,
  10193,
  10196,
  10199,
  10203,
  10206,
  10209,
  10213,
  10216,
  10219,
  10223,
  10226,
  10229,
  10233,
  10236,
  10239,
  10243,
  10246,
  10249,
  10253,
  10256,
  10259,
  10263,
  10266,
  10269,
  10273,
  10276,
  10279,
  10282,
  10286,
  10289,
  10292,
  10296,
  10299,
  10302,
  10306,
  10309,
  10312,
  10316,
  10319,
  10322,
  10326,
  10329,
  10332,
  10336,
  10339,
  10342,
  10346,
  10349,
  10352,
  10356,
  10359,
  10362,
  10366,
  10369,
  10372,
  10376,
  10379,
  10382,
  10385,
  10389,
  10392,
  10395,
  10399,
  10402,
  10405,
  10409,
  10412,
  10415,
  10419,
  10422,
  10425,
  10429,
  10432,
  10435,
  10439,
  10442,
  10445,
  10449,
  10452,
  10455,
  10459,
  10462,
  10465,
  10469,
  10472,
  10475,
  10478,
  10482,
  10485,
  10488,
  10492,
  10495,
  10498,
  10502,
  10505,
  10508,
  10512,
  10515,
  10518,
  10522,
  10525,
  10528,
  10532,
  10535,
  10538,
  10542,
  10545,
  10548,
  10552,
  10555,
  10558,
  10562,
  10565,
  10568,
  10572,
  10575,
  10578,
  10581,
  10585,
  10588,
  10591,
  10595,
  10598,
  10601,
  10605,
  10608,
  10611,
  10615,
  10618,
  10621,
  10625,
  10628,
  10631,
  10635,
  10638,
  10641,
  10645,
  10648,
  10651,
  10655,
  10658,
  10661,
  10665,
  10668,
  10671,
  10674,
  10678,
  10681,
  10684,
  10688,
  10691,
  10694,
  10698,
  10701,
  10704,
  10708,
  10711,
  10714,
  10718,
  10721,
  10724,
  10728,
  10731,
  10734,
  10738,
  10741,
  10744,
  10748,
  10751,
  10754,
  10758,
  10761,
  10764,
  10767,
  10771,
  10774,
  10777,
  10781,
  10784,
  10787,
  10791,
  10794,
  10797,
  10801,
  10804,
  10807,
  10811,
  10814,
  10817,
  10821,
  10824,
  10827,
  10831,
  10834,
  10837,
  10841,
  10844,
  10847,
  10851,
  10854,
  10857,
  10861,
  10864,
  10867,
  10870,
  10874,
  10877,
  10880,
  10884,
  10887,
  10890,
  10894,
  10897,
  10900,
  10904,
  10907,
  10910,
  10914,
  10917,
  10920,
  10924,
  10927,
  10930,
  10934,
  10937,
  10940,
  10944,
  10947,
  10950,
  10954,
  10957,
  10960,
  10963,
  10967,
  10970,
  10973,
  10977,
  10980,
  10983,
  10987,
  10990,
  10993,
  10997,
  11000,
  11003,
  11007,
  11010,
  11013,
  11017,
  11020,
  11023,
  11027,
  11030,
  11033,
  11037,
  11040,
  11043,
  11047,
  11050,
  11053,
  11057,
  11060,
  11063,
  11066,
  11070,
  11073,
  11076,
  11080,
  11083,
  11086,
  11090,
  11093,
  11096,
  11100,
  11103,
  11106,
  11110,
  11113,
  11116,
  11120,
  11123,
  11126,
  11130,
  11133,
  11136,
  11140,
  11143,
  11146,
  11150,
  11153,
  11156,
  11159,
  11163,
  11166,
  11169,
  11173,
  11176,
  11179,
  11183,
  11186,
  11189,
  11193,
  11196,
  11199,
  11203,
  11206,
  11209,
  11213,
  11216,
  11219,
  11223,
  11226,
  11229,
  11233,
  11236,
  11239,
  11243,
  11246,
  11249,
  11252,
  11256,
  11259,
  11262,
  11266,
  11269,
  11272,
  11276,
  11279,
  11282,
  11286,
  11289,
  11292,
  11296,
  11299,
  11302,
  11306,
  11309,
  11312,
  11316,
  11319,
  11322,
  11326,
  11329,
  11332,
  11336,
  11339,
  11342,
  11346,
  11349,
  11352,
  11355,
  11359,
  11362,
  11365,
  11369,
  11372,
  11375,
  11379,
  11382,
  11385,
  11389,
  11392,
  11395,
  11399,
  11402,
  11405,
  11409,
  11412,
  11415,
  11419,
  11422,
  11425,
  11429,
  11432,
  11435,
  11439,
  11442,
  11445,
  11448,
  11452,
  11455,
  11458,
  11462,
  11465,
  11468,
  11472,
  11475,
  11478,
  11482,
  11485,
  11488,
  11492,
  11495,
  11498,
  11502,
  11505,
  11508,
  11512,
  11515,
  11518,
  11522,
  11525,
  11528,
  11532,
  11535,
  11538,
  11542,
  11545,
  11548,
  11551,
  11555,
  11558,
  11561,
  11565,
  11568,
  11571,
  11575,
  11578,
  11581,
  11585,
  11588,
  11591,
  11595,
  11598,
  11601,
  11605,
  11608,
  11611,
  11615,
  11618,
  11621,
  11625,
  11628,
  11631,
  11635,
  11638,
  11641,
  11644,
  11648,
  11651,
  11654,
  11658,
  11661,
  11664,
  11668,
  11671,
  11674,
  11678,
  11681,
  11684,
  11688,
  11691,
  11694,
  11698,
  11701,
  11704,
  11708,
  11711,
  11714,
  11718,
  11721,
  11724,
  11728,
  11731,
  11734,
  11737,
  11741,
  11744,
  11747,
  11751,
  11754,
  11757,
  11761,
  11764,
  11767,
  11771,
  11774,
  11777,
  11781,
  11784,
  11787,
  11791,
  11794,
  11797,
  11801,
  11804,
  11807,
  11811,
  11814,
  11817,
  11821,
  11824,
  11827,
  11831,
  11834,
  11837,
  11840,
  11844,
  11847,
  11850,
  11854,
  11857,
  11860,
  11864,
  11867,
  11870,
  11874,
  11877,
  11880,
  11884,
  11887,
  11890,
  11894,
  11897,
  11900,
  11904,
  11907,
  11910,
  11914,
  11917,
  11920,
  11924,
  11927,
  11930,
  11933,
  11937,
  11940,
  11943,
  11947,
  11950,
  11953,
  11957,
  11960,
  11963,
  11967,
  11970,
  11973,
  11977,
  11980,
  11983,
  11987,
  11990,
  11993,
  11997,
  12000,
  12003,
  12007,
  12010,
  12013,
  12017,
  12020,
  12023,
  12027,
  12030,
  12033,
  12036,
  12040,
  12043,
  12046,
  12050,
  12053,
  12056,
  12060,
  12063,
  12066,
  12070,
  12073,
  12076,
  12080,
  12083,
  12086,
  12090,
  12093,
  12096,
  12100,
  12103,
  12106,
  12110,
  12113,
  12116,
  12120,
  12123,
  12126,
  12129,
  12133,
  12136,
  12139,
  12143,
  12146,
  12149,
  12153,
  12156,
  12159,
  12163,
  12166,
  12169,
  12173,
  12176,
  12179,
  12183,
  12186,
  12189,
  12193,
  12196,
  12199,
  12203,
  12206,
  12209,
  12213,
  12216,
  12219,
  12223,
  12226,
  12229,
  12232,
  12236,
  12239,
  12242,
  12246,
  12249,
  12252,
  12256,
  12259,
  12262,
  12266,
  12269,
  12272,
  12276,
  12279,
  12282,
  12286,
  12289,
  12292,
  12296,
  12299,
  12302,
  12306,
  12309,
  12312,
  12316,
  12319,
  12322,
  12325,
  12329,
  12332,
  12335,
  12339,
  12342,
  12345,
  12349,
  12352,
  12355,
  12359,
  12362,
  12365,
  12369,
  12372,
  12375,
  12379,
  12382,
  12385,
  12389,
  12392,
  12395,
  12399,
  12402,
  12405,
  12409,
  12412,
  12415,
  12418,
  12422,
  12425,
  12428,
  12432,
  12435,
  12438,
  12442,
  12445,
  12448,
  12452,
  12455,
  12458,
  12462,
  12465,
  12468,
  12472,
  12475,
  12478,
  12482,
  12485,
  12488,
  12492,
  12495,
  12498,
  12502,
  12505,
  12508,
  12512,
  12515,
  12518,
  12521,
  12525,
  12528,
  12531,
  12535,
  12538,
  12541,
  12545,
  12548,
  12551,
  12555,
  12558,
  12561,
  12565,
  12568,
  12571,
  12575,
  12578,
  12581,
  12585,
  12588,
  12591,
  12595,
  12598,
  12601,
  12605,
  12608,
  12611,
  12614,
  12618,
  12621,
  12624,
  12628,
  12631,
  12634,
  12638,
  12641,
  12644,
  12648,
  12651,
  12654,
  12658,
  12661,
  12664,
  12668,
  12671,
  12674,
  12678,
  12681,
  12684,
  12688,
  12691,
  12694,
  12698,
  12701,
  12704,
  12708,
  12711,
  12714,
  12717,
  12721,
  12724,
  12727,
  12731,
  12734,
  12737,
  12741,
  12744,
  12747,
  12751,
  12754,
  12757,
  12761,
  12764,
  12767,
  12771,
  12774,
  12777,
  12781,
  12784,
  12787,
  12791,
  12794,
  12797,
  12801,
  12804,
  12807,
  12810,
  12814,
  12817,
  12820,
  12824,
  12827,
  12830,
  12834,
  12837,
  12840,
  12844,
  12847,
  12850,
  12854,
  12857,
  12860,
  12864,
  12867,
  12870,
  12874,
  12877,
  12880,
  12884,
  12887,
  12890,
  12894,
  12897,
  12900,
  12903,
  12907,
  12910,
  12913,
  12917,
  12920,
  12923,
  12927,
  12930,
  12933,
  12937,
  12940,
  12943,
  12947,
  12950,
  12953,
  12957,
  12960,
  12963,
  12967,
  12970,
  12973,
  12977,
  12980,
  12983,
  12987,
  12990,
  12993,
  12997,
  13000,
  13003,
  13006,
  13010,
  13013,
  13016,
  13020,
  13023,
  13026,
  13030,
  13033,
  13036,
  13040,
  13043,
  13046,
  13050,
  13053,
  13056,
  13060,
  13063,
  13066,
  13070,
  13073,
  13076,
  13080,
  13083,
  13086,
  13090,
  13093,
  13096,
  13099,
  13103,
  13106,
  13109,
  13113,
  13116,
  13119,
  13123,
  13126,
  13129,
  13133,
  13136,
  13139,
  13143,
  13146,
  13149,
  13153,
  13156,
  13159,
  13163,
  13166,
  13169,
  13173,
  13176,
  13179,
  13183,
  13186,
  13189,
  13193,
  13196,
  13199,
  13202,
  13206,
  13209,
  13212,
  13216,
  13219,
  13222,
  13226,
  13229,
  13232,
  13236,
  13239,
  13242,
  13246,
  13249,
  13252,
  13256,
  13259,
  13262,
  13266,
  13269,
  13272,
  13276,
  13279,
  13282,
  13286,
  13289,
  13292,
  13295,
  13299,
  13302,
  13305,
  13309,
  13312,
  13315,
  13319,
  13322,
  13325,
  13329,
  13332,
  13335,
  13339,
  13342,
  13345,
  13349,
  13352,
  13355,
  13359,
  13362,
  13365,
  13369,
  13372,
  13375,
  13379,
  13382,
  13385,
  13388,
  13392,
  13395,
  13398,
  13402,
  13405,
  13408,
  13412,
  13415,
  13418,
  13422,
  13425,
  13428,
  13432,
  13435,
  13438,
  13442,
  13445,
  13448,
  13452,
  13455,
  13458,
  13462,
  13465,
  13468,
  13472,
  13475,
  13478,
  13482,
  13485,
  13488,
  13491,
  13495,
  13498,
  13501,
  13505,
  13508,
  13511,
  13515,
  13518,
  13521,
  13525,
  13528,
  13531,
  13535,
  13538,
  13541,
  13545,
  13548,
  13551,
  13555,
  13558,
  13561,
  13565,
  13568,
  13571,
  13575,
  13578,
  13581,
  13584,
  13588,
  13591,
  13594,
  13598,
  13601,
  13604,
  13608,
  13611,
  13614,
  13618,
  13621,
  13624,
  13628,
  13631,
  13634,
  13638,
  13641,
  13644,
  13648,
  13651,
  13654,
  13658,
  13661,
  13664,
  13668,
  13671,
  13674,
  13678,
  13681,
  13684,
  13687,
  13691,
  13694,
  13697,
  13701,
  13704,
  13707,
  13711,
  13714,
  13717,
  13721,
  13724,
  13727,
  13731,
  13734,
  13737,
  13741,
  13744,
  13747,
  13751,
  13754,
  13757,
  13761,
  13764,
  13767,
  13771,
  13774,
  13777,
  13780,
  13784,
  13787,
  13790,
  13794,
  13797,
  13800,
  13804,
  13807,
  13810,
  13814,
  13817,
  13820,
  13824,
  13827,
  13830,
  13834,
  13837,
  13840,
  13844,
  13847,
  13850,
  13854,
  13857,
  13860,
  13864,
  13867,
  13870,
  13873,
  13877,
  13880,
  13883,
  13887,
  13890,
  13893,
  13897,
  13900,
  13903,
  13907,
  13910,
  13913,
  13917,
  13920,
  13923,
  13927,
  13930,
  13933,
  13937,
  13940,
  13943,
  13947,
  13950,
  13953,
  13957,
  13960,
  13963,
  13967,
  13970,
  13973,
  13976,
  13980,
  13983,
  13986,
  13990,
  13993,
  13996,
  14000,
  14003,
  14006,
  14010,
  14013,
  14016,
  14020,
  14023,
  14026,
  14030,
  14033,
  14036,
  14040,
  14043,
  14046,
  14050,
  14053,
  14056,
  14060,
  14063,
  14066,
  14069,
  14073,
  14076,
  14079,
  14083,
  14086,
  14089,
  14093,
  14096,
  14099,
  14103,
  14106,
  14109,
  14113,
  14116,
  14119,
  14123,
  14126,
  14129,
  14133,
  14136,
  14139,
  14143,
  14146,
  14149,
  14153,
  14156,
  14159,
  14163,
  14166,
  14169,
  14172,
  14176,
  14179,
  14182,
  14186,
  14189,
  14192,
  14196,
  14199,
  14202,
  14206,
  14209,
  14212,
  14216,
  14219,
  14222,
  14226,
  14229,
  14232,
  14236,
  14239,
  14242,
  14246,
  14249,
  14252,
  14256,
  14259,
  14262,
  14265,
  14269,
  14272,
  14275,
  14279,
  14282,
  14285,
  14289,
  14292,
  14295,
  14299,
  14302,
  14305,
  14309,
  14312,
  14315,
  14319,
  14322,
  14325,
  14329,
  14332,
  14335,
  14339,
  14342,
  14345,
  14349,
  14352,
  14355,
  14359,
  14362,
  14365,
  14368,
  14372,
  14375,
  14378,
  14382,
  14385,
  14388,
  14392,
  14395,
  14398,
  14402,
  14405,
  14408,
  14412,
  14415,
  14418,
  14422,
  14425,
  14428,
  14432,
  14435,
  14438,
  14442,
  14445,
  14448,
  14452,
  14455,
  14458,
  14461,
  14465,
  14468,
  14471,
  14475,
  14478,
  14481,
  14485,
  14488,
  14491,
  14495,
  14498,
  14501,
  14505,
  14508,
  14511,
  14515,
  14518,
  14521,
  14525,
  14528,
  14531,
  14535,
  14538,
  14541,
  14545,
  14548,
  14551,
  14554,
  14558,
  14561,
  14564,
  14568,
  14571,
  14574,
  14578,
  14581,
  14584,
  14588,
  14591,
  14594,
  14598,
  14601,
  14604,
  14608,
  14611,
  14614,
  14618,
  14621,
  14624,
  14628,
  14631,
  14634,
  14638,
  14641,
  14644,
  14648,
  14651,
  14654,
  14657,
  14661,
  14664,
  14667,
  14671,
  14674,
  14677,
  14681,
  14684,
  14687,
  14691,
  14694,
  14697,
  14701,
  14704,
  14707,
  14711,
  14714,
  14717,
  14721,
  14724,
  14727,
  14731,
  14734,
  14737,
  14741,
  14744,
  14747,
  14750,
  14754,
  14757,
  14760,
  14764,
  14767,
  14770,
  14774,
  14777,
  14780,
  14784,
  14787,
  14790,
  14794,
  14797,
  14800,
  14804,
  14807,
  14810,
  14814,
  14817,
  14820,
  14824,
  14827,
  14830,
  14834,
  14837,
  14840,
  14844,
  14847,
  14850,
  14853,
  14857,
  14860,
  14863,
  14867,
  14870,
  14873,
  14877,
  14880,
  14883,
  14887,
  14890,
  14893,
  14897,
  14900,
  14903,
  14907,
  14910,
  14913,
  14917,
  14920,
  14923,
  14927,
  14930,
  14933,
  14937,
  14940,
  14943,
  14946,
  14950,
  14953,
  14956,
  14960,
  14963,
  14966,
  14970,
  14973,
  14976,
  14980,
  14983,
  14986,
  14990,
  14993,
  14996,
  15000,
  15003,
  15006,
  15010,
  15013,
  15016,
  15020,
  15023,
  15026,
  15030,
  15033,
  15036,
  15039,
  15043,
  15046,
  15049,
  15053,
  15056,
  15059,
  15063,
  15066,
  15069,
  15073,
  15076,
  15079,
  15083,
  15086,
  15089,
  15093,
  15096,
  15099,
  15103,
  15106,
  15109,
  15113,
  15116,
  15119,
  15123,
  15126,
  15129,
  15133,
  15136,
  15139,
  15142,
  15146,
  15149,
  15152,
  15156,
  15159,
  15162,
  15166,
  15169,
  15172,
  15176,
  15179,
  15182,
  15186,
  15189,
  15192,
  15196,
  15199,
  15202,
  15206,
  15209,
  15212,
  15216,
  15219,
  15222,
  15226,
  15229,
  15232,
  15235,
  15239,
  15242,
  15245,
  15249,
  15252,
  15255,
  15259,
  15262,
  15265,
  15269,
  15272,
  15275,
  15279,
  15282,
  15285,
  15289,
  15292,
  15295,
  15299,
  15302,
  15305,
  15309,
  15312,
  15315,
  15319,
  15322,
  15325,
  15329,
  15332,
  15335,
  15338,
  15342,
  15345,
  15348,
  15352,
  15355,
  15358,
  15362,
  15365,
  15368,
  15372,
  15375,
  15378,
  15382,
  15385,
  15388,
  15392,
  15395,
  15398,
  15402,
  15405,
  15408,
  15412,
  15415,
  15418,
  15422,
  15425,
  15428,
  15431,
  15435,
  15438,
  15441,
  15445,
  15448,
  15451,
  15455,
  15458,
  15461,
  15465,
  15468,
  15471,
  15475,
  15478,
  15481,
  15485,
  15488,
  15491,
  15495,
  15498,
  15501,
  15505,
  15508,
  15511,
  15515,
  15518,
  15521,
  15524,
  15528,
  15531,
  15534,
  15538,
  15541,
  15544,
  15548,
  15551,
  15554,
  15558,
  15561,
  15564,
  15568,
  15571,
  15574,
  15578,
  15581,
  15584,
  15588,
  15591,
  15594,
  15598,
  15601,
  15604,
  15608,
  15611,
  15614,
  15618,
  15621,
  15624,
  15627,
  15631,
  15634,
  15637,
  15641,
  15644,
  15647,
  15651,
  15654,
  15657,
  15661,
  15664,
  15667,
  15671,
  15674,
  15677,
  15681,
  15684,
  15687,
  15691,
  15694,
  15697,
  15701,
  15704,
  15707,
  15711,
  15714,
  15717,
  15720,
  15724,
  15727,
  15730,
  15734,
  15737,
  15740,
  15744,
  15747,
  15750,
  15754,
  15757,
  15760,
  15764,
  15767,
  15770,
  15774,
  15777,
  15780,
  15784,
  15787,
  15790,
  15794,
  15797,
  15800,
  15804,
  15807,
  15810,
  15814,
  15817,
  15820,
  15823,
  15827,
  15830,
  15833,
  15837,
  15840,
  15843,
  15847,
  15850,
  15853,
  15857,
  15860,
  15863,
  15867,
  15870,
  15873,
  15877,
  15880,
  15883,
  15887,
  15890,
  15893,
  15897,
  15900,
  15903,
  15907,
  15910,
  15913,
  15916,
  15920,
  15923,
  15926,
  15930,
  15933,
  15936,
  15940,
  15943,
  15946,
  15950,
  15953,
  15956,
  15960,
  15963,
  15966,
  15970,
  15973,
  15976,
  15980,
  15983,
  15986,
  15990,
  15993,
  15996,
  16000,
  16003,
  16006,
  16009,
  16013,
  16016,
  16019,
  16023,
  16026,
  16029,
  16033,
  16036,
  16039,
  16043,
  16046,
  16049,
  16053,
  16056,
  16059,
  16063,
  16066,
  16069,
  16073,
  16076,
  16079,
  16083,
  16086,
  16089,
  16093,
  16096,
  16099,
  16103,
  16106,
  16109,
  16112,
  16116,
  16119,
  16122,
  16126,
  16129,
  16132,
  16136,
  16139,
  16142,
  16146,
  16149,
  16152,
  16156,
  16159,
  16162,
  16166,
  16169,
  16172,
  16176,
  16179,
  16182,
  16186,
  16189,
  16192,
  16196,
  16199,
  16202,
  16205,
  16209,
  16212,
  16215,
  16219,
  16222,
  16225,
  16229,
  16232,
  16235,
  16239,
  16242,
  16245,
  16249,
  16252,
  16255,
  16259,
  16262,
  16265,
  16269,
  16272,
  16275,
  16279,
  16282,
  16285,
  16289,
  16292,
  16295,
  16299,
  16302,
  16305,
  16308,
  16312,
  16315,
  16318,
  16322,
  16325,
  16328,
  16332,
  16335,
  16338,
  16342,
  16345,
  16348,
  16352,
  16355,
  16358,
  16362,
  16365,
  16368,
  16372,
  16375,
  16378,
  16382,
  16385,
  16388,
  16392,
  16395,
  16398,
  16401,
  16405,
  16408,
  16411,
  16415,
  16418,
  16421,
  16425,
  16428,
  16431,
  16435,
  16438,
  16441,
  16445,
  16448,
  16451,
  16455,
  16458,
  16461,
  16465,
  16468,
  16471,
  16475,
  16478,
  16481,
  16485,
  16488,
  16491,
  16494,
  16498,
  16501,
  16504,
  16508,
  16511,
  16514,
  16518,
  16521,
  16524,
  16528,
  16531,
  16534,
  16538,
  16541,
  16544,
  16548,
  16551,
  16554,
  16558,
  16561,
  16564,
  16568,
  16571,
  16574,
  16578,
  16581,
  16584,
  16588,
  16591,
  16594,
  16597,
  16601,
  16604,
  16607,
  16611,
  16614,
  16617,
  16621,
  16624,
  16627,
  16631,
  16634,
  16637,
  16641,
  16644,
  16647,
  16651,
  16654,
  16657,
  16661,
  16664,
  16667,
  16671,
  16674,
  16677,
  16681,
  16684,
  16687,
  16690,
  16694,
  16697,
  16700,
  16704,
  16707,
  16710,
  16714,
  16717,
  16720,
  16724,
  16727,
  16730,
  16734,
  16737,
  16740,
  16744,
  16747,
  16750,
  16754,
  16757,
  16760,
  16764,
  16767,
  16770,
  16774,
  16777,
  16780,
  16784,
  16787,
  16790,
  16793,
  16797,
  16800,
  16803,
  16807,
  16810,
  16813,
  16817,
  16820,
  16823,
  16827,
  16830,
  16833,
  16837,
  16840,
  16843,
  16847,
  16850,
  16853,
  16857,
  16860,
  16863,
  16867,
  16870,
  16873,
  16877,
  16880,
  16883,
  16886,
  16890,
  16893,
  16896,
  16900,
  16903,
  16906,
  16910,
  16913,
  16916,
  16920,
  16923,
  16926,
  16930,
  16933,
  16936,
  16940,
  16943,
  16946,
  16950,
  16953,
  16956,
  16960,
  16963,
  16966,
  16970,
  16973,
  16976,
  16980,
  16983,
  16986,
  16989,
  16993,
  16996,
  16999,
  17003,
  17006,
  17009,
  17013,
  17016,
  17019,
  17023,
  17026,
  17029,
  17033,
  17036,
  17039,
  17043,
  17046,
  17049,
  17053,
  17056,
  17059,
  17063,
  17066,
  17069,
  17073,
  17076,
  17079,
  17082,
  17086,
  17089,
  17092,
  17096,
  17099,
  17102,
  17106,
  17109,
  17112,
  17116,
  17119,
  17122,
  17126,
  17129,
  17132,
  17136,
  17139,
  17142,
  17146,
  17149,
  17152,
  17156,
  17159,
  17162,
  17166,
  17169,
  17172,
  17175,
  17179,
  17182,
  17185,
  17189,
  17192,
  17195,
  17199,
  17202,
  17205,
  17209,
  17212,
  17215,
  17219,
  17222,
  17225,
  17229,
  17232,
  17235,
  17239,
  17242,
  17245,
  17249,
  17252,
  17255,
  17259,
  17262,
  17265,
  17269,
  17272,
  17275,
  17278,
  17282,
  17285,
  17288,
  17292,
  17295,
  17298,
  17302,
  17305,
  17308,
  17312,
  17315,
  17318,
  17322,
  17325,
  17328,
  17332,
  17335,
  17338,
  17342,
  17345,
  17348,
  17352,
  17355,
  17358,
  17362,
  17365,
  17368,
  17371,
  17375,
  17378,
  17381,
  17385,
  17388,
  17391,
  17395,
  17398,
  17401,
  17405,
  17408,
  17411,
  17415,
  17418,
  17421,
  17425,
  17428,
  17431,
  17435,
  17438,
  17441,
  17445,
  17448,
  17451,
  17455,
  17458,
  17461,
  17465,
  17468,
  17471,
  17474,
  17478,
  17481,
  17484,
  17488,
  17491,
  17494,
  17498,
  17501,
  17504,
  17508,
  17511,
  17514,
  17518,
  17521,
  17524,
  17528,
  17531,
  17534,
  17538,
  17541,
  17544,
  17548,
  17551,
  17554,
  17558,
  17561,
  17564,
  17567,
  17571,
  17574,
  17577,
  17581,
  17584,
  17587,
  17591,
  17594,
  17597,
  17601,
  17604,
  17607,
  17611,
  17614,
  17617,
  17621,
  17624,
  17627,
  17631,
  17634,
  17637,
  17641,
  17644,
  17647,
  17651,
  17654,
  17657,
  17660,
  17664,
  17667,
  17670,
  17674,
  17677,
  17680,
  17684,
  17687,
  17690,
  17694,
  17697,
  17700,
  17704,
  17707,
  17710,
  17714,
  17717,
  17720,
  17724,
  17727,
  17730,
  17734,
  17737,
  17740,
  17744,
  17747,
  17750,
  17754,
  17757,
  17760,
  17763,
  17767,
  17770,
  17773,
  17777,
  17780,
  17783,
  17787,
  17790,
  17793,
  17797,
  17800,
  17803,
  17807,
  17810,
  17813,
  17817,
  17820,
  17823,
  17827,
  17830,
  17833,
  17837,
  17840,
  17843,
  17847,
  17850,
  17853,
  17856,
  17860,
  17863,
  17866,
  17870,
  17873,
  17876,
  17880,
  17883,
  17886,
  17890,
  17893,
  17896,
  17900,
  17903,
  17906,
  17910,
  17913,
  17916,
  17920,
  17923,
  17926,
  17930,
  17933,
  17936,
  17940,
  17943,
  17946,
  17950,
  17953,
  17956,
  17959,
  17963,
  17966,
  17969,
  17973,
  17976,
  17979,
  17983,
  17986,
  17989,
  17993,
  17996,
  17999,
  18003,
  18006,
  18009,
  18013,
  18016,
  18019,
  18023,
  18026,
  18029,
  18033,
  18036,
  18039,
  18043,
  18046,
  18049,
  18052,
  18056,
  18059,
  18062,
  18066,
  18069,
  18072,
  18076,
  18079,
  18082,
  18086,
  18089,
  18092,
  18096,
  18099,
  18102,
  18106,
  18109,
  18112,
  18116,
  18119,
  18122,
  18126,
  18129,
  18132,
  18136,
  18139,
  18142,
  18145,
  18149,
  18152,
  18155,
  18159,
  18162,
  18165,
  18169,
  18172,
  18175,
  18179,
  18182,
  18185,
  18189,
  18192,
  18195,
  18199,
  18202,
  18205,
  18209,
  18212,
  18215,
  18219,
  18222,
  18225,
  18229,
  18232,
  18235,
  18239,
  18242,
  18245,
  18248,
  18252,
  18255,
  18258,
  18262,
  18265,
  18268,
  18272,
  18275,
  18278,
  18282,
  18285,
  18288,
  18292,
  18295,
  18298,
  18302,
  18305,
  18308,
  18312,
  18315,
  18318,
  18322,
  18325,
  18328,
  18332,
  18335,
  18338,
  18341,
  18345,
  18348,
  18351,
  18355,
  18358,
  18361,
  18365,
  18368,
  18371,
  18375,
  18378,
  18381,
  18385,
  18388,
  18391,
  18395,
  18398,
  18401,
  18405,
  18408,
  18411,
  18415,
  18418,
  18421,
  18425,
  18428,
  18431,
  18435,
  18438,
  18441,
  18444,
  18448,
  18451,
  18454,
  18458,
  18461,
  18464,
  18468,
  18471,
  18474,
  18478,
  18481,
  18484,
  18488,
  18491,
  18494,
  18498,
  18501,
  18504,
  18508,
  18511,
  18514,
  18518,
  18521,
  18524,
  18528,
  18531,
  18534,
  18537,
  18541,
  18544,
  18547,
  18551,
  18554,
  18557,
  18561,
  18564,
  18567,
  18571,
  18574,
  18577,
  18581,
  18584,
  18587,
  18591,
  18594,
  18597,
  18601,
  18604,
  18607,
  18611,
  18614,
  18617,
  18621,
  18624,
  18627,
  18630,
  18634,
  18637,
  18640,
  18644,
  18647,
  18650,
  18654,
  18657,
  18660,
  18664,
  18667,
  18670,
  18674,
  18677,
  18680,
  18684,
  18687,
  18690,
  18694,
  18697,
  18700,
  18704,
  18707,
  18710,
  18714,
  18717,
  18720,
  18724,
  18727,
  18730,
  18733,
  18737,
  18740,
  18743,
  18747,
  18750,
  18753,
  18757,
  18760,
  18763,
  18767,
  18770,
  18773,
  18777,
  18780,
  18783,
  18787,
  18790,
  18793,
  18797,
  18800,
  18803,
  18807,
  18810,
  18813,
  18817,
  18820,
  18823,
  18826,
  18830,
  18833,
  18836,
  18840,
  18843,
  18846,
  18850,
  18853,
  18856,
  18860,
  18863,
  18866,
  18870,
  18873,
  18876,
  18880,
  18883,
  18886,
  18890,
  18893,
  18896,
  18900,
  18903,
  18906,
  18910,
  18913,
  18916,
  18920,
  18923,
  18926,
  18929,
  18933,
  18936,
  18939,
  18943,
  18946,
  18949,
  18953,
  18956,
  18959,
  18963,
  18966,
  18969,
  18973,
  18976,
  18979,
  18983,
  18986,
  18989,
  18993,
  18996,
  18999,
  19003,
  19006,
  19009,
  19013,
  19016,
  19019,
  19022,
  19026,
  19029,
  19032,
  19036,
  19039,
  19042,
  19046,
  19049,
  19052,
  19056,
  19059,
  19062,
  19066,
  19069,
  19072,
  19076,
  19079,
  19082,
  19086,
  19089,
  19092,
  19096,
  19099,
  19102,
  19106,
  19109,
  19112,
  19116,
  19119,
  19122,
  19125,
  19129,
  19132,
  19135,
  19139,
  19142,
  19145,
  19149,
  19152,
  19155,
  19159,
  19162,
  19165,
  19169,
  19172,
  19175,
  19179,
  19182,
  19185,
  19189,
  19192,
  19195,
  19199,
  19202,
  19205,
  19209,
  19212,
  19215,
  19218,
  19222,
  19225,
  19228,
  19232,
  19235,
  19238,
  19242,
  19245,
  19248,
  19252,
  19255,
  19258,
  19262,
  19265,
  19268,
  19272,
  19275,
  19278,
  19282,
  19285,
  19288,
  19292,
  19295,
  19298,
  19302,
  19305,
  19308,
  19311,
  19315,
  19318,
  19321,
  19325,
  19328,
  19331,
  19335,
  19338,
  19341,
  19345,
  19348,
  19351,
  19355,
  19358,
  19361,
  19365,
  19368,
  19371,
  19375,
  19378,
  19381,
  19385,
  19388,
  19391,
  19395,
  19398,
  19401,
  19405,
  19408,
  19411,
  19414,
  19418,
  19421,
  19424,
  19428,
  19431,
  19434,
  19438,
  19441,
  19444,
  19448,
  19451,
  19454,
  19458,
  19461,
  19464,
  19468,
  19471,
  19474,
  19478,
  19481,
  19484,
  19488,
  19491,
  19494,
  19498,
  19501,
  19504,
  19507,
  19511,
  19514,
  19517,
  19521,
  19524,
  19527,
  19531,
  19534,
  19537,
  19541,
  19544,
  19547,
  19551,
  19554,
  19557,
  19561,
  19564,
  19567,
  19571,
  19574,
  19577,
  19581,
  19584,
  19587,
  19591,
  19594,
  19597,
  19601,
  19604,
  19607,
  19610,
  19614,
  19617,
  19620,
  19624,
  19627,
  19630,
  19634,
  19637,
  19640,
  19644,
  19647,
  19650,
  19654,
  19657,
  19660,
  19664,
  19667,
  19670,
  19674,
  19677,
  19680,
  19684,
  19687,
  19690,
  19694,
  19697,
  19700,
  19703,
  19707,
  19710,
  19713,
  19717,
  19720,
  19723,
  19727,
  19730,
  19733,
  19737,
  19740,
  19743,
  19747,
  19750,
  19753,
  19757,
  19760,
  19763,
  19767,
  19770,
  19773,
  19777,
  19780,
  19783,
  19787,
  19790,
  19793,
  19796,
  19800,
  19803,
  19806,
  19810,
  19813,
  19816,
  19820,
  19823,
  19826,
  19830,
  19833,
  19836,
  19840,
  19843,
  19846,
  19850,
  19853,
  19856,
  19860,
  19863,
  19866,
  19870,
  19873,
  19876,
  19880,
  19883,
  19886,
  19890,
  19893,
  19896,
  19899,
  19903,
  19906,
  19909,
  19913,
  19916,
  19919,
  19923,
  19926,
  19929,
  19933,
  19936,
  19939,
  19943,
  19946,
  19949,
  19953,
  19956,
  19959,
  19963,
  19966,
  19969,
  19973,
  19976,
  19979,
  19983,
  19986,
  19989,
  19992,
  19996,
  19999,
  20002,
  20006,
  20009,
  20012,
  20016,
  20019,
  20022,
  20026,
  20029,
  20032,
  20036,
  20039,
  20042,
  20046,
  20049,
  20052,
  20056,
  20059,
  20062,
  20066,
  20069,
  20072,
  20076,
  20079,
  20082,
  20086,
  20089,
  20092,
  20095,
  20099,
  20102,
  20105,
  20109,
  20112,
  20115,
  20119,
  20122,
  20125,
  20129,
  20132,
  20135,
  20139,
  20142,
  20145,
  20149,
  20152,
  20155,
  20159,
  20162,
  20165,
  20169,
  20172,
  20175,
  20179,
  20182,
  20185,
  20188,
  20192,
  20195,
  20198,
  20202,
  20205,
  20208,
  20212,
  20215,
  20218,
  20222,
  20225,
  20228,
  20232,
  20235,
  20238,
  20242,
  20245,
  20248,
  20252,
  20255,
  20258,
  20262,
  20265,
  20268,
  20272,
  20275,
  20278,
  20281,
  20285,
  20288,
  20291,
  20295,
  20298,
  20301,
  20305,
  20308,
  20311,
  20315,
  20318,
  20321,
  20325,
  20328,
  20331,
  20335,
  20338,
  20341,
  20345,
  20348,
  20351,
  20355,
  20358,
  20361,
  20365,
  20368,
  20371,
  20375,
  20378,
  20381,
  20384,
  20388,
  20391,
  20394,
  20398,
  20401,
  20404,
  20408,
  20411,
  20414,
  20418,
  20421,
  20424,
  20428,
  20431,
  20434,
  20438,
  20441,
  20444,
  20448,
  20451,
  20454,
  20458,
  20461,
  20464,
  20468,
  20471,
  20474,
  20477,
  20481,
  20484,
  20487,
  20491,
  20494,
  20497,
  20501,
  20504,
  20507,
  20511,
  20514,
  20517,
  20521,
  20524,
  20527,
  20531,
  20534,
  20537,
  20541,
  20544,
  20547,
  20551,
  20554,
  20557,
  20561,
  20564,
  20567,
  20571,
  20574,
  20577,
  20580,
  20584,
  20587,
  20590,
  20594,
  20597,
  20600,
  20604,
  20607,
  20610,
  20614,
  20617,
  20620,
  20624,
  20627,
  20630,
  20634,
  20637,
  20640,
  20644,
  20647,
  20650,
  20654,
  20657,
  20660,
  20664,
  20667,
  20670,
  20673,
  20677,
  20680,
  20683,
  20687,
  20690,
  20693,
  20697,
  20700,
  20703,
  20707,
  20710,
  20713,
  20717,
  20720,
  20723,
  20727,
  20730,
  20733,
  20737,
  20740,
  20743,
  20747,
  20750,
  20753,
  20757,
  20760,
  20763,
  20766,
  20770,
  20773,
  20776,
  20780,
  20783,
  20786,
  20790,
  20793,
  20796,
  20800,
  20803,
  20806,
  20810,
  20813,
  20816,
  20820,
  20823,
  20826,
  20830,
  20833,
  20836,
  20840,
  20843,
  20846,
  20850,
  20853,
  20856,
  20860,
  20863,
  20866,
  20869,
  20873,
  20876,
  20879,
  20883,
  20886,
  20889,
  20893,
  20896,
  20899,
  20903,
  20906,
  20909,
  20913,
  20916,
  20919,
  20923,
  20926,
  20929,
  20933,
  20936,
  20939,
  20943,
  20946,
  20949,
  20953,
  20956,
  20959,
  20962,
  20966,
  20969,
  20972,
  20976,
  20979,
  20982,
  20986,
  20989,
  20992,
  20996,
  20999,
  21002,
  21006,
  21009,
  21012,
  21016,
  21019,
  21022,
  21026,
  21029,
  21032,
  21036,
  21039,
  21042,
  21046,
  21049,
  21052,
  21056,
  21059,
  21062,
  21065,
  21069,
  21072,
  21075,
  21079,
  21082,
  21085,
  21089,
  21092,
  21095,
  21099,
  21102,
  21105,
  21109,
  21112,
  21115,
  21119,
  21122,
  21125,
  21129,
  21132,
  21135,
  21139,
  21142,
  21145,
  21149,
  21152,
  21155,
  21158,
  21162,
  21165,
  21168,
  21172,
  21175,
  21178,
  21182,
  21185,
  21188,
  21192,
  21195,
  21198,
  21202,
  21205,
  21208,
  21212,
  21215,
  21218,
  21222,
  21225,
  21228,
  21232,
  21235,
  21238,
  21242,
  21245,
  21248,
  21252,
  21255,
  21258,
  21261,
  21265,
  21268,
  21271,
  21275,
  21278,
  21281,
  21285,
  21288,
  21291,
  21295,
  21298,
  21301,
  21305,
  21308,
  21311,
  21315,
  21318,
  21321,
  21325,
  21328,
  21331,
  21335,
  21338,
  21341,
  21345,
  21348,
  21351,
  21354,
  21358,
  21361,
  21364,
  21368,
  21371,
  21374,
  21378,
  21381,
  21384,
  21388,
  21391,
  21394,
  21398,
  21401,
  21404,
  21408,
  21411,
  21414,
  21418,
  21421,
  21424,
  21428,
  21431,
  21434,
  21438,
  21441,
  21444,
  21447,
  21451,
  21454,
  21457,
  21461,
  21464,
  21467,
  21471,
  21474,
  21477,
  21481,
  21484,
  21487,
  21491,
  21494,
  21497,
  21501,
  21504,
  21507,
  21511,
  21514,
  21517,
  21521,
  21524,
  21527,
  21531,
  21534,
  21537,
  21541,
  21544,
  21547,
  21550,
  21554,
  21557,
  21560,
  21564,
  21567,
  21570,
  21574,
  21577,
  21580,
  21584,
  21587,
  21590,
  21594,
  21597,
  21600,
  21604,
  21607,
  21610,
  21614,
  21617,
  21620,
  21624,
  21627,
  21630,
  21634,
  21637,
  21640,
  21643,
  21647,
  21650,
  21653,
  21657,
  21660,
  21663,
  21667,
  21670,
  21673,
  21677,
  21680,
  21683,
  21687,
  21690,
  21693,
  21697,
  21700,
  21703,
  21707,
  21710,
  21713,
  21717,
  21720,
  21723,
  21727,
  21730,
  21733,
  21737,
  21740,
  21743,
  21746,
  21750,
  21753,
  21756,
  21760,
  21763,
  21766,
  21770,
  21773,
  21776,
  21780,
  21783,
  21786,
  21790,
  21793,
  21796,
  21800,
  21803,
  21806,
  21810,
  21813,
  21816,
  21820,
  21823,
  21826,
  21830,
  21833,
  21836,
  21839,
  21843,
  21846,
  21849,
  21853,
  21856,
  21859,
  21863,
  21866,
  21869,
  21873,
  21876,
  21879,
  21883,
  21886,
  21889,
  21893,
  21896,
  21899,
  21903,
  21906,
  21909,
  21913,
  21916,
  21919,
  21923,
  21926,
  21929,
  21932,
  21936,
  21939,
  21942,
  21946,
  21949,
  21952,
  21956,
  21959,
  21962,
  21966,
  21969,
  21972,
  21976,
  21979,
  21982,
  21986,
  21989,
  21992,
  21996,
  21999,
  22002,
  22006,
  22009,
  22012,
  22016,
  22019,
  22022,
  22026,
  22029,
  22032,
  22035,
  22039,
  22042,
  22045,
  22049,
  22052,
  22055,
  22059,
  22062,
  22065,
  22069,
  22072,
  22075,
  22079,
  22082,
  22085,
  22089,
  22092,
  22095,
  22099,
  22102,
  22105,
  22109,
  22112,
  22115,
  22119,
  22122,
  22125,
  22128,
  22132,
  22135,
  22138,
  22142,
  22145,
  22148,
  22152,
  22155,
  22158,
  22162,
  22165,
  22168,
  22172,
  22175,
  22178,
  22182,
  22185,
  22188,
  22192,
  22195,
  22198,
  22202,
  22205,
  22208,
  22212,
  22215,
  22218,
  22222,
  22225,
  22228,
  22231,
  22235,
  22238,
  22241,
  22245,
  22248,
  22251,
  22255,
  22258,
  22261,
  22265,
  22268,
  22271,
  22275,
  22278,
  22281,
  22285,
  22288,
  22291,
  22295,
  22298,
  22301,
  22305,
  22308,
  22311,
  22315,
  22318,
  22321,
  22324,
  22328,
  22331,
  22334,
  22338,
  22341,
  22344,
  22348,
  22351,
  22354,
  22358,
  22361,
  22364,
  22368,
  22371,
  22374,
  22378,
  22381,
  22384,
  22388,
  22391,
  22394,
  22398,
  22401,
  22404,
  22408,
  22411,
  22414,
  22417,
  22421,
  22424,
  22427,
  22431,
  22434,
  22437,
  22441,
  22444,
  22447,
  22451,
  22454,
  22457,
  22461,
  22464,
  22467,
  22471,
  22474,
  22477,
  22481,
  22484,
  22487,
  22491,
  22494,
  22497,
  22501,
  22504,
  22507,
  22511,
  22514,
  22517,
  22520,
  22524,
  22527,
  22530,
  22534,
  22537,
  22540,
  22544,
  22547,
  22550,
  22554,
  22557,
  22560,
  22564,
  22567,
  22570,
  22574,
  22577,
  22580,
  22584,
  22587,
  22590,
  22594,
  22597,
  22600,
  22604,
  22607,
  22610,
  22613,
  22617,
  22620,
  22623,
  22627,
  22630,
  22633,
  22637,
  22640,
  22643,
  22647,
  22650,
  22653,
  22657,
  22660,
  22663,
  22667,
  22670,
  22673,
  22677,
  22680,
  22683,
  22687,
  22690,
  22693,
  22697,
  22700,
  22703,
  22707,
  22710,
  22713,
  22716,
  22720,
  22723,
  22726,
  22730,
  22733,
  22736,
  22740,
  22743,
  22746,
  22750,
  22753,
  22756,
  22760,
  22763,
  22766,
  22770,
  22773,
  22776,
  22780,
  22783,
  22786,
  22790,
  22793,
  22796,
  22800,
  22803,
  22806,
  22809,
  22813,
  22816,
  22819,
  22823,
  22826,
  22829,
  22833,
  22836,
  22839,
  22843,
  22846,
  22849,
  22853,
  22856,
  22859,
  22863,
  22866,
  22869,
  22873,
  22876,
  22879,
  22883,
  22886,
  22889,
  22893,
  22896,
  22899,
  22902,
  22906,
  22909,
  22912,
  22916,
  22919,
  22922,
  22926,
  22929,
  22932,
  22936,
  22939,
  22942,
  22946,
  22949,
  22952,
  22956,
  22959,
  22962,
  22966,
  22969,
  22972,
  22976,
  22979,
  22982,
  22986,
  22989,
  22992,
  22996,
  22999,
  23002,
  23005,
  23009,
  23012,
  23015,
  23019,
  23022,
  23025,
  23029,
  23032,
  23035,
  23039,
  23042,
  23045,
  23049,
  23052,
  23055,
  23059,
  23062,
  23065,
  23069,
  23072,
  23075,
  23079,
  23082,
  23085,
  23089,
  23092,
  23095,
  23098,
  23102,
  23105,
  23108,
  23112,
  23115,
  23118,
  23122,
  23125,
  23128,
  23132,
  23135,
  23138,
  23142,
  23145,
  23148,
  23152,
  23155,
  23158,
  23162,
  23165,
  23168,
  23172,
  23175,
  23178,
  23182,
  23185,
  23188,
  23192,
  23195,
  23198,
  23201,
  23205,
  23208,
  23211,
  23215,
  23218,
  23221,
  23225,
  23228,
  23231,
  23235,
  23238,
  23241,
  23245,
  23248,
  23251,
  23255,
  23258,
  23261,
  23265,
  23268,
  23271,
  23275,
  23278,
  23281,
  23285,
  23288,
  23291,
  23294,
  23298,
  23301,
  23304,
  23308,
  23311,
  23314,
  23318,
  23321,
  23324,
  23328,
  23331,
  23334,
  23338,
  23341,
  23344,
  23348,
  23351,
  23354,
  23358,
  23361,
  23364,
  23368,
  23371,
  23374,
  23378,
  23381,
  23384,
  23388,
  23391,
  23394,
  23397,
  23401,
  23404,
  23407,
  23411,
  23414,
  23417,
  23421,
  23424,
  23427,
  23431,
  23434,
  23437,
  23441,
  23444,
  23447,
  23451,
  23454,
  23457,
  23461,
  23464,
  23467,
  23471,
  23474,
  23477,
  23481,
  23484,
  23487,
  23490,
  23494,
  23497,
  23500,
  23504,
  23507,
  23510,
  23514,
  23517,
  23520,
  23524,
  23527,
  23530,
  23534,
  23537,
  23540,
  23544,
  23547,
  23550,
  23554,
  23557,
  23560,
  23564,
  23567,
  23570,
  23574,
  23577,
  23580,
  23583,
  23587,
  23590,
  23593,
  23597,
  23600,
  23603,
  23607,
  23610,
  23613,
  23617,
  23620,
  23623,
  23627,
  23630,
  23633,
  23637,
  23640,
  23643,
  23647,
  23650,
  23653,
  23657,
  23660,
  23663,
  23667,
  23670,
  23673,
  23677,
  23680,
  23683,
  23686,
  23690,
  23693,
  23696,
  23700,
  23703,
  23706,
  23710,
  23713,
  23716,
  23720,
  23723,
  23726,
  23730,
  23733,
  23736,
  23740,
  23743,
  23746,
  23750,
  23753,
  23756,
  23760,
  23763,
  23766,
  23770,
  23773,
  23776,
  23779,
  23783,
  23786,
  23789,
  23793,
  23796,
  23799,
  23803,
  23806,
  23809,
  23813,
  23816,
  23819,
  23823,
  23826,
  23829,
  23833,
  23836,
  23839,
  23843,
  23846,
  23849,
  23853,
  23856,
  23859,
  23863,
  23866,
  23869,
  23873,
  23876,
  23879,
  23882,
  23886,
  23889,
  23892,
  23896,
  23899,
  23902,
  23906,
  23909,
  23912,
  23916,
  23919,
  23922,
  23926,
  23929,
  23932,
  23936,
  23939,
  23942,
  23946,
  23949,
  23952,
  23956,
  23959,
  23962,
  23966,
  23969,
  23972,
  23975,
  23979,
  23982,
  23985,
  23989,
  23992,
  23995,
  23999,
  24002,
  24005,
  24009,
  24012,
  24015,
  24019,
  24022,
  24025,
  24029,
  24032,
  24035,
  24039,
  24042,
  24045,
  24049,
  24052,
  24055,
  24059,
  24062,
  24065,
  24068,
  24072,
  24075,
  24078,
  24082,
  24085,
  24088,
  24092,
  24095,
  24098,
  24102,
  24105,
  24108,
  24112,
  24115,
  24118,
  24122,
  24125,
  24128,
  24132,
  24135,
  24138,
  24142,
  24145,
  24148,
  24152,
  24155,
  24158,
  24162,
  24165,
  24168,
  24171,
  24175,
  24178,
  24181,
  24185,
  24188,
  24191,
  24195,
  24198,
  24201,
  24205,
  24208,
  24211,
  24215,
  24218,
  24221,
  24225,
  24228,
  24231,
  24235,
  24238,
  24241,
  24245,
  24248,
  24251,
  24255,
  24258,
  24261,
  24264,
  24268,
  24271,
  24274,
  24278,
  24281,
  24284,
  24288,
  24291,
  24294,
  24298,
  24301,
  24304,
  24308,
  24311,
  24314,
  24318,
  24321,
  24324,
  24328,
  24331,
  24334,
  24338,
  24341,
  24344,
  24348,
  24351,
  24354,
  24358,
  24361,
  24364,
  24367,
  24371,
  24374,
  24377,
  24381,
  24384,
  24387,
  24391,
  24394,
  24397,
  24401,
  24404,
  24407,
  24411,
  24414,
  24417,
  24421,
  24424,
  24427,
  24431,
  24434,
  24437,
  24441,
  24444,
  24447,
  24451,
  24454,
  24457,
  24460,
  24464,
  24467,
  24470,
  24474,
  24477,
  24480,
  24484,
  24487,
  24490,
  24494,
  24497,
  24500,
  24504,
  24507,
  24510,
  24514,
  24517,
  24520,
  24524,
  24527,
  24530,
  24534,
  24537,
  24540,
  24544,
  24547,
  24550,
  24553,
  24557,
  24560,
  24563,
  24567,
  24570,
  24573,
  24577,
  24580,
  24583,
  24587,
  24590,
  24593,
  24597,
  24600,
  24603,
  24607,
  24610,
  24613,
  24617,
  24620,
  24623,
  24627,
  24630,
  24633,
  24637,
  24640,
  24643,
  24647,
  24650,
  24653,
  24656,
  24660,
  24663,
  24666,
  24670,
  24673,
  24676,
  24680,
  24683,
  24686,
  24690,
  24693,
  24696,
  24700,
  24703,
  24706,
  24710,
  24713,
  24716,
  24720,
  24723,
  24726,
  24730,
  24733,
  24736,
  24740,
  24743,
  24746,
  24749,
  24753,
  24756,
  24759,
  24763,
  24766,
  24769,
  24773,
  24776,
  24779,
  24783,
  24786,
  24789,
  24793,
  24796,
  24799,
  24803,
  24806,
  24809,
  24813,
  24816,
  24819,
  24823,
  24826,
  24829,
  24833,
  24836,
  24839,
  24843,
  24846,
  24849,
  24852,
  24856,
  24859,
  24862,
  24866,
  24869,
  24872,
  24876,
  24879,
  24882,
  24886,
  24889,
  24892,
  24896,
  24899,
  24902,
  24906,
  24909,
  24912,
  24916,
  24919,
  24922,
  24926,
  24929,
  24932,
  24936,
  24939,
  24942,
  24945,
  24949,
  24952,
  24955,
  24959,
  24962,
  24965,
  24969,
  24972,
  24975,
  24979,
  24982,
  24985,
  24989,
  24992,
  24995,
  24999,
  25002,
  25005,
  25009,
  25012,
  25015,
  25019,
  25022,
  25025,
  25029,
  25032,
  25035,
  25038,
  25042,
  25045,
  25048,
  25052,
  25055,
  25058,
  25062,
  25065,
  25068,
  25072,
  25075,
  25078,
  25082,
  25085,
  25088,
  25092,
  25095,
  25098,
  25102,
  25105,
  25108,
  25112,
  25115,
  25118,
  25122,
  25125,
  25128,
  25132,
  25135,
  25138,
  25141,
  25145,
  25148,
  25151,
  25155,
  25158,
  25161,
  25165,
  25168,
  25171,
  25175,
  25178,
  25181,
  25185,
  25188,
  25191,
  25195,
  25198,
  25201,
  25205,
  25208,
  25211,
  25215,
  25218,
  25221,
  25225,
  25228,
  25231,
  25234,
  25238,
  25241,
  25244,
  25248,
  25251,
  25254,
  25258,
  25261,
  25264,
  25268,
  25271,
  25274,
  25278,
  25281,
  25284,
  25288,
  25291,
  25294,
  25298,
  25301,
  25304,
  25308,
  25311,
  25314,
  25318,
  25321,
  25324,
  25328,
  25331,
  25334,
  25337,
  25341,
  25344,
  25347,
  25351,
  25354,
  25357,
  25361,
  25364,
  25367,
  25371,
  25374,
  25377,
  25381,
  25384,
  25387,
  25391,
  25394,
  25397,
  25401,
  25404,
  25407,
  25411,
  25414,
  25417,
  25421,
  25424,
  25427,
  25430,
  25434,
  25437,
  25440,
  25444,
  25447,
  25450,
  25454,
  25457,
  25460,
  25464,
  25467,
  25470,
  25474,
  25477,
  25480,
  25484,
  25487,
  25490,
  25494,
  25497,
  25500,
  25504,
  25507,
  25510,
  25514,
  25517,
  25520,
  25524,
  25527,
  25530,
  25533,
  25537,
  25540,
  25543,
  25547,
  25550,
  25553,
  25557,
  25560,
  25563,
  25567,
  25570,
  25573,
  25577,
  25580,
  25583,
  25587,
  25590,
  25593,
  25597,
  25600,
  25603,
  25607,
  25610,
  25613,
  25617,
  25620,
  25623,
  25626,
  25630,
  25633,
  25636,
  25640,
  25643,
  25646,
  25650,
  25653,
  25656,
  25660,
  25663,
  25666,
  25670,
  25673,
  25676,
  25680,
  25683,
  25686,
  25690,
  25693,
  25696,
  25700,
  25703,
  25706,
  25710,
  25713,
  25716,
  25719,
  25723,
  25726,
  25729,
  25733,
  25736,
  25739,
  25743,
  25746,
  25749,
  25753,
  25756,
  25759,
  25763,
  25766,
  25769,
  25773,
  25776,
  25779,
  25783,
  25786,
  25789,
  25793,
  25796,
  25799,
  25803,
  25806,
  25809,
  25813,
  25816,
  25819,
  25822,
  25826,
  25829,
  25832,
  25836,
  25839,
  25842,
  25846,
  25849,
  25852,
  25856,
  25859,
  25862,
  25866,
  25869,
  25872,
  25876,
  25879,
  25882,
  25886,
  25889,
  25892,
  25896,
  25899,
  25902,
  25906,
  25909,
  25912,
  25915,
  25919,
  25922,
  25925,
  25929,
  25932,
  25935,
  25939,
  25942,
  25945,
  25949,
  25952,
  25955,
  25959,
  25962,
  25965,
  25969,
  25972,
  25975,
  25979,
  25982,
  25985,
  25989,
  25992,
  25995,
  25999,
  26002,
  26005,
  26009,
  26012,
  26015,
  26018,
  26022,
  26025,
  26028,
  26032,
  26035,
  26038,
  26042,
  26045,
  26048,
  26052,
  26055,
  26058,
  26062,
  26065,
  26068,
  26072,
  26075,
  26078,
  26082,
  26085,
  26088,
  26092,
  26095,
  26098,
  26102,
  26105,
  26108,
  26111,
  26115,
  26118,
  26121,
  26125,
  26128,
  26131,
  26135,
  26138,
  26141,
  26145,
  26148,
  26151,
  26155,
  26158,
  26161,
  26165,
  26168,
  26171,
  26175,
  26178,
  26181,
  26185,
  26188,
  26191,
  26195,
  26198,
  26201,
  26204,
  26208,
  26211,
  26214,
  26218,
  26221,
  26224,
  26228,
  26231,
  26234,
  26238,
  26241,
  26244,
  26248,
  26251,
  26254,
  26258,
  26261,
  26264,
  26268,
  26271,
  26274,
  26278,
  26281,
  26284,
  26288,
  26291,
  26294,
  26298,
  26301,
  26304,
  26307,
  26311,
  26314,
  26317,
  26321,
  26324,
  26327,
  26331,
  26334,
  26337,
  26341,
  26344,
  26347,
  26351,
  26354,
  26357,
  26361,
  26364,
  26367,
  26371,
  26374,
  26377,
  26381,
  26384,
  26387,
  26391,
  26394,
  26397,
  26400,
  26404,
  26407,
  26410,
  26414,
  26417,
  26420,
  26424,
  26427,
  26430,
  26434,
  26437,
  26440,
  26444,
  26447,
  26450,
  26454,
  26457,
  26460,
  26464,
  26467,
  26470,
  26474,
  26477,
  26480,
  26484,
  26487,
  26490,
  26494,
  26497,
  26500,
  26503,
  26507,
  26510,
  26513,
  26517,
  26520,
  26523,
  26527,
  26530,
  26533,
  26537,
  26540,
  26543,
  26547,
  26550,
  26553,
  26557,
  26560,
  26563,
  26567,
  26570,
  26573,
  26577,
  26580,
  26583,
  26587,
  26590,
  26593,
  26596,
  26600,
  26603,
  26606,
  26610,
  26613,
  26616,
  26620,
  26623,
  26626,
  26630,
  26633,
  26636,
  26640,
  26643,
  26646,
  26650,
  26653,
  26656,
  26660,
  26663,
  26666,
  26670,
  26673,
  26676,
  26680,
  26683,
  26686,
  26689,
  26693,
  26696,
  26699,
  26703,
  26706,
  26709,
  26713,
  26716,
  26719,
  26723,
  26726,
  26729,
  26733,
  26736,
  26739,
  26743,
  26746,
  26749,
  26753,
  26756,
  26759,
  26763,
  26766,
  26769,
  26773,
  26776,
  26779,
  26783,
  26786,
  26789,
  26792,
  26796,
  26799,
  26802,
  26806,
  26809,
  26812,
  26816,
  26819,
  26822,
  26826,
  26829,
  26832,
  26836,
  26839,
  26842,
  26846,
  26849,
  26852,
  26856,
  26859,
  26862,
  26866,
  26869,
  26872,
  26876,
  26879,
  26882,
  26885,
  26889,
  26892,
  26895,
  26899,
  26902,
  26905,
  26909,
  26912,
  26915,
  26919,
  26922,
  26925,
  26929,
  26932,
  26935,
  26939,
  26942,
  26945,
  26949,
  26952,
  26955,
  26959,
  26962,
  26965,
  26969,
  26972,
  26975,
  26979,
  26982,
  26985,
  26988,
  26992,
  26995,
  26998,
  27002,
  27005,
  27008,
  27012,
  27015,
  27018,
  27022,
  27025,
  27028,
  27032,
  27035,
  27038,
  27042,
  27045,
  27048,
  27052,
  27055,
  27058,
  27062,
  27065,
  27068,
  27072,
  27075,
  27078,
  27081,
  27085,
  27088,
  27091,
  27095,
  27098,
  27101,
  27105,
  27108,
  27111,
  27115,
  27118,
  27121,
  27125,
  27128,
  27131,
  27135,
  27138,
  27141,
  27145,
  27148,
  27151,
  27155,
  27158,
  27161,
  27165,
  27168,
  27171,
  27174,
  27178,
  27181,
  27184,
  27188,
  27191,
  27194,
  27198,
  27201,
  27204,
  27208,
  27211,
  27214,
  27218,
  27221,
  27224,
  27228,
  27231,
  27234,
  27238,
  27241,
  27244,
  27248,
  27251,
  27254,
  27258,
  27261,
  27264,
  27268,
  27271,
  27274,
  27277,
  27281,
  27284,
  27287,
  27291,
  27294,
  27297,
  27301,
  27304,
  27307,
  27311,
  27314,
  27317,
  27321,
  27324,
  27327,
  27331,
  27334,
  27337,
  27341,
  27344,
  27347,
  27351,
  27354,
  27357,
  27361,
  27364,
  27367,
  27370,
  27374,
  27377,
  27380,
  27384,
  27387,
  27390,
  27394,
  27397,
  27400,
  27404,
  27407,
  27410,
  27414,
  27417,
  27420,
  27424,
  27427,
  27430,
  27434,
  27437,
  27440,
  27444,
  27447,
  27450,
  27454,
  27457,
  27460,
  27464,
  27467,
  27470,
  27473,
  27477,
  27480,
  27483,
  27487,
  27490,
  27493,
  27497,
  27500,
  27503,
  27507,
  27510,
  27513,
  27517,
  27520,
  27523,
  27527,
  27530,
  27533,
  27537,
  27540,
  27543,
  27547,
  27550,
  27553,
  27557,
  27560,
  27563,
  27566,
  27570,
  27573,
  27576,
  27580,
  27583,
  27586,
  27590,
  27593,
  27596,
  27600,
  27603,
  27606,
  27610,
  27613,
  27616,
  27620,
  27623,
  27626,
  27630,
  27633,
  27636,
  27640,
  27643,
  27646,
  27650,
  27653,
  27656,
  27660,
  27663,
  27666,
  27669,
  27673,
  27676,
  27679,
  27683,
  27686,
  27689,
  27693,
  27696,
  27699,
  27703,
  27706,
  27709,
  27713,
  27716,
  27719,
  27723,
  27726,
  27729,
  27733,
  27736,
  27739,
  27743,
  27746,
  27749,
  27753,
  27756,
  27759,
  27762,
  27766,
  27769,
  27772,
  27776,
  27779,
  27782,
  27786,
  27789,
  27792,
  27796,
  27799,
  27802,
  27806,
  27809,
  27812,
  27816,
  27819,
  27822,
  27826,
  27829,
  27832,
  27836,
  27839,
  27842,
  27846,
  27849,
  27852,
  27855,
  27859,
  27862,
  27865,
  27869,
  27872,
  27875,
  27879,
  27882,
  27885,
  27889,
  27892,
  27895,
  27899,
  27902,
  27905,
  27909,
  27912,
  27915,
  27919,
  27922,
  27925,
  27929,
  27932,
  27935,
  27939,
  27942,
  27945,
  27949,
  27952,
  27955,
  27958,
  27962,
  27965,
  27968,
  27972,
  27975,
  27978,
  27982,
  27985,
  27988,
  27992,
  27995,
  27998,
  28002,
  28005,
  28008,
  28012,
  28015,
  28018,
  28022,
  28025,
  28028,
  28032,
  28035,
  28038,
  28042,
  28045,
  28048,
  28051,
  28055,
  28058,
  28061,
  28065,
  28068,
  28071,
  28075,
  28078,
  28081,
  28085,
  28088,
  28091,
  28095,
  28098,
  28101,
  28105,
  28108,
  28111,
  28115,
  28118,
  28121,
  28125,
  28128,
  28131,
  28135,
  28138,
  28141,
  28145,
  28148,
  28151,
  28154,
  28158,
  28161,
  28164,
  28168,
  28171,
  28174,
  28178,
  28181,
  28184,
  28188,
  28191,
  28194,
  28198,
  28201,
  28204,
  28208,
  28211,
  28214,
  28218,
  28221,
  28224,
  28228,
  28231,
  28234,
  28238,
  28241,
  28244,
  28247,
  28251,
  28254,
  28257,
  28261,
  28264,
  28267,
  28271,
  28274,
  28277,
  28281,
  28284,
  28287,
  28291,
  28294,
  28297,
  28301,
  28304,
  28307,
  28311,
  28314,
  28317,
  28321,
  28324,
  28327,
  28331,
  28334,
  28337,
  28340,
  28344,
  28347,
  28350,
  28354,
  28357,
  28360,
  28364,
  28367,
  28370,
  28374,
  28377,
  28380,
  28384,
  28387,
  28390,
  28394,
  28397,
  28400,
  28404,
  28407,
  28410,
  28414,
  28417,
  28420,
  28424,
  28427,
  28430,
  28434,
  28437,
  28440,
  28443,
  28447,
  28450,
  28453,
  28457,
  28460,
  28463,
  28467,
  28470,
  28473,
  28477,
  28480,
  28483,
  28487,
  28490,
  28493,
  28497,
  28500,
  28503,
  28507,
  28510,
  28513,
  28517,
  28520,
  28523,
  28527,
  28530,
  28533,
  28536,
  28540,
  28543,
  28546,
  28550,
  28553,
  28556,
  28560,
  28563,
  28566,
  28570,
  28573,
  28576,
  28580,
  28583,
  28586,
  28590,
  28593,
  28596,
  28600,
  28603,
  28606,
  28610,
  28613,
  28616,
  28620,
  28623,
  28626,
  28630,
  28633,
  28636,
  28639,
  28643,
  28646,
  28649,
  28653,
  28656,
  28659,
  28663,
  28666,
  28669,
  28673,
  28676,
  28679,
  28683,
  28686,
  28689,
  28693,
  28696,
  28699,
  28703,
  28706,
  28709,
  28713,
  28716,
  28719,
  28723,
  28726,
  28729,
  28732,
  28736,
  28739,
  28742,
  28746,
  28749,
  28752,
  28756,
  28759,
  28762,
  28766,
  28769,
  28772,
  28776,
  28779,
  28782,
  28786,
  28789,
  28792,
  28796,
  28799,
  28802,
  28806,
  28809,
  28812,
  28816,
  28819,
  28822,
  28825,
  28829,
  28832,
  28835,
  28839,
  28842,
  28845,
  28849,
  28852,
  28855,
  28859,
  28862,
  28865,
  28869,
  28872,
  28875,
  28879,
  28882,
  28885,
  28889,
  28892,
  28895,
  28899,
  28902,
  28905,
  28909,
  28912,
  28915,
  28919,
  28922,
  28925,
  28928,
  28932,
  28935,
  28938,
  28942,
  28945,
  28948,
  28952,
  28955,
  28958,
  28962,
  28965,
  28968,
  28972,
  28975,
  28978,
  28982,
  28985,
  28988,
  28992,
  28995,
  28998,
  29002,
  29005,
  29008,
  29012,
  29015,
  29018,
  29021,
  29025,
  29028,
  29031,
  29035,
  29038,
  29041,
  29045,
  29048,
  29051,
  29055,
  29058,
  29061,
  29065,
  29068,
  29071,
  29075,
  29078,
  29081,
  29085,
  29088,
  29091,
  29095,
  29098,
  29101,
  29105,
  29108,
  29111,
  29115,
  29118,
  29121,
  29124,
  29128,
  29131,
  29134,
  29138,
  29141,
  29144,
  29148,
  29151,
  29154,
  29158,
  29161,
  29164,
  29168,
  29171,
  29174,
  29178,
  29181,
  29184,
  29188,
  29191,
  29194,
  29198,
  29201,
  29204,
  29208,
  29211,
  29214,
  29217,
  29221,
  29224,
  29227,
  29231,
  29234,
  29237,
  29241,
  29244,
  29247,
  29251,
  29254,
  29257,
  29261,
  29264,
  29267,
  29271,
  29274,
  29277,
  29281,
  29284,
  29287,
  29291,
  29294,
  29297,
  29301,
  29304,
  29307,
  29310,
  29314,
  29317,
  29320,
  29324,
  29327,
  29330,
  29334,
  29337,
  29340,
  29344,
  29347,
  29350,
  29354,
  29357,
  29360,
  29364,
  29367,
  29370,
  29374,
  29377,
  29380,
  29384,
  29387,
  29390,
  29394,
  29397,
  29400,
  29404,
  29407,
  29410,
  29413,
  29417,
  29420,
  29423,
  29427,
  29430,
  29433,
  29437,
  29440,
  29443,
  29447,
  29450,
  29453,
  29457,
  29460,
  29463,
  29467,
  29470,
  29473,
  29477,
  29480,
  29483,
  29487,
  29490,
  29493,
  29497,
  29500,
  29503,
  29506,
  29510,
  29513,
  29516,
  29520,
  29523,
  29526,
  29530,
  29533,
  29536,
  29540,
  29543,
  29546,
  29550,
  29553,
  29556,
  29560,
  29563,
  29566,
  29570,
  29573,
  29576,
  29580,
  29583,
  29586,
  29590,
  29593,
  29596,
  29600,
  29603,
  29606,
  29609,
  29613,
  29616,
  29619,
  29623,
  29626,
  29629,
  29633,
  29636,
  29639,
  29643,
  29646,
  29649,
  29653,
  29656,
  29659,
  29663,
  29666,
  29669,
  29673,
  29676,
  29679,
  29683,
  29686,
  29689,
  29693,
  29696,
  29699,
  29702,
  29706,
  29709,
  29712,
  29716,
  29719,
  29722,
  29726,
  29729,
  29732,
  29736,
  29739,
  29742,
  29746,
  29749,
  29752,
  29756,
  29759,
  29762,
  29766,
  29769,
  29772,
  29776,
  29779,
  29782,
  29786,
  29789,
  29792,
  29796,
  29799,
  29802,
  29805,
  29809,
  29812,
  29815,
  29819,
  29822,
  29825,
  29829,
  29832,
  29835,
  29839,
  29842,
  29845,
  29849,
  29852,
  29855,
  29859,
  29862,
  29865,
  29869,
  29872,
  29875,
  29879,
  29882,
  29885,
  29889,
  29892,
  29895,
  29898,
  29902,
  29905,
  29908,
  29912,
  29915,
  29918,
  29922,
  29925,
  29928,
  29932,
  29935,
  29938,
  29942,
  29945,
  29948,
  29952,
  29955,
  29958,
  29962,
  29965,
  29968,
  29972,
  29975,
  29978,
  29982,
  29985,
  29988,
  29991,
  29995,
  29998,
  30001,
  30005,
  30008,
  30011,
  30015,
  30018,
  30021,
  30025,
  30028,
  30031,
  30035,
  30038,
  30041,
  30045,
  30048,
  30051,
  30055,
  30058,
  30061,
  30065,
  30068,
  30071,
  30075,
  30078,
  30081,
  30085,
  30088,
  30091,
  30094,
  30098,
  30101,
  30104,
  30108,
  30111,
  30114,
  30118,
  30121,
  30124,
  30128,
  30131,
  30134,
  30138,
  30141,
  30144,
  30148,
  30151,
  30154,
  30158,
  30161,
  30164,
  30168,
  30171,
  30174,
  30178,
  30181,
  30184,
  30187,
  30191,
  30194,
  30197,
  30201,
  30204,
  30207,
  30211,
  30214,
  30217,
  30221,
  30224,
  30227,
  30231,
  30234,
  30237,
  30241,
  30244,
  30247,
  30251,
  30254,
  30257,
  30261,
  30264,
  30267,
  30271,
  30274,
  30277,
  30281,
  30284,
  30287,
  30290,
  30294,
  30297,
  30300,
  30304,
  30307,
  30310,
  30314,
  30317,
  30320,
  30324,
  30327,
  30330,
  30334,
  30337,
  30340,
  30344,
  30347,
  30350,
  30354,
  30357,
  30360,
  30364,
  30367,
  30370,
  30374,
  30377,
  30380,
  30383,
  30387,
  30390,
  30393,
  30397,
  30400,
  30403,
  30407,
  30410,
  30413,
  30417,
  30420,
  30423,
  30427,
  30430,
  30433,
  30437,
  30440,
  30443,
  30447,
  30450,
  30453,
  30457,
  30460,
  30463,
  30467,
  30470,
  30473,
  30476,
  30480,
  30483,
  30486,
  30490,
  30493,
  30496,
  30500,
  30503,
  30506,
  30510,
  30513,
  30516,
  30520,
  30523,
  30526,
  30530,
  30533,
  30536,
  30540,
  30543,
  30546,
  30550,
  30553,
  30556,
  30560,
  30563,
  30566,
  30570,
  30573,
  30576,
  30579,
  30583,
  30586,
  30589,
  30593,
  30596,
  30599,
  30603,
  30606,
  30609,
  30613,
  30616,
  30619,
  30623,
  30626,
  30629,
  30633,
  30636,
  30639,
  30643,
  30646,
  30649,
  30653,
  30656,
  30659,
  30663,
  30666,
  30669,
  30672,
  30676,
  30679,
  30682,
  30686,
  30689,
  30692,
  30696,
  30699,
  30702,
  30706,
  30709,
  30712,
  30716,
  30719,
  30722,
  30726,
  30729,
  30732,
  30736,
  30739,
  30742,
  30746,
  30749,
  30752,
  30756,
  30759,
  30762,
  30766,
  30769,
  30772,
  30775,
  30779,
  30782,
  30785,
  30789,
  30792,
  30795,
  30799,
  30802,
  30805,
  30809,
  30812,
  30815,
  30819,
  30822,
  30825,
  30829,
  30832,
  30835,
  30839,
  30842,
  30845,
  30849,
  30852,
  30855,
  30859,
  30862,
  30865,
  30868,
  30872,
  30875,
  30878,
  30882,
  30885,
  30888,
  30892,
  30895,
  30898,
  30902,
  30905,
  30908,
  30912,
  30915,
  30918,
  30922,
  30925,
  30928,
  30932,
  30935,
  30938,
  30942,
  30945,
  30948,
  30952,
  30955,
  30958,
  30961,
  30965,
  30968,
  30971,
  30975,
  30978,
  30981,
  30985,
  30988,
  30991,
  30995,
  30998,
  31001,
  31005,
  31008,
  31011,
  31015,
  31018,
  31021,
  31025,
  31028,
  31031,
  31035,
  31038,
  31041,
  31045,
  31048,
  31051,
  31055,
  31058,
  31061,
  31064,
  31068,
  31071,
  31074,
  31078,
  31081,
  31084,
  31088,
  31091,
  31094,
  31098,
  31101,
  31104,
  31108,
  31111,
  31114,
  31118,
  31121,
  31124,
  31128,
  31131,
  31134,
  31138,
  31141,
  31144,
  31148,
  31151,
  31154,
  31157,
  31161,
  31164,
  31167,
  31171,
  31174,
  31177,
  31181,
  31184,
  31187,
  31191,
  31194,
  31197,
  31201,
  31204,
  31207,
  31211,
  31214,
  31217,
  31221,
  31224,
  31227,
  31231,
  31234,
  31237,
  31241,
  31244,
  31247,
  31251,
  31254,
  31257,
  31260,
  31264,
  31267,
  31270,
  31274,
  31277,
  31280,
  31284,
  31287,
  31290,
  31294,
  31297,
  31300,
  31304,
  31307,
  31310,
  31314,
  31317,
  31320,
  31324,
  31327,
  31330,
  31334,
  31337,
  31340,
  31344,
  31347,
  31350,
  31353,
  31357,
  31360,
  31363,
  31367,
  31370,
  31373,
  31377,
  31380,
  31383,
  31387,
  31390,
  31393,
  31397,
  31400,
  31403,
  31407,
  31410,
  31413,
  31417,
  31420,
  31423,
  31427,
  31430,
  31433,
  31437,
  31440,
  31443,
  31446,
  31450,
  31453,
  31456,
  31460,
  31463,
  31466,
  31470,
  31473,
  31476,
  31480,
  31483,
  31486,
  31490,
  31493,
  31496,
  31500,
  31503,
  31506,
  31510,
  31513,
  31516,
  31520,
  31523,
  31526,
  31530,
  31533,
  31536,
  31540,
  31543,
  31546,
  31549,
  31553,
  31556,
  31559,
  31563,
  31566,
  31569,
  31573,
  31576,
  31579,
  31583,
  31586,
  31589,
  31593,
  31596,
  31599,
  31603,
  31606,
  31609,
  31613,
  31616,
  31619,
  31623,
  31626,
  31629,
  31633,
  31636,
  31639,
  31642,
  31646,
  31649,
  31652,
  31656,
  31659,
  31662,
  31666,
  31669,
  31672,
  31676,
  31679,
  31682,
  31686,
  31689,
  31692,
  31696,
  31699,
  31702,
  31706,
  31709,
  31712,
  31716,
  31719,
  31722,
  31726,
  31729,
  31732,
  31736,
  31739,
  31742,
  31745,
  31749,
  31752,
  31755,
  31759,
  31762,
  31765,
  31769,
  31772,
  31775,
  31779,
  31782,
  31785,
  31789,
  31792,
  31795,
  31799,
  31802,
  31805,
  31809,
  31812,
  31815,
  31819,
  31822,
  31825,
  31829,
  31832,
  31835,
  31838,
  31842,
  31845,
  31848,
  31852,
  31855,
  31858,
  31862,
  31865,
  31868,
  31872,
  31875,
  31878,
  31882,
  31885,
  31888,
  31892,
  31895,
  31898,
  31902,
  31905,
  31908,
  31912,
  31915,
  31918,
  31922,
  31925,
  31928,
  31931,
  31935,
  31938,
  31941,
  31945,
  31948,
  31951,
  31955,
  31958,
  31961,
  31965,
  31968,
  31971,
  31975,
  31978,
  31981,
  31985,
  31988,
  31991,
  31995,
  31998,
  32001,
  32005,
  32008,
  32011,
  32015,
  32018,
  32021,
  32025,
  32028,
  32031,
  32034,
  32038,
  32041,
  32044,
  32048,
  32051,
  32054,
  32058,
  32061,
  32064,
  32068,
  32071,
  32074,
  32078,
  32081,
  32084,
  32088,
  32091,
  32094,
  32098,
  32101,
  32104,
  32108,
  32111,
  32114,
  32118,
  32121,
  32124,
  32127,
  32131,
  32134,
  32137,
  32141,
  32144,
  32147,
  32151,
  32154,
  32157,
  32161,
  32164,
  32167,
  32171,
  32174,
  32177,
  32181,
  32184,
  32187,
  32191,
  32194,
  32197,
  32201,
  32204,
  32207,
  32211,
  32214,
  32217,
  32221,
  32224,
  32227,
  32230,
  32234,
  32237,
  32240,
  32244,
  32247,
  32250,
  32254,
  32257,
  32260,
  32264,
  32267,
  32270,
  32274,
  32277,
  32280,
  32284,
  32287,
  32290,
  32294,
  32297,
  32300,
  32304,
  32307,
  32310,
  32314,
  32317,
  32320,
  32323,
  32327,
  32330,
  32333,
  32337,
  32340,
  32343,
  32347,
  32350,
  32353,
  32357,
  32360,
  32363,
  32367,
  32370,
  32373,
  32377,
  32380,
  32383,
  32387,
  32390,
  32393,
  32397,
  32400,
  32403,
  32407,
  32410,
  32413,
  32417,
  32420,
  32423,
  32426,
  32430,
  32433,
  32436,
  32440,
  32443,
  32446,
  32450,
  32453,
  32456,
  32460,
  32463,
  32466,
  32470,
  32473,
  32476,
  32480,
  32483,
  32486,
  32490,
  32493,
  32496,
  32500,
  32503,
  32506,
  32510,
  32513,
  32516,
  32519,
  32523,
  32526,
  32529,
  32533,
  32536,
  32539,
  32543,
  32546,
  32549,
  32553,
  32556,
  32559,
  32563,
  32566,
  32569,
  32573,
  32576,
  32579,
  32583,
  32586,
  32589,
  32593,
  32596,
  32599,
  32603,
  32606,
  32609,
  32612,
  32616,
  32619,
  32622,
  32626,
  32629,
  32632,
  32636,
  32639,
  32642,
  32646,
  32649,
  32652,
  32656,
  32659,
  32662,
  32666,
  32669,
  32672,
  32676,
  32679,
  32682,
  32686,
  32689,
  32692,
  32696,
  32699,
  32702,
  32706,
  32709,
  32712,
  32715,
  32719,
  32722,
  32725,
  32729,
  32732,
  32735,
  32739,
  32742,
  32745,
  32749,
  32752,
  32755,
  32759,
  32762,
  32765,
  32769,
  32772,
  32775,
  32779,
  32782,
  32785,
  32789,
  32792,
  32795,
  32799,
  32802,
  32805,
  32808,
  32812,
  32815,
  32818,
  32822,
  32825,
  32828,
  32832,
  32835,
  32838,
  32842,
  32845,
  32848,
  32852,
  32855,
  32858,
  32862,
  32865,
  32868,
  32872,
  32875,
  32878,
  32882,
};

static const UINT256 multipliers1_binary80[] =
  { {{12415850090107640902ull, 14557465677128539270ull,
      4938398379086257084ull, 5255184001115807319ull}},
{{6296440575779775320ull, 18196832096410674088ull,
  1561311955430433451ull, 6568980001394759149ull}},
{{7870550719724719149ull, 18134354102085954706ull,
  6563325962715429718ull, 8211225001743448936ull}},
{{9530780218255337373ull, 6722285295376333787ull,
  4102078726697143574ull, 5132015626089655585ull}},
{{7301789254391783812ull, 17626228656075193042ull,
  9739284426798817371ull, 6415019532612069481ull}},
{{18350608604844505572ull, 17421099801666603398ull,
  16785791551925909618ull, 8018774415765086851ull}},
{{6857444359600428079ull, 15499873394469015028ull,
  8185276710739999559ull, 5011734009853179282ull}},
{{8571805449500535098ull, 14763155724658880881ull,
  1008223851570223641ull, 6264667512316474103ull}},
{{15326442830303056777ull, 4618886600541437389ull,
  15095337869744943264ull, 7830834390395592628ull}},
{{11884869778153104438ull, 2886804125338398368ull,
  211214131735813732ull, 4894271493997245393ull}},
{{14856087222691380547ull, 3608505156672997960ull,
  4875703683097155069ull, 6117839367496556741ull}},
{{123364954654674068ull, 9122317464268635355ull,
  10706315622298831740ull, 7647299209370695926ull}},
{{16218004161155028957ull, 14924820452022672904ull,
  2079761245509381933ull, 4779562005856684954ull}},
{{1825761127734234580ull, 4820967509746177419ull,
  11823073593741503225ull, 5974452507320856192ull}},
{{16117259464949956936ull, 10637895405610109677ull,
  14778841992176879031ull, 7468065634151070240ull}},
{{12379130174807417037ull, 13566213656147400404ull,
  9236776245110549394ull, 4667541021344418900ull}},
{{15473912718509271297ull, 7734395033329474697ull,
  11545970306388186743ull, 5834426276680523625ull}},
{{5507332842854425409ull, 5056307773234455468ull, 597404827703069717ull,
  7293032845850654532ull}},
{{6884166053568031761ull, 10932070734970457239ull,
  746756034628837146ull, 9116291057313318165ull}},
{{11220132811121101707ull, 11444230227783923678ull,
  2772565530856717168ull, 5697681910820823853ull}},
{{4801793977046601325ull, 14305287784729904598ull,
  8077392931998284364ull, 7122102388526029816ull}},
{{15225614508163027464ull, 17881609730912380747ull,
  10096741164997855455ull, 8902627985657537270ull}},
{{7210166058388198213ull, 18093535109461319823ull,
  1698777209696271755ull, 5564142491035960794ull}},
{{4401021554557859863ull, 18005232868399261875ull,
  11346843548975115502ull, 6955178113794950992ull}},
{{889590924769936924ull, 13283169048644301536ull,
  14183554436218894378ull, 8693972642243688740ull}},
{{555994327981210578ull, 12913666673830076364ull,
  18088093559491584794ull, 5433732901402305462ull}},
{{694992909976513222ull, 6918711305432819647ull,
  13386744912509705185ull, 6792166126752881828ull}},
{{14703799192752805239ull, 13260075150218412462ull,
  16733431140637131481ull, 8490207658441102285ull}},
{{4578188477043115371ull, 1370017941245425933ull,
  12764237472111901128ull, 5306379786525688928ull}},
{{10334421614731282117ull, 1712522426556782416ull,
  15955296840139876410ull, 6632974733157111160ull}},
{{12918027018414102647ull, 11364025070050753828ull,
  1497376976465293896ull, 8291218416446388951ull}},
{{17297138923363589962ull, 7102515668781721142ull,
  7853389637931890541ull, 5182011510278993094ull}},
{{12398051617349711645ull, 13489830604404539332ull,
  593365010560087368ull, 6477514387848741368ull}},
{{15497564521687139556ull, 16862288255505674165ull,
  741706263200109210ull, 8096892984810926710ull}},
{{11991820835268156175ull, 15150616178118434257ull,
  14298624469782231968ull, 5060558115506829193ull}},
{{1154717988803031506ull, 491526148938491206ull, 4038222531945626249ull,
  6325697644383536492ull}},
{{10666769522858565191ull, 5226093704600501911ull,
  5047778164932032811ull, 7907122055479420615ull}},
{{13584259979427685100ull, 960465556161619742ull,
  10072390380723602363ull, 4941951284674637884ull}},
{{7756952937429830567ull, 15035640000484188390ull,
  12590487975904502953ull, 6177439105843297355ull}},
{{472819134932512401ull, 4959491945323071776ull,
  11126423951453240788ull, 7721798882304121694ull}},
{{295511959332820251ull, 12323054502681695668ull,
  2342328951230887588ull, 4826124301440076059ull}},
{{369389949166025313ull, 15403818128352119585ull,
  16762969244320773197ull, 6032655376800095073ull}},
{{5073423454884919546ull, 5419714605157985769ull,
  7118653500118802785ull, 7540819221000118842ull}},
{{14700104705371544476ull, 14916536674292210865ull,
  9060844456001639644ull, 4713012013125074276ull}},
{{4540072826432266883ull, 198926769155711966ull,
  11326055570002049556ull, 5891265016406342845ull}},
{{14898463069895109412ull, 248658461444639957ull, 322511407220398233ull,
  7364081270507928557ull}},
{{4788020782086723053ull, 4922509095233187851ull,
  5014825277452885695ull, 9205101588134910696ull}},
{{686669979590507956ull, 9994097212161824263ull, 3134265798408053559ull,
  5753188492584319185ull}},
{{14693395529770298657ull, 7880935496774892424ull,
  8529518266437454853ull, 7191485615730398981ull}},
{{18366744412212873321ull, 14462855389396003434ull,
  15273583851474206470ull, 8989357019662998726ull}},
{{16090901276060433730ull, 4427598599945114242ull,
  4934303888743991140ull, 5618348137289374204ull}},
{{10890254558220766354ull, 5534498249931392803ull,
  6167879860929988925ull, 7022935171611717755ull}},
{{9001132179348570039ull, 11529808830841628908ull,
  3098163807735098252ull, 8778668964514647194ull}},
{{14849079648947632082ull, 16429502556130793875ull,
  6548038398261824311ull, 5486668102821654496ull}},
{{13949663542757152199ull, 15925192176736104440ull,
  8185047997827280389ull, 6858335128527068120ull}},
{{17437079428446440248ull, 6071432165637966838ull,
  10231309997284100487ull, 8572918910658835150ull}},
{{6286488624351637251ull, 10712174131164811130ull,
  1782882729875174900ull, 5358074319161771969ull}},
{{17081482817294322372ull, 13390217663956013912ull,
  6840289430771356529ull, 6697592898952214961ull}},
{{2905109447908351349ull, 2902714024662853679ull,
  13162047806891583566ull, 8371991123690268701ull}},
{{8733222432583801449ull, 15649254320696447261ull,
  10532122888520933680ull, 5232494452306417938ull}},
{{15528214059157139716ull, 1114823827161007460ull,
  3941781573796391293ull, 6540618065383022423ull}},
{{963523500236873028ull, 6005215802378647230ull, 315540948818101212ull,
  8175772581728778029ull}},
{{14437260242930209355ull, 12976631913341430326ull,
  2503056102225007209ull, 5109857863580486268ull}},
{{8823203266807985885ull, 2385731836394624196ull,
  3128820127781259012ull, 6387322329475607835ull}},
{{11029004083509982357ull, 2982164795493280245ull,
  17746083215008737477ull, 7984152911844509793ull}},
{{9198970561407432925ull, 4169696006396994105ull,
  4173772981739379067ull, 4990095569902818621ull}},
{{16110399220186679060ull, 600433989568854727ull,
  9828902245601611738ull, 6237619462378523276ull}},
{{15526313006805960921ull, 9973914523815844217ull,
  12286127807002014672ull, 7797024327973154095ull}},
{{2786416601612643720ull, 6233696577384902636ull,
  14596358907017341026ull, 4873140204983221309ull}},
{{3483020752015804650ull, 17015492758585904103ull,
  4410390578489512570ull, 6091425256229026637ull}},
{{18188833995301919524ull, 12045993911377604320ull,
  10124674241539278617ull, 7614281570286283296ull}},
{{11368021247063699703ull, 611217166969920844ull,
  6327921400962049136ull, 4758925981428927060ull}},
{{14210026558829624628ull, 764021458712401055ull,
  7909901751202561420ull, 5948657476786158825ull}},
{{13150847180109642881ull, 955026823390501319ull,
  14499063207430589679ull, 7435821845982698531ull}},
{{15136808515209608657ull, 7514420792260145180ull,
  6756071495430424597ull, 4647388653739186582ull}},
{{474266570302459205ull, 14004712008752569380ull,
  17668461406142806554ull, 5809235817173983227ull}},
{{592833212878074006ull, 8282517974085935917ull,
  17473890739251120289ull, 7261544771467479034ull}},
{{5352727534524980412ull, 14964833486034807800ull,
  12618991387209124553ull, 9076930964334348793ull}},
{{3345454709078112758ull, 2435491901130673019ull, 969340589364620990ull,
  5673081852708967996ull}},
{{18016876441629804659ull, 12267736913268117081ull,
  1211675736705776237ull, 7091352315886209995ull}},
{{8686037496755092111ull, 1499613086302982640ull,
  15349652726164384009ull, 8864190394857762493ull}},
{{5428773435471932570ull, 12466473225007833910ull,
  11899375963066433957ull, 5540118996786101558ull}},
{{16009338831194691520ull, 1748033475977628675ull,
  5650847916978266639ull, 6925148745982626948ull}},
{{15399987520565976496ull, 16020099900254199556ull,
  7063559896222833298ull, 8656435932478283685ull}},
{{401620163498959502ull, 14624248456086262627ull,
  6720567944352964763ull, 5410272457798927303ull}},
{{14337083259655863090ull, 13668624551680440379ull,
  3789023912013818050ull, 6762840572248659129ull}},
{{13309668056142440958ull, 7862408652745774666ull,
  9347965908444660467ull, 8453550715310823911ull}},
{{12930228553516413503ull, 2608162398752415214ull,
  12760007720418994648ull, 5283469197069264944ull}},
{{6939413655040741070ull, 3260202998440519018ull,
  15950009650523743310ull, 6604336496336581180ull}},
{{17897639105655702146ull, 13298625784905424580ull,
  1490767989445127521ull, 8255420620420726476ull}},
{{1962652404180038033ull, 1394112087924808507ull,
  10155102030257980509ull, 5159637887762954047ull}},
{{16288373560507211254ull, 6354326128333398537ull,
  8082191519395087732ull, 6449547359703692559ull}},
{{6525408895351850355ull, 7942907660416748172ull,
  5491053380816471761ull, 8061934199629615699ull}},
{{13301752596449682280ull, 16493532333828937367ull,
  1126065353796600898ull, 5038708874768509812ull}},
{{12015504727134714946ull, 11393543380431395901ull,
  1407581692245751123ull, 6298386093460637265ull}},
{{1184322853636229970ull, 9630243207111856973ull,
  6371163133734576808ull, 7872982616825796581ull}},
{{3046044792736337684ull, 6018902004444910608ull,
  6287819967797804457ull, 4920614135516122863ull}},
{{3807555990920422104ull, 12135313523983526164ull,
  3248088941319867667ull, 6150767669395153579ull}},
{{4759444988650527630ull, 10557455886552019801ull,
  17895169231931998296ull, 7688459586743941973ull}},
{{14503868163975049529ull, 6598409929095012375ull,
  13490323779171192887ull, 4805287241714963733ull}},
{{13518149186541424007ull, 3636326392941377565ull,
  3027846668681827397ull, 6006609052143704667ull}},
{{3062628427894616297ull, 9157094009604109861ull,
  17619866391134447958ull, 7508261315179630833ull}},
{{4219985776647829138ull, 1111497737575180759ull,
  4094887466817948118ull, 4692663321987269271ull}},
{{663296202382398518ull, 10612744208823751757ull, 506923315095047243ull,
  5865829152484086589ull}},
{{5440806271405386052ull, 8654244242602301792ull,
  5245340162296196958ull, 7332286440605108236ull}},
{{6801007839256732564ull, 1594433266398101432ull,
  6556675202870246198ull, 9165358050756385295ull}},
{{4250629899535457853ull, 14831578846780977107ull,
  11015451029434985729ull, 5728348781722740809ull}},
{{701601355991934412ull, 4704415503194057672ull,
  18380999805221120066ull, 7160435977153426011ull}},
{{877001694989918015ull, 15103891415847347898ull,
  18364563738099012178ull, 8950544971441782514ull}},
{{5159812077796086663ull, 14051618153331980340ull,
  16089538354739270515ull, 5594090607151114071ull}},
{{6449765097245108329ull, 12952836673237587521ull,
  15500236924996700240ull, 6992613258938892589ull}},
{{12673892389983773315ull, 16191045841546984401ull,
  5540238100963711588ull, 8740766573673615737ull}},
{{1003653716098776466ull, 896031614112089443ull,
  14991863859170789503ull, 5462979108546009835ull}},
{{15089625200405634295ull, 14955097572922275515ull,
  14128143805536098974ull, 6828723885682512294ull}},
{{14250345482079654964ull, 9470499929298068586ull,
  8436807720065347910ull, 8535904857103140368ull}},
{{13518151944727172257ull, 1307376437383904962ull,
  5273004825040842444ull, 5334940535689462730ull}},
{{7674317894054189513ull, 1634220546729881203ull,
  15814628068155828863ull, 6668675669611828412ull}},
{{4981211349140348987ull, 15877833738694515216ull,
  1321541011485234462ull, 8335844587014785516ull}},
{{3113257093212718117ull, 5311960068256684106ull,
  10049335169033047347ull, 5209902866884240947ull}},
{{13114943403370673454ull, 2028264066893467228ull,
  7949982942863921280ull, 6512378583605301184ull}},
{{16393679254213341818ull, 2535330083616834035ull,
  9937478678579901600ull, 8140473229506626480ull}},
{{7940206524669644684ull, 1584581302260521272ull,
  6210924174112438500ull, 5087795768441641550ull}},
{{9925258155837055855ull, 1980726627825651590ull,
  16987027254495323933ull, 6359744710552051937ull}},
{{3183200657941544011ull, 7087594303209452392ull,
  7398726012836991204ull, 7949680888190064922ull}},
{{1989500411213465007ull, 13653118476360683553ull,
  9235889776450507406ull, 4968550555118790576ull}},
{{7098561532444219163ull, 7843026058596078633ull,
  11544862220563134258ull, 6210688193898488220ull}},
{{13484887933982661857ull, 580410536390322483ull,
  14431077775703917823ull, 7763360242373110275ull}},
{{6122211949525469709ull, 7280285612885033408ull,
  6713580600601254687ull, 4852100151483193922ull}},
{{7652764936906837136ull, 4488670997678903856ull,
  17615347787606344167ull, 6065125189353992402ull}},
{{9565956171133546420ull, 999152728671241916ull,
  12795812697653154401ull, 7581406486692490503ull}},
{{15202094643813242321ull, 12153685501487995957ull,
  14914911963674303356ull, 4738379054182806564ull}},
{{5167560249484389189ull, 15192106876859994947ull,
  196895880883327579ull, 5922973817728508206ull}},
{{1847764293428098582ull, 14378447577647605780ull,
  9469491887958935282ull, 7403717272160635257ull}},
{{10378224720247337422ull, 13598215754457141516ull,
  17447647476042804311ull, 4627323295100397035ull}},
{{12972780900309171777ull, 12386083674644038991ull,
  17197873326626117485ull, 5784154118875496294ull}},
{{11604290106959076817ull, 1647546538022885027ull,
  12273969621427871049ull, 7230192648594370368ull}},
{{9893676615271458117ull, 6671119190955994188ull,
  15342462026784838811ull, 9037740810742962960ull}},
{{15406919921399437132ull, 1863606485133802415ull,
  9589038766740524257ull, 5648588006714351850ull}},
{{14646963883321908510ull, 6941194124844640923ull,
  2762926421570879513ull, 7060735008392939813ull}},
{{13697018835724997734ull, 13288178674483189058ull,
  8065344045390987295ull, 8825918760491174766ull}},
{{13172322790755511488ull, 15222640699193075017ull,
  429154009941979155ull, 5516199225306984229ull}},
{{2630345433162225648ull, 14416614855563955868ull,
  5148128530854861848ull, 6895249031633730286ull}},
{{3287931791452782059ull, 18020768569454944835ull,
  15658532700423353118ull, 8619061289542162857ull}},
{{18195858434153846451ull, 6651294337481952617ull,
  2869053910123513843ull, 5386913305963851786ull}},
{{8909764987410144352ull, 3702431903425052868ull,
  12809689424509168112ull, 6733641632454814732ull}},
{{11137206234262680440ull, 4628039879281316085ull,
  16012111780636460140ull, 8417052040568518415ull}},
{{9266596905627869227ull, 12115896961405598361ull,
  16925098890538869443ull, 5260657525355324009ull}},
{{16194932150462224438ull, 10533185183329610047ull,
  7321315557891423092ull, 6575821906694155012ull}},
{{15631979169650392643ull, 13166481479162012559ull,
  9151644447364278865ull, 8219777383367693765ull}},
{{16687516008672577258ull, 1311521896835175993ull,
  8025620788816368243ull, 5137360864604808603ull}},
{{7024336955558557860ull, 15474460426326133704ull,
  5420339967593072399ull, 6421701080756010754ull}},
{{8780421194448197325ull, 14731389514480279226ull,
  15998796996346116307ull, 8027126350945013442ull}},
{{10099449264957511233ull, 6901275437336480564ull,
  14610934141143710596ull, 5016953969340633401ull}},
{{12624311581196889041ull, 8626594296670600705ull,
  4428609621147474533ull, 6271192461675791752ull}},
{{1945331421213947589ull, 15394928889265638786ull,
  5535762026434343166ull, 7838990577094739690ull}},
{{5827518156686105147ull, 5010144537363636337ull,
  8071537284948852383ull, 4899369110684212306ull}},
{{11896083714285019338ull, 1650994653277157517ull,
  866049569331289671ull, 6124211388355265383ull}},
{{1035046587574110460ull, 15898801371878610609ull,
  14917620016946275800ull, 7655264235444081728ull}},
{{12176119163302288798ull, 9936750857424131630ull,
  9323512510591422375ull, 4784540147152551080ull}},
{{5996776917273085189ull, 7809252553352776634ull,
  11654390638239277969ull, 5980675183940688850ull}},
{{16719343183446132294ull, 14373251710118358696ull,
  5344616260944321653ull, 7475843979925861063ull}},
{{10449589489653832684ull, 11289125328037668137ull,
  10257914190731282889ull, 4672402487453663164ull}},
{{17673672880494678759ull, 276348604764921459ull,
  12822392738414103612ull, 5840503109317078955ull}},
{{17480405082190960545ull, 345435755956151824ull,
  11416304904590241611ull, 7300628886646348694ull}},
{{3403762279029149065ull, 14266852750227353493ull,
  5047009093883026205ull, 9125786108307935868ull}},
{{4433194433606912118ull, 11222625978105789885ull,
  12377752720531667186ull, 5703616317692459917ull}},
{{10153179060436028051ull, 4804910435777461548ull,
  1637132845382420271ull, 7129520397115574897ull}},
{{12691473825545035063ull, 1394452026294439031ull,
  6658102075155413243ull, 8911900496394468621ull}},
{{14849700168606728771ull, 17012433580929882058ull,
  6467156806185827228ull, 5569937810246542888ull}},
{{9338753173903635155ull, 2818797902452800957ull,
  8083946007732284036ull, 6962422262808178610ull}},
{{16285127485806931848ull, 3523497378066001196ull,
  881560472810579237ull, 8703027828510223263ull}},
{{954832641774556597ull, 4508028870504944700ull, 7468504323147693879ull,
  5439392392818889539ull}},
{{1193540802218195746ull, 1023350069703792971ull,
  4723944385507229445ull, 6799240491023611924ull}},
{{15326984058054908395ull, 5890873605557129117ull,
  5904930481884036806ull, 8499050613779514905ull}},
{{11885208045498011699ull, 17516854058755369410ull,
  15219796597245992763ull, 5311906633612196815ull}},
{{5633138020017738816ull, 17284381555016823859ull,
  14413059728130103050ull, 6639883292015246019ull}},
{{2429736506594785615ull, 12382104906916254016ull,
  13404638641735240909ull, 8299854115019057524ull}},
{{1518585316621741010ull, 10044658576036352712ull,
  17601271187939301376ull, 5187408821886910952ull}},
{{1898231645777176262ull, 12555823220045440890ull,
  3554844911214575104ull, 6484261027358638691ull}},
{{11596161594076246136ull, 15694779025056801112ull,
  18278614194300382592ull, 8105326284198298363ull}},
{{7247600996297653835ull, 9809236890660500695ull,
  9118290862224045168ull, 5065828927623936477ull}},
{{4447815226944679390ull, 12261546113325625869ull,
  16009549596207444364ull, 6332286159529920596ull}},
{{10171455052108237141ull, 15326932641657032336ull,
  1565192921549753839ull, 7915357699412400746ull}},
{{6357159407567648213ull, 16496861928676727066ull,
  5589931594395984053ull, 4947098562132750466ull}},
{{17169821296314336074ull, 6786019355563745120ull,
  16210786529849755875ull, 6183873202665938082ull}},
{{3015532546683368477ull, 3870838176027293497ull,
  11040111125457419036ull, 7729841503332422603ull}},
{{13413922887745575058ull, 11642645896871834243ull,
  4594226444197192945ull, 4831150939582764127ull}},
{{12155717591254580919ull, 718249315807629092ull,
  1131097036819103278ull, 6038938674478455159ull}},
{{15194646989068226148ull, 10121183681614312173ull,
  15248929351306042809ull, 7548673343098068948ull}},
{{11802497377381335295ull, 17854954847077414868ull,
  307208807711500947ull, 4717920839436293093ull}},
{{14753121721726669118ull, 17707007540419380681ull,
  4995697028066764088ull, 5897401049295366366ull}},
{{4606344096876172686ull, 3687015351814674236ull,
  15467993321938230919ull, 7371751311619207957ull}},
{{5757930121095215857ull, 18443827245050506507ull,
  5499933597140624936ull, 9214689139524009947ull}},
{{1292863316470815959ull, 11527392028156566567ull,
  1131615488999196633ull, 5759180712202506217ull}},
{{15451137200870683660ull, 574181979913544496ull,
  6026205379676383696ull, 7198975890253132771ull}},
{{867177427378802959ull, 717727474891930621ull, 2921070706168091716ull,
  8998719862816415964ull}},
{{2847828901325445802ull, 9671951708662232446ull,
  11049041228209833130ull, 5624199914260259977ull}},
{{12783158163511583060ull, 2866567598973014749ull,
  18422987553689679317ull, 7030249892825324971ull}},
{{2143889649107315113ull, 8194895517143656341ull,
  18417048423684711242ull, 8787812366031656214ull}},
{{3645774039905765898ull, 9733495716642173117ull,
  6898969246375556622ull, 5492382728769785134ull}},
{{9168903568309595276ull, 2943497608947940588ull,
  17847083594824221586ull, 6865478410962231417ull}},
{{11461129460386994095ull, 12902744048039701543ull,
  8473796438248113270ull, 8581848013702789272ull}},
{{14080734940382953166ull, 3452529011597425560ull,
  5296122773905070794ull, 5363655008564243295ull}},
{{17600918675478691457ull, 13539033301351557758ull,
  2008467448953950588ull, 6704568760705304119ull}},
{{12777776307493588513ull, 16923791626689447198ull,
  16345642366474601947ull, 8380710950881630148ull}},
{{3374424173756104917ull, 8271526757467210547ull, 992654442191850409ull,
  5237944344301018843ull}},
{{18053088272477294858ull, 14951094465261401087ull,
  15075876108021976723ull, 6547430430376273553ull}},
{{17954674322169230668ull, 14077182063149363455ull,
  5009787079745307192ull, 8184288037970341942ull}},
{{18139200478996851024ull, 8798238789468352159ull,
  16966174980122980707ull, 5115180023731463713ull}},
{{18062314580318675876ull, 6386112468408052295ull,
  7372660669871562172ull, 6393975029664329642ull}},
{{17966207206970956941ull, 7982640585510065369ull,
  18439197874194228523ull, 7992468787080412052ull}},
{{4311350476715766232ull, 2683307356730096904ull,
  2301126634516617019ull, 4995292991925257533ull}},
{{5389188095894707790ull, 17189192251194784842ull,
  7488094311573159177ull, 6244116239906571916ull}},
{{15959857156723160545ull, 7651432258711317340ull,
  9360117889466448972ull, 7805145299883214895ull}},
{{751538686097199533ull, 14005517198549349146ull,
  12767602708557612463ull, 4878215812427009309ull}},
{{10162795394476275224ull, 12895210479759298528ull,
  2124445330414851867ull, 6097769765533761637ull}},
{{12703494243095344030ull, 11507327081271735256ull,
  7267242681445952738ull, 7622212206917202046ull}},
{{7939683901934590019ull, 11803765444222222439ull,
  18377084731185884173ull, 4763882629323251278ull}},
{{5312918858990849620ull, 919648749995614337ull,
  13747983877127579409ull, 5954853286654064098ull}},
{{11252834592165949928ull, 5761246955921905825ull,
  7961607809554698453ull, 7443566608317580123ull}},
{{115492592462636849ull, 5906622356664885093ull, 2670161871757992581ull,
  4652229130198487577ull}},
{{4756051759005683966ull, 11994963964258494270ull,
  7949388358124878630ull, 5815286412748109471ull}},
{{15168436735611880765ull, 5770332918468342029ull,
  5325049429228710384ull, 7269108015935136839ull}},
{{5125487864232687244ull, 7212916148085427537ull,
  2044625768108500076ull, 9086385019918921049ull}},
{{14732644961213899288ull, 13731444629408168018ull,
  12807106151136282307ull, 5678990637449325655ull}},
{{9192434164662598301ull, 12552619768332822119ull,
  11397196670492964980ull, 7098738296811657069ull}},
{{6878856687400859973ull, 15690774710416027649ull,
  411437782834042513ull, 8873422871014571337ull}},
{{15828500475694007243ull, 2889205166368935424ull,
  11786363660339746331ull, 5545889294384107085ull}},
{{1338881520907957438ull, 17446564513243332993ull,
  897896520142519201ull, 6932361617980133857ull}},
{{6285287919562334701ull, 7973147586272002529ull,
  5734056668605536906ull, 8665452022475167321ull}},
{{15457519995794928948ull, 9594903259847389484ull,
  15113000463946930326ull, 5415907514046979575ull}},
{{875155921034109569ull, 2770257037954461048ull,
  14279564561506275004ull, 6769884392558724469ull}},
{{1093944901292636962ull, 3462821297443076310ull,
  4014397646600680043ull, 8462355490698405587ull}},
{{14518773618590061813ull, 18305164375397780357ull,
  203155519911731074ull, 5288972181686503492ull}},
{{4313408967955413554ull, 13658083432392449639ull,
  253944399889663843ull, 6611215227108129365ull}},
{{780075191516879039ull, 12460918272063174145ull,
  4929116518289467708ull, 8264019033885161706ull}},
{{12016762040766519159ull, 17011445956894259648ull,
  7692383842358305221ull, 5165011896178226066ull}},
{{15020952550958148949ull, 7429249390835660848ull,
  392107766093105719ull, 6456264870222782583ull}},
{{329446614988134570ull, 4674875720117188157ull,
  14325192762898545861ull, 8070331087778478228ull}},
{{2511747143581278059ull, 5227640334286936550ull,
  18176617513666366971ull, 5043956929861548892ull}},
{{12363055966331373381ull, 1922864399431282783ull,
  4274027818373407098ull, 6304946162326936116ull}},
{{10842133939486828822ull, 11626952536143879287ull,
  5342534772966758872ull, 7881182702908670145ull}},
{{13693862739820349870ull, 7266845335089924554ull,
  14868299279172694055ull, 4925739189317918840ull}},
{{7893956387920661530ull, 4471870650435017789ull, 138630025256315953ull,
  6157173986647398551ull}},
{{14479131503328214816ull, 10201524331471160140ull,
  14008345586852558653ull, 7696467483309248188ull}},
{{18272829226434910068ull, 8681795716383169039ull,
  17978588028637624966ull, 4810292177068280117ull}},
{{18229350514616249681ull, 1628872608624185491ull,
  8638176980514867496ull, 6012865221335350147ull}},
{{18175002124842924197ull, 2036090760780231864ull,
  6186035207216196466ull, 7516081526669187684ull}},
{{11359376328026827623ull, 5884242743915032819ull,
  13089644041364898599ull, 4697550954168242302ull}},
{{9587534391606146625ull, 2743617411466403120ull,
  7138683014851347441ull, 5871938692710302878ull}},
{{11984417989507683281ull, 8041207782760391804ull,
  18146725805418960109ull, 7339923365887878597ull}},
{{14980522486884604101ull, 14663195746877877659ull,
  8848349201491536424ull, 9174904207359848247ull}},
{{7056983545089183612ull, 9164497341798673537ull,
  12447747278573292121ull, 5734315129599905154ull}},
{{13432915449788867418ull, 16067307695675729825ull,
  6336312061361839343ull, 7167893911999881443ull}},
{{2956086256953920561ull, 15472448601167274378ull,
  3308704058274911275ull, 8959867389999851804ull}},
{{6459239929023588255ull, 7364437366515852534ull,
  11291312073276595355ull, 5599917118749907377ull}},
{{17297421948134261126ull, 4593860689717427763ull,
  279082036313580482ull, 6999896398437384222ull}},
{{17010091416740438504ull, 14965697899001560512ull,
  9572224582246751410ull, 8749870498046730277ull}},
{{10631307135462774065ull, 13965247205303363224ull,
  8288483373117913583ull, 5468669061279206423ull}},
{{13289133919328467581ull, 12844872988201816126ull,
  5748918197970004075ull, 6835836326599008029ull}},
{{7388045362305808668ull, 11444405216824882254ull,
  11797833765889892998ull, 8544795408248760036ull}},
{{5842333013742514ull, 2541067242088163505ull, 16597018140535958932ull,
  5340497130155475022ull}},
{{4618988934694566046ull, 3176334052610204381ull,
  11522900638815172857ull, 6675621412694343778ull}},
{{10385422186795595462ull, 8582103584190143380ull,
  5180253761664190263ull, 8344526765867929723ull}},
{{15714260903602022972ull, 12281343767759921468ull,
  931815591826424962ull, 5215329228667456077ull}},
{{1196082055792977098ull, 6128307672845126028ull,
  5776455508210419107ull, 6519161535834320096ull}},
{{1495102569741221373ull, 3048698572629019631ull,
  7220569385263023884ull, 8148951919792900120ull}},
{{7851968133729345214ull, 11128808644747913077ull,
  4512855865789389927ull, 5093094949870562575ull}},
{{14426646185589069422ull, 9299324787507503442ull,
  1029383813809349505ull, 6366368687338203219ull}},
{{8809935695131560969ull, 16235842002811767207ull,
  15121787822543850593ull, 7957960859172754023ull}},
{{12423738837098307462ull, 3229872224116272648ull,
  16368646416730988477ull, 4973725536982971264ull}},
{{15529673546372884327ull, 8649026298572728714ull,
  2014063947204183980ull, 6217156921228714081ull}},
{{10188719896111329601ull, 10811282873215910893ull,
  7129265952432617879ull, 7771446151535892601ull}},
{{8673792944283274953ull, 13674580823401026164ull,
  15985006266338855934ull, 4857153844709932875ull}},
{{10842241180354093691ull, 7869853992396506897ull,
  15369571814496182014ull, 6071442305887416094ull}},
{{18164487493870005017ull, 613945453640857813ull,
  9988592731265451710ull, 7589302882359270118ull}},
{{13658647692882447088ull, 14218773963807699845ull,
  1631184438613519414ull, 4743314301474543824ull}},
{{3238251560820895148ull, 8550095417904848999ull,
  2038980548266899268ull, 5929142876843179780ull}},
{{17882872506308282647ull, 10687619272381061248ull,
  2548725685333624085ull, 7411428596053974725ull}},
{{11176795316442676654ull, 8985605054451857232ull,
  3898796562547209005ull, 4632142872533734203ull}},
{{13970994145553345818ull, 15843692336492209444ull,
  261809684756623352ull, 5790178590667167754ull}},
{{17463742681941682272ull, 1357871346905710189ull,
  9550634142800554999ull, 7237723238333959692ull}},
{{7994620297144939128ull, 15532397238914301449ull,
  11938292678500693748ull, 9047154047917449615ull}},
{{16525852731784056715ull, 484376237466662597ull,
  14378961951704015449ull, 5654471279948406009ull}},
{{6822257859447907182ull, 5217156315260716151ull,
  4138644384347855599ull, 7068089099935507512ull}},
{{3916136305882496073ull, 1909759375648507285ull,
  5173305480434819499ull, 8835111374919384390ull}},
{{4753428200390253998ull, 17334500674276174717ull,
  17068373980553925898ull, 5521944609324615243ull}},
{{10553471268915205401ull, 12444753805990442588ull,
  16723781457265019469ull, 6902430761655769054ull}},
{{13191839086144006752ull, 1720884202205889523ull,
  11681354784726498529ull, 8628038452069711318ull}},
{{5939056419626310268ull, 12604767672447150712ull,
  2689160722026673676ull, 5392524032543569574ull}},
{{7423820524532887835ull, 15755959590558938390ull,
  12584822939388117903ull, 6740655040679461967ull}},
{{56403618811333985ull, 15083263469771285084ull,
  11119342655807759475ull, 8425818800849327459ull}},
{{9258624298611859549ull, 7121196659393359225ull,
  4643746150666155720ull, 5266136750530829662ull}},
{{16184966391692212340ull, 8901495824241699031ull,
  15028054725187470458ull, 6582670938163537077ull}},
{{15619521971187877521ull, 1903497743447347981ull,
  4950010351202174361ull, 8228338672704421347ull}},
{{12068044241206117403ull, 12718901135723062248ull,
  787913460287665023ull, 5142711670440263342ull}},
{{15085055301507646754ull, 11286940401226439906ull,
  10208263862214357087ull, 6428389588050329177ull}},
{{9632947090029782634ull, 9496989483105661979ull,
  17372015846195334263ull, 8035486985062911471ull}},
{{3714748922054920194ull, 12853147454582120593ull,
  17775038931513165770ull, 5022179365664319669ull}},
{{9255122170996038147ull, 6843062281372874933ull,
  8383740609109293501ull, 6277724207080399587ull}},
{{16180588732172435587ull, 13165513870143481570ull,
  5867989742959228972ull, 7847155258850499484ull}},
{{14724553976035160146ull, 17451818205694451789ull,
  12890865626204293915ull, 4904472036781562177ull}},
{{4570634414761786471ull, 17203086738690676833ull,
  2278523977473203682ull, 6130590045976952722ull}},
{{10324979036879620992ull, 12280486386508570233ull,
  12071527008696280411ull, 7663237557471190902ull}},
{{17982326944118232880ull, 5369460982354162443ull,
  2933018362007787353ull, 4789523473419494314ull}},
{{17866222661720403196ull, 11323512246370090958ull,
  12889644989364509999ull, 5986904341774367892ull}},
{{13109406290295728187ull, 9542704289535225794ull,
  16112056236705637499ull, 7483630427217959865ull}},
{{12805064949862218021ull, 3658347171745822169ull,
  3152506120299941581ull, 4677269017011224916ull}},
{{2171273132045608814ull, 9184619983109665616ull,
  3940632650374926976ull, 5846586271264031145ull}},
{{2714091415057011018ull, 11480774978887082020ull,
  9537476831396046624ull, 7308232839080038931ull}},
{{3392614268821263772ull, 14350968723608852525ull,
  7310160020817670376ull, 9135291048850048664ull}},
{{4426226927226983810ull, 8969355452255532828ull,
  4568850013011043985ull, 5709556905531280415ull}},
{{5532783659033729762ull, 15823380333746803939ull,
  1099376497836417077ull, 7136946131914100519ull}},
{{2304293555364774299ull, 5944167361901341212ull,
  15209278677577685059ull, 8921182664892625648ull}},
{{10663555508957759745ull, 1409261591974644305ull,
  9505799173486053162ull, 5575739165557891030ull}},
{{17941130404624587585ull, 10984949026823081189ull,
  2658876930002790644ull, 6969673956947363788ull}},
{{8591354950498570769ull, 13731186283528851487ull,
  3323596162503488305ull, 8712092446184204735ull}},
{{12287125871702688587ull, 1664462399564450323ull,
  8994776629205762047ull, 5445057778865127959ull}},
{{10747221321200972829ull, 15915636054737726616ull,
  6631784768079814654ull, 6806322223581409949ull}},
{{13434026651501216037ull, 10671173031567382462ull,
  12901416978527156222ull, 8507902779476762436ull}},
{{3784580638760872119ull, 2057797126302226135ull,
  17286757648434248447ull, 5317439237172976522ull}},
{{119039780023702245ull, 16407304463159946381ull,
  12385075023688034750ull, 6646799046466220653ull}},
{{4760485743457015710ull, 11285758542095157168ull,
  1646285724327879726ull, 8308498808082775817ull}},
{{2975303589660634819ull, 2441913070382085326ull,
  12558143623773394589ull, 5192811755051734885ull}},
{{12942501523930569331ull, 7664077356404994561ull,
  1862621474434579524ull, 6491014693814668607ull}},
{{2343068849631047952ull, 9580096695506243202ull,
  16163334898325388117ull, 8113768367268335758ull}},
{{6076104049446792874ull, 8293403443905095953ull,
  5490398293025979669ull, 5071105229542709849ull}},
{{12206816080235878997ull, 14978440323308757845ull,
  11474683884709862490ull, 6338881536928387311ull}},
{{1423462045012685034ull, 9499678367281171499ull,
  9731668837459940209ull, 7923601921160484139ull}},
{{17030564842628785810ull, 17466514025619201946ull,
  3776450014198768678ull, 4952251200725302587ull}},
{{12064834016431206455ull, 12609770495169226625ull,
  108876499321072944ull, 6190314000906628234ull}},
{{1245984465256844356ull, 15762213118961533282ull,
  9359467661006116988ull, 7737892501133285292ull}},
{{5390426309212915627ull, 628011162496182493ull,
  15073039324983598926ull, 4836182813208303307ull}},
{{11349718904943532437ull, 10008385989975003924ull,
  14229613137802110753ull, 6045228516510379134ull}},
{{14187148631179415547ull, 17122168505896142809ull,
  8563644385397862633ull, 7556535645637973918ull}},
{{1949438866846052861ull, 3783826288544007400ull, 740591722446276242ull,
  4722834778523733699ull}},
{{2436798583557566076ull, 13953154897534785058ull,
  14760797708340009014ull, 5903543473154667123ull}},
{{12269370266301733403ull, 8218071585063705514ull,
  13839311116997623364ull, 7379429341443333904ull}},
{{12280042434865971281ull, 14359666777519591754ull,
  8649569448123514602ull, 4612143338402083690ull}},
{{6126681006727688293ull, 8726211435044713885ull,
  1588589773299617445ull, 5765179173002604613ull}},
{{12270037276836998270ull, 15519450312233280260ull,
  6597423235051909710ull, 7206473966253255766ull}},
{{15337546596046247838ull, 10175940853436824517ull,
  17470151080669662946ull, 9008092457816569707ull}},
{{11891809631742598851ull, 10971649051825403227ull,
  8613001416204845389ull, 5630057786135356067ull}},
{{10253076021250860659ull, 18326247333209141938ull,
  6154565751828668832ull, 7037572232669195084ull}},
{{3592972989708800016ull, 4461065092801875807ull,
  7693207189785836041ull, 8796965290836493855ull}},
{{9163137146209081866ull, 14317380729069642139ull,
  11725783521257229381ull, 5498103306772808659ull}},
{{6842235414333964429ull, 4061667856054888962ull,
  10045543383144148823ull, 6872629133466010824ull}},
{{17776166304772231344ull, 465398801641223298ull,
  12556929228930186029ull, 8590786416832513530ull}},
{{15721789958910032494ull, 2596717260239458513ull,
  12459766786508754172ull, 5369241510520320956ull}},
{{5817179393355376905ull, 3245896575299323142ull,
  15574708483135942715ull, 6711551888150401195ull}},
{{16494846278548996939ull, 17892428774406317639ull,
  14856699585492540489ull, 8389439860188001494ull}},
{{17226807951734204943ull, 4265238956362866668ull,
  4673751222505449902ull, 5243399912617500934ull}},
{{3086765865958204563ull, 14554920732308359144ull,
  15065561064986588185ull, 6554249890771876167ull}},
{{3858457332447755704ull, 4358592860103285218ull,
  14220265312805847328ull, 8192812363464845209ull}},
{{7023221851207235219ull, 2724120537564553261ull,
  1970136792862572724ull, 5120507727165528256ull}},
{{13390713332436431928ull, 3405150671955691576ull,
  2462670991078215905ull, 6400634658956910320ull}},
{{16738391665545539909ull, 8868124358372002374ull,
  3078338738847769881ull, 8000793323696137900ull}},
{{5849808772538574540ull, 17071792770050971244ull,
  11147333748634631983ull, 5000495827310086187ull}},
{{7312260965673218174ull, 16728054944136326151ull,
  9322481167365902075ull, 6250619784137607734ull}},
{{4528640188664134814ull, 16298382661743019785ull,
  2429729422352601786ull, 7813274730172009668ull}},
{{14359615163983554019ull, 14798175182016775269ull,
  10741952925825151924ull, 4883296706357506042ull}},
{{4114460899697278811ull, 50974903811417471ull, 4204069120426664098ull,
  6104120882946882553ull}},
{{531390106194210610ull, 9287090666619047647ull, 9866772418960718026ull,
  7630151103683603191ull}},
{{7249647844012463487ull, 10416117685064292683ull,
  13084261789491530622ull, 4768844439802251994ull}},
{{4450373786588191455ull, 3796775069475590046ull,
  7131955200009637470ull, 5961055549752814993ull}},
{{14786339270090015127ull, 13969340873699263365ull,
  13526630018439434741ull, 7451319437191018741ull}},
{{11547305053019953406ull, 11036681055275733555ull,
  10759986770738340665ull, 4657074648244386713ull}},
{{9822445297847553854ull, 18407537337522054848ull,
  18061669481850313735ull, 5821343310305483391ull}},
{{12278056622309442317ull, 18397735653475180656ull,
  17965400833885504265ull, 7276679137881854239ull}},
{{15347570777886802897ull, 9162111511561812108ull,
  17845065023929492428ull, 9095848922352317799ull}},
{{368859699324476003ull, 14949691731580908376ull,
  18070694667597014623ull, 5684905576470198624ull}},
{{461074624155595003ull, 14075428646048747566ull,
  4141624260786716663ull, 7106131970587748281ull}},
{{9799715317049269562ull, 12982599789133546553ull,
  9788716344410783733ull, 8882664963234685351ull}},
{{17654037119224263236ull, 10419967877422160547ull,
  13035476742897821689ull, 5551665602021678344ull}},
{{17455860380602941141ull, 17636645865205088588ull,
  16294345928622277111ull, 6939582002527097930ull}},
{{3373081402044124810ull, 17434121313078972832ull,
  11144560373923070581ull, 8674477503158872413ull}},
{{2108175876277578007ull, 13202168829888051972ull,
  9271193242915613065ull, 5421548439474295258ull}},
{{2635219845346972508ull, 2667652982077901253ull,
  2365619516789740524ull, 6776935549342869073ull}},
{{7905710825111103539ull, 3334566227597376566ull,
  7568710414414563559ull, 8471169436678586341ull}},
{{329383247267051808ull, 9001632919889442210ull, 7036287018222796176ull,
  5294480897924116463ull}},
{{9635101095938590568ull, 11252041149861802762ull,
  4183672754351107316ull, 6618101122405145579ull}},
{{2820504333068462402ull, 14065051437327253453ull,
  617904924511496241ull, 8272626403006431974ull}},
{{4068658217381482953ull, 1873128120688451552ull,
  14221248633101848863ull, 5170391501879019983ull}},
{{5085822771726853692ull, 16176468206142728152ull,
  13164874772949923174ull, 6462989377348774979ull}},
{{6357278464658567114ull, 10997213220823634382ull,
  11844407447760016064ull, 8078736721685968724ull}},
{{17808357095693768159ull, 6873258263014771488ull,
  16626126691704785848ull, 5049210451053730452ull}},
{{3813702295907658582ull, 8591572828768464361ull,
  2335914290921430694ull, 6311513063817163066ull}},
{{9378813888311961132ull, 1516093999105804643ull,
  12143264900506564176ull, 7889391329771453832ull}},
{{3555915670981281755ull, 947558749441127902ull, 7589540562816602610ull,
  4930869581107158645ull}},
{{13668266625581378002ull, 10407820473656185685ull,
  14098611721948141166ull, 6163586976383948306ull}},
{{3250275226694558791ull, 3786403555215456299ull,
  8399892615580400650ull, 7704483720479935383ull}},
{{18172323081179956908ull, 6978188240437048090ull,
  12167461912378832262ull, 4815302325299959614ull}},
{{13492031814620170327ull, 17946107337401085921ull,
  5985955353618764519ull, 6019127906624949518ull}},
{{3029981712993049197ull, 17820948153323969498ull,
  16705816228878231457ull, 7523909883281186897ull}},
{{6505424589048043652ull, 4220563568186399080ull,
  3523606115407812805ull, 4702443677050741811ull}},
{{8131780736310054565ull, 9887390478660386754ull,
  18239565699541929718ull, 5878054596313427263ull}},
{{941353883532792398ull, 3135866061470707635ull,
  18187771106000024244ull, 7347568245391784079ull}},
{{15011750409698154210ull, 3919832576838384543ull,
  18123027864072642401ull, 9184460306739730099ull}},
{{16299873033702428237ull, 13979110406592460099ull,
  9021049405831707548ull, 5740287691712331312ull}},
{{15763155273700647393ull, 17473888008240575124ull,
  11276311757289634435ull, 7175359614640414140ull}},
{{1257200018416257625ull, 17230673991873331002ull,
  14095389696612043044ull, 8969199518300517675ull}},
{{5397436029937548920ull, 1545799208066056068ull,
  6503775551168832951ull, 5605749698937823547ull}},
{{6746795037421936149ull, 15767307065364733797ull,
  3518033420533653284ull, 7007187123672279434ull}},
{{13045179815204808091ull, 1262389757996365630ull,
  13620913812521842414ull, 8758983904590349292ull}},
{{3541551366075617153ull, 14624051654029892231ull,
  17736443169680927316ull, 5474364940368968307ull}},
{{18261997262876685153ull, 18280064567537365288ull,
  17558867943673771241ull, 6842956175461210384ull}},
{{4380752504886304825ull, 9015022654139542899ull,
  3501840855882662436ull, 8553695219326512981ull}},
{{432127306340246564ull, 14857761195691990120ull,
  4494493544140357974ull, 5346059512079070613ull}},
{{540159132925308205ull, 9348829457760211842ull,
  10229802948602835372ull, 6682574390098838266ull}},
{{9898570953011411064ull, 11686036822200264802ull,
  3563881648898768407ull, 8353217987623547833ull}},
{{10798292864059519819ull, 14221302041516247357ull,
  13756641076630200014ull, 5220761242264717395ull}},
{{18109552098501787678ull, 8553255515040533388ull,
  12584115327360362114ull, 6525951552830896744ull}},
{{4190196049417682981ull, 1468197356945890928ull,
  15730144159200452643ull, 8157439441038620930ull}},
{{2618872530886051863ull, 17058524412587039494ull,
  14443026117927670805ull, 5098399650649138081ull}},
{{12496962700462340637ull, 7488097460451635655ull,
  4218724592127424795ull, 6372999563311422602ull}},
{{11009517357150537892ull, 4748435807137156665ull,
  14496777777014056802ull, 7966249454139278252ull}},
{{18410163394287555943ull, 7579458397888110819ull,
  18283858147488561309ull, 4978905908837048907ull}},
{{18401018224432057024ull, 14086009015787526428ull,
  18243136665933313732ull, 6223632386046311134ull}},
{{4554528706830519664ull, 17607511269734408036ull,
  13580548795561866357ull, 7779540482557888918ull}},
{{12069952478623850598ull, 13310537552797698974ull,
  3876156978798778569ull, 4862212801598680574ull}},
{{5864068561425037440ull, 2803113885714960006ull,
  14068568260353249020ull, 6077766001998350717ull}},
{{16553457738636072608ull, 3503892357143700007ull,
  3750652270159397563ull, 7597207502497938397ull}},
{{17263440114288627236ull, 18330833787710670168ull,
  4650000678063317428ull, 4748254689061211498ull}},
{{3132556069151232429ull, 4466798160928786095ull,
  15035872884433922594ull, 5935318361326514372ull}},
{{17750753141721204248ull, 14806869738015758426ull,
  348097031832851626ull, 7419147951658142966ull}},
{{15705906732003140559ull, 13865979604687236920ull,
  14052618700177695978ull, 4636967469786339353ull}},
{{1185639341294374083ull, 8109102469004270343ull,
  3730715319939956261ull, 5796209337232924192ull}},
{{15317107231900131315ull, 14748064104682725832ull,
  4663394149924945326ull, 7245261671541155240ull}},
{{699639966165612528ull, 9211708093998631483ull, 5829242687406181658ull,
  9056577089426444050ull}},
{{16578176043349365494ull, 10369003577176532580ull,
  8254962698056251440ull, 5660360680891527531ull}},
{{2275975980477155252ull, 12961254471470665726ull,
  5707017354142926396ull, 7075450851114409414ull}},
{{12068342012451219872ull, 16201568089338332157ull,
  16357143729533433803ull, 8844313563893011767ull}},
{{9848556766995706372ull, 7820137046622763646ull,
  17140743858599477983ull, 5527695977433132354ull}},
{{3087323921889857157ull, 5163485289851066654ull,
  12202557786394571671ull, 6909619971791415443ull}},
{{13082526939217097255ull, 1842670593886445413ull,
  10641511214565826685ull, 8637024964739269304ull}},
{{10482422346224379736ull, 3457512130392722335ull,
  6650944509103641678ull, 5398140602962043315ull}},
{{8491341914353086766ull, 13545262199845678727ull,
  3701994617952164193ull, 6747675753702554144ull}},
{{6002491374513970554ull, 3096519694524934697ull,
  4627493272440205242ull, 8434594692128192680ull}},
{{15280772155139701356ull, 6547010827505472089ull,
  2892183295275128276ull, 5271621682580120425ull}},
{{5265907138642462983ull, 8183763534381840112ull,
  8226915137521298249ull, 6589527103225150531ull}},
{{6582383923303078729ull, 14841390436404688044ull,
  5671957903474234907ull, 8236908879031438164ull}},
{{13337361988919200014ull, 6970026013539236075ull,
  12768345726526172625ull, 5148068049394648852ull}},
{{12060016467721612113ull, 13324218535351432998ull,
  15960432158157715781ull, 6435085061743311065ull}},
{{5851648547797239333ull, 2820215113907127536ull,
  6115482142414981015ull, 8043856327179138832ull}},
{{3657280342373274583ull, 8680163473833036566ull,
  3822176339009363134ull, 5027410204486961770ull}},
{{13794972464821369037ull, 1626832305436519899ull,
  14001092460616479726ull, 6284262755608702212ull}},
{{12632029562599323392ull, 11256912418650425682ull,
  17501365575770599657ull, 7855328444510877765ull}},
{{12506704495051965024ull, 118041234015434195ull,
  13244196494070318738ull, 4909580277819298603ull}},
{{11021694600387568376ull, 9370923579374068552ull,
  11943559599160510518ull, 6136975347274123254ull}},
{{13777118250484460470ull, 2490282437362809882ull,
  5706077462095862340ull, 7671219184092654068ull}},
{{13222384924980175698ull, 10779798560206531984ull,
  12789670450664689770ull, 4794511990057908792ull}},
{{16527981156225219623ull, 4251376163403389172ull,
  15987088063330862213ull, 5993139987572385990ull}},
{{2213232371571972912ull, 9925906222681624370ull,
  10760488042308801958ull, 7491424984465482488ull}},
{{5994956250659870974ull, 1592005370748627327ull,
  6725305026443001224ull, 4682140615290926555ull}},
{{2882009294897450814ull, 1990006713435784159ull,
  3794945264626363626ull, 5852675769113658194ull}},
{{17437569673903977229ull, 11710880428649506006ull,
  13967053617637730340ull, 7315844711392072742ull}},
{{12573590055525195728ull, 14638600535811882508ull,
  8235444985192387117ull, 9144805889240090928ull}},
{{17081865821558023138ull, 11454968344096120519ull,
  5147153115745241948ull, 5715503680775056830ull}},
{{16740646258520141019ull, 14318710430120150649ull,
  15657313431536328243ull, 7144379600968821037ull}},
{{7090749767868012561ull, 13286702019222800408ull,
  5736583734138246592ull, 8930474501211026297ull}},
{{4431718604917507851ull, 8304188762014250255ull,
  15114579879904873880ull, 5581546563256891435ull}},
{{927962237719496910ull, 10380235952517812819ull,
  14281538831453704446ull, 6976933204071114294ull}},
{{14995010852431534849ull, 3751922903792490215ull,
  8628551502462354750ull, 8721166505088892868ull}},
{{16289410810410791137ull, 16180009870152470096ull,
  14616216725893747526ull, 5450729065680558042ull}},
{{1915019439303937305ull, 11001640300835811813ull,
  9046898870512408600ull, 6813411332100697553ull}},
{{7005460317557309535ull, 13752050376044764766ull,
  15920309606567898654ull, 8516764165125871941ull}},
{{18213470753755482171ull, 3983345466600590074ull,
  12256036513318630611ull, 5322977603203669963ull}},
{{13543466405339576906ull, 367495814823349689ull,
  10708359623220900360ull, 6653722004004587454ull}},
{{3094274951392307421ull, 459369768529187112ull, 4162077492171349642ull,
  8317152505005734318ull}},
{{1933921844620192138ull, 4898792123758129849ull,
  16436356487889257238ull, 5198220315628583948ull}},
{{7029088324202628076ull, 15346862191552438119ull,
  2098701536152019931ull, 6497775394535729936ull}},
{{4174674386825897191ull, 14571891721013159745ull,
  2623376920190024914ull, 8122219243169662420ull}},
{{14138386537834655505ull, 13719118344060612744ull,
  10862982611973541379ull, 5076387026981039012ull}},
{{17672983172293319381ull, 12537211911648378026ull,
  13578728264966926724ull, 6345483783726298765ull}},
{{12867856928511873418ull, 15671514889560472533ull,
  3138352275926494693ull, 7931854729657873457ull}},
{{10348253589533614838ull, 12100539815188989285ull,
  13490685218522528943ull, 4957409206036170910ull}},
{{17547003005344406452ull, 10513988750558848702ull,
  7639984486298385371ull, 6196761507545213638ull}},
{{12710381719825732257ull, 8530799919771172974ull,
  326608571018205906ull, 7745951884431517048ull}},
{{3332302556463694757ull, 9943435968284371013ull, 204130356886378691ull,
  4841219927769698155ull}},
{{8777064214007006350ull, 7817608941928075862ull,
  14090221001390137076ull, 6051524909712122693ull}},
{{1747958230653982129ull, 9772011177410094828ull,
  3777718196455507633ull, 7564406137140153367ull}},
{{10315845931013514639ull, 17636722031949779027ull,
  9278602900425774126ull, 4727753835712595854ull}},
{{8283121395339505394ull, 12822530503082447976ull,
  2374881588677441850ull, 5909692294640744818ull}},
{{10353901744174381743ull, 6804791091998284162ull,
  12191974022701578121ull, 7387115368300931022ull}},
{{11082874608536376494ull, 15782209478567397361ull,
  3008297745761098421ull, 4616947105188081889ull}},
{{18535205388306905ull, 5892703792927082990ull, 8372058200628760931ull,
  5771183881485102361ull}},
{{9246541043590159439ull, 2754193722731465833ull,
  15076758769213339068ull, 7213979851856377951ull}},
{{16169862322915087202ull, 3442742153414332291ull,
  14234262443089285931ull, 9017474814820472439ull}},
{{7800320942608235550ull, 18292614910379815346ull,
  15813943054571885562ull, 5635921759262795274ull}},
{{527029141405518629ull, 13642396601119993375ull,
  10544056781360081145ull, 7044902199078494093ull}},
{{14493844482039061998ull, 3217937696117828006ull,
  17791756995127489336ull, 8806127748848117616ull}},
{{4446966782847025845ull, 2011211060073642504ull,
  11119848121954680835ull, 5503829843030073510ull}},
{{5558708478558782306ull, 16349071880374216842ull,
  4676438115588575235ull, 6879787303787591888ull}},
{{16171757635053253691ull, 15824653832040383148ull,
  5845547644485719044ull, 8599734129734489860ull}},
{{883976485053507749ull, 667036608170463660ull, 12876839314658350211ull,
  5374833831084056162ull}},
{{1104970606316884686ull, 14668853815495243287ull,
  6872677106468161955ull, 6718542288855070203ull}},
{{15216271313178269569ull, 13724381250941666204ull,
  3979160364657814540ull, 8398177861068837754ull}},
{{286797533881642673ull, 17801110318693317186ull,
  7098661246338521991ull, 5248861163168023596ull}},
{{9581868954206829149ull, 17639701879939258578ull,
  8873326557923152489ull, 6561076453960029495ull}},
{{2753964155903760628ull, 8214569294641909511ull,
  6479972178976552708ull, 8201345567450036869ull}},
{{8638756625080932249ull, 14357477846005969252ull,
  6355825621074039394ull, 5125840979656273043ull}},
{{10798445781351165311ull, 8723475270652685757ull,
  3333096007915161339ull, 6407301224570341304ull}},
{{18109743245116344542ull, 6292658069888469292ull,
  4166370009893951674ull, 8009126530712926630ull}},
{{2095217491342939531ull, 8544597312107681212ull,
  16439039311465883508ull, 5005704081695579143ull}},
{{2619021864178674414ull, 10680746640134601515ull,
  15937113120904966481ull, 6257130102119473929ull}},
{{17108835385505506729ull, 17962619318595639797ull,
  6086333345849044389ull, 7821412627649342412ull}},
{{12998865125154635658ull, 13532480083335968825ull,
  13027330378010428551ull, 4888382892280839007ull}},
{{2413523351161130860ull, 12303914085742573128ull,
  11672476954085647785ull, 6110478615351048759ull}},
{{3016904188951413575ull, 1544834551896052698ull,
  9978910174179671828ull, 7638098269188810949ull}},
{{6497251136522021389ull, 10188893631789808744ull,
  8542661868075988844ull, 4773811418243006843ull}},
{{8121563920652526736ull, 12736117039737260930ull,
  6066641316667598151ull, 5967264272803758554ull}},
{{928582863960882612ull, 11308460281244188259ull,
  16806673682689273497ull, 7459080341004698192ull}},
{{16721265354471409296ull, 150258648136535805ull,
  10504171051680795936ull, 4661925213127936370ull}},
{{7066523637807097908ull, 187823310170669757ull, 3906841777746219112ull,
  5827406516409920463ull}},
{{13444840565686260289ull, 234779137713337196ull, 271866203755385986ull,
  7284258145512400579ull}},
{{16806050707107825362ull, 9516845958996447303ull,
  14174890809976396194ull, 9105322681890500723ull}},
{{17421310719583472707ull, 10559714742800167468ull,
  6553463747021553669ull, 5690826676181562952ull}},
{{3329894325769789268ull, 17811329446927597240ull,
  8191829683776942086ull, 7113533345226953690ull}},
{{4162367907212236585ull, 13040789771804720742ull,
  1016415067866401800ull, 8891916681533692113ull}},
{{16436537997289811578ull, 8150493607377950463ull,
  12164474463484970885ull, 5557447925958557570ull}},
{{15933986478184876568ull, 14799803027649825983ull,
  5982221042501437798ull, 6946809907448196963ull}},
{{15305797079303707806ull, 9276381747707506671ull,
  2866090284699409344ull, 8683512384310246204ull}},
{{16483652202205899235ull, 5797738592317191669ull,
  11014678464791906648ull, 5427195240193903877ull}},
{{6769507197475210331ull, 7247173240396489587ull,
  18380034099417271214ull, 6783994050242379846ull}},
{{3850197978416625010ull, 18282338587350387792ull,
  13751670587416813209ull, 8479992562802974808ull}},
{{2406373736510390632ull, 4508932589452910514ull,
  8594794117135508256ull, 5299995351751859255ull}},
{{12231339207492764097ull, 5636165736816138142ull,
  6131806627991997416ull, 6624994189689824069ull}},
{{6065801972511179314ull, 7045207171020172678ull,
  12276444303417384674ull, 8281242737112280086ull}},
{{17626184288101650783ull, 9014940500314995827ull,
  3061091671208477517ull, 5175776710695175054ull}},
{{17421044341699675575ull, 15880361643821132688ull,
  13049736625865372704ull, 6469720888368968817ull}},
{{3329561353415042852ull, 1403707981066864245ull,
  2477112727049552169ull, 8087151110461211022ull}},
{{4386818855098095735ull, 12406532534235259913ull,
  15383253509688133817ull, 5054469444038256888ull}},
{{10095209587300007573ull, 1673107612511911179ull,
  782322813400615656ull, 6318086805047821111ull}},
{{8007325965697621562ull, 2091384515639888974ull,
  14812961572032933282ull, 7897608506309776388ull}},
{{392892710133625572ull, 5918801340702318513ull, 34728945665807493ull,
  4936005316443610243ull}},
{{5102801906094419869ull, 12010187694305286045ull,
  13878469237364423078ull, 6170006645554512803ull}},
{{10990188401045412740ull, 5789362581026831748ull,
  12736400528278140944ull, 7712508306943141004ull}},
{{16092239787508158771ull, 3618351613141769842ull,
  17183622367028613898ull, 4820317691839463127ull}},
{{10891927697530422655ull, 13746311553281988111ull,
  16867841940358379468ull, 6025397114799328909ull}},
{{9003223603485640415ull, 17182889441602485139ull,
  7249744370165810623ull, 7531746393499161137ull}},
{{3321171742964831308ull, 17656834928642635068ull,
  16060305277422101399ull, 4707341495936975710ull}},
{{4151464678706039134ull, 17459357642375905931ull,
  10852009559922850941ull, 5884176869921219638ull}},
{{577644829955161014ull, 7989138997687718702ull, 4341639913048787869ull,
  7355221087401524548ull}},
{{9945428074298727075ull, 14598109765537036281ull,
  5427049891310984836ull, 9194026359251905685ull}},
{{17745107592505174182ull, 18347190640315423483ull,
  5697749191283059474ull, 5746266474532441053ull}},
{{17569698472204079824ull, 13710616263539503546ull,
  11733872507531212247ull, 7182833093165551316ull}},
{{12738751053400323971ull, 12526584310996991529ull,
  14667340634414015309ull, 8978541366456939145ull}},
{{1044190380734120626ull, 10134958203586813658ull,
  2249558868867677712ull, 5611588354035586966ull}},
{{10528610012772426591ull, 12668697754483517072ull,
  12035320622939372948ull, 7014485442544483707ull}},
{{13160762515965533238ull, 15835872193104396340ull,
  10432464760246828281ull, 8768106803180604634ull}},
{{17448848609333234082ull, 2979891093049165856ull,
  11131976493581655580ull, 5480066751987877896ull}},
{{3364316687956990987ull, 3724863866311457321ull,
  13914970616977069475ull, 6850083439984847370ull}},
{{8817081878373626637ull, 44393814461933747ull, 8170341234366561036ull,
  8562604299981059213ull}},
{{3204833164769822696ull, 9251118170893484400ull,
  7412306280692794599ull, 5351627687488162008ull}},
{{4006041455962278370ull, 6952211695189467596ull,
  9265382850865993249ull, 6689534609360202510ull}},
{{5007551819952847963ull, 13301950637414222399ull,
  2358356526727715753ull, 8361918261700253138ull}},
{{10047248915111611833ull, 1396190120742807143ull,
  6085658847632210250ull, 5226198913562658211ull}},
{{7947375125462126887ull, 10968609687783284737ull,
  2995387541112874908ull, 6532748641953322764ull}},
{{14545904925255046513ull, 13710762109729105921ull,
  3744234426391093635ull, 8165935802441653455ull}},
{{2173661550643322215ull, 6263383309366997249ull,
  9257675544135515378ull, 5103709876526033409ull}},
{{7328762956731540672ull, 17052601173563522369ull,
  16183780448596782126ull, 6379637345657541761ull}},
{{13772639714341813744ull, 12092379430099627153ull,
  6394667505463813946ull, 7974546682071927202ull}},
{{1690370793822551734ull, 12169423162239654875ull,
  8608353209342271620ull, 4984091676294954501ull}},
{{15948021547560353380ull, 15211778952799568593ull,
  15372127530105227429ull, 6230114595368693126ull}},
{{6099968879168278012ull, 5179665635717297030ull,
  9991787375776758479ull, 7787643244210866408ull}},
{{17647538604762337470ull, 10154820049964392499ull,
  6244867109860474049ull, 4867277027631791505ull}},
{{17447737237525533933ull, 17305211080882878528ull,
  12417769905752980465ull, 6084096284539739381ull}},
{{3362927473197365801ull, 7796455795821434449ull,
  1687154326909061870ull, 7605120355674674227ull}},
{{13631044716816823386ull, 261098853961008626ull,
  17195372518814021333ull, 4753200222296671391ull}},
{{7815433859166253424ull, 4938059585878648687ull,
  16882529630090138762ull, 5941500277870839239ull}},
{{5157606305530428876ull, 15395946519203086667ull,
  16491476019185285548ull, 7426875347338549049ull}},
{{917660931742824095ull, 399094537647153359ull, 3389643484349721612ull,
  4641797092086593156ull}},
{{14982134219960693831ull, 498868172058941698ull,
  4237054355437152015ull, 5802246365108241445ull}},
{{9504295738096091481ull, 14458643270355840835ull,
  9908003962723827922ull, 7252807956385301806ull}},
{{7268683654192726447ull, 8849932051090025236ull,
  3161632916550009095ull, 9066009945481627258ull}},
{{13766299320725229838ull, 12448736559572347628ull,
  6587706591271143588ull, 5666256215926017036ull}},
{{17207874150906537297ull, 15560920699465434535ull,
  8234633239088929485ull, 7082820269907521295ull}},
{{16898156670205783717ull, 5616092819049629457ull,
  5681605530433773953ull, 8853525337384401619ull}},
{{3643818891237532967ull, 15039273057974488171ull,
  1245160447307414768ull, 5533453335865251012ull}},
{{18389831669329079921ull, 352347248758558597ull,
  1556450559134268461ull, 6916816669831563765ull}},
{{9152231531379186189ull, 5052120079375586151ull,
  6557249217345223480ull, 8646020837289454706ull}},
{{12637673734753073224ull, 3157575049609741344ull,
  8709966779268152579ull, 5403763023305909191ull}},
{{15797092168441341530ull, 17782026867294340392ull,
  6275772455657802819ull, 6754703779132386489ull}},
{{1299621136842125297ull, 17615847565690537587ull,
  12456401587999641428ull, 8443379723915483111ull}},
{{16953164275022185975ull, 1786532691701810183ull,
  14702780020140857749ull, 5277112327447176944ull}},
{{16579769325350344564ull, 6844851883054650633ull,
  18378475025176072186ull, 6596390409308971180ull}},
{{6889653601405766993ull, 17779436890673089100ull,
  4526349707760538616ull, 8245488011636213976ull}},
{{13529405537733380179ull, 11112148056670680687ull,
  2828968567350336635ull, 5153430007272633735ull}},
{{12300070903739337319ull, 9278499052410962955ull,
  17371268764470084506ull, 6441787509090792168ull}},
{{10763402611246783745ull, 2374751778658927886ull,
  3267341881878054017ull, 8052234386363490211ull}},
{{2115440613601851937ull, 13013434907730299689ull,
  18182989740669641424ull, 5032646491477181381ull}},
{{7255986785429702825ull, 16266793634662874611ull,
  8893679120554888068ull, 6290808114346476727ull}},
{{4458297463359740627ull, 1886747969619041648ull,
  6505412882266222182ull, 7863510142933095909ull}},
{{2786435914599837892ull, 15014275536294064742ull,
  6371726060630082815ull, 4914693839333184943ull}},
{{12706416930104573173ull, 14156158401940193023ull,
  3352971557360215615ull, 6143367299166481179ull}},
{{11271335144203328562ull, 13083511983997853375ull,
  18026272501982433231ull, 7679209123958101473ull}},
{{13962113492768162208ull, 15094724017639740215ull,
  4348891286097938913ull, 4799505702473813421ull}},
{{12840955847532814855ull, 5033346966767511557ull,
  10047800126049811546ull, 5999382128092266776ull}},
{{2216136754133854857ull, 15515055745314165255ull,
  12559750157562264432ull, 7499227660115333470ull}},
{{8302614498974741142ull, 9696909840821353284ull,
  3238157830049027366ull, 4687017287572083419ull}},
{{10378268123718426427ull, 2897765264171915797ull,
  17882755342843447920ull, 5858771609465104273ull}},
{{17584521173075420938ull, 3622206580214894746ull,
  8518386123272146188ull, 7323464511831380342ull}},
{{12757279429489500364ull, 4527758225268618433ull,
  1424610617235406927ull, 9154330639789225428ull}},
{{1055770615789855872ull, 9747377918433968377ull,
  10113753672626905137ull, 5721456649868265892ull}},
{{5931399288164707744ull, 16795908416469848375ull,
  12642192090783631421ull, 7151820812335332365ull}},
{{2802563091778496775ull, 7159827465305146757ull,
  1967682058197375565ull, 8939776015419165457ull}},
{{4057444941575254437ull, 6780735175029410675ull,
  12759016332441829488ull, 5587360009636978410ull}},
{{460120158541680142ull, 8475918968786763344ull, 6725398378697511052ull,
  6984200012046223013ull}},
{{575150198177100177ull, 10594898710983454180ull,
  13018433991799276719ull, 8730250015057778766ull}},
{{9582840910715463419ull, 13539340722005740718ull,
  3524835226447160045ull, 5456406259411111729ull}},
{{2755179101539553466ull, 3089117847225012186ull,
  9017730051486337961ull, 6820507824263889661ull}},
{{12667345913779217640ull, 8473083327458653136ull,
  15883848582785310355ull, 8525634780329862076ull}},
{{7917091196112011025ull, 2989834070447964258ull, 704033327386043164ull,
  5328521737706163798ull}},
{{672991958285237973ull, 3737292588059955323ull,
  10103413696087329763ull, 6660652172132704747ull}},
{{14676298003138711178ull, 59929716647556249ull, 8017581101681774300ull,
  8325815215165880934ull}},
{{2255157224320612631ull, 9260828109759498464ull, 399302170123721033ull,
  5203634509478675584ull}},
{{2818946530400765788ull, 16187721155626760984ull,
  499127712654651291ull, 6504543136848344480ull}},
{{3523683163000957235ull, 15622965426106063326ull,
  623909640818314114ull, 8130678921060430600ull}},
{{16037360032157761984ull, 14376039409743677482ull,
  389943525511446321ull, 5081674325662769125ull}},
{{10823328003342426672ull, 4134991206897433141ull,
  5099115425316695806ull, 6352092907078461406ull}},
{{18140846022605421244ull, 14392111045476567234ull,
  15597266318500645565ull, 7940116133848076757ull}},
{{15949714782555776182ull, 11300912412636548473ull,
  12054134458276597430ull, 4962572583655047973ull}},
{{6102085422912556515ull, 4902768478940909784ull,
  1232610017563583076ull, 6203215729568809967ull}},
{{7627606778640695644ull, 6128460598676137230ull,
  15375820577236642557ull, 7754019661961012458ull}},
{{155568218223046873ull, 6136130883386279721ull,
  14221573879200289502ull, 4846262288725632786ull}},
{{4806146291206196496ull, 16893535641087625459ull,
  8553595312145586069ull, 6057827860907040983ull}},
{{1395996845580357715ull, 7281861496077368112ull,
  6080308121754594683ull, 7572284826133801229ull}},
{{872498028487723572ull, 2245320425834661118ull, 6106035585310315629ull,
  4732678016333625768ull}},
{{10313994572464430273ull, 7418336550720714301ull,
  7632544481637894536ull, 5915847520417032210ull}},
{{17504179234007925746ull, 9272920688400892876ull,
  317308565192592362ull, 7394809400521290263ull}},
{{1716739984400177783ull, 10407261448677945952ull,
  7115846880886452082ull, 4621755875325806414ull}},
{{2145924980500222229ull, 3785704773992656632ull,
  18118180637962840911ull, 5777194844157258017ull}},
{{2682406225625277786ull, 120444949063432886ull, 8812667742171387427ull,
  7221493555196572522ull}},
{{12576379818886373040ull, 13985614241611454819ull,
  1792462640859458475ull, 9026866943995715653ull}},
{{5554394377590289198ull, 6435165891793465310ull,
  3426132159750855499ull, 5641791839997322283ull}},
{{16166365008842637306ull, 3432271346314443733ull,
  18117723254970733086ull, 7052239799996652853ull}},
{{6372898205771132920ull, 13513711219747830475ull,
  8812096013431252645ull, 8815299749995816067ull}},
{{1677218369393264123ull, 10751912521556087999ull,
  3201716999180838951ull, 5509562343747385042ull}},
{{15931581017023743866ull, 8828204633517722094ull,
  13225518285830824497ull, 6886952929684231302ull}},
{{10691104234424904024ull, 15646941810324540522ull,
  7308525820433754813ull, 8608691162105289128ull}},
{{11293626164942952919ull, 12085181640666531778ull,
  4567828637771096758ull, 5380431976315805705ull}},
{{4893660669323915341ull, 5883105013978388915ull,
  10321471815641258852ull, 6725539970394757131ull}},
{{1505389818227506272ull, 7353881267472986144ull,
  8290153751124185661ull, 8406924962993446414ull}},
{{940868636392191420ull, 6902018801384310292ull, 569660076025228134ull,
  5254328101870904009ull}},
{{1176085795490239275ull, 17850895538585163673ull,
  5323761113458923071ull, 6567910127338630011ull}},
{{6081793262790186998ull, 17701933404804066687ull,
  2043015373396265935ull, 8209887659173287514ull}},
{{10718649816884948730ull, 17981237405643623535ull,
  5888570626800054113ull, 5131179786983304696ull}},
{{8786626252678798008ull, 8641488701772365707ull,
  7360713283500067642ull, 6413974733729130870ull}},
{{6371596797421109606ull, 1578488840360681326ull,
  18424263641229860361ull, 8017468417161413587ull}},
{{17817306053670357216ull, 12515770571293895588ull,
  9209321766554968773ull, 5010917760725883492ull}},
{{3824888493378394904ull, 1809655158835205774ull,
  11511652208193710967ull, 6263647200907354365ull}},
{{14004482653577769438ull, 16097127003826170929ull,
  554507204959974996ull, 7829559001134192957ull}},
{{1835272630845024043ull, 837332340536581023ull, 2652410012313678325ull,
  4893474375708870598ull}},
{{16129148843838443765ull, 5658351444098114182ull,
  12538884552246873714ull, 6116842969636088247ull}},
{{10938064017943278899ull, 16296311341977418536ull,
  11061919671881204238ull, 7646053712045110309ull}},
{{6836290011214549312ull, 5573508570308498681ull,
  9219542804139446601ull, 4778783570028193943ull}},
{{13157048532445574544ull, 11578571731313011255ull,
  6912742486746920347ull, 5973479462535242429ull}},
{{11834624647129580276ull, 9861528645713876165ull,
  13252614126861038338ull, 7466849328169053036ull}},
{{9702483413669681624ull, 10775141421998560507ull,
  17506255866142924769ull, 4666780830105658147ull}},
{{7516418248659714126ull, 18080612795925588538ull,
  17271133814251268057ull, 5833476037632072684ull}},
{{172150773969866850ull, 8765707939624821961ull, 3142173194104533456ull,
  7291845047040090856ull}},
{{4826874485889721466ull, 10957134924531027451ull,
  3927716492630666820ull, 9114806308800113570ull}},
{{710953544467381965ull, 16071581364686667965ull,
  7066508826321554666ull, 5696753943000070981ull}},
{{5500377949011615360ull, 10866104669003559148ull,
  13444822051329331237ull, 7120942428750088726ull}},
{{6875472436264519199ull, 18194316854681836839ull,
  7582655527306888238ull, 8901178035937610908ull}},
{{11214699300306406356ull, 6759762015748760120ull,
  13962531741421580957ull, 5563236272461006817ull}},
{{14018374125383007945ull, 13061388538113338054ull,
  3618106621494812484ull, 6954045340576258522ull}},
{{8299595619873984123ull, 16326735672641672568ull,
  13746005313723291413ull, 8692556675720323152ull}},
{{5187247262421240077ull, 12510052804614739307ull,
  8591253321077057133ull, 5432847922325201970ull}},
{{1872373059599162192ull, 1802507950486260422ull,
  1515694614491545609ull, 6791059902906502463ull}},
{{11563838361353728548ull, 6864820956535213431ull,
  15729676323396595723ull, 8488824878633128078ull}},
{{14144928003487162198ull, 1984670088620814442ull,
  5219361683695484423ull, 5305515549145705049ull}},
{{8457787967504176940ull, 16315895666058181765ull,
  11135888123046743432ull, 6631894436432131311ull}},
{{15183920977807609079ull, 1948125508863175590ull,
  9308174135381041387ull, 8289868045540164139ull}},
{{4878264592702367770ull, 17358479507535342408ull,
  3511765825399456914ull, 5181167528462602587ull}},
{{6097830740877959713ull, 12474727347564402202ull,
  18224765337031484855ull, 6476459410578253233ull}},
{{16845660462952225449ull, 10981723166028114848ull,
  8945898616007192357ull, 8095574263222816542ull}},
{{10528537789345140906ull, 9169419987981265732ull,
  979500616577107319ull, 5059733914514260339ull}},
{{13160672236681426132ull, 6850088966549194261ull,
  15059433826003547861ull, 6324667393142825423ull}},
{{2615782240569618953ull, 13174297226613880731ull,
  14212606264077046922ull, 7905834241428531779ull}},
{{17775764964851869510ull, 12845621785061063360ull,
  6577035905834460374ull, 4941146400892832362ull}},
{{3772962132355285271ull, 6833655194471553393ull,
  17444666919147851276ull, 6176433001116040452ull}},
{{9327888683871494493ull, 8542068993089441741ull,
  3359089575225262479ull, 7720541251395050566ull}},
{{8135773436633378010ull, 12256322148321982944ull,
  15934489039797952761ull, 4825338282121906603ull}},
{{10169716795791722513ull, 1485344630120314968ull,
  15306425281320053048ull, 6031672852652383254ull}},
{{12712145994739653141ull, 1856680787650393710ull,
  9909659564795290502ull, 7539591065815479068ull}},
{{3333405228284895309ull, 14995483547563659781ull,
  15416909264851832371ull, 4712244416134674417ull}},
{{8778442553783507040ull, 14132668416027186822ull,
  5436078525782626752ull, 5890305520168343022ull}},
{{1749681155374607992ull, 17665835520033983528ull,
  16018470194083059248ull, 7362881900210428777ull}},
{{2187101444218259990ull, 3635550326332927794ull,
  6188029687321660349ull, 9203602375263035972ull}},
{{5978624421063800398ull, 4578061963171773823ull,
  13090890591430813526ull, 5752251484539397482ull}},
{{2861594507902362593ull, 14945949490819493087ull,
  7140241202433741099ull, 7190314355674246853ull}},
{{17412051190160116954ull, 14070750845096978454ull,
  13536987521469564278ull, 8987892944592808566ull}},
{{6270845975422685192ull, 4182533259758223630ull,
  3848931182491089770ull, 5617433090370505354ull}},
{{17061929506133132298ull, 14451538611552555345ull,
  14034536014968638020ull, 7021791362963131692ull}},
{{7492353827384251661ull, 18064423264440694182ull,
  17543170018710797525ull, 8777239203703914615ull}},
{{71035123687769384ull, 13596107549489127816ull,
  17882010289335330309ull, 5485774502314946634ull}},
{{88793904609711730ull, 3160076381579246058ull, 13129140824814387079ull,
  6857218127893683293ull}},
{{9334364417616915470ull, 17785153532256221284ull,
  2576367975735820136ull, 8571522659867104117ull}},
{{15057349797865347977ull, 11115720957660138302ull,
  3916072994048581537ull, 5357201662416940073ull}},
{{9598315210476909163ull, 59593141793009166ull, 9506777260988114826ull,
  6696502078021175091ull}},
{{2774521976241360646ull, 9297863464096037266ull,
  7271785557807755628ull, 8370627597526468864ull}},
{{6345762253578238308ull, 15034536701914799099ull,
  4544865973629847267ull, 5231642248454043040ull}},
{{3320516798545409981ull, 14181484858966110970ull,
  5681082467037309084ull, 6539552810567553800ull}},
{{13374018035036538284ull, 17726856073707638712ull,
  7101353083796636355ull, 8174441013209442250ull}},
{{8358761271897836428ull, 8773442036853580243ull,
  9050031695800285626ull, 5109025633255901406ull}},
{{5836765571444907630ull, 1743430509212199496ull,
  2089167582895581225ull, 6386282041569876758ull}},
{{7295956964306134538ull, 6790974154942637274ull,
  11834831515474252339ull, 7982852551962345947ull}},
{{9171659121118721990ull, 1938515837625454344ull,
  5090926687957713760ull, 4989282844976466217ull}},
{{11464573901398402488ull, 2423144797031817930ull,
  10975344378374530104ull, 6236603556220582771ull}},
{{5107345339893227302ull, 3028930996289772413ull,
  9107494454540774726ull, 7795754445275728464ull}},
{{5497933846646961016ull, 15728139927963271470ull,
  5692184034087984203ull, 4872346528297330290ull}},
{{16095789345163477078ull, 15048488891526701433ull,
  16338602079464756062ull, 6090433160371662862ull}},
{{6284678626172182635ull, 9587239077553600984ull,
  11199880562476169270ull, 7613041450464578578ull}},
{{3927924141357614147ull, 1380338405043612711ull,
  11611611369974993698ull, 4758150906540361611ull}},
{{298219158269629780ull, 10948795043159291697ull,
  9902828194041354218ull, 5947688633175452014ull}},
{{4984459966264425128ull, 4462621767094338813ull,
  3155163205696916965ull, 7434610791469315018ull}},
{{5421130488128959657ull, 5094981613647655710ull,
  6583663021987961007ull, 4646631744668321886ull}},
{{15999785147015975380ull, 1757040998632181733ull,
  17452950814339727067ull, 5808289680835402357ull}},
{{6164673378487805512ull, 16031359303572390879ull,
  7981130462642495121ull, 7260362101044252947ull}},
{{3094155704682368986ull, 6204141074183324887ull,
  5364727059875730998ull, 9075452626305316184ull}},
{{8851376343067562473ull, 17712646226646741766ull,
  3352954412422331873ull, 5672157891440822615ull}},
{{1840848391979677283ull, 8305749728026263496ull,
  18026251070810078554ull, 7090197364301028268ull}},
{{2301060489974596603ull, 1158815123178053562ull,
  4086069764803046577ull, 8862746705376285336ull}},
{{6049848824661510781ull, 12253474498054753236ull,
  2553793603001904110ull, 5539216690860178335ull}},
{{7562311030826888476ull, 6093471085713665737ull,
  17027300059034543850ull, 6924020863575222918ull}},
{{14064574806960998499ull, 16840210893996857979ull,
  12060753036938404004ull, 8655026079469028648ull}},
{{6484516245136930110ull, 1301759771893260429ull,
  7537970648086502503ull, 5409391299668142905ull}},
{{12717331324848550542ull, 15462257770148739248ull,
  14034149328535516032ull, 6761739124585178631ull}},
{{15896664156060688177ull, 881078138976372444ull,
  12931000642242007137ull, 8452173905731473289ull}},
{{712043060683154303ull, 12079888882928702538ull,
  1164346373760172604ull, 5282608691082170806ull}},
{{10113425862708718686ull, 15099861103660878172ull,
  10678805004054991563ull, 6603260863852713507ull}},
{{12641782328385898358ull, 14263140361148709811ull,
  8736820236641351550ull, 8254076079815891884ull}},
{{5595270946027492522ull, 4302776707290555728ull,
  14683884684755620527ull, 5158797549884932427ull}},
{{6994088682534365652ull, 766784865685806756ull,
  13743169837517137755ull, 6448496937356165534ull}},
{{8742610853167957065ull, 14793539137389422157ull,
  7955590260041646385ull, 8060621171695206918ull}},
{{7769974792443667118ull, 2328432933227306992ull, 360557894098641087ull,
  5037888232309504324ull}},
{{9712468490554583897ull, 16745599221816297452ull,
  450697367623301358ull, 6297360290386880405ull}},
{{12140585613193229871ull, 11708626990415596007ull,
  5175057727956514602ull, 7871700362983600506ull}},
{{14505395035886850526ull, 11929577887437135408ull,
  7846097098400209530ull, 4919812726864750316ull}},
{{18131743794858563157ull, 5688600322441643452ull,
  9807621373000261913ull, 6149765908580937895ull}},
{{4217935669863652330ull, 11722436421479442220ull,
  7647840697822939487ull, 7687207385726172369ull}},
{{11859581830519558515ull, 14244051791065733243ull,
  16309115482207806939ull, 4804504616078857730ull}},
{{10212791269722060239ull, 13193378720404778650ull,
  11163022315904982866ull, 6005630770098572163ull}},
{{3542617050297799491ull, 7268351363651197505ull,
  9342091876453840679ull, 7507038462623215204ull}},
{{13743350702504594442ull, 11460248629923080296ull,
  15062179459638426232ull, 4691899039139509502ull}},
{{17179188378130743052ull, 14325310787403850370ull,
  9604352287693256982ull, 5864873798924386878ull}},
{{12250613435808653007ull, 8683266447400037155ull,
  2782068322761795420ull, 7331092248655483598ull}},
{{10701580776333428355ull, 10854083059250046444ull,
  12700957440307020083ull, 9163865310819354497ull}},
{{15911860022063168530ull, 4477958902817585075ull,
  1020569372550805696ull, 5727415819262096561ull}},
{{15278139009151572758ull, 5597448628521981344ull,
  5887397734115895024ull, 7159269774077620701ull}},
{{650929687729914332ull, 6996810785652476681ull,
  11970933186072256684ull, 8949087217597025876ull}},
{{11936046100899666218ull, 13596378777887573733ull,
  16705205278149936235ull, 5593179510998141172ull}},
{{1084999570842419060ull, 12383787453932079263ull,
  2434762523977868678ull, 6991474388747676466ull}},
{{15191307518835187537ull, 6256362280560323270ull,
  12266825191827111656ull, 8739342985934595582ull}},
{{4882881180844604307ull, 3910226425350202044ull,
  3055079726464556881ull, 5462089366209122239ull}},
{{6103601476055755383ull, 9499469050115140459ull,
  17653907713362859813ull, 6827611707761402798ull}},
{{3017815826642306325ull, 16486022331071313478ull,
  12844012604848798958ull, 8534514634701753498ull}},
{{15721192946933605165ull, 5692077938492183019ull,
  12639193896457887253ull, 5334071646688595936ull}},
{{15039805165239618552ull, 11726783441542616678ull,
  15798992370572359066ull, 6667589558360744920ull}},
{{9576384419694747382ull, 5435107265073495040ull,
  1301996389505897217ull, 8334486947950931151ull}},
{{5985240262309217114ull, 14926157086739404160ull,
  7731276771082267616ull, 5209054342469331969ull}},
{{7481550327886521393ull, 210952284714703584ull,
  14275781982280222425ull, 6511317928086664961ull}},
{{9351937909858151741ull, 4875376374320767384ull,
  4009669422568114319ull, 8139147410108331202ull}},
{{5844961193661344838ull, 9964639261591561471ull,
  7117729407532459353ull, 5086967131317707001ull}},
{{2694515473649293144ull, 17067485095416839743ull,
  13508847777842962095ull, 6358708914147133751ull}},
{{17203202397343780141ull, 16722670350843661774ull,
  12274373703876314715ull, 7948386142683917189ull}},
{{6140315479912474684ull, 8145825960063594657ull,
  9977326574136390649ull, 4967741339177448243ull}},
{{12287080368317981259ull, 14793968468506881225ull,
  7859972199243100407ull, 6209676673971810304ull}},
{{1523792405115312862ull, 13880774567206213628ull,
  9824965249053875509ull, 7762095842464762880ull}},
{{10175742290051846347ull, 10981327113717577469ull,
  6140603280658672193ull, 4851309901540476800ull}},
{{17331363880992195838ull, 18338344910574359740ull,
  7675754100823340241ull, 6064137376925596000ull}},
{{3217460777530693181ull, 9087873082935785964ull,
  9594692626029175302ull, 7580171721156995000ull}},
{{11234285022811459046ull, 1068234658407478323ull,
  5996682891268234564ull, 4737607325723121875ull}},
{{9431170260086935904ull, 1335293323009347904ull,
  2884167595657905301ull, 5922009157153902344ull}},
{{11788962825108669880ull, 6280802672189072784ull,
  3605209494572381626ull, 7402511446442377930ull}},
{{7368101765692918675ull, 8537187688545558394ull,
  6864941952535126420ull, 4626569654026486206ull}},
{{18433499243970924152ull, 10671484610681947992ull,
  17804549477523683833ull, 5783212067533107757ull}},
{{4595129981254103573ull, 17951041781779822895ull,
  8420628791622441079ull, 7229015084416384697ull}},
{{1132226458140241563ull, 17827116208797390715ull,
  15137472007955439253ull, 9036268855520480871ull}},
{{16848542600833508641ull, 13447790639712063148ull,
  16378449032613231389ull, 5647668034700300544ull}},
{{2613934177332334185ull, 2974680244357915224ull,
  2026317217056987621ull, 7059585043375375681ull}},
{{3267417721665417731ull, 8330036323874781934ull,
  7144582539748622430ull, 8824481304219219601ull}},
{{15877194131323049794ull, 594586683994350804ull,
  15994579133411358779ull, 5515300815137012250ull}},
{{1399748590444260626ull, 14578291410275102218ull,
  10769851879909422665ull, 6894126018921265313ull}},
{{10973057774910101591ull, 4387806207561714060ull,
  18074000868314166236ull, 8617657523651581641ull}},
{{16081533146173589302ull, 11965750916580847095ull,
  4378721515055272041ull, 5386035952282238526ull}},
{{15490230414289598724ull, 1122130590443895157ull,
  14696773930673865860ull, 6732544940352798157ull}},
{{5527729962579834693ull, 1402663238054868947ull,
  4535909358060168613ull, 8415681175440997697ull}},
{{1148988217398702731ull, 3182507532997987044ull,
  14364158394856075143ull, 5259800734650623560ull}},
{{1436235271748378414ull, 17813192471529647517ull,
  17955197993570093928ull, 6574750918313279450ull}},
{{6406980108112860921ull, 3819746515702507780ull,
  13220625455107841603ull, 8218438647891599313ull}},
{{13227734604425313884ull, 81498563100373410ull, 1345361881801319146ull,
  5136524154932249571ull}},
{{7311296218676866547ull, 9325245240730242571ull,
  15516760407533812644ull, 6420655193665311963ull}},
{{4527434254918695279ull, 11656556550912803214ull,
  14784264490989877901ull, 8025818992081639954ull}},
{{16664704464606348262ull, 9591190853534195960ull,
  13851851325296061592ull, 5016136870051024971ull}},
{{2384136507048383711ull, 11988988566917744951ull,
  12703128138192689086ull, 6270171087563781214ull}},
{{16815228689092643351ull, 5762863671792405380ull,
  6655538135886085550ull, 7837713859454726518ull}},
{{1286145893828126286ull, 17436847850152417075ull,
  17994769390210967180ull, 4898571162159204073ull}},
{{15442740422567321570ull, 3349315738980969727ull,
  8658403682481545264ull, 6123213952699005092ull}},
{{14691739509781764058ull, 4186644673726212159ull,
  10823004603101931580ull, 7654017440873756365ull}},
{{16099866221254684393ull, 11840024957933658407ull,
  9070220886152401189ull, 4783760900546097728ull}},
{{15513146758140967587ull, 964973142134909297ull,
  11337776107690501487ull, 5979701125682622160ull}},
{{5556375392394045771ull, 15041274482950800334ull,
  14172220134613126858ull, 7474626407103277700ull}},
{{17307792675528442319ull, 14012482570271638112ull,
  18081009620987980094ull, 4671641504439548562ull}},
{{3187996770701001283ull, 8292231175984771833ull,
  13377889989380199310ull, 5839551880549435703ull}},
{{8596681981803639507ull, 1141916933126188983ull,
  12110676468297861234ull, 7299439850686794629ull}},
{{6134166458827161480ull, 10650768203262512037ull,
  1303287530090162830ull, 9124299813358493287ull}},
{{6139697045980669877ull, 2045044108611682119ull,
  7732083733947433625ull, 5702687383349058304ull}},
{{3062935289048449442ull, 7167991154191990553ull,
  9665104667434292031ull, 7128359229186322880ull}},
{{8440355129737949707ull, 4348302924312600287ull,
  12081380834292865039ull, 8910449036482903600ull}},
{{12192750983727300423ull, 9635218355336457035ull,
  7550863021433040649ull, 5569030647801814750ull}},
{{10629252711231737625ull, 16655708962597959198ull,
  215206739936525003ull, 6961288309752268438ull}},
{{4063193852184896223ull, 16207950184820061094ull,
  9492380461775432062ull, 8701610387190335547ull}},
{{16374554212897723851ull, 5518282847085150279ull,
  3626894779395951087ull, 5438506491993959717ull}},
{{15856506747694766910ull, 2286167540429049945ull,
  9145304492672326763ull, 6798133114992449646ull}},
{{5985575379336294926ull, 16692767480818476144ull,
  2208258578985632645ull, 8497666393740562058ull}},
{{3740984612085184329ull, 12738822684725241542ull,
  5991847630293408307ull, 5311041496087851286ull}},
{{13899602801961256219ull, 11311842337479164023ull,
  16713181574721536192ull, 6638801870109814107ull}},
{{12762817484024182369ull, 14139802921848955029ull,
  16279790949974532336ull, 8298502337637267634ull}},
{{10282603936728807933ull, 8837376826155596893ull,
  14786555362161470614ull, 5186563961023292271ull}},
{{17464940939338397820ull, 1823348995839720308ull,
  13871508184274450364ull, 6483204951279115339ull}},
{{3384432100463445659ull, 2279186244799650386ull,
  12727699211915675051ull, 8104006189098894174ull}},
{{6726956081217041441ull, 17565392467495639155ull,
  3343125989019909002ull, 5065003868186808859ull}},
{{3797009083093913897ull, 12733368547514773136ull,
  18013965541557049965ull, 6331254835233511073ull}},
{{4746261353867392371ull, 2081652629111302708ull,
  8682398871664148745ull, 7914068544041888842ull}},
{{12189785383021896040ull, 12830247939263033952ull,
  10038185313217480869ull, 4946292840026180526ull}},
{{15237231728777370050ull, 2202751868796628728ull,
  3324359604667075279ull, 6182866050032725658ull}},
{{599795587262160947ull, 16588497891277949623ull,
  13378821542688619906ull, 7728582562540907072ull}},
{{7292401269679932448ull, 14979497200476106418ull,
  8361763464180387441ull, 4830364101588066920ull}},
{{18338873623954691368ull, 4889313445312969310ull,
  10452204330225484302ull, 6037955126985083650ull}},
{{13700219993088588401ull, 15335013843495987446ull,
  3841883375927079569ull, 7547443908731354563ull}},
{{3950951477252979847ull, 2666854624543910298ull, 95334100740730779ull,
  4717152442957096602ull}},
{{14162061383421000617ull, 17168626335962051584ull,
  9342539662780689281ull, 5896440553696370752ull}},
{{17702576729276250771ull, 7625724864670400768ull,
  11678174578475861602ull, 7370550692120463440ull}},
{{3681476837885761847ull, 308784043983225153ull,
  14597718223094827003ull, 9213188365150579300ull}},
{{13830138069747070915ull, 16333891091985373384ull,
  18346945926289042684ull, 5758242728219112062ull}},
{{17287672587183838643ull, 1970619791272165114ull,
  13710310371006527548ull, 7197803410273890078ull}},
{{12386218697125022496ull, 2463274739090206393ull,
  7914515926903383627ull, 8997254262842362598ull}},
{{823857658062057204ull, 17680447776427236660ull, 334886435887226862ull,
  5623283914276476624ull}},
{{1029822072577571505ull, 12877187683679270017ull,
  418608044859033578ull, 7029104892845595780ull}},
{{5898963609149352285ull, 6873112567744311713ull, 523260056073791973ull,
  8786381116056994725ull}},
{{15216067301786814939ull, 6601538364053888772ull,
  2632880544259813935ull, 5491488197535621703ull}},
{{573340053523967057ull, 3640236936639973062ull,
  17126158735606931131ull, 6864360246919527128ull}},
{{9940047103759734629ull, 18385354226082130039ull,
  2960954345799112297ull, 8580450308649408911ull}},
{{13130058467490915999ull, 4573317363660249418ull,
  8768125493765527042ull, 5362781442905880569ull}},
{{7189201047508869191ull, 14940018741430087581ull,
  15571842885634296706ull, 6703476803632350711ull}},
{{13598187327813474393ull, 9451651389932833668ull,
  14853117588615482979ull, 8379346004540438389ull}},
{{17722239116738197304ull, 3601439109494327090ull,
  11589041502098370814ull, 5237091252837773993ull}},
{{12929426859067970822ull, 13725170923722684671ull,
  651243822340799805ull, 6546364066047217492ull}},
{{11550097555407575623ull, 3321405599371192127ull,
  814054777925999757ull, 8182955082559021865ull}},
{{14136339999770816620ull, 4381721508820689031ull,
  12037999282272219608ull, 5114346926599388665ull}},
{{13058738981286132871ull, 5477151886025861289ull,
  1212441047558110798ull, 6392933658249235832ull}},
{{2488365671325502377ull, 16069811894387102420ull,
  1515551309447638497ull, 7991167072811544790ull}},
{{10778600581433214794ull, 3126103406350857156ull,
  14782277623686937773ull, 4994479420507215493ull}},
{{13473250726791518492ull, 8519315276365959349ull,
  4642788974326508504ull, 6243099275634019367ull}},
{{3006505353207234403ull, 10649144095457449187ull,
  1191800199480747726ull, 7803874094542524209ull}},
{{18019966910250379166ull, 2044029041233517837ull,
  12274090170743937089ull, 4877421309089077630ull}},
{{8689900582530810246ull, 7166722319969285201ull,
  6119240676575145553ull, 6096776636361347038ull}},
{{15474061746590900711ull, 13570088918388994405ull,
  16872422882573707749ull, 7620970795451683797ull}},
{{11977131600833006896ull, 10787148583206815455ull,
  12851107310822261295ull, 4763106747157302373ull}},
{{10359728482613870716ull, 8872249710581131415ull,
  2228826083245662907ull, 5953883433946627967ull}},
{{8337974584839950491ull, 6478626119799026365ull,
  16621090659339242346ull, 7442354292433284958ull}},
{{7517077124738663009ull, 8660827343301779382ull,
  5776495643659638562ull, 4651471432770803099ull}},
{{172974369068552954ull, 1602662142272448420ull, 2608933536147160299ull,
  5814339290963503874ull}},
{{216217961335691192ull, 15838385733122724237ull,
  12484538957038726181ull, 7267924113704379842ull}},
{{4881958470097001894ull, 5962924111121241584ull,
  6382301659443631919ull, 9084905142130474803ull}},
{{3051224043810626184ull, 10644356597091857846ull,
  1683095527938575997ull, 5678065713831546752ull}},
{{13037402091618058538ull, 17917131764792210211ull,
  2103869409923219996ull, 7097582142289433440ull}},
{{11685066596095185268ull, 3949670632280711148ull,
  2629836762404024996ull, 8871977677861791800ull}},
{{16526538659414266601ull, 11691916182030220275ull,
  1643647976502515622ull, 5544986048663619875ull}},
{{16046487305840445347ull, 5391523190682999536ull,
  15889618025910308240ull, 6931232560829524843ull}},
{{1611365058591005067ull, 6739403988353749421ull,
  15250336513960497396ull, 8664040701036906054ull}},
{{3312946170833072119ull, 13435499529575869196ull,
  4919774302797922968ull, 5415025438148066284ull}},
{{4141182713541340149ull, 16794374411969836495ull,
  6149717878497403710ull, 6768781797685082855ull}},
{{564792373499287282ull, 11769595978107519811ull,
  3075461329694366734ull, 8460977247106353569ull}},
{{16493896297932912215ull, 2744311467889811977ull,
  13451378377127448969ull, 5288110779441470980ull}},
{{6782312317133976557ull, 8042075353289652876ull,
  16814222971409311211ull, 6610138474301838725ull}},
{{8477890396417470696ull, 5440908173184678191ull,
  7182720658979475302ull, 8262673092877298407ull}},
{{12216210525402001041ull, 17235625663522587581ull,
  11406729439503253919ull, 5164170683048311504ull}},
{{1435205101470337590ull, 16932846060975846573ull,
  14258411799379067399ull, 6455213353810389380ull}},
{{6405692395265309891ull, 16554371557792420312ull,
  17823014749223834249ull, 8069016692262986725ull}},
{{4003557747040818682ull, 3428953195979180839ull,
  13445227227478590358ull, 5043135432664366703ull}},
{{392761165373635448ull, 13509563531828751857ull,
  12194848015920850043ull, 6303919290830458379ull}},
{{5102637475144432214ull, 12275268396358551917ull,
  10631874001473674650ull, 7879899113538072974ull}},
{{5494991431178964086ull, 12283728766151482852ull,
  2033235232493658752ull, 4924936945961295609ull}},
{{6868739288973705107ull, 15354660957689353565ull,
  7153230059044461344ull, 6156171182451619511ull}},
{{13197610129644519288ull, 746582123402140340ull,
  4329851555378188777ull, 7695213978064524389ull}},
{{17471878367882600363ull, 11995828873194807472ull,
  5012000231325061937ull, 4809508736290327743ull}},
{{3393103886143698838ull, 1159728036211345629ull,
  1653314270728939518ull, 6011885920362909679ull}},
{{8853065876107011451ull, 10673032082118957844ull,
  15901700893693338109ull, 7514857400453637098ull}},
{{14756538209421657965ull, 8976488060538042604ull,
  14550249076985724222ull, 4696785875283523186ull}},
{{18445672761777072457ull, 1997238038817777447ull,
  8964439309377379470ull, 5870982344104403983ull}},
{{18445404933793952667ull, 11719919585376997617ull,
  6593863118294336433ull, 7338727930130504979ull}},
{{9221698111960277121ull, 814841426439083310ull, 3630642879440532638ull,
  9173409912663131224ull}},
{{1151875301547785297ull, 14344333946806590781ull,
  2269151799650332898ull, 5733381195414457015ull}},
{{6051530145362119525ull, 8707045396653462668ull,
  16671497804845079835ull, 7166726494268071268ull}},
{{7564412681702649406ull, 6272120727389440431ull,
  2392628182346798178ull, 8958408117835089086ull}},
{{11645286953705237735ull, 8531761473045788173ull,
  15330450669248912573ull, 5599005073646930678ull}},
{{721550636849383457ull, 15276387859734623121ull,
  9939691299706364908ull, 6998756342058663348ull}},
{{5513624314489117225ull, 648740750958727285ull,
  12424614124632956136ull, 8748445427573329185ull}},
{{5751858205769392218ull, 405462969349204553ull, 847854800254515729ull,
  5467778392233330741ull}},
{{11801508775639128176ull, 5118514730113893595ull,
  5671504518745532565ull, 6834722990291663426ull}},
{{10140199951121522316ull, 11009829431069754898ull,
  16312752685286691514ull, 8543403737864579282ull}},
{{10949310987878339351ull, 11492829412845984715ull,
  14807156446731570100ull, 5339627336165362051ull}},
{{9074952716420536285ull, 14366036766057480894ull,
  13897259539987074721ull, 6674534170206702564ull}},
{{2120318858670894548ull, 4122487902289687406ull,
  17371574424983843402ull, 8343167712758378205ull}},
{{15160257341951472805ull, 7188240957358442532ull,
  13163077024828596078ull, 5214479820473986378ull}},
{{503577603729789390ull, 18208673233552828974ull,
  7230474244180969289ull, 6518099775592482973ull}},
{{9852844041517012545ull, 8925783486658872505ull,
  13649778823653599516ull, 8147624719490603716ull}},
{{17687242572016602601ull, 14801986716016571123ull,
  17754483801638275505ull, 5092265449681627322ull}},
{{17497367196593365347ull, 4667425339738550192ull,
  12969732715193068574ull, 6365331812102034153ull}},
{{3424964922032155068ull, 15057653711527963549ull,
  2377107838709172005ull, 7956664765127542692ull}},
{{4446446085483790870ull, 11716876578918671170ull,
  10709064436048008311ull, 4972915478204714182ull}},
{{14781429643709514395ull, 10034409705220951058ull,
  4162958508205234581ull, 6216144347755892728ull}},
{{9253415017782117185ull, 17154698149953576727ull,
  5203698135256543226ull, 7770180434694865910ull}},
{{12700913413754905097ull, 15333372362148373358ull,
  17087369389817503228ull, 4856362771684291193ull}},
{{6652769730338855563ull, 719971378975915082ull, 7524153681989715324ull,
  6070453464605363992ull}},
{{17539334199778345262ull, 899964223719893852ull,
  9405192102487144155ull, 7588066830756704990ull}},
{{1738711838006689981ull, 16703378704320791322ull,
  1266559045627077192ull, 4742541769222940619ull}},
{{11396761834363138284ull, 2432479306691437536ull,
  15418256862316010203ull, 5928177211528675773ull}},
{{14245952292953922855ull, 16875657188646460632ull,
  5437763022612849041ull, 7410221514410844717ull}},
{{8903720183096201784ull, 3629756715262956039ull,
  5704444898346724603ull, 4631388446506777948ull}},
{{6517964210442864326ull, 18372253949360858761ull,
  7130556122933405753ull, 5789235558133472435ull}},
{{12759141281480968312ull, 9130259381418909739ull,
  4301509135239369288ull, 7236544447666840544ull}},
{{11337240583423822486ull, 11412824226773637174ull,
  5376886419049211610ull, 9045680559583550680ull}},
{{2474089346212501150ull, 11744701160160911138ull,
  3360554011905757256ull, 5653550349739719175ull}},
{{12315983719620402245ull, 14680876450201138922ull,
  18035750570164360282ull, 7066937937174648968ull}},
{{6171607612670726998ull, 9127723525896647845ull,
  4097944138995898737ull, 8833672421468311211ull}},
{{6163097767132898326ull, 17234042249753874663ull,
  255372077658742758ull, 5521045263417694507ull}},
{{3092186190488735004ull, 12319180775337567521ull,
  14154273152355592160ull, 6901306579272118133ull}},
{{8476918756538306658ull, 15398975969171959401ull,
  3857783385162326488ull, 8626633224090147667ull}},
{{16827289268904911422ull, 9624359980732474625ull,
  105271606512760103ull, 5391645765056342292ull}},
{{7199053530848975565ull, 7418763957488205378ull, 131589508140950129ull,
  6739557206320427865ull}},
{{18222188950415995264ull, 13885140965287644626ull,
  4776172903603575565ull, 8424446507900534831ull}},
{{16000554112437384944ull, 10984056112518471843ull,
  9902637092393316584ull, 5265279067437834269ull}},
{{15389006622119343276ull, 13730070140648089804ull,
  16989982383919033634ull, 6581598834297292836ull}},
{{789514203939627479ull, 7939215638955336448ull, 2790733906189240427ull,
  8226998542871616046ull}},
{{493446377462267175ull, 2656166765133391328ull,
  15579266746650438979ull, 5141874089294760028ull}},
{{616807971827833968ull, 17155266511698902872ull,
  1027339359603497107ull, 6427342611618450036ull}},
{{771009964784792460ull, 16832397121196240686ull,
  1284174199504371384ull, 8034178264523062545ull}},
{{14316939283272659000ull, 10520248200747650428ull,
  12331823920758701875ull, 5021361415326914090ull}},
{{17896174104090823750ull, 8538624232507175131ull,
  6191407864093601536ull, 6276701769158642613ull}},
{{17758531611686141783ull, 10673280290633968914ull,
  12350945848544389824ull, 7845877211448303266ull}},
{{15710768275731226518ull, 6670800181646230571ull,
  12331027173767631544ull, 4903673257155189541ull}},
{{15026774326236645244ull, 8338500227057788214ull,
  1578725911927375718ull, 6129591571443986927ull}},
{{9560095870941030747ull, 1199753246967459460ull,
  15808465445191383360ull, 7661989464304983658ull}},
{{15198431956192920025ull, 749845779354662162ull,
  14491976921672002504ull, 4788743415190614786ull}},
{{9774667908386374223ull, 937307224193327703ull, 8891599115235227322ull,
  5985929268988268483ull}},
{{7606648867055579875ull, 10395006067096435437ull,
  6502812875616646248ull, 7482411586235335604ull}},
{{7059998551123431374ull, 6496878791935272148ull,
  13287630084115179713ull, 4676507241397084752ull}},
{{8824998188904289217ull, 12732784508346478089ull,
  16609537605143974641ull, 5845634051746355940ull}},
{{15642933754557749425ull, 2080922580150933899ull,
  2315177932720416686ull, 7307042564682944926ull}},
{{14941981174769798878ull, 11824525262043443182ull,
  12117344452755296665ull, 9133803205853681157ull}},
{{4727052215803736395ull, 472799261136070133ull, 9879183292185754368ull,
  5708627003658550723ull}},
{{10520501288182058397ull, 590999076420087666ull,
  7737293096804805056ull, 7135783754573188404ull}},
{{3927254573372797188ull, 738748845525109583ull, 9671616371006006320ull,
  8919729693216485505ull}},
{{9372063135999080099ull, 461718028453193489ull,
  17573975277947223710ull, 5574831058260303440ull}},
{{16326764938426238028ull, 9800519572421267669ull,
  3520725023724478021ull, 6968538822825379301ull}},
{{6573398117750633822ull, 16862335483953972491ull,
  9012592298082985430ull, 8710673528531724126ull}},
{{1802530814380452187ull, 5927273659043844903ull,
  1021184167874477990ull, 5444170955332327579ull}},
{{16088221573257728946ull, 16632464110659581936ull,
  15111538265125261199ull, 6805213694165409473ull}},
{{1663532892862609566ull, 16178894119897089517ull,
  5054364776124412787ull, 8506517117706761842ull}},
{{3345551067252824931ull, 7805965815721986996ull,
  7770664003505145896ull, 5316573198566726151ull}},
{{4181938834066031164ull, 9757457269652483745ull,
  5101643985954044466ull, 6645716498208407689ull}},
{{9839109561009926858ull, 2973449550210828873ull,
  10988741000869943487ull, 8307145622760509611ull}},
{{17678658521699674047ull, 8775934996522849901ull,
  4562120116330020727ull, 5191966014225318507ull}},
{{8263265096842428846ull, 6358232727226174473ull,
  1090964126985138005ull, 6489957517781648134ull}},
{{14940767389480423962ull, 12559476927460105995ull,
  10587077195586198314ull, 8112446897227060167ull}},
{{7032136609211571024ull, 12461359098089954151ull,
  13534452274882455802ull, 5070279310766912604ull}},
{{4178484743087075876ull, 6353326835757666881ull,
  16918065343603069753ull, 6337849138458640755ull}},
{{9834791947286232749ull, 12553344563124471505ull,
  16535895661076449287ull, 7922311423073300944ull}},
{{17675960013122365228ull, 14763369379593876546ull,
  10334934788172780804ull, 4951444639420813090ull}},
{{12871577979548180727ull, 7467650782794067ull, 3695296448361200198ull,
  6189305799276016363ull}},
{{11477786456007838005ull, 9232706600333268392ull, 7434542024112343ull,
  7736632249095020454ull}},
{{7173616535004898753ull, 12687970652849374601ull,
  13839704644047233926ull, 4835395155684387783ull}},
{{13578706687183511346ull, 6636591279206942443ull,
  12687944786631654504ull, 6044243944605484729ull}},
{{12361697340552001278ull, 8295739099008678054ull,
  2024872928007404418ull, 7555304930756855912ull}},
{{3114374819417612895ull, 9796522955307811688ull,
  1265545580004627761ull, 4722065581723034945ull}},
{{3892968524272016118ull, 16857339712562152514ull,
  6193617993433172605ull, 5902581977153793681ull}},
{{14089582692194795956ull, 7236616585420526930ull,
  12353708510218853661ull, 7378227471442242101ull}},
{{8388606328388719137ull, 13657456750203046567ull,
  1607077582491403364ull, 9222784339302802627ull}},
{{12160407982884031317ull, 17759282505731679912ull,
  17145324553552984766ull, 5764240212064251641ull}},
{{15200509978605039146ull, 12975731095309824082ull,
  7596597636659067246ull, 7205300265080314552ull}},
{{9777265436401523124ull, 6996291832282504295ull,
  9495747045823834058ull, 9006625331350393190ull}},
{{13028319925392033809ull, 8984368413603953088ull,
  1323155885212508382ull, 5629140832093995744ull}},
{{16285399906740042261ull, 2007088480150165552ull,
  1653944856515635478ull, 7036426040117494680ull}},
{{1910005809715501210ull, 11732232637042482749ull,
  2067431070644544347ull, 8795532550146868350ull}},
{{3499596640285882208ull, 5026802388937857766ull,
  15127202474435003929ull, 5497207843841792718ull}},
{{13597867837212128568ull, 10895189004599710111ull,
  9685631056188979103ull, 6871509804802240898ull}},
{{12385648778087772806ull, 9007300237322249735ull,
  2883666783381448071ull, 8589387256002801123ull}},
{{14658559513945939860ull, 12547091675967487940ull,
  17943192804109262708ull, 5368367035001750701ull}},
{{18323199392432424825ull, 15683864594959359925ull,
  8593932949854414673ull, 6710458793752188377ull}},
{{9068941185258367319ull, 5769772688417036195ull,
  15354102205745406246ull, 8388073492190235471ull}},
{{3362245231572785623ull, 17441165985542811334ull,
  16513842906231960759ull, 5242545932618897169ull}},
{{13426178576320757836ull, 17189771463501126263ull,
  6807245577507787237ull, 6553182415773621462ull}},
{{12171037201973559391ull, 7652156274094244117ull,
  17732429008739509855ull, 8191478019717026827ull}},
{{9912741260447168572ull, 11700126698949984429ull,
  8776925121248499707ull, 5119673762323141767ull}},
{{17002612593986348618ull, 10013472355260092632ull,
  6359470383133236730ull, 6399592202903927209ull}},
{{2806521668773384157ull, 3293468407220339983ull,
  12561023997343933817ull, 7999490253629909011ull}},
{{8671605070624446954ull, 13587632800581182249ull,
  5544796989126264683ull, 4999681408518693132ull}},
{{15451192356707946597ull, 12372854982299089907ull,
  6930996236407830854ull, 6249601760648366415ull}},
{{14702304427457545342ull, 6242696691019086576ull,
  4052059277082400664ull, 7812002200810458019ull}},
{{9188940267160965839ull, 3901685431886929110ull, 226694038962806463ull,
  4882501375506536262ull}},
{{2262803297096431490ull, 265420771431273484ull, 9506739585558283887ull,
  6103126719383170327ull}},
{{2828504121370539363ull, 14166834019571255567ull,
  7271738463520466954ull, 7628908399228962909ull}},
{{8685344103497668958ull, 13465957280659422633ull,
  6850679548913985798ull, 4768067749518101818ull}},
{{15468366147799474101ull, 7609074563969502483ull,
  17786721472997258056ull, 5960084686897627272ull}},
{{14723771666321954722ull, 9511343204961878104ull,
  3786657767537020954ull, 7450105858622034091ull}},
{{9202357291451221702ull, 10556275521528561719ull, 60818095496944144ull,
  4656316161638771307ull}},
{{6891260595886639223ull, 13195344401910702149ull,
  13911080674653343892ull, 5820395202048464133ull}},
{{13225761763285686933ull, 16494180502388377686ull,
  3553792788034516153ull, 7275494002560580167ull}},
{{7308830167252332858ull, 6782667572703308396ull,
  18277299040325308904ull, 9094367503200725208ull}},
{{13791390891387483844ull, 4239167232939567747ull,
  11423311900203318065ull, 5683979689500453255ull}},
{{12627552595806966901ull, 9910645059601847588ull,
  9667453856826759677ull, 7104974611875566569ull}},
{{15784440744758708626ull, 16999992342929697389ull,
  16696003339460837500ull, 8881218264844458211ull}},
{{12171118474687886844ull, 1401623177476285060ull,
  8129159077949329486ull, 5550761415527786382ull}},
{{15213898093359858554ull, 10975401008700132133ull,
  938076810581886049ull, 6938451769409732978ull}},
{{5182314561417659481ull, 18330937279302553071ull,
  10395968050082133369ull, 8673064711762166222ull}},
{{10156475628527119032ull, 4539306771923013813ull,
  1885794012873945452ull, 5420665444851353889ull}},
{{17307280554086286694ull, 5674133464903767266ull,
  6968928534519819719ull, 6775831806064192361ull}},
{{12410728655753082559ull, 2480980812702321179ull,
  13322846686577162553ull, 8469789757580240451ull}},
{{5450862400631982647ull, 13079828054007420497ull,
  6020936169897032643ull, 5293618598487650282ull}},
{{11425264019217366213ull, 11738099049081887717ull,
  16749542249226066612ull, 6617023248109562852ull}},
{{446521968739544054ull, 14672623811352359647ull,
  2490183737823031649ull, 8271279060136953566ull}},
{{7196605258103296890ull, 2252860854454142923ull,
  15391422891421558493ull, 5169549412585595978ull}},
{{4384070554201733209ull, 7427762086495066558ull,
  10015906577422172308ull, 6461936765731994973ull}},
{{14703460229606942319ull, 9284702608118833197ull,
  17131569240205103289ull, 8077420957164993716ull}},
{{11495505652718032901ull, 17332154176142740508ull,
  1483858738273413747ull, 5048388098228121073ull}},
{{14369382065897541126ull, 17053506701751037731ull,
  6466509441269155088ull, 6310485122785151341ull}},
{{13350041563944538504ull, 2870139303479245548ull,
  12694822820013831765ull, 7888106403481439176ull}},
{{17567148014320112373ull, 4099680073888222419ull,
  7934264262508644853ull, 4930066502175899485ull}},
{{17347248999472752562ull, 9736286110787665928ull,
  14529516346563193970ull, 6162583127719874356ull}},
{{3237317175631389087ull, 2946985601629806603ull,
  18161895433203992463ull, 7703228909649842945ull}},
{{18164224299265475843ull, 8759395028659710982ull,
  4433655618111413433ull, 4814518068531151841ull}},
{{13481908337227068996ull, 15560929804252026632ull,
  10153755541066654695ull, 6018147585663939801ull}},
{{16852385421533836245ull, 14839476236887645386ull,
  17303880444760706273ull, 7522684482079924751ull}},
{{15144426906886035557ull, 2357143620413696510ull,
  17732454305616523277ull, 4701677801299952969ull}},
{{9707161596752768639ull, 7558115543944508542ull,
  8330509826738490384ull, 5877097251624941212ull}},
{{2910579959086184990ull, 9447644429930635678ull,
  10413137283423112980ull, 7346371564531176515ull}},
{{12861596985712507045ull, 11809555537413294597ull,
  8404735585851503321ull, 9182964455663970644ull}},
{{10344341125284010856ull, 463443183242227267ull,
  14476331778011965384ull, 5739352784789981652ull}},
{{8318740388177625665ull, 579303979052784084ull,
  18095414722514956730ull, 7174190980987477065ull}},
{{10398425485222032082ull, 9947502010670755913ull,
  8784210347861532200ull, 8967738726234346332ull}},
{{18028230974332239811ull, 6217188756669222445ull,
  14713503504268233433ull, 5604836703896466457ull}},
{{8700230662633136052ull, 12383171964263915961ull,
  4556821325053128079ull, 7006045879870583072ull}},
{{15486974346718807969ull, 10867278936902507047ull,
  5696026656316410099ull, 8757557349838228840ull}},
{{16596887994340336837ull, 4486206326350372952ull,
  3560016660197756312ull, 5473473343648893025ull}},
{{2299365919215869430ull, 5607757907937966191ull,
  9061706843674583294ull, 6841841679561116281ull}},
{{16709265454302000499ull, 16233069421777233546ull,
  15938819573020617021ull, 8552302099451395351ull}},
{{15054976927366138216ull, 12451511397824464918ull,
  16879291260778967494ull, 5345188812157122094ull}},
{{9595349122352896962ull, 6341017210425805340ull,
  11875742039118933560ull, 6681486015196402618ull}},
{{11994186402941121202ull, 7926271513032256675ull,
  5621305512043891142ull, 8351857518995503273ull}},
{{5190523492624506800ull, 342233677217772518ull,
  15042530991095901724ull, 5219910949372189545ull}},
{{15711526402635409307ull, 427792096522215647ull,
  4968105683587713443ull, 6524888686715236932ull}},
{{15027721984866873730ull, 14369798175934933271ull,
  6210132104484641803ull, 8156110858394046165ull}},
{{16309855268182877938ull, 6675280850745639342ull,
  6187175574516595079ull, 5097569286496278853ull}},
{{11163947048373821614ull, 3732415045004661274ull,
  12345655486573131753ull, 6371961608120348566ull}},
{{4731561773612501209ull, 9277204824683214497ull,
  6208697321361638883ull, 7964952010150435708ull}},
{{14486441154576283016ull, 3492410006213315108ull,
  13103807862705800110ull, 4978095006344022317ull}},
{{18108051443220353770ull, 13588884544621419693ull,
  2544701773100086425ull, 6222618757930027897ull}},
{{8800006248743278500ull, 3151047625494610905ull,
  7792563234802495936ull, 7778273447412534871ull}},
{{17029218951533018823ull, 1969404765934131815ull,
  11787881049392641816ull, 4861420904632834294ull}},
{{16674837670988885624ull, 2461755957417664769ull,
  5511479274886026462ull, 6076776130791042868ull}},
{{7008489033453943318ull, 12300566983626856770ull,
  6889349093607533077ull, 7595970163488803585ull}},
{{8991991664336102478ull, 9993697373980479433ull,
  15835058229573177933ull, 4747481352180502240ull}},
{{15851675598847516001ull, 17103807735902987195ull,
  1347078713256920800ull, 5934351690225627801ull}},
{{15202908480132007098ull, 2933015596169182378ull,
  6295534409998538905ull, 7417939612782034751ull}},
{{14113503818509892340ull, 13362349793674208746ull,
  10852238033890168671ull, 4636212257988771719ull}},
{{8418507736282589617ull, 12091251223665373029ull,
  8953611523935322935ull, 5795265322485964649ull}},
{{15134820688780624925ull, 10502378011154328382ull,
  15803700423346541573ull, 7244081653107455811ull}},
{{9695153824121005349ull, 17739658532370298382ull,
  15142939510755789062ull, 9055102066384319764ull}},
{{1447785121648240439ull, 6475600564304048585ull, 240965157367592356ull,
  5659438791490199853ull}},
{{6421417420487688453ull, 8094500705380060731ull,
  4912892465136878349ull, 7074298489362749816ull}},
{{3415085757182222662ull, 14729811900152463818ull,
  6141115581421097936ull, 8842873111703437270ull}},
{{6746114616666277068ull, 9206132437595289886ull,
  17673255293670349922ull, 5526795694814648293ull}},
{{17656015307687622143ull, 2284293510139336549ull,
  8256511061805773691ull, 6908494618518310367ull}},
{{8234961079327363966ull, 16690424942956334399ull,
  5708952808829829209ull, 8635618273147887959ull}},
{{12064379702220684335ull, 3513986561706627143ull,
  10485624533159725112ull, 5397261420717429974ull}},
{{10468788609348467515ull, 4392483202133283929ull,
  3883658629594880582ull, 6746576775896787468ull}},
{{17697671780112972297ull, 14713976039521380719ull,
  4854573286993600727ull, 8433220969870984335ull}},
{{17978573890211689542ull, 16113764052341944805ull,
  9951637332012082310ull, 5270763106169365209ull}},
{{8638159307482448215ull, 10918833028572655199ull,
  17051232683442490792ull, 6588453882711706511ull}},
{{6186013115925672365ull, 13648541285715818999ull,
  16702354835875725586ull, 8235567353389633139ull}},
{{10783787225094627084ull, 13142024321999774778ull,
  8133128763208634539ull, 5147229595868520712ull}},
{{4256361994513508047ull, 11815844384072330569ull,
  10166410954010793174ull, 6434036994835650890ull}},
{{9932138511569272963ull, 5546433443235637403ull,
  3484641655658715660ull, 8042546243544563613ull}},
{{3901743560517101650ull, 12689892938877049185ull,
  4483744044000391239ull, 5026591402215352258ull}},
{{9488865469073764966ull, 11250680155168923577ull,
  14828052091855264857ull, 6283239252769190322ull}},
{{16472767854769594112ull, 228292138678990759ull,
  9311693077964305264ull, 7854049065961487903ull}},
{{17213008936872078176ull, 142682586674369224ull,
  12737337201368772646ull, 4908780666225929939ull}},
{{3069517097380546104ull, 9401725270197737339ull,
  11309985483283577903ull, 6135975832782412424ull}},
{{17671954427007846342ull, 7140470569319783769ull,
  14137481854104472379ull, 7669969790978015530ull}},
{{4127442489238822108ull, 2156951096611170904ull,
  13447612177242683141ull, 4793731119361259706ull}},
{{5159303111548527635ull, 7307874889191351534ull,
  7586143184698578118ull, 5992163899201574633ull}},
{{15672500926290435351ull, 18358215648343965225ull,
  14094364999300610551ull, 7490204874001968291ull}},
{{2877784051290440239ull, 18391413807856060122ull,
  6503135115349187642ull, 4681378046251230182ull}},
{{12820602100967826106ull, 13765895222965299344ull,
  17352290931041260361ull, 5851722557814037727ull}},
{{16025752626209782633ull, 3372310973424460468ull,
  17078677645374187548ull, 7314653197267547159ull}},
{{1585446709052676675ull, 4215388716780575586ull,
  16736661038290346531ull, 9143316496584433949ull}},
{{5602590211585310826ull, 328774938774165789ull,
  12766256158145160534ull, 5714572810365271218ull}},
{{11614923782909026436ull, 9634340710322483044ull,
  6734448160826674859ull, 7143216012956589023ull}},
{{14518654728636283045ull, 7431239869475715901ull,
  3806374182605955670ull, 8929020016195736279ull}},
{{11380002214611370855ull, 32838899994934534ull, 9296512891769804150ull,
  5580637510122335174ull}},
{{5001630731409437761ull, 9264420661848443976ull,
  2397269077857479379ull, 6975796887652918968ull}},
{{6252038414261797201ull, 6968839808883167066ull,
  2996586347321849224ull, 8719746109566148710ull}},
{{8519210027341011155ull, 4355524880551979416ull,
  15707924522358319477ull, 5449841318478842943ull}},
{{10649012534176263944ull, 10056092119117362174ull,
  15023219634520511442ull, 6812301648098553679ull}},
{{4087893630865554121ull, 3346743112041926910ull,
  14167338524723251399ull, 8515377060123192099ull}},
{{16389991574573135038ull, 9009243472667286174ull,
  6548743568738338172ull, 5322110662576995062ull}},
{{11264117431361642989ull, 11261554340834107718ull,
  17409301497777698523ull, 6652638328221243827ull}},
{{4856774752347277929ull, 9465256907615246744ull,
  17149940853794735250ull, 8315797910276554784ull}},
{{3035484220217048706ull, 10527471585686917119ull,
  10718713033621709531ull, 5197373693922846740ull}},
{{17629413330553474594ull, 8547653463681258494ull,
  13398391292027136914ull, 6496717117403558425ull}},
{{12813394626337067434ull, 1461194792746797310ull,
  2912931059751757431ull, 8120896396754448032ull}},
{{3396685623033279243ull, 7830775773107830175ull,
  1820581912344848394ull, 5075560247971530020ull}},
{{18080915084073762765ull, 565097679530011910ull,
  2275727390431060493ull, 6344450309964412525ull}},
{{13377771818237427648ull, 5318058117839902792ull,
  7456345256466213520ull, 7930562887455515656ull}},
{{8361107386398392280ull, 3323786323649939245ull,
  4660215785291383450ull, 4956601804659697285ull}},
{{15063070251425378254ull, 13378104941417199864ull,
  10436955750041617216ull, 6195752255824621606ull}},
{{382093740572171202ull, 16722631176771499831ull,
  3822822650697245712ull, 7744690319780777008ull}},
{{7156337615498688857ull, 10451644485482187394ull,
  2389264156685778570ull, 4840431449862985630ull}},
{{18168794056228136880ull, 3841183569997958434ull,
  12209952232711999021ull, 6050539312328732037ull}},
{{13487620533430395291ull, 9413165480924835947ull,
  1427382235607835064ull, 7563174140410915047ull}},
{{6123919824180303105ull, 5883228425578022467ull,
  7809642924895978771ull, 4726983837756821904ull}},
{{3043213761797990977ull, 2742349513545140180ull,
  9762053656119973464ull, 5908729797196027380ull}},
{{3804017202247488722ull, 3427936891931425225ull,
  12202567070149966830ull, 7385912246495034225ull}},
{{13906725797473150211ull, 15977518612739304477ull,
  709075391202647412ull, 4616195154059396391ull}},
{{3548349191559274052ull, 1525154192214578981ull,
  14721402294285472978ull, 5770243942574245488ull}},
{{9047122507876480469ull, 11129814777122999534ull,
  18401752867856841222ull, 7212804928217806860ull}},
{{2085531097990824778ull, 4688896434548973610ull,
  4555447011111499912ull, 9016006160272258576ull}},
{{5915142954671653390ull, 2930560271593108506ull,
  2847154381944687445ull, 5635003850170161610ull}},
{{16617300730194342546ull, 8274886357918773536ull,
  12782315014285635114ull, 7043754812712702012ull}},
{{2324881839033376566ull, 1120235910543691113ull,
  15977893767857043893ull, 8804693515890877515ull}},
{{12982266195464330114ull, 3005990453303500897ull,
  7680340595696958481ull, 5502933447431798447ull}},
{{2392774689048248930ull, 8369174085056764026ull,
  4988739726193810197ull, 6878666809289748059ull}},
{{12214340398165086971ull, 15073153624748342936ull,
  1624238639314874842ull, 8598333511612185074ull}},
{{7633962748853179357ull, 14032407033895102239ull,
  5626835167999184680ull, 5373958444757615671ull}},
{{4930767417639086292ull, 17540508792368877799ull,
  2421857941571592946ull, 6717448055947019589ull}},
{{1551773253621469961ull, 12702263953606321441ull,
  7639008445391879087ull, 8396810069933774486ull}},
{{12499073329581888486ull, 14856443998645032756ull,
  162694259942536525ull, 5248006293708609054ull}},
{{15623841661977360607ull, 4735496943024127233ull,
  9426739861782946465ull, 6560007867135761317ull}},
{{5694744022189537047ull, 10531057197207546946ull,
  16395110845656070985ull, 8200009833919701646ull}},
{{8170901032295848558ull, 18111125794323186601ull,
  5635258260107656461ull, 5125006146199813529ull}},
{{14825312308797198602ull, 8803849187621819539ull,
  11655758843561958481ull, 6406257682749766911ull}},
{{13919954367569110348ull, 15616497502954662328ull,
  9958012536025060197ull, 8007822103437208639ull}},
{{8699971479730693968ull, 12066153948560357907ull,
  13141286862656744479ull, 5004888814648255399ull}},
{{6263278331235979556ull, 10471006417273059480ull,
  11814922559893542695ull, 6256111018310319249ull}},
{{7829097914044974444ull, 8477072003163936446ull, 933595144584764657ull,
  7820138772887899062ull}},
{{281500177850721124ull, 16827385048045930039ull,
  14418555020647641622ull, 4887586733054936913ull}},
{{14186933277595565117ull, 11810859273202636740ull,
  4188135720527388316ull, 6109483416318671142ull}},
{{17733666596994456396ull, 14763574091503295925ull,
  14458541687514011203ull, 7636854270398338927ull}},
{{13389384632335229200ull, 6921390797975866001ull,
  15954117582337338858ull, 4773033918998961829ull}},
{{2901672735136872787ull, 17875110534324608310ull,
  6107588922639509860ull, 5966292398748702287ull}},
{{12850462955775866792ull, 3897144094196208771ull,
  3022800134871999422ull, 7457865498435877859ull}},
{{5725696338146222793ull, 16270773114154794194ull,
  18030151148790857302ull, 4661165936522423661ull}},
{{16380492459537554299ull, 11115094355838716934ull,
  8702630880706407916ull, 5826457420653029577ull}},
{{11252243537567167066ull, 13893867944798396168ull,
  15489974619310397799ull, 7283071775816286971ull}},
{{14065304421958958833ull, 12755648912570607306ull,
  14750782255710609345ull, 9103839719770358714ull}},
{{13402501282151737175ull, 1054751542715547710ull,
  13830924928246518745ull, 5689899824856474196ull}},
{{7529754565834895660ull, 5930125446821822542ull,
  17288656160308148431ull, 7112374781070592745ull}},
{{188821170438843767ull, 2800970790099890274ull, 7775762145103021827ull,
  8890468476338240932ull}},
{{4729699249951665259ull, 17891507808308289085ull,
  14083223377544164449ull, 5556542797711400582ull}},
{{10523810080866969477ull, 8529326705103197644ull,
  8380657185075429754ull, 6945678497139250728ull}},
{{13154762601083711846ull, 1438286344524221247ull,
  10475821481344287193ull, 8682098121424063410ull}},
{{15139255653318401760ull, 12428144011396108039ull,
  11159074444267567399ull, 5426311325890039631ull}},
{{14312383548220614296ull, 10923493995817747145ull,
  9337157036907071345ull, 6782889157362549539ull}},
{{4055421379993604158ull, 18266053513199571836ull,
  7059760277706451277ull, 8478611446703186924ull}},
{{11758010399350778407ull, 13722126454963426349ull,
  13635722210421307856ull, 5299132154189491827ull}},
{{862454943906309296ull, 17152658068704282937ull,
  12432966744599246916ull, 6623915192736864784ull}},
{{5689754698310274524ull, 2994078512170802055ull,
  15541208430749058646ull, 8279893990921080980ull}},
{{10473625714085003434ull, 15706357125388914996ull,
  489883232363385845ull, 5174933744325675613ull}},
{{13092032142606254292ull, 5797888351453980033ull,
  5224040058881620211ull, 6468667180407094516ull}},
{{2529982122975654153ull, 2635674420890087138ull,
  6530050073602025264ull, 8085833975508868145ull}},
{{6192924845287171750ull, 1647296513056304461ull,
  15610496342069735550ull, 5053646234693042590ull}},
{{12352842075036352591ull, 11282492678175156384ull,
  10289748390732393629ull, 6317057793366303238ull}},
{{15441052593795440739ull, 268057792436781768ull,
  3638813451560716229ull, 7896322241707879048ull}},
{{9650657871122150462ull, 2473379129486682557ull,
  2274258407225447643ull, 4935201401067424405ull}},
{{16675008357330075982ull, 16926781967140516908ull,
  7454509027459197457ull, 6169001751334280506ull}},
{{2397016372953043361ull, 7323419403643482424ull, 94764247469221014ull,
  7711252189167850633ull}},
{{1498135233095652101ull, 18412195182559340227ull,
  11588442700736732893ull, 4819532618229906645ull}},
{{15707727096651728838ull, 9180185922917011571ull,
  650495320638752405ull, 6024415772787383307ull}},
{{15022972852387273143ull, 16086918422073652368ull,
  14648177206080604218ull, 7530519715984229133ull}},
{{9389358032742045715ull, 14666010032223420634ull,
  11460953763014071588ull, 4706574822490143208ull}},
{{2513325504072781335ull, 18332512540279275793ull,
  14326192203767589485ull, 5883218528112679010ull}},
{{7753342898518364573ull, 9080582620066931029ull,
  8684368217854711049ull, 7354023160140848763ull}},
{{14303364641575343620ull, 15962414293511051690ull,
  6243774253891000907ull, 9192528950176060954ull}},
{{13551288919411977667ull, 7670665924230713354ull,
  8514044927109263471ull, 5745330593860038096ull}},
{{7715739112410196275ull, 4976646386861003789ull,
  10642556158886579339ull, 7181663242325047620ull}},
{{14256359908940133248ull, 1609121965148866832ull,
  13303195198608224174ull, 8977079052906309525ull}},
{{8910224943087583280ull, 14840759283500205482ull,
  10620340008343834060ull, 5610674408066443453ull}},
{{1914409142004703292ull, 104205030665705237ull,
  17887111028857180480ull, 7013343010083054316ull}},
{{7004697445933267019ull, 130256288332131546ull, 3912144712361923984ull,
  8766678762603817896ull}},
{{8989621922135679791ull, 81410180207582216ull, 2445090445226202490ull,
  5479174226627386185ull}},
{{11237027402669599738ull, 9325134762114253578ull,
  7668049074960141016ull, 6848967783284232731ull}},
{{4822912216482223865ull, 11656418452642816973ull,
  4973375325272788366ull, 8561209729105290914ull}},
{{5320163144515083868ull, 2673575514474372704ull,
  7720045596722880633ull, 5350756080690806821ull}},
{{6650203930643854835ull, 7953655411520353784ull,
  14261743014330988695ull, 6688445100863508526ull}},
{{8312754913304818543ull, 5330383245973054326ull,
  8603806731058960061ull, 8360556376079385658ull}},
{{583785802388123686ull, 5637332537946852906ull, 9989065225339237942ull,
  5225347735049616036ull}},
{{9953104289839930415ull, 16270037709288341940ull,
  12486331531674047427ull, 6531684668812020045ull}},
{{12441380362299913019ull, 15725861118183039521ull,
  1772856359310395572ull, 8164605836015025057ull}},
{{858333698796363781ull, 605291162009623893ull, 12637250270637466993ull,
  5102878647509390660ull}},
{{5684603141922842630ull, 5368299970939417770ull,
  15796562838296833741ull, 6378598309386738325ull}},
{{16329125964258329095ull, 11322060982101660116ull,
  5910645492588878464ull, 7973247886733422907ull}},
{{982331690806679877ull, 7076288113813537573ull, 1388310423654355088ull,
  4983279929208389317ull}},
{{5839600631935737750ull, 8845360142266921966ull,
  6347074047995331764ull, 6229099911510486646ull}},
{{16522872826774447995ull, 11056700177833652457ull,
  17157214596848940513ull, 7786374889388108307ull}},
{{3409266489092948141ull, 18439652657214502546ull,
  8417416113816893868ull, 4866484305867567692ull}},
{{13484955148220960984ull, 4602821747808576566ull,
  10521770142271117336ull, 6083105382334459615ull}},
{{7632821898421425422ull, 5753527184760720708ull,
  8540526659411508766ull, 7603881727918074519ull}},
{{13993885723368166697ull, 17431012545757614154ull,
  12255358189773274834ull, 4752426079948796574ull}},
{{8268985117355432563ull, 12565393645342241885ull,
  6095825700361817735ull, 5940532599935995718ull}},
{{14947917415121678608ull, 11095056038250414452ull,
  16843154162307047977ull, 7425665749919994647ull}},
{{119076347596273322ull, 16880996265427177ull, 17444500379082986842ull,
  4641041093699996654ull}},
{{4760531452922729557ull, 9244473282186559779ull,
  12582253436998957744ull, 5801301367124995818ull}},
{{1338978297726024042ull, 11555591602733199724ull,
  6504444759393921372ull, 7251626708906244773ull}},
{{1673722872157530052ull, 14444489503416499655ull,
  12742241967669789619ull, 9064533386132805966ull}},
{{7963605822739538139ull, 6721962930421618332ull,
  3352215211366230608ull, 5665333366333003729ull}},
{{9954507278424422673ull, 8402453663027022915ull,
  8801955032635176164ull, 7081666707916254661ull}},
{{7831448079603140437ull, 10503067078783778644ull,
  15614129809221358109ull, 8852083384895318326ull}},
{{14118027086606738581ull, 8870259933453555604ull,
  5147145112335960914ull, 5532552115559573954ull}},
{{17647533858258423227ull, 1864452879962168697ull,
  15657303427274726951ull, 6915690144449467442ull}},
{{8224359267540865321ull, 16165624155234874584ull,
  10348257247238632880ull, 8644612680561834303ull}},
{{5140224542213040826ull, 10103515097021796615ull,
  13385189807165227406ull, 5402882925351146439ull}},
{{1813594659338913128ull, 3406021834422469961ull,
  12119801240529146354ull, 6753603656688933049ull}},
{{6878679342601029314ull, 13480899329882863259ull,
  1314693495379269230ull, 8442004570861166312ull}},
{{1993331579911949370ull, 3813876062749401633ull, 821683434612043269ull,
  5276252856788228945ull}},
{{7103350493317324616ull, 9379031096864139945ull,
  5638790311692441990ull, 6595316070985286181ull}},
{{13490874135074043674ull, 2500416834225399123ull,
  11660173908042940392ull, 8244145088731607726ull}},
{{6125953325207583344ull, 1562760521390874452ull,
  2675922674099449841ull, 5152590680457254829ull}},
{{7657441656509479180ull, 6565136670165980969ull,
  7956589361051700205ull, 6440738350571568536ull}},
{{14183488089064236879ull, 12818106856134864115ull,
  9945736701314625256ull, 8050922938214460670ull}},
{{6558837046451454098ull, 8011316785084290072ull,
  1604399419894252881ull, 5031826836384037919ull}},
{{8198546308064317622ull, 14625831999782750494ull,
  15840557330149979813ull, 6289783545480047398ull}},
{{1024810848225621219ull, 4447231944446274406ull,
  10577324625832698959ull, 7862229431850059248ull}},
{{14475564835423176974ull, 9697048992920003359ull,
  6610827891145436849ull, 4913893394906287030ull}},
{{13482770025851583314ull, 16732997259577392103ull,
  17486906900786571869ull, 6142366743632858787ull}},
{{12241776513887091238ull, 7081188519189576417ull,
  17246947607555826933ull, 7677958429541073484ull}},
{{733581293538350168ull, 6731585833707179213ull, 1555970217867616025ull,
  4798724018463170928ull}},
{{5528662635350325614ull, 13026168310561361920ull,
  1944962772334520031ull, 5998405023078963660ull}},
{{6910828294187907017ull, 11671024369774314496ull,
  2431203465418150039ull, 7498006278848704575ull}},
{{4319267683867441886ull, 14211919258750028416ull,
  8437031193527425630ull, 4686253924280440359ull}},
{{5399084604834302357ull, 8541527036582759712ull,
  5934602973481894134ull, 5857817405350550449ull}},
{{6748855756042877946ull, 1453536758873673832ull,
  12029939735279755572ull, 7322271756688188061ull}},
{{8436069695053597433ull, 1816920948592092290ull,
  1202366613817530753ull, 9152839695860235077ull}},
{{9884229577835886300ull, 12664790638938527441ull,
  3057322142849650672ull, 5720524809912646923ull}},
{{16966972990722245779ull, 15830988298673159301ull,
  17656710733844227052ull, 7150656012390808653ull}},
{{7373658183120643511ull, 1341991299631897511ull,
  8235830362023120104ull, 8938320015488510817ull}},
{{11526065392091484051ull, 838744562269935944ull,
  16676609022332919825ull, 5586450009680319260ull}},
{{14407581740114355063ull, 5660116721264807834ull,
  2399017204206598165ull, 6983062512100399076ull}},
{{8786105138288168021ull, 11686831920008397697ull,
  2998771505258247706ull, 8728828140125498845ull}},
{{17020530757498574773ull, 11915955968432636464ull,
  4180075200000098768ull, 5455517587578436778ull}},
{{2828919373163666850ull, 14894944960540795581ull,
  14448466036854899268ull, 6819396984473045972ull}},
{{8147835234881971467ull, 171937126966442860ull,
  18060582546068624086ull, 8524246230591307465ull}},
{{14315769058656007975ull, 13942518759636190499ull,
  4370335063651808197ull, 5327653894119567166ull}},
{{13283025304892622065ull, 3593090394263074412ull,
  14686290866419536055ull, 6659567367649458957ull}},
{{16603781631115777581ull, 18326421048111006727ull,
  4522805527742256356ull, 8324459209561823697ull}},
{{17294892547088442844ull, 2230641118214603396ull,
  14355968500907379983ull, 5202787005976139810ull}},
{{3171871610151001939ull, 16623359453050417958ull,
  8721588589279449170ull, 6503483757470174763ull}},
{{13188211549543528231ull, 11555827279458246639ull,
  6290299718171923559ull, 8129354696837718454ull}},
{{15160161246105787001ull, 14139921077302486005ull,
  17766495379139615936ull, 5080846685523574033ull}},
{{5115143502350070039ull, 17674901346628107507ull,
  8373061168642356208ull, 6351058356904467542ull}},
{{1782243359510199645ull, 3646882609575582768ull,
  1242954423948169453ull, 7938822946130584428ull}},
{{1113902099693874778ull, 4585144640198433182ull,
  10000218551822381716ull, 4961764341331615267ull}},
{{10615749661472119280ull, 5731430800248041477ull,
  7888587171350589241ull, 6202205426664519084ull}},
{{17881373095267537004ull, 11775974518737439750ull,
  9860733964188236551ull, 7752756783330648855ull}},
{{6564172166114822724ull, 14277513101851981700ull,
  13080487755258729700ull, 4845472989581655534ull}},
{{8205215207643528405ull, 17846891377314977125ull,
  7127237657218636317ull, 6056841236977069418ull}},
{{14868205027981798410ull, 8473556166361557694ull,
  18132419108378071205ull, 7571051546221336772ull}},
{{4680942124061236102ull, 7601815613189667511ull,
  2109389905881518695ull, 4731907216388335483ull}},
{{1239491636649157224ull, 4890583498059696485ull,
  16471795437634062081ull, 5914884020485419353ull}},
{{6161050564238834434ull, 10724915391002008510ull,
  6754686241760413889ull, 7393605025606774192ull}},
{{17685714657931435233ull, 18232287165444725078ull,
  4221678901100258680ull, 4621003141004233870ull}},
{{12883771285559518233ull, 4343614883096354732ull,
  14500470663230099159ull, 5776253926255292337ull}},
{{16104714106949397792ull, 817832585443055511ull,
  4290530273755460237ull, 7220317407819115422ull}},
{{15519206615259359335ull, 5633976750231207293ull,
  14586534879049101104ull, 9025396759773894277ull}},
{{12005347143750793537ull, 3521235468894504558ull,
  11422427308619382142ull, 5640872974858683923ull}},
{{5783311892833716113ull, 13624916372972906506ull,
  9666348117346839773ull, 7051091218573354904ull}},
{{16452511902896920949ull, 3196087410933969420ull,
  12082935146683549717ull, 8813864023216693630ull}},
{{1059447902455799785ull, 4303397641047424840ull,
  2940148448249830669ull, 5508665014510433519ull}},
{{1324309878069749732ull, 9990933069736668954ull,
  17510243615594452048ull, 6885831268138041898ull}},
{{10878759384441962972ull, 12488666337170836192ull,
  12664432482638289252ull, 8607289085172552373ull}},
{{6799224615276226858ull, 17028788497586548428ull,
  10221113310862624734ull, 5379555678232845233ull}},
{{8499030769095283572ull, 12062613585128409727ull,
  17388077657005668822ull, 6724444597791056541ull}},
{{6012102442941716561ull, 5854894944555736351ull,
  7900039015974922316ull, 8405555747238820677ull}},
{{10675093054479654707ull, 12882681377202111027ull,
  7243367394198020399ull, 5253472342024262923ull}},
{{8732180299672180479ull, 11491665703075250880ull,
  4442523224320137595ull, 6566840427530328654ull}},
{{10915225374590225599ull, 9752896110416675696ull,
  14776526067254947802ull, 8208550534412910817ull}},
{{6822015859118891000ull, 10707246087437810214ull,
  2317799764393260520ull, 5130344084008069261ull}},
{{17750891860753389558ull, 13384057609297262767ull,
  7508935723918963554ull, 6412930105010086576ull}},
{{17576928807514349043ull, 7506699974766802651ull,
  9386169654898704443ull, 8016162631262608220ull}},
{{8679737495482774200ull, 2385844475015557705ull,
  15089728071166466085ull, 5010101644539130137ull}},
{{15461357887780855654ull, 7593991612196835035ull,
  5027102033675918894ull, 6262627055673912672ull}},
{{14715011341298681663ull, 269117478391267986ull,
  6283877542094898618ull, 7828283819592390840ull}},
{{13808568106739063944ull, 4779884442421930395ull,
  3927423463809311636ull, 4892677387245244275ull}},
{{12649024114996442025ull, 5974855553027412994ull,
  297593311334251641ull, 6115846734056555344ull}},
{{6587908106890776724ull, 12080255459711654147ull,
  371991639167814551ull, 7644808417570694180ull}},
{{1811599557593041500ull, 14467688689960865698ull,
  9455866811334659902ull, 4778005260981683862ull}},
{{11487871483846077683ull, 8861238825596306314ull,
  2596461477313549070ull, 5972506576227104828ull}},
{{5136467317952821296ull, 1853176495140607085ull,
  3245576846641936338ull, 7465633220283881035ull}},
{{5516135082934207262ull, 5769921327890267332ull,
  18169386593647067875ull, 4666020762677425646ull}},
{{6895168853667759078ull, 2600715641435446261ull,
  13488361205204059036ull, 5832525953346782058ull}},
{{13230647085512086751ull, 3250894551794307826ull,
  7637079469650297987ull, 7290657441683477573ull}},
{{7314936820035332631ull, 17898676245025048495ull,
  14158035355490260387ull, 9113321802104346966ull}},
{{11489364540163164750ull, 8880829643926961357ull,
  4237086078754024838ull, 5695826126315216854ull}},
{{526647619921792226ull, 1877665018053925889ull,
  14519729635297306856ull, 7119782657894021067ull}},
{{5269995543329628186ull, 2347081272567407361ull,
  13537976025694245666ull, 8899728322367526334ull}},
{{14822962260649487377ull, 6078611813782017504ull,
  3849548997631515637ull, 5562330201479703959ull}},
{{81958752102307605ull, 12209950785654909785ull, 200250228612006642ull,
  6952912751849629949ull}},
{{4714134458555272410ull, 6039066445213861423ull,
  4861998804192396207ull, 8691140939812037436ull}},
{{9863863064238127112ull, 10691945555899745245ull,
  12262121289475023437ull, 5431963087382523397ull}},
{{16941514848725046794ull, 17976617963302069460ull,
  1492593556561615584ull, 6789953859228154247ull}},
{{2730149487196756876ull, 4024028380418035210ull,
  15700800000984183193ull, 8487442324035192808ull}},
{{6318029447925360952ull, 14044232783829741766ull,
  9813000000615114495ull, 5304651452521995505ull}},
{{17120908846761476998ull, 12943604961359789303ull,
  16877936019196281023ull, 6630814315652494381ull}},
{{16789450040024458343ull, 11567820183272348725ull,
  7262361968713187567ull, 8288517894565617977ull}},
{{12799249284228980417ull, 14147416642186299809ull,
  16068191276514211989ull, 5180323684103511235ull}},
{{2164003550004061809ull, 3849212747450711050ull,
  15473553077215377083ull, 6475404605129389044ull}},
{{11928376474359853069ull, 199829915886000908ull, 895197272809669738ull,
  8094255756411736306ull}},
{{16678607333329683976ull, 4736579715856138471ull,
  5171184313933431490ull, 5058909847757335191ull}},
{{16236573148234717066ull, 15144096681674948897ull,
  1852294373989401458ull, 6323637309696668989ull}},
{{6460658380011232621ull, 9706748815238910314ull,
  6927053985914139727ull, 7904546637120836236ull}},
{{8649597505934408292ull, 12984247037165400802ull,
  13552780778051113137ull, 4940341648200522647ull}},
{{1588624845563234557ull, 2395250741174587291ull,
  12329289954136503518ull, 6175427060250653309ull}},
{{15820839112236206908ull, 12217435463323009921ull,
  1576554387388465685ull, 7719283825313316637ull}},
{{2970495417506547462ull, 9941740173790575153ull,
  3291189501331485005ull, 4824552390820822898ull}},
{{8324805290310572231ull, 17038861235665606845ull,
  13337358913519132064ull, 6030690488526028622ull}},
{{15017692631315603193ull, 2851832470872456940ull,
  7448326605044139273ull, 7538363110657535778ull}},
{{162685857717476188ull, 13311610340363755348ull,
  9266890146579974949ull, 4711476944160959861ull}},
{{203357322146845234ull, 2804454870172530473ull,
  16195298701652356591ull, 5889346180201199826ull}},
{{4865882671110944447ull, 17340626642997826803ull,
  11020751340210669930ull, 7361682725251499783ull}},
{{1470667320461292654ull, 12452411266892507696ull,
  9164253156835949509ull, 9202103406564374729ull}},
{{919167075288307909ull, 10088600051021511262ull,
  17256873269090938203ull, 5751314629102734205ull}},
{{10372330880965160694ull, 7999064045349501173ull,
  7736033531081509042ull, 7189143286378417757ull}},
{{17577099619633838772ull, 775458019832100658ull,
  14281727932279274207ull, 8986429107973022196ull}},
{{15597373280698537137ull, 7402190290036144767ull,
  18149451994529322187ull, 5616518192483138872ull}},
{{14885030582445783517ull, 4641051844117793055ull,
  4240070919452101118ull, 7020647740603923591ull}},
{{13994602209629841492ull, 15024686842002017127ull,
  688402630887738493ull, 8775809675754904489ull}},
{{15664155408659732788ull, 11696272285464954656ull,
  11959466690373306318ull, 5484881047346815305ull}},
{{1133450187115114369ull, 5396968319976417513ull,
  1114275307684469186ull, 6856101309183519132ull}},
{{6028498752321280866ull, 15969582436825297699ull,
  1392844134605586482ull, 8570126636479398915ull}},
{{1461968710987106589ull, 14592675041443198966ull,
  17011428648624349215ull, 5356329147799624321ull}},
{{11050832925588659044ull, 13629157783376610803ull,
  7429227755498272807ull, 6695411434749530402ull}},
{{9201855138558435901ull, 12424761210793375600ull, 63162657518065201ull,
  8369264293436913003ull}},
{{5751159461599022439ull, 847946729104777894ull,
  16180377725444648415ull, 5230790183398070626ull}},
{{16412321363853553856ull, 14894991466663136079ull,
  11002100119951034710ull, 6538487729247588283ull}},
{{15903715686389554416ull, 9395367296474144291ull,
  9140939131511405484ull, 8173109661559485354ull}},
{{7633979294779777558ull, 15095476597151115990ull,
  10324772975622016331ull, 5108193538474678346ull}},
{{319102081619946140ull, 14257659728011507084ull,
  3682594182672744606ull, 6385241923093347933ull}},
{{398877602024932674ull, 8598702623159608047ull, 9214928746768318662ull,
  7981552403866684916ull}},
{{7166827528906664778ull, 762503121047367125ull,
  14982702503584974972ull, 4988470252416678072ull}},
{{13570220429560718876ull, 953128901309208906ull, 281634055771667099ull,
  6235587815520847591ull}},
{{7739403500096122787ull, 15026469181918674845ull,
  14187100624996747585ull, 7794484769401059488ull}},
{{7142970196773770694ull, 2474014211058089922ull,
  8866937890622967241ull, 4871552980875662180ull}},
{{18152084782821989175ull, 7704203782250000306ull,
  11083672363278709051ull, 6089441226094577725ull}},
{{13466733941672710661ull, 5018568709385112479ull, 19532398816222602ull,
  7611801532618222157ull}},
{{15334237741186526019ull, 7748291461793083203ull,
  2318050758473833078ull, 4757375957886388848ull}},
{{14556111158055769620ull, 461992290386578196ull,
  2897563448092291348ull, 5946719947357986060ull}},
{{18195138947569712025ull, 577490362983222745ull,
  3621954310115364185ull, 7433399934197482575ull}},
{{4454432814589988160ull, 11890146522932983976ull,
  9181250471463184471ull, 4645874958873426609ull}},
{{5568041018237485200ull, 10250997135238842066ull,
  16088249107756368493ull, 5807343698591783261ull}},
{{16183423309651632307ull, 17425432437475940486ull,
  6275253329413296904ull, 7259179623239729077ull}},
{{11005907100209764576ull, 3335046473135373992ull,
  12455752680194009035ull, 9073974529049661346ull}},
{{6878691937631102860ull, 18225305110205466409ull,
  12396531443548643550ull, 5671234080656038341ull}},
{{13210050940466266479ull, 13558259350902057203ull,
  1660606249153640726ull, 7089042600820047927ull}},
{{11900877657155445195ull, 7724452151772795696ull,
  15910815866724214620ull, 8861303251025059908ull}},
{{7438048535722153247ull, 14051154631712773118ull,
  720887879847858329ull, 5538314531890662443ull}},
{{74188632797915751ull, 3728885234358802686ull, 14736167905091986624ull,
  6922893164863328053ull}},
{{9316107827852170496ull, 4661106542948503357ull,
  4585151826082819568ull, 8653616456079160067ull}},
{{8128410401621300512ull, 2913191589342814598ull, 559876882088068278ull,
  5408510285049475042ull}},
{{937140965171849832ull, 12864861523533294056ull,
  9923218139464861155ull, 6760637856311843802ull}},
{{1171426206464812290ull, 11469390885989229666ull,
  3180650637476300636ull, 8450797320389804753ull}},
{{5343827397467895585ull, 16391741340598044349ull,
  13517121694491157657ull, 5281748325243627970ull}},
{{11291470265262257386ull, 6654618620465391724ull,
  7673030081259171264ull, 6602185406554534963ull}},
{{14114337831577821732ull, 8318273275581739655ull,
  4979601583146576176ull, 8252731758193168704ull}},
{{15738990172377220439ull, 5198920797238587284ull,
  3112250989466610110ull, 5157957348870730440ull}},
{{1226993641761973932ull, 15722023033403009914ull,
  3890313736833262637ull, 6447446686088413050ull}},
{{10757114089057243223ull, 5817470736471598680ull,
  14086264207896354105ull, 8059308357610516312ull}},
{{6723196305660777015ull, 15165134256363218935ull,
  8803915129935221315ull, 5037067723506572695ull}},
{{3792309363648583364ull, 14344731802026635765ull,
  6393207893991638740ull, 6296334654383215869ull}},
{{9352072722988117109ull, 17930914752533294706ull,
  12603195885916936329ull, 7870418317979019836ull}},
{{10456731470294961097ull, 4289292692692227335ull,
  17100369465552861014ull, 4919011448736887397ull}},
{{8459228319441313468ull, 14584987902720059977ull,
  7540403776658912555ull, 6148764310921109247ull}},
{{15185721417729029738ull, 13619548859972687067ull,
  4813818702396252790ull, 7685955388651386559ull}},
{{7185232876866949635ull, 3900532019055541513ull,
  9926165716638739850ull, 4803722117907116599ull}},
{{13593227114511074947ull, 14099037060674202699ull,
  7796021127371036908ull, 6004652647383895749ull}},
{{12379847874711455780ull, 17623796325842753374ull,
  14356712427641184039ull, 7505815809229869686ull}},
{{3125718903267271959ull, 17932401731292802715ull,
  4361259248848352120ull, 4691134880768668554ull}},
{{17742206684366253660ull, 3968758090406451777ull,
  14674946097915215959ull, 5863918600960835692ull}},
{{8342700300175653363ull, 349261594580676818ull,
  18343682622394019949ull, 7329898251201044615ull}},
{{1205003338364790896ull, 5048263011653233927ull,
  18317917259565137032ull, 9162372814001305769ull}},
{{7670656114119076166ull, 3155164382283271204ull,
  4531169259587128789ull, 5726483008750816106ull}},
{{9588320142648845207ull, 8555641496281476909ull,
  14887333611338686794ull, 7158103760938520132ull}},
{{16597086196738444413ull, 1471179833497070328ull,
  162422940463806877ull, 8947629701173150166ull}},
{{10373178872961527758ull, 3225330405149362907ull,
  13936572393072043010ull, 5592268563233218853ull}},
{{8354787572774521794ull, 13255035043291479442ull,
  3585657436057890050ull, 6990335704041523567ull}},
{{1220112429113376434ull, 7345421767259573495ull,
  18317129850354526275ull, 8737919630051904458ull}},
{{7680099295836942128ull, 2285045595323539482ull,
  16059892174898966826ull, 5461199768782440286ull}},
{{376752082941401851ull, 12079679031009200161ull,
  10851493181768932724ull, 6826499710978050358ull}},
{{5082626122104140218ull, 15099598788761500201ull,
  4340994440356390097ull, 8533124638722562948ull}},
{{14705856372383557396ull, 2519720215334855769ull,
  11936493562077519619ull, 5333202899201601842ull}},
{{4547262410197283033ull, 16984708324450733424ull,
  5697244915742123715ull, 6666503624002002303ull}},
{{5684078012746603792ull, 16619199387136028876ull,
  2509870126250266740ull, 8333129530002502879ull}},
{{12775920794821403178ull, 1163627580105242239ull,
  8486197856547498569ull, 5208205956251564299ull}},
{{11358214975099366068ull, 6066220493558940703ull,
  5996061302256985307ull, 6510257445314455374ull}},
{{9586082700446819681ull, 2971089598521287975ull,
  16718448664676007442ull, 8137821806643069217ull}},
{{12908830715420344157ull, 6468617017503192888ull,
  3531501387781422795ull, 5086138629151918261ull}},
{{16136038394275430196ull, 3474085253451603206ull,
  9026062753154166398ull, 6357673286439897826ull}},
{{10946675955989511937ull, 13565978603669279816ull,
  2059206404587932189ull, 7947091608049872283ull}},
{{6841672472493444961ull, 10784579636506993837ull,
  17427905067363315282ull, 4966932255031170176ull}},
{{13163776609044194105ull, 4257352508778966488ull,
  3338137260494592487ull, 6208665318788962721ull}},
{{16454720761305242631ull, 710004617546320206ull,
  8784357594045628513ull, 7760831648486203401ull}},
{{5672514457388388741ull, 11972967932034919889ull,
  17019438542346987580ull, 4850519780303877125ull}},
{{11702329090162873830ull, 14966209915043649861ull,
  7439240122651570763ull, 6063149725379846407ull}},
{{792853307421428575ull, 14096076375377174423ull,
  4687364134887075550ull, 7578937156724808009ull}},
{{7413062344779474715ull, 4198361716183346110ull,
  14458817630372891979ull, 4736835722953005005ull}},
{{42955894119567586ull, 636266126801794734ull, 4238463982683951262ull,
  5921044653691256257ull}},
{{9277066904504235291ull, 10018704695357019225ull,
  9909765996782326981ull, 7401305817114070321ull}},
{{17327381861383616817ull, 8567533443811830967ull,
  17722818794057424123ull, 4625816135696293950ull}},
{{17047541308302133117ull, 6097730786337400805ull,
  12930151455717004346ull, 5782270169620367438ull}},
{{7474368580095502684ull, 16845535519776526815ull,
  6939317282791479624ull, 7227837712025459298ull}},
{{4731274706691990451ull, 2610175326011106903ull,
  17897518640344125339ull, 9034797140031824122ull}},
{{9874575719323575888ull, 17772260643252799478ull,
  15797635168642466240ull, 5646748212519890076ull}},
{{3119847612299694052ull, 3768581730356447732ull,
  1300299887093531185ull, 7058435265649862596ull}},
{{3899809515374617565ull, 9322413181372947569ull,
  1625374858866913981ull, 8823044082062328245ull}},
{{13966595993177605738ull, 8132351247571786182ull,
  3321702296005515190ull, 5514402551288955153ull}},
{{8234872954617231365ull, 942067022609956920ull, 8763813888434281892ull,
  6893003189111193941ull}},
{{10293591193271539206ull, 1177583778262446150ull,
  15566453378970240269ull, 8616253986388992426ull}},
{{1821808477367324100ull, 3041832870627722796ull,
  14340719380283788072ull, 5385158741493120266ull}},
{{2277260596709155124ull, 3802291088284653495ull,
  8702527188499959282ull, 6731448426866400333ull}},
{{16681633801168607617ull, 13976235897210592676ull,
  15489845004052337006ull, 8414310533583000416ull}},
{{1202649088875603953ull, 4123461417329232519ull,
  9681153127532710629ull, 5258944083489375260ull}},
{{15338369416376668653ull, 9766012790088928552ull,
  12101441409415888286ull, 6573680104361719075ull}},
{{726217696761284200ull, 2984143950756384883ull,
  10515115743342472454ull, 8217100130452148844ull}},
{{16594787124971660289ull, 15700148024504904263ull,
  15795319376443821091ull, 5135687581532593027ull}},
{{16131797887787187458ull, 15013499012203742425ull,
  15132463202127388460ull, 6419609476915741284ull}},
{{6329689304451820610ull, 320129691545126416ull, 468834928949683960ull,
  8024511846144676606ull}},
{{3956055815282387881ull, 200081057215704010ull,
  14128079885875716187ull, 5015319903840422878ull}},
{{14168441805957760660ull, 14085159376801793724ull,
  8436727820489869425ull, 6269149879800528598ull}},
{{17710552257447200824ull, 3771391165720078443ull,
  1322537738757560974ull, 7836437349750660748ull}},
{{8763252151690806563ull, 16192177533857212739ull,
  10049958123578251416ull, 4897773343594162967ull}},
{{6342379171186120300ull, 1793477843611964308ull,
  7950761636045426367ull, 6122216679492703709ull}},
{{7927973963982650375ull, 16076905359797119097ull,
  14550138063484170862ull, 7652770849365879636ull}},
{{16484198773557626245ull, 5436379831445811531ull,
  18317208326532382597ull, 4782981780853674772ull}},
{{15993562448519644902ull, 11407160807734652318ull,
  4449766334455926630ull, 5978727226067093466ull}},
{{10768581023794780319ull, 5035578972813539590ull,
  14785579954924684096ull, 7473409032583866832ull}},
{{2118677121444349796ull, 3147236858008462244ull,
  9240987471827927560ull, 4670880645364916770ull}},
{{2648346401805437244ull, 3934046072510577805ull,
  2327862302930133642ull, 5838600806706145963ull}},
{{7922119020684184459ull, 14140929627492998064ull,
  16744885933944830764ull, 7298251008382682453ull}},
{{9902648775855230574ull, 17676162034366247580ull,
  7096049362148874743ull, 9122813760478353067ull}},
{{15412527521764294917ull, 17965130299119986593ull,
  2129187842129352762ull, 5701758600298970667ull}},
{{5430601346923204934ull, 13233040837045207434ull,
  16496542857943854665ull, 7127198250373713333ull}},
{{16011623720508781975ull, 2706242991024345580ull,
  6785620517147654620ull, 8908997812967141667ull}},
{{783892788463212927ull, 10914773906244991796ull,
  1935169814003590185ull, 5568123633104463542ull}},
{{979865985579016158ull, 18255153401233627649ull,
  11642334304359263539ull, 6960154541380579427ull}},
{{5836518500401158102ull, 18207255733114646657ull,
  9941231862021691520ull, 8700193176725724284ull}},
{{15177039108819193574ull, 11379534833196654160ull,
  15436641950618333008ull, 5437620735453577677ull}},
{{524554812314440351ull, 14224418541495817701ull,
  5460744382990752548ull, 6797025919316972097ull}},
{{5267379533820438343ull, 17780523176869772126ull,
  11437616497165828589ull, 8496282399146215121ull}},
{{17127170263919937677ull, 13418669994757301530ull,
  230981283087561012ull, 5310176499466384451ull}},
{{12185590793045146288ull, 16773337493446626913ull,
  14123784659141614977ull, 6637720624332980563ull}},
{{1396930436024269147ull, 7131613811526119930ull,
  13043044805499630818ull, 8297150780416225704ull}},
{{5484767540942556121ull, 9068944650631212860ull,
  8151903003437269261ull, 5185719237760141065ull}},
{{6855959426178195151ull, 15947866831716403979ull,
  14801564772723974480ull, 6482149047200176331ull}},
{{3958263264295356035ull, 1488089465935953358ull,
  13890269947477580197ull, 8102686309000220414ull}},
{{16308972595466761234ull, 3235898925423664800ull,
  4069732698746099719ull, 5064178943125137759ull}},
{{1939471670623899927ull, 17879931712061744713ull,
  475479855005236744ull, 6330223678906422199ull}},
{{7036025606707262812ull, 3903170566367629275ull,
  14429407874038709643ull, 7912779598633027748ull}},
{{2091672994978345306ull, 133638594766074345ull,
  18241751958128969335ull, 4945487249145642342ull}},
{{7226277262150319536ull, 14002106298739756643ull,
  13578817910806435860ull, 6181859061432052928ull}},
{{4421160559260511516ull, 17502632873424695804ull,
  16973522388508044825ull, 7727323826790066160ull}},
{{11986597386392595506ull, 4021616518249353021ull,
  10608451492817528016ull, 4829577391743791350ull}},
{{1148188677708580670ull, 5027020647811691277ull,
  4037192329167134212ull, 6036971739679739188ull}},
{{6046921865563113741ull, 6283775809764614096ull,
  5046490411458917765ull, 7546214674599673985ull}},
{{3779326165976946088ull, 6233202890316577762ull,
  14683271553230293363ull, 4716384171624796240ull}},
{{13947529744325958418ull, 3179817594468334298ull,
  18354089441537866704ull, 5895480214530995300ull}},
{{8211040143552672215ull, 3974771993085417873ull,
  4495867728212781764ull, 7369350268163744126ull}},
{{14875486197868228173ull, 4968464991356772341ull,
  14843206697120753013ull, 9211687835204680157ull}},
{{11603021882881336560ull, 5411133628811676665ull,
  11582847194914164585ull, 5757304897002925098ull}},
{{668719298319506988ull, 11375603054441983736ull,
  5255186956787929923ull, 7196631121253656373ull}},
{{835899122899383735ull, 9607817799625091766ull,
  11180669714412300308ull, 8995788901567070466ull}},
{{14357495007094278546ull, 15228258161620458161ull,
  11599604589935075596ull, 5622368063479419041ull}},
{{4111810703585684471ull, 588578628316021086ull, 664447682136680784ull,
  7027960079349273802ull}},
{{14363135416336881397ull, 735723285395026357ull,
  10053931639525626788ull, 8784950099186592252ull}},
{{11282802644424244825ull, 9683199090226667281ull,
  15507079311558292550ull, 5490593811991620157ull}},
{{268445250248142319ull, 2880626825928558294ull, 5548791084165701976ull,
  6863242264989525197ull}},
{{9558928599664953707ull, 3600783532410697867ull,
  11547674873634515374ull, 8579052831236906496ull}},
{{3668487365576902115ull, 16085547763038849879ull,
  7217296796021572108ull, 5361908019523066560ull}},
{{18420667262253291356ull, 1660190630089010732ull,
  9021620995026965136ull, 6702385024403833200ull}},
{{4579090004107062578ull, 2075238287611263416ull,
  11277026243783706420ull, 8377981280504791500ull}},
{{2861931252566914112ull, 10520395966611815443ull,
  16271513439219592320ull, 5236238300315494687ull}},
{{17412472120990806351ull, 13150494958264769303ull,
  15727705780597102496ull, 6545297875394368359ull}},
{{17153904132811120035ull, 16438118697830961629ull,
  15047946207318990216ull, 8181622344242960449ull}},
{{13027033092220643974ull, 10273824186144351018ull,
  2487437351933287029ull, 5113513965151850281ull}},
{{7060419328421029160ull, 17453966251107826677ull,
  7720982708343996690ull, 6391892456439812851ull}},
{{13437210178953674353ull, 12594085777030007538ull,
  5039542367002607959ull, 7989865570549766064ull}},
{{13009942380273434375ull, 14788832638284836567ull,
  3149713979376629974ull, 4993665981593603790ull}},
{{11650741956914405065ull, 9262668761001269901ull,
  13160514511075563276ull, 6242082476992004737ull}},
{{728369390860842619ull, 11578335951251587377ull,
  2615585083562290383ull, 7802603096240005922ull}},
{{11984445915356496397ull, 14153988997173323966ull,
  6246426695653819393ull, 4876626935150003701ull}},
{{5757185357340844688ull, 3857428191184491246ull,
  12419719387994662146ull, 6095783668937504626ull}},
{{16419853733530831668ull, 14045157275835389865ull,
  6301277198138551874ull, 7619729586171880783ull}},
{{3344879555815687937ull, 13389909315824506570ull,
  10855827276477676777ull, 4762330991357425489ull}},
{{13404471481624385729ull, 2902328589498469500ull,
  18181470114024483876ull, 5952913739196781861ull}},
{{16755589352030482161ull, 3627910736873086875ull,
  8891779587248441133ull, 7441142173995977327ull}},
{{8166400335805357399ull, 4573287219759373249ull,
  12474891269671357564ull, 4650713858747485829ull}},
{{14819686438184084652ull, 5716609024699216561ull,
  1758556031807033243ull, 5813392323434357287ull}},
{{4689549992447942103ull, 2534075262446632798ull,
  16033253095040955266ull, 7266740404292946608ull}},
{{15085309527414703437ull, 12390966114913066805ull,
  1594822295091642466ull, 9083425505366183261ull}},
{{11734161463847883600ull, 12356039840248054657ull,
  3302606943645970493ull, 5677140940853864538ull}},
{{832643774527690788ull, 1609991745027904610ull,
  13351630716412238925ull, 7096426176067330672ull}},
{{10264176755014389293ull, 6624175699712268666ull,
  16689538395515298656ull, 8870532720084163340ull}},
{{11026796490311381212ull, 4140109812320167916ull,
  1207589460342285852ull, 5544082950052602088ull}},
{{13783495612889226515ull, 5175137265400209895ull,
  1509486825427857315ull, 6930103687565752610ull}},
{{12617683497684145240ull, 1857235563322874465ull,
  11110230568639597452ull, 8662629609457190762ull}},
{{968523158411508919ull, 10384144263931572349ull,
  11555580123827136311ull, 5414143505910744226ull}},
{{5822339966441774053ull, 8368494311487077532ull,
  5221103117929144581ull, 6767679382388430283ull}},
{{7277924958052217566ull, 15072303907786234819ull,
  1914692878984042822ull, 8459599227985537854ull}},
{{2242860089568942027ull, 4808503923939008858ull,
  15031741104647190476ull, 5287249517490961158ull}},
{{12026947148815953341ull, 6010629904923761072ull,
  9566304343954212287ull, 6609061896863701448ull}},
{{15033683936019941677ull, 2901601362727313436ull,
  11957880429942765359ull, 8261327371079626810ull}},
{{172680423157687740ull, 8731029879345652754ull,
  12085361287141616253ull, 5163329606924766756ull}},
{{9439222565801885483ull, 15525473367609453846ull,
  15106701608927020316ull, 6454162008655958445ull}},
{{2575656170397581046ull, 960097635802265692ull, 5048318955876611684ull,
  8067702510819948057ull}},
{{10833157143353263962ull, 9823433059231191865ull,
  14684414393491352062ull, 5042314069262467535ull}},
{{18153132447618967856ull, 3055919287184214023ull,
  13743831973436802174ull, 6302892586578084419ull}},
{{18079729541096321916ull, 13043271145835043337ull,
  12568103948368614813ull, 7878615733222605524ull}},
{{4382301935544119342ull, 10457887475360596038ull,
  17078437004585160066ull, 4924134833264128452ull}},
{{14701249456284924985ull, 3848987307345969239ull,
  2901302182021898467ull, 6155168541580160566ull}},
{{13764875801928768327ull, 199548115755073645ull,
  12849999764382148892ull, 7693960676975200707ull}},
{{10908890385419174157ull, 9348089609201696836ull,
  5725406843525149105ull, 4808725423109500442ull}},
{{13636112981773967696ull, 16296798029929508949ull,
  16380130591261212189ull, 6010906778886875552ull}},
{{3210083171935295907ull, 6535939482129722475ull,
  2028419165366963621ull, 7513633473608594441ull}},
{{18147203046955417606ull, 6390805185544770498ull,
  12796977024422822023ull, 4696020921005371525ull}},
{{13460631771839496200ull, 3376820463503575219ull,
  2161163225246363817ull, 5870026151256714407ull}},
{{12214103696371982345ull, 8832711597806856928ull,
  16536512086840118483ull, 7337532689070893008ull}},
{{15267629620464977932ull, 6429203478831183256ull,
  2223896034840596488ull, 9171915861338616261ull}},
{{9542268512790611207ull, 4018252174269489535ull,
  3695778030989066757ull, 5732447413336635163ull}},
{{7316149622560876105ull, 9634501236264249823ull, 8036520308945542ull,
  7165559266670793954ull}},
{{4533501009773707227ull, 2819754508475536471ull,
  9233417687240957736ull, 8956949083338492442ull}},
{{9750967158749648873ull, 1762346567797210294ull,
  10382572072952986489ull, 5598093177086557776ull}},
{{2965336911582285284ull, 6814619228173900772ull,
  12978215091191233111ull, 6997616471358197220ull}},
{{3706671139477856604ull, 3906588016789988061ull,
  16222768863989041389ull, 8747020589197746525ull}},
{{4622512471387354330ull, 4747460519707436490ull,
  12445073549206844820ull, 5466887868248591578ull}},
{{15001512626088968720ull, 5934325649634295612ull,
  6332969899653780217ull, 6833609835310739473ull}},
{{305146708901659284ull, 12029593080470257420ull,
  12527898392994613175ull, 8542012294138424341ull}},
{{9414088729918312861ull, 14436024702934992743ull,
  10135779504835327186ull, 5338757683836515213ull}},
{{7155924893970503172ull, 8821658841813965121ull,
  17281410399471546887ull, 6673447104795644016ull}},
{{13556592135890516869ull, 6415387533840068497ull,
  3155018925629881993ull, 8341808880994555021ull}},
{{1555341057290491187ull, 15538832254718512571ull,
  4277729837732370197ull, 5213630550621596888ull}},
{{15779234376895277696ull, 5588482263115977001ull,
  5347162297165462747ull, 6517038188276996110ull}},
{{5888984915836933408ull, 2373916810467583348ull,
  15907324908311604242ull, 8146297735346245137ull}},
{{12903987609252859188ull, 6095384024969627496ull,
  3024549040053670795ull, 5091436084591403211ull}},
{{16129984511566073985ull, 3007544012784646466ull,
  17615744355349252206ull, 6364295105739254013ull}},
{{10939108602602816673ull, 12982802052835583891ull,
  8184622388904401545ull, 7955368882174067517ull}},
{{4531099867413066469ull, 1196722255381158076ull,
  7421232002278944918ull, 4972105551358792198ull}},
{{5663874834266333086ull, 10719274856081223403ull, 53167965993905339ull,
  6215131939198490248ull}},
{{2468157524405528453ull, 8787407551674141350ull, 66459957492381674ull,
  7768914923998112810ull}},
{{15377656508035618995ull, 10103815738223726247ull,
  4653223491860126450ull, 4855571827498820506ull}},
{{14610384616617135840ull, 3406397635924882001ull,
  15039901401679933871ull, 6069464784373525632ull}},
{{4427922715489256088ull, 18093055100188266214ull,
  353132678390365722ull, 7586830980466907041ull}},
{{16602509752462948767ull, 15919845456045054287ull,
  11749922970062448336ull, 4741769362791816900ull}},
{{16141451172151298055ull, 1453062746346766243ull,
  14687403712578060421ull, 5927211703489771125ull}},
{{15565127946761734664ull, 6428014451360845708ull,
  4524196585440411814ull, 7409014629362213907ull}},
{{504832929871308357ull, 17852567087382692280ull, 521779856686563431ull,
  4630634143351383692ull}},
{{631041162339135447ull, 17704022840800977446ull, 652224820858204289ull,
  5788292679189229615ull}},
{{10012173489778695116ull, 8294970495719058095ull,
  14650339081354919074ull, 7235365848986537018ull}},
{{7903530843795980991ull, 1145341082794046811ull,
  9089551814838873035ull, 9044207311233171273ull}},
{{2633863768158794168ull, 16856739241242136921ull,
  17210184930342765406ull, 5652629569520732045ull}},
{{7904015728625880613ull, 11847552014697895343ull,
  7677673107646293046ull, 7065786961900915057ull}},
{{5268333642354962863ull, 5586067981517593371ull,
  14208777402985254212ull, 8832233702376143821ull}},
{{986865517258157837ull, 12714664525303271665ull,
  11186328886079477834ull, 5520146063985089888ull}},
{{5845267915000085201ull, 6669958619774313773ull,
  13982911107599347293ull, 6900182579981362360ull}},
{{11918270912177494405ull, 12949134293145280120ull,
  17478638884499184116ull, 8625228224976702950ull}},
{{7448919320110934003ull, 17316580970070575883ull,
  6312463284384602168ull, 5390767640610439344ull}},
{{4699463131711279600ull, 3198982138878668238ull,
  7890579105480752711ull, 6738459550763049180ull}},
{{15097700951493875308ull, 17833785728880499009ull,
  9863223881850940888ull, 8423074438453811475ull}},
{{2518534067042590211ull, 11146116080550311881ull,
  3858671916943144103ull, 5264421524033632172ull}},
{{7759853602230625668ull, 9320959082260501947ull,
  4823339896178930129ull, 6580526905042040215ull}},
{{5088130984360894181ull, 16262884871253015338ull,
  1417488851796274757ull, 8225658631302550269ull}},
{{7791767883652946767ull, 12470146053746828538ull,
  3191773541586365675ull, 5141036644564093918ull}},
{{516337817711407651ull, 10975996548756147769ull,
  13213088963837732902ull, 6426295805705117397ull}},
{{5257108290566647468ull, 4496623649090408903ull,
  2681303149515002416ull, 8032869757131396747ull}},
{{10203221709245236523ull, 2810389780681505564ull,
  17816715532942734174ull, 5020543598207122966ull}},
{{12754027136556545654ull, 12736359262706657763ull,
  13047522379323641909ull, 6275679497758903708ull}},
{{11330847902268294164ull, 2085391023101158492ull,
  16309402974154552387ull, 7844599372198629635ull}},
{{16305151975772459660ull, 17444270453934081721ull,
  7887533849632901289ull, 4902874607624143522ull}},
{{6546381914433410863ull, 7970280012135438440ull, 636045275186350804ull,
  6128593259530179403ull}},
{{8182977393041763579ull, 9962850015169298050ull,
  14630114649265102217ull, 7660741574412724253ull}},
{{9726046889078490141ull, 17755996305549281041ull,
  11449664665004382837ull, 4787963484007952658ull}},
{{16769244629775500580ull, 8359937326654437589ull,
  5088708794400702739ull, 5984954355009940823ull}},
{{7126497731937212013ull, 5838235639890659083ull,
  1749199974573490520ull, 7481192943762426029ull}},
{{2148218073247063557ull, 3648897274931661927ull,
  3399092993322125527ull, 4675745589851516268ull}},
{{16520330646840993158ull, 18396179648946741120ull,
  4248866241652656908ull, 5844681987314395335ull}},
{{2203669234841689831ull, 4548480487473874785ull, 699396783638433232ull,
  7305852484142994169ull}},
{{7366272561979500192ull, 5685600609342343481ull,
  5485931997975429444ull, 9132315605178742711ull}},
{{16133135397305657380ull, 12776872417693740483ull,
  10346236526375725258ull, 5707697253236714194ull}},
{{15554733228204683821ull, 6747718485262399796ull,
  3709423621114880765ull, 7134621566545892743ull}},
{{996672461546303161ull, 13046334125005387650ull, 25093507966213052ull,
  8918276958182365929ull}},
{{5234606306893827380ull, 17377330864983143089ull,
  11544898488547352917ull, 5573923098863978705ull}},
{{11154943902044672128ull, 7886605525946765149ull,
  596065055402027435ull, 6967403873579973382ull}},
{{108621822273676448ull, 5246570889006068533ull, 9968453356107310102ull,
  8709254841974966727ull}},
{{2373731648134741732ull, 17114164860910956545ull,
  13147812375208150669ull, 5443284276234354204ull}},
{{7578850578595815069ull, 7557648020856531969ull,
  16434765469010188337ull, 6804105345292942755ull}},
{{14085249241672156741ull, 14058746044498052865ull,
  15931770817835347517ull, 8505131681616178444ull}},
{{1885751748404016107ull, 11092559287024976993ull,
  733984724292316390ull, 5315707301010111528ull}},
{{6968875703932408038ull, 4642327071926445433ull, 917480905365395488ull,
  6644634126262639410ull}},
{{13322780648342897951ull, 5802908839908056791ull,
  10370223168561520168ull, 8305792657828299262ull}},
{{15244266932855393076ull, 3626818024942535494ull,
  1869703461923562201ull, 5191120411142687039ull}},
{{9831961629214465536ull, 9145208549605557272ull,
  16172187382686616463ull, 6488900513928358798ull}},
{{12289952036518081920ull, 6819824668579558686ull,
  10991862191503494771ull, 8111125642410448498ull}},
{{3069534004396413296ull, 1956547408648530227ull,
  11481599888117072136ull, 5069453526506530311ull}},
{{17671975560777680332ull, 2445684260810662783ull,
  9740313841718952266ull, 6336816908133162889ull}},
{{17478283432544712511ull, 12280477362868104287ull,
  16787078320576078236ull, 7921021135166453611ull}},
{{17841456172981527176ull, 16898670388647340987ull,
  8186080941146354945ull, 4950638209479033507ull}},
{{17690134197799521066ull, 7288279930527012522ull,
  5620915158005555778ull, 6188297761848791884ull}},
{{12889295710394625524ull, 18333721950013541461ull,
  7026143947506944722ull, 7735372202310989855ull}},
{{10361652828210334905ull, 16070262237185851317ull,
  11308868994832922307ull, 4834607626444368659ull}},
{{17563752053690306535ull, 15476141778054926242ull,
  9524400225113764980ull, 6043259533055460824ull}},
{{12731318030258107360ull, 898433148859106187ull,
  11905500281392206226ull, 7554074416319326030ull}},
{{5651230759697623148ull, 5173206736464329271ull,
  2829251657442740987ull, 4721296510199578769ull}},
{{2452352431194641031ull, 1854822402153023685ull,
  8148250590230814138ull, 5901620637749473461ull}},
{{7677126557420689193ull, 11541900039546055414ull,
  14796999256215905576ull, 7377025797186841826ull}},
{{373036159921085683ull, 14427375049432569268ull,
  9272877033415106162ull, 9221282246483552283ull}},
{{9456519636805454360ull, 13628795424322743696ull,
  3489705136670747399ull, 5763301404052220177ull}},
{{11820649546006817950ull, 12424308261976041716ull,
  8973817439265822153ull, 7204126755065275221ull}},
{{14775811932508522437ull, 1695327272187888433ull,
  15828957817509665596ull, 9005158443831594026ull}},
{{2317353430176744667ull, 10282951581972206079ull,
  14504784654370928901ull, 5628224027394746266ull}},
{{16731749843003094546ull, 17465375495892645502ull,
  8907608781108885318ull, 7035280034243432833ull}},
{{11691315266899092375ull, 12608347333011031070ull,
  15746196994813494552ull, 8794100042804291041ull}},
{{2695386023384544830ull, 7880217083131894419ull,
  2923844094117352239ull, 5496312526752681901ull}},
{{17204290584512844750ull, 5238585335487480119ull,
  8266491136074078203ull, 6870390658440852376ull}},
{{16893677212213668033ull, 1936545650931962245ull,
  10333113920092597754ull, 8587988323051065470ull}},
{{12864391266847236473ull, 5822027050259864307ull,
  1846510181630485692ull, 5367492701906915919ull}},
{{11468803065131657687ull, 7277533812824830384ull,
  16143195782320270827ull, 6709365877383644898ull}},
{{14336003831414572109ull, 4485231247603650076ull,
  10955622691045562726ull, 8386707346729556123ull}},
{{18183374431488883376ull, 16638327585034445009ull,
  4541421172689782751ull, 5241692091705972577ull}},
{{8894159984078940508ull, 16186223462865668358ull,
  10288462484289616343ull, 6552115114632465721ull}},
{{1894327943243899827ull, 15621093310154697544ull,
  17472264123789408333ull, 8190143893290582151ull}},
{{1183954964527437392ull, 12069026328060379917ull,
  17837694105009462064ull, 5118839933306613844ull}},
{{6091629724086684644ull, 15086282910075474896ull,
  3850373557552275964ull, 6398549916633267306ull}},
{{7614537155108355805ull, 411109563884792004ull,
  14036338983795120764ull, 7998187395791584132ull}},
{{13982457758797498186ull, 9480315514282770810ull,
  17996083901726726285ull, 4998867122369740082ull}},
{{8254700161642096924ull, 16462080411280851417ull,
  13271732840303632048ull, 6248583902962175103ull}},
{{14930061220480009059ull, 2130856440391512655ull,
  11977980031952152157ull, 7810729878702718879ull}},
{{16248817290441087518ull, 3637628284458389361ull,
  14403766547611176954ull, 4881706174189199299ull}},
{{6475963557769195686ull, 13770407392427762510ull,
  13393022166086583288ull, 6102132717736499124ull}},
{{17318326484066270415ull, 17213009240534703137ull,
  16741277707608229110ull, 7627665897170623905ull}},
{{3906425024900337154ull, 6146444756906801557ull,
  3545769539614061338ull, 4767291185731639941ull}},
{{9494717299552809346ull, 16906427982988277754ull,
  9043897942944964576ull, 5959113982164549926ull}},
{{2645024587586235874ull, 2686290905025795577ull,
  2081500391826429913ull, 7448892477705687408ull}},
{{13182355413309867182ull, 13208146861709591995ull,
  1300937744891518695ull, 4655557798566054630ull}},
{{11866258248209946073ull, 11898497558709602090ull,
  10849544217969174177ull, 5819447248207568287ull}},
{{5609450773407656783ull, 1038063893104838901ull,
  8950244254034079818ull, 7274309060259460359ull}},
{{11623499485186958883ull, 10520951903235824434ull,
  6576119299115211868ull, 9092886325324325449ull}},
{{11876373196669237206ull, 15798966976377166079ull,
  15639289608015477177ull, 5683053953327703405ull}},
{{10233780477409158603ull, 5913650665189293887ull,
  5714053954737182760ull, 7103817441659629257ull}},
{{8180539578334060350ull, 7392063331486617359ull,
  11754253461848866354ull, 8879771802074536571ull}},
{{12030366264099869575ull, 9231725600606523753ull,
  5040565404441847519ull, 5549857376296585357ull}},
{{1202899774842673256ull, 6927970982330766788ull,
  10912392773979697303ull, 6937321720370731696ull}},
{{1503624718553341570ull, 4048277709486070581ull,
  13640490967474621629ull, 8671652150463414620ull}},
{{3245608458309532434ull, 4836016577642488065ull,
  17748678891526414326ull, 5419782594039634137ull}},
{{8668696591314303446ull, 15268392758907885889ull,
  8350790559125854195ull, 6774728242549542672ull}},
{{15447556757570267211ull, 14473804930207469457ull,
  10438488198907317744ull, 8468410303186928340ull}},
{{2737193945840335151ull, 9046128081379668411ull,
  15747427161171849398ull, 5292756439491830212ull}},
{{17256550487582582651ull, 2084288064869809705ull,
  1237539877755260132ull, 6615945549364787766ull}},
{{7735630054196064602ull, 2605360081087262132ull,
  10770296884048850973ull, 8269931936705984707ull}},
{{14058140820727316184ull, 3934193059893232784ull,
  4425592543316837906ull, 5168707460441240442ull}},
{{17572676025909145230ull, 14141113361721316788ull,
  14755362716000823190ull, 6460884325551550552ull}},
{{3519100958676879922ull, 8453019665296870178ull,
  18444203395001028988ull, 8076105406939438190ull}},
{{6811124117600437855ull, 14506509327665319669ull,
  6915941103448255213ull, 5047565879337148869ull}},
{{13125591165427935223ull, 4298078604299485874ull,
  13256612397737706921ull, 6309457349171436086ull}},
{{7183616919930143220ull, 9984284273801745247ull,
  7347393460317357843ull, 7886821686464295108ull}},
{{11407289602597421369ull, 3934334661912396827ull,
  13815492949553124460ull, 4929263554040184442ull}},
{{9647425984819388807ull, 4917918327390496034ull,
  8045994150086629767ull, 6161579442550230553ull}},
{{2835910444169460201ull, 1535711890810732139ull,
  14669178706035675113ull, 7701974303187788191ull}},
{{17913345092101770290ull, 12489034977825177346ull,
  16085765718913378801ull, 4813733939492367619ull}},
{{13168309328272437054ull, 1776235666999307971ull,
  15495521130214335598ull, 6017167424365459524ull}},
{{11848700641913158413ull, 11443666620603910772ull,
  922657339058367881ull, 7521459280456824406ull}},
{{16628809938050499816ull, 234762610236362376ull,
  14411718892193643638ull, 4700912050285515253ull}},
{{2339268348853573154ull, 9516825299650228779ull,
  4179590559959890835ull, 5876140062856894067ull}},
{{16759143491349130155ull, 7284345606135398069ull,
  612802181522475640ull, 7345175078571117584ull}},
{{7113871308904248982ull, 9105432007669247587ull, 766002726903094550ull,
  9181468848213896980ull}},
{{2140326558851461662ull, 1079208986365891838ull,
  9702123741169209902ull, 5738418030133685612ull}},
{{11898780235419102885ull, 10572383269812140605ull,
  12127654676461512377ull, 7173022537667107015ull}},
{{1038417238991714894ull, 17827165105692563661ull,
  10547882327149502567ull, 8966278172083883769ull}},
{{2954853783583515761ull, 18059507218698934144ull,
  18121641500536908864ull, 5603923857552427355ull}},
{{3693567229479394701ull, 4127639949664116064ull,
  18040365857243748177ull, 7004904821940534194ull}},
{{4616959036849243376ull, 9771235955507532984ull,
  13327085284699909413ull, 8756131027425667743ull}},
{{2885599398030777110ull, 8412865481405902067ull,
  15246957330578525239ull, 5472581892141042339ull}},
{{17442057302820635100ull, 5904395833329989679ull,
  14447010644795768645ull, 6840727365176302924ull}},
{{17190885610098405971ull, 11992180810089875003ull,
  18058763305994710806ull, 8550909206470378655ull}},
{{8438460497097809780ull, 2883426987878783973ull,
  18204256093887776110ull, 5344318254043986659ull}},
{{15159761639799650129ull, 12827655771703255774ull,
  18143634098932332233ull, 6680397817554983324ull}},
{{9726330012894786853ull, 2199511659346906006ull,
  4232798549955863676ull, 8350497271943729156ull}},
{{1467270239631853879ull, 10598066823946592062ull,
  11868871130577190605ull, 5219060794964830722ull}},
{{11057459836394593157ull, 17859269548360627981ull,
  5612716876366712448ull, 6523825993706038403ull}},
{{18433510813920629350ull, 3877342861741233360ull,
  2404210077031002657ull, 8154782492132548004ull}},
{{11520944258700393344ull, 13952554334656740610ull,
  10726003334999152468ull, 5096739057582842502ull}},
{{5177808286520715872ull, 17440692918320925763ull,
  4184132131894164777ull, 6370923821978553128ull}},
{{1860574339723506935ull, 7965808092618993492ull,
  5230165164867705972ull, 7963654777473191410ull}},
{{10386230999181967643ull, 14202002094741646740ull,
  7880539246469704136ull, 4977284235920744631ull}},
{{12982788748977459553ull, 17752502618427058425ull,
  5238988039659742266ull, 6221605294900930789ull}},
{{2393427880939660730ull, 12967256236179047224ull,
  11160421068002065737ull, 7777006618626163486ull}},
{{1495892425587287956ull, 1187006119970822659ull,
  2363577149073903182ull, 4860629136641352179ull}},
{{15704923587266273657ull, 10707129686818304131ull,
  16789529491624542689ull, 6075786420801690223ull}},
{{15019468465655454167ull, 17995598126950268068ull,
  16375225846103290457ull, 7594733026002112779ull}},
{{163795754179883047ull, 4329719801702835687ull, 7928673144600862584ull,
  4746708141251320487ull}},
{{14039802748007017520ull, 5412149752128544608ull,
  5299155412323690326ull, 5933385176564150609ull}},
{{17549753435008771900ull, 15988559227015456568ull,
  11235630283832000811ull, 7416731470705188261ull}},
{{10968595896880482438ull, 7687006507670966403ull,
  9328111936608694459ull, 4635457169190742663ull}},
{{9099058852673215143ull, 4997072116161320100ull,
  7048453902333480170ull, 5794321461488428329ull}},
{{11373823565841518929ull, 15469712182056425933ull,
  13422253396344238116ull, 7242901826860535411ull}},
{{382221402019734949ull, 890396153860980801ull, 12166130727002909742ull,
  9053627283575669264ull}},
{{11768103422330804103ull, 14391555651445276712ull,
  7603831704376818588ull, 5658517052234793290ull}},
{{14710129277913505129ull, 17989444564306595890ull,
  281417593616247427ull, 7073146315293491613ull}},
{{9164289560537105603ull, 17875119686955856959ull,
  4963458010447697188ull, 8841432894116864516ull}},
{{12645210002976772858ull, 1948577767492634791ull,
  12325533293384586551ull, 5525895558823040322ull}},
{{11194826485293578169ull, 16270780264647957201ull,
  6183544579875957380ull, 6907369448528800403ull}},
{{158475051334808999ull, 1891731257100394886ull, 3117744706417558822ull,
  8634211810661000504ull}},
{{13934104962366419336ull, 15017390090969910515ull,
  1948590441510974263ull, 5396382381663125315ull}},
{{12805945184530636266ull, 14160051595285000240ull,
  16270796107170881541ull, 6745477977078906643ull}},
{{16007431480663295333ull, 3865006438824086588ull,
  15726809115536214023ull, 8431847471348633304ull}},
{{781272638559783775ull, 9333158051906135974ull, 9829255697210133764ull,
  5269904669592895815ull}},
{{10199962835054505527ull, 11666447564882669967ull,
  7674883603085279301ull, 6587380836991119769ull}},
{{8138267525390744004ull, 748001400821173747ull,
  14205290522283987031ull, 8234226046238899711ull}},
{{2780574194155521051ull, 7385029903154315448ull,
  15795835604068573750ull, 5146391278899312319ull}},
{{3475717742694401313ull, 7915342088118502ull, 15133108486658329284ull,
  6432989098624140399ull}},
{{13568019215222777450ull, 9894177610148127ull, 14304699589895523701ull,
  8041236373280175499ull}},
{{15397541037155317762ull, 2312026870220036531ull,
  6634594234471008361ull, 5025772733300109687ull}},
{{14635240278016759299ull, 7501719606202433568ull,
  3681556774661372547ull, 6282215916625137109ull}},
{{18294050347520949123ull, 4765463489325654056ull,
  9213631986754103588ull, 7852769895781421386ull}},
{{11433781467200593202ull, 12201786717683309593ull,
  10370206010148702646ull, 4907981184863388366ull}},
{{457168778718577791ull, 6028861360249361184ull, 3739385475831102500ull,
  6134976481079235458ull}},
{{571460973398222238ull, 7536076700311701480ull,
  13897603881643653933ull, 7668720601349044322ull}},
{{357163108373888899ull, 7015890946908507377ull,
  13297688444454671612ull, 4792950375843152701ull}},
{{5058139903894749028ull, 8769863683635634221ull,
  2787052500286175803ull, 5991187969803940877ull}},
{{10934360898295824189ull, 6350643586117154872ull,
  8095501643785107658ull, 7488984962254926096ull}},
{{6833975561434890118ull, 8580838259750609699ull,
  5059688527365692286ull, 4680615601409328810ull}},
{{3930783433366224743ull, 1502675787833486316ull,
  15547982696061891166ull, 5850769501761661012ull}},
{{4913479291707780929ull, 11101716771646633703ull,
  988234296367812341ull, 7313461877202076266ull}},
{{1530163096207338257ull, 42087909276128417ull, 10458664907314541235ull,
  9141827346502595332ull}},
{{12485566981198056171ull, 16167206007793437924ull,
  15760037603926364079ull, 5713642091564122082ull}},
{{15606958726497570214ull, 15597321491314409501ull,
  10476674968053179291ull, 7142052614455152603ull}},
{{5673640352839799055ull, 14884965845715623973ull,
  8484157691639086210ull, 8927565768068940754ull}},
{{5851868229738568361ull, 13914789671999652887ull,
  9914284575701816785ull, 5579728605043087971ull}},
{{2703149268745822548ull, 3558429034717402397ull,
  7781169701199883078ull, 6974660756303859964ull}},
{{7990622604359666089ull, 13671408330251528804ull,
  9726462126499853847ull, 8718325945379824955ull}},
{{14217511164579567114ull, 15462159234048287358ull,
  3773195819848714702ull, 5448953715862390597ull}},
{{8548516918869683084ull, 10104327005705583390ull,
  9328180793238281282ull, 6811192144827988246ull}},
{{1462274111732328047ull, 3407036720277203430ull,
  2436853954693075795ull, 8513990181034985308ull}},
{{14748979375114868741ull, 18270299014669109807ull,
  10746405758537948179ull, 5321243863146865817ull}},
{{13824538200466198023ull, 18226187749908999355ull,
  18044693216599823128ull, 6651554828933582271ull}},
{{12668986732155359624ull, 4335990613676697578ull,
  17944180502322391007ull, 8314443536166977839ull}},
{{12529802726024487669ull, 9627523161189017842ull,
  18132641841592576235ull, 5196527210104361149ull}},
{{6438881370675833778ull, 7422717933058884399ull,
  8830744246708556582ull, 6495659012630451437ull}},
{{3436915694917404319ull, 55025379468829691ull, 15650116326813083632ull,
  8119573765788064296ull}},
{{18288973373819235363ull, 34390862168018556ull, 9781322704258177270ull,
  5074733603617540185ull}},
{{4414472643564492588ull, 9266360614564799004ull,
  16838339398750109491ull, 6343417004521925231ull}},
{{5518090804455615735ull, 6971264749778610851ull,
  16436238230010248960ull, 7929271255652406539ull}},
{{1142963743571065883ull, 4357040468611631782ull,
  7966805884542711648ull, 4955794534782754087ull}},
{{10652076716318608161ull, 5446300585764539727ull,
  5346821337251001656ull, 6194743168478442609ull}},
{{8703409876970872297ull, 6807875732205674659ull,
  11295212689991139974ull, 7743428960598053261ull}},
{{3133788163893101234ull, 18089980387910710374ull,
  9365350940458156435ull, 4839643100373783288ull}},
{{13140607241721152350ull, 18000789466461000063ull,
  11706688675572695544ull, 6049553875467229110ull}},
{{11814073033724052534ull, 4054242759366698463ull,
  5409988807611093623ull, 7561942344334036388ull}},
{{14301324673718614690ull, 9451430752245268395ull,
  12604615041611709322ull, 4726213965208772742ull}},
{{13264969823720880458ull, 2590916403451809686ull,
  6532396765159860845ull, 5907767456510965928ull}},
{{7357840242796324765ull, 7850331522742150012ull,
  8165495956449826056ull, 7384709320638707410ull}},
{{13822022188602478786ull, 4906457201713843757ull,
  9715120991208529189ull, 4615443325399192131ull}},
{{3442469680470934770ull, 10744757520569692601ull,
  7532215220583273582ull, 5769304156748990164ull}},
{{8914773119016056367ull, 4207574863857339943ull,
  9415269025729091978ull, 7211630195936237705ull}},
{{6531780380342682555ull, 14482840616676450737ull,
  16380772300588752876ull, 9014537744920297131ull}},
{{15611577783782646357ull, 18275147422277557518ull,
  7932139678654276595ull, 5634086090575185707ull}},
{{10291100192873532138ull, 18232248259419558994ull,
  5303488579890457840ull, 7042607613218982134ull}},
{{3640503204237139364ull, 4343566250564897127ull,
  15852732761717848109ull, 8803259516523727667ull}},
{{9192843530289293959ull, 5020571915816754656ull,
  7602114966859961116ull, 5502037197827329792ull}},
{{11491054412861617448ull, 6275714894770943320ull,
  9502643708574951395ull, 6877546497284162240ull}},
{{14363818016077021810ull, 3232957600036291246ull,
  11878304635718689244ull, 8596933121605202800ull}},
{{4365700241620750728ull, 11243970536877457837ull,
  7423940397324180777ull, 5373083201003251750ull}},
{{10068811320453326313ull, 219905115814658584ull, 56553459800450164ull,
  6716354001254064688ull}},
{{12586014150566657892ull, 274881394768323230ull, 70691824750562705ull,
  8395442501567580860ull}},
{{3254572825676773279ull, 11701015917798671779ull,
  9267554427323877498ull, 5247151563479738037ull}},
{{17903274087378130310ull, 5402897860393563915ull,
  16196129052582234777ull, 6558939454349672546ull}},
{{17767406590795274983ull, 11365308343919342798ull,
  11021789278873017663ull, 8198674317937090683ull}},
{{6492943100819658961ull, 14020846742590671105ull,
  4582775290081942087ull, 5124171448710681677ull}},
{{12727864894451961605ull, 12914372409810950977ull,
  10340155131029815513ull, 6405214310888352096ull}},
{{2074773062782788294ull, 2307907456981525010ull,
  12925193913787269392ull, 8006517888610440120ull}},
{{5908419182666630588ull, 1442442160613453131ull,
  8078246196117043370ull, 5004073680381525075ull}},
{{2773837959905900331ull, 11026424737621592222ull,
  5486121726718916308ull, 6255092100476906344ull}},
{{12690669486737151221ull, 13783030922026990277ull,
  6857652158398645385ull, 7818865125596132930ull}},
{{10237511438424413466ull, 1696865298625787067ull,
  8897718617426541270ull, 4886790703497583081ull}},
{{8185203279603128928ull, 11344453660137009642ull,
  15733834290210564491ull, 6108488379371978851ull}},
{{1008132062649135352ull, 9568881056743874149ull,
  15055606844335817710ull, 7635610474214973564ull}},
{{2935925548369403547ull, 1368864642037533439ull, 186382240855110261ull,
  4772256546384358478ull}},
{{17504964990743918146ull, 6322766820974304702ull,
  9456349837923663634ull, 5965320682980448097ull}},
{{12657834201575121874ull, 17126830563072656686ull,
  16432123315831967446ull, 7456650853725560121ull}},
{{3299460357557063267ull, 6092583083493022525ull,
  3352548044753897798ull, 4660406783578475076ull}},
{{8736011465373716988ull, 16839100891221053964ull,
  4190685055942372247ull, 5825508479473093845ull}},
{{10920014331717146235ull, 16437190095598929551ull,
  9850042338355353213ull, 7281885599341367306ull}},
{{9038331896219044890ull, 6711429564216498227ull,
  3089180886089415709ull, 9102356999176709133ull}},
{{3343114425923209104ull, 6500486486849005344ull,
  4236581063019578770ull, 5688973124485443208ull}},
{{4178893032404011380ull, 17348980145416032488ull,
  5295726328774473462ull, 7111216405606804010ull}},
{{5223616290505014225ull, 12462853144915264802ull,
  15843029947822867636ull, 8889020507008505012ull}},
{{7876446199993021795ull, 17012655252426816309ull,
  678521680534516464ull, 5555637816880315633ull}},
{{14457243768418665147ull, 2819074991823968770ull,
  5459838119095533485ull, 6944547271100394541ull}},
{{8848182673668555626ull, 8135529758207348867ull,
  11436483667296804760ull, 8680684088875493176ull}},
{{3224271161829153314ull, 5084706098879593042ull,
  7147802292060502975ull, 5425427555547183235ull}},
{{13253710989141217451ull, 1744196605172103398ull,
  4323066846648240815ull, 6781784444433979044ull}},
{{7343766699571746006ull, 16015303811747292960ull,
  5403833558310301018ull, 8477230555542473805ull}},
{{4589854187232341254ull, 14621250900769446004ull,
  5683238983157632088ull, 5298269097214046128ull}},
{{5737317734040426567ull, 18276563625961807505ull,
  7104048728947040110ull, 6622836371517557660ull}},
{{11783333185977921113ull, 13622332495597483573ull,
  8880060911183800138ull, 8278545464396947075ull}},
{{9670426250449894648ull, 13125643828175815137ull,
  3244195060276181134ull, 5174090915248091922ull}},
{{16699718831489756213ull, 7183682748364993113ull,
  13278615862200002226ull, 6467613644060114902ull}},
{{7039590484080031555ull, 18202975472311017200ull,
  7374897790895226974ull, 8084517055075143628ull}},
{{4399744052550019722ull, 6765173651766997846ull,
  13832683156164292667ull, 5052823159421964767ull}},
{{14723052102542300460ull, 3844781046281359403ull,
  12679167926777977930ull, 6316028949277455959ull}},
{{13792129109750487671ull, 14029348344706475062ull,
  11237273890045084508ull, 7895036186596819949ull}},
{{4008394675166666891ull, 17991714752296322722ull,
  9329139190491871769ull, 4934397616623012468ull}},
{{14233865380813109421ull, 8654585385088239690ull,
  11661423988114839712ull, 6167997020778765585ull}},
{{8568959689161610968ull, 10818231731360299613ull,
  741721929861385928ull, 7709996275973456982ull}},
{{7661442814939700807ull, 6761394832100187258ull,
  14298634261445529917ull, 4818747672483410613ull}},
{{353431481819850201ull, 13063429558552621977ull,
  4038234771524748684ull, 6023434590604263267ull}},
{{5053475370702200655ull, 16329286948190777471ull,
  436107445978547951ull, 7529293238255329084ull}},
{{10075951134329957266ull, 17123333370260317775ull,
  9495939190591368277ull, 4705808273909580677ull}},
{{7983252899485058678ull, 7569108657543233507ull,
  16481610006666598251ull, 5882260342386975846ull}},
{{5367380105928935443ull, 4849699803501653980ull,
  11378640471478472006ull, 7352825427983719808ull}},
{{6709225132411169304ull, 15285496791231843283ull,
  14223300589348090007ull, 9191031784979649760ull}},
{{1887422698543286863ull, 16470964522160983908ull,
  8889562868342556254ull, 5744394865612281100ull}},
{{2359278373179108579ull, 11365333615846454077ull,
  11111953585428195318ull, 7180493582015351375ull}},
{{7560783984901273627ull, 4983294982953291788ull,
  9278255963357856244ull, 8975616977519189219ull}},
{{13948862027418071825ull, 12337931401200583175ull,
  3493066967884966200ull, 5609760610949493262ull}},
{{12824391515845201878ull, 15422414251500728969ull,
  13589705746710983558ull, 7012200763686866577ull}},
{{2195431339524338635ull, 10054645777521135404ull,
  3152074128106565736ull, 8765250954608583222ull}},
{{10595516624057487455ull, 6284153610950709627ull,
  15805104385348767297ull, 5478281846630364513ull}},
{{8632709761644471415ull, 12466878032115774938ull,
  5921322426403795409ull, 6847852308287955642ull}},
{{1567515165200813460ull, 1748539484862554961ull,
  16625025069859520070ull, 8559815385359944552ull}},
{{12508912024318978173ull, 14927895233321260562ull,
  10390640668662200043ull, 5349884615849965345ull}},
{{6412767993543946908ull, 14048183023224187799ull,
  17599986854255137958ull, 6687355769812456681ull}},
{{3404273973502545731ull, 8336856742175458941ull,
  8164925512536758736ull, 8359194712265570852ull}},
{{4433514242652785034ull, 5210535463859661838ull,
  14326450482190250018ull, 5224496695165981782ull}},
{{14765264840170757100ull, 15736541366679353105ull,
  8684691065883036714ull, 6530620868957477228ull}},
{{4621522994931282663ull, 10447304671494415574ull,
  10855863832353795893ull, 8163276086196846535ull}},
{{16723509927114215377ull, 8835408428897703685ull,
  13702443922862204289ull, 5102047553873029084ull}},
{{7069329353610605509ull, 15655946554549517511ull,
  17128054903577755361ull, 6377559442341286355ull}},
{{4224975673585868982ull, 5734875137904733177ull,
  16798382611044806298ull, 7971949302926607944ull}},
{{14169824842059637874ull, 8195982979617846139ull,
  10498989131903003936ull, 4982468314329129965ull}},
{{13100595034147159438ull, 10244978724522307674ull,
  17735422433306142824ull, 6228085392911412456ull}},
{{7152371755829173489ull, 12806223405652884593ull,
  3722533967923126914ull, 7785106741139265571ull}},
{{15999447393461703191ull, 12615575646960440774ull,
  20740720738260369ull, 4865691713212040982ull}},
{{10775937204972353181ull, 1934411503418387256ull,
  9249297937777601270ull, 6082114641515051227ull}},
{{13469921506215441476ull, 11641386416127759878ull,
  6949936403794613683ull, 7602643301893814034ull}},
{{3807014922957263019ull, 4970023500866155972ull,
  8955396270799021456ull, 4751652063683633771ull}},
{{4758768653696578773ull, 6212529376082694965ull,
  6582559320071388916ull, 5939565079604542214ull}},
{{10560146835548111370ull, 7765661720103368706ull,
  17451571186944011953ull, 7424456349505677767ull}},
{{11211777790644957511ull, 16382753621133075201ull,
  17824761019481089326ull, 4640285218441048604ull}},
{{179664183024033176ull, 11255069989561568194ull,
  3834207200641810042ull, 5800356523051310756ull}},
{{9447952265634817278ull, 4845465450097184434ull,
  4792759000802262553ull, 7250445653814138445ull}},
{{2586568295188745789ull, 10668517831048868447ull,
  10602634769430216095ull, 9063057067267673056ull}},
{{8534134212134047975ull, 13585352672046624635ull,
  6626646730893885059ull, 5664410667042295660ull}},
{{6055981746740172064ull, 12370004821630892890ull,
  8283308413617356324ull, 7080513333802869575ull}},
{{16793349220279990888ull, 15462506027038616112ull,
  5742449498594307501ull, 8850641667253586969ull}},
{{10495843262674994305ull, 11969909276112829022ull,
  15118245982689911948ull, 5531651042033491855ull}},
{{3896432041488967073ull, 14962386595141036278ull,
  14286121459935002031ull, 6914563802541864819ull}},
{{14093912088715984649ull, 14091297225498907443ull,
  13245965806491364635ull, 8643204753177331024ull}},
{{6502852046233796454ull, 6501217756723123200ull,
  8278728629057102897ull, 5402002970735831890ull}},
{{8128565057792245568ull, 12738208214331291904ull,
  1125038749466602813ull, 6752503713419789863ull}},
{{10160706322240306959ull, 2087702212631951168ull,
  15241356492115417229ull, 8440629641774737328ull}},
{{6350441451400191850ull, 3610656892108663432ull,
  9525847807572135768ull, 5275393526109210830ull}},
{{7938051814250239812ull, 4513321115135829290ull,
  2683937722610393902ull, 6594241907636513538ull}},
{{699192730958023957ull, 14865023430774562421ull,
  12578294190117768185ull, 8242802384545641922ull}},
{{2742838466062458925ull, 2373110616593019657ull,
  12473119887250993020ull, 5151751490341026201ull}},
{{8040234101005461560ull, 2966388270741274571ull,
  1756341803781577563ull, 6439689362926282752ull}},
{{5438606607829439046ull, 17543043393708756926ull,
  2195427254726971953ull, 8049611703657853440ull}},
{{17234187185175563116ull, 4046873093426891222ull,
  1372142034204357471ull, 5031007314786158400ull}},
{{12319361944614678087ull, 446905348356226124ull,
  1715177542755446839ull, 6288759143482698000ull}},
{{15399202430768347609ull, 14393689740727446367ull,
  2143971928444308548ull, 7860948929353372500ull}},
{{16542030546871299112ull, 18219428124809429787ull,
  10563354492132468650ull, 4913093080845857812ull}},
{{16065852165161735985ull, 13550913119157011426ull,
  13204193115165585813ull, 6141366351057322265ull}},
{{10858943169597394174ull, 3103583343664100571ull,
  2670183338674818555ull, 7676707938821652832ull}},
{{4480996471784677407ull, 18080640654285920521ull,
  1668864586671761596ull, 4797942461763533020ull}},
{{10212931608158234662ull, 4154056744147849035ull,
  2086080733339701996ull, 5997428077204416275ull}},
{{8154478491770405424ull, 5192570930184811294ull,
  16442658971956791207ull, 7496785096505520343ull}},
{{484863038929115486ull, 10162885859006588915ull,
  17194190885114076360ull, 4685490685315950214ull}},
{{14441136853943558069ull, 12703607323758236143ull,
  12269366569537819642ull, 5856863356644937768ull}},
{{13439735049002059683ull, 6656137117843019371ull,
  15336708211922274553ull, 7321079195806172210ull}},
{{12187982792825186699ull, 12931857415731162118ull,
  9947513228048067383ull, 9151348994757715263ull}},
{{3005803227088353783ull, 14999939912473058180ull,
  13134724795171123970ull, 5719593121723572039ull}},
{{3757254033860442229ull, 9526552853736546917ull,
  11806719975536517059ull, 7149491402154465049ull}},
{{9308253560752940690ull, 7296505048743295742ull, 923341914138482612ull,
  8936864252693081312ull}},
{{1205972457043200027ull, 13783687692319335647ull,
  577088696336551632ull, 5585540157933175820ull}},
{{15342523626586163746ull, 17229609615399169558ull,
  721360870420689540ull, 6981925197416469775ull}},
{{9954782496377928875ull, 3090267945539410332ull,
  14736759143308025638ull, 8727406496770587218ull}},
{{15445111097090981355ull, 15766475521244295169ull,
  13822160482994903927ull, 5454629060481617011ull}},
{{5471330816081562981ull, 15096408383127981058ull,
  12666014585316242005ull, 6818286325602021264ull}},
{{16062535556956729535ull, 5035452423627812610ull,
  15832518231645302507ull, 8522857907002526580ull}},
{{14650770741525343863ull, 841314755553688929ull, 671951857923538259ull,
  5326786191876579113ull}},
{{4478405371624516117ull, 14886701499724274874ull,
  5451625840831810727ull, 6658482739845723891ull}},
{{14821378751385420954ull, 13996690856227955688ull,
  2202846282612375505ull, 8323103424807154864ull}},
{{9263361719615888097ull, 1830402757501390449ull,
  1376778926632734691ull, 5201939640504471790ull}},
{{16190888167947248025ull, 16123061502158901773ull,
  10944345695145694171ull, 6502424550630589737ull}},
{{6403552154651896319ull, 15542140859271239313ull,
  18292118137359505618ull, 8128030688288237171ull}},
{{15531435142725904959ull, 14325524055471912474ull,
  9126730826635997059ull, 5080019180180148232ull}},
{{10190921891552605391ull, 13295219050912502689ull,
  11408413533294996324ull, 6350023975225185290ull}},
{{17350338382868144643ull, 16619023813640628361ull,
  5037144879763969597ull, 7937529969031481613ull}},
{{3926432461651508546ull, 12692732892739086678ull,
  5454058559066174950ull, 4960956230644676008ull}},
{{14131412613919161490ull, 6642544079069082539ull,
  6817573198832718688ull, 6201195288305845010ull}},
{{13052579748971563959ull, 8303180098836353174ull,
  17745338535395674168ull, 7751494110382306262ull}},
{{3546176324679839570ull, 5189487561772720734ull,
  6479150566194908451ull, 4844683818988941414ull}},
{{13656092442704575271ull, 1875173433788513013ull,
  17322310244598411372ull, 6055854773736176767ull}},
{{3235057498098555376ull, 2343966792235641267ull,
  17041201787320626311ull, 7569818467170220959ull}},
{{18162812000807454774ull, 8382508272788357647ull,
  17568280144716473300ull, 4731136541981388099ull}},
{{18091828982581930564ull, 10478135340985447059ull,
  17348664162468203721ull, 5913920677476735124ull}},
{{18003100209800025301ull, 17709355194659196728ull,
  3239086129375703035ull, 7392400846845918906ull}},
{{11251937631125015813ull, 8762503987448304003ull,
  6636114849287202301ull, 4620250529278699316ull}},
{{9453236020478881862ull, 15564816002737767908ull,
  8295143561609002876ull, 5775313161598374145ull}},
{{11816545025598602328ull, 1009275929712658269ull,
  14980615470438641500ull, 7219141451997967681ull}},
{{935623226716089197ull, 1261594912140822837ull, 4890711282766138163ull,
  9023926814997459602ull}},
{{2890607525911249701ull, 16929397884583871937ull,
  7668380570156224255ull, 5639954259373412251ull}},
{{8224945425816450030ull, 16550061337302452017ull,
  4973789694267892415ull, 7049942824216765314ull}},
{{14892867800697950441ull, 16075890653200677117ull,
  15440609154689641327ull, 8812428530270956642ull}},
{{11613885384649912978ull, 16964960685891505054ull,
  14262066740108413733ull, 5507767831419347901ull}},
{{5293984693957615414ull, 7371142802082217606ull,
  3992525369853353455ull, 6884709789274184877ull}},
{{15840852904301795075ull, 4602242484175384103ull,
  9602342730744079723ull, 8605887236592731096ull}},
{{16818062092829703778ull, 570558543395921112ull,
  6001464206715049827ull, 5378679522870456935ull}},
{{2575833542327578107ull, 14548256234527065103ull,
  2890144239966424379ull, 6723349403588071169ull}},
{{17054849983191636345ull, 13573634274731443474ull,
  8224366318385418378ull, 8404186754485088961ull}},
{{15270967257922160620ull, 13095207440134540075ull,
  16669443995059356246ull, 5252616721553180600ull}},
{{14477023053975312871ull, 7145637263313399286ull,
  2390060920114643692ull, 6565770901941475751ull}},
{{8872906780614365281ull, 8932046579141749108ull,
  16822634205425468327ull, 8207213627426844688ull}},
{{14768938774738754109ull, 12500058139604675048ull,
  10514146378390917704ull, 5129508517141777930ull}},
{{14429394713891020ull, 15625072674505843811ull, 3919310936133871322ull,
  6411885646427222413ull}},
{{13853094798674527486ull, 10307968806277528955ull,
  9510824688594727057ull, 8014857058034028016ull}},
{{6352341239957885727ull, 17971695549991925357ull,
  5944265430371704410ull, 5009285661271267510ull}},
{{12552112568374745063ull, 13241247400635130888ull,
  16653703824819406321ull, 6261607076589084387ull}},
{{15690140710468431328ull, 2716501195511749898ull,
  16205443762596869998ull, 7827008845736355484ull}},
{{14418023962470157484ull, 15532871302477007398ull,
  905030314768267940ull, 4891880528585222178ull}},
{{8799157916232921047ull, 969345054386707632ull,
  10354659930315110734ull, 6114850660731527722ull}},
{{10998947395291151309ull, 10435053354838160348ull,
  3719952876039112609ull, 7643563325914409653ull}},
{{16097714158911745376ull, 18051123392842319977ull,
  4630813556738139332ull, 4777227078696506033ull}},
{{6287084643357518008ull, 4117160167343348356ull,
  10400202964350062070ull, 5971533848370632541ull}},
{{7858855804196897510ull, 14369822246033961253ull,
  17611939723864965491ull, 7464417310463290676ull}},
{{7217627886836754896ull, 6675295894557531831ull,
  1784090290560827624ull, 4665260819039556673ull}},
{{4410348840118555716ull, 8344119868196914789ull,
  6841798881628422434ull, 5831576023799445841ull}},
{{10124622068575582549ull, 1206777798391367678ull,
  13163934620462915947ull, 7289470029749307301ull}},
{{3432405548864702378ull, 15343530303271373310ull,
  2619860220296481221ull, 9111837537186634127ull}},
{{15980311523322602698ull, 11895549448758302270ull,
  8554941665326382619ull, 5694898460741646329ull}},
{{10752017367298477565ull, 10257750792520489934ull,
  15305363100085366178ull, 7118623075927057911ull}},
{{4216649672268321148ull, 3598816453795836610ull,
  14520017856679319819ull, 8898278844908822389ull}},
{{7247092063595088622ull, 18390161348118255545ull,
  11380854169638268838ull, 5561424278068013993ull}},
{{13670551097921248681ull, 13764329648293043623ull,
  391009656765672336ull, 6951780347585017492ull}},
{{12476502853974172947ull, 17205412060366304529ull,
  488762070957090420ull, 8689725434481271865ull}},
{{880285256092776236ull, 1530010500874164523ull,
  11834691340416651273ull, 5431078396550794915ull}},
{{14935414625398134007ull, 6524199144520093557ull,
  10181678157093426187ull, 6788847995688493644ull}},
{{4834210226465503797ull, 3543562912222729043ull,
  12727097696366782734ull, 8486059994610617055ull}},
{{715538382327245921ull, 16049784875421369364ull,
  14871965087870321064ull, 5303787496631635659ull}},
{{894422977909057401ull, 1615487020567160089ull,
  13978270341410513427ull, 6629734370789544574ull}},
{{5729714740813709656ull, 15854416830991113823ull,
  8249465889908365975ull, 8287167963486930718ull}},
{{10498600740649650391ull, 16826539547010527995ull,
  544230162765340830ull, 5179479977179331699ull}},
{{8511564907384675084ull, 11809802396908384186ull,
  14515345758738839750ull, 6474349971474164623ull}},
{{1416084097376068047ull, 5538880959280704425ull,
  13532496179996161784ull, 8092937464342705779ull}},
{{12414267606928512290ull, 3461800599550440265ull,
  6151967103283907163ull, 5058085915214191112ull}},
{{1682776453378476650ull, 18162308804720214044ull,
  7689958879104883953ull, 6322607394017738890ull}},
{{2103470566723095813ull, 8867827950618103843ull, 389076562026329134ull,
  7903259242522173613ull}},
{{17455570168697792547ull, 930706450708926997ull,
  2549015860480149661ull, 4939537026576358508ull}},
{{7984404655590076972ull, 5775069081813546651ull,
  3186269825600187076ull, 6174421283220448135ull}},
{{5368819801060208311ull, 7218836352266933314ull,
  17817895337282397557ull, 7718026604025560168ull}},
{{7967198394090018098ull, 6817615729380527273ull,
  11136184585801498473ull, 4823766627515975105ull}},
{{14570684011039910527ull, 13133705680153046995ull,
  85172676969709379ull, 6029708284394968882ull}},
{{13601668995372500254ull, 11805446081763920840ull,
  9329837883066912532ull, 7537135355493711102ull}},
{{8501043122107812659ull, 16601775837957226333ull,
  1219462658489432428ull, 4710709597183569439ull}},
{{15237989921062153728ull, 2305475723736981300ull,
  15359386378393954248ull, 5888386996479461798ull}},
{{600743327618140544ull, 2881844654671226626ull, 9975860936137667002ull,
  7360483745599327248ull}},
{{9974301196377451487ull, 12825677855193809090ull,
  12469826170172083752ull, 9200604681999159060ull}},
{{10845624266163295084ull, 8016048659496130681ull,
  17017013393212328153ull, 5750377926249474412ull}},
{{18168716351131506759ull, 14631746842797551255ull,
  2824522667805858575ull, 7187972407811843016ull}},
{{18099209420486995544ull, 13677997535069551165ull,
  3530653334757323219ull, 8984965509764803770ull}},
{{13617848897018066167ull, 6242905450204775526ull,
  6818344352650714916ull, 5615603443603002356ull}},
{{7798939084417806901ull, 7803631812755969408ull,
  8522930440813393645ull, 7019504304503752945ull}},
{{9748673855522258626ull, 14366225784372349664ull,
  15265349069444129960ull, 8774380380629691181ull}},
{{6092921159701411641ull, 8978891115232718540ull,
  11846686177616275177ull, 5483987737893556988ull}},
{{7616151449626764552ull, 15835299912468286079ull,
  14808357722020343971ull, 6854984672366946235ull}},
{{4908503293606067786ull, 15182438872157969695ull,
  13898761134098042060ull, 8568730840458682794ull}},
{{9985343586144874222ull, 265652258243955251ull,
  13298411727238664192ull, 5355456775286676746ull}},
{{7869993464253704874ull, 332065322804944064ull, 7399642622193554432ull,
  6694320969108345933ull}},
{{9837491830317131092ull, 415081653506180080ull,
  13861239296169330944ull, 8367901211385432416ull}},
{{6148432393948206933ull, 259426033441362550ull, 8663274560105831840ull,
  5229938257115895260ull}},
{{16908912529290034474ull, 324282541801703187ull,
  10829093200132289800ull, 6537422821394869075ull}},
{{16524454643185155188ull, 405353177252128984ull,
  8924680481737974346ull, 8171778526743586344ull}},
{{10327784151990721993ull, 4865031754209968519ull,
  5577925301086233966ull, 5107361579214741465ull}},
{{8298044171561014587ull, 15304661729617236457ull,
  11584092644785180361ull, 6384201974018426831ull}},
{{14984241232878656137ull, 5295769106739381859ull,
  9868429787554087548ull, 7980252467523033539ull}},
{{7059307761335466134ull, 12533227728566889470ull,
  3861925608007610765ull, 4987657792201895962ull}},
{{18047506738524108475ull, 1831476605426448125ull,
  14050779046864289265ull, 6234572240252369952ull}},
{{8724325367872971882ull, 6901031775210448061ull,
  17563473808580361581ull, 7793215300315462440ull}},
{{7758546364134301378ull, 6618987868720223990ull,
  10977171130362725988ull, 4870759562697164025ull}},
{{474810918313100915ull, 8273734835900279988ull,
  18333149931380795389ull, 6088449453371455031ull}},
{{593513647891376143ull, 14953854563302737889ull,
  18304751395798606332ull, 7610561816714318789ull}},
{{11900161076000579850ull, 122787065209435372ull,
  13746312631587822910ull, 4756601135446449243ull}},
{{14875201345000724812ull, 9376855868366570023ull,
  12571204771057390733ull, 5945751419308061554ull}},
{{13982315662823518111ull, 16332755853885600433ull,
  6490633926966962608ull, 7432189274135076943ull}},
{{1821418261623616964ull, 10207972408678500271ull,
  10974175231995433486ull, 4645118296334423089ull}},
{{16111830882311684916ull, 3536593473993349530ull,
  18329405058421679762ull, 5806397870418028861ull}},
{{10916416566034830337ull, 13644113879346462721ull,
  9076698267744935990ull, 7257997338022536077ull}},
{{18257206725970925826ull, 7831770312328302593ull,
  15957558853108557892ull, 9072496672528170096ull}},
{{4493225176090746785ull, 14118228482059964929ull,
  9973474283192848682ull, 5670310420330106310ull}},
{{10228217488540821385ull, 8424413565720180353ull,
  3243470817136285045ull, 7087888025412632888ull}},
{{17396957879103414636ull, 15142202975577613345ull,
  4054338521420356306ull, 8859860031765791110ull}},
{{3955569646798552291ull, 14075562878163396245ull,
  16369019631169886403ull, 5537412519853619443ull}},
{{9556148076925578268ull, 12982767579276857402ull,
  15849588520534970100ull, 6921765649817024304ull}},
{{2721813059302197027ull, 16228459474096071753ull,
  1365241576959161009ull, 8652207062271280381ull}},
{{13230348208132342902ull, 3225258143668962989ull,
  3159118994813169583ull, 5407629413919550238ull}},
{{2702877204883264916ull, 17866630734868367449ull,
  13172270780371237786ull, 6759536767399437797ull}},
{{7990282524531469048ull, 13109916381730683503ull,
  2630280420181883521ull, 8449420959249297247ull}},
{{11911455605473250011ull, 1276168710940595333ull,
  8561454290254759057ull, 5280888099530810779ull}},
{{1054261451559398802ull, 6206896907103132071ull,
  6090131844391060917ull, 6601110124413513474ull}},
{{15152884869731412214ull, 12370307152306302992ull,
  16836036842343601954ull, 8251387655516891842ull}},
{{9470553043582132634ull, 12343127988618827274ull,
  15134209044892139125ull, 5157117284698057401ull}},
{{2614819267622889985ull, 1593851930491370381ull,
  5082703250833010195ull, 6446396605872571752ull}},
{{7880210102956000385ull, 15827372968396376688ull,
  6353379063541262743ull, 8057995757340714690ull}},
{{4925131314347500241ull, 16809637132888817286ull,
  8582547933140677118ull, 5036247348337946681ull}},
{{15379786179789151109ull, 11788674379256245799ull,
  15339870934853234302ull, 6295309185422433351ull}},
{{14613046706309050982ull, 5512470937215531441ull,
  14563152650139154974ull, 7869136481778041689ull}},
{{2215625163802075008ull, 17280352391041870863ull,
  2184441378695890002ull, 4918210301111276056ull}},
{{16604589510034757472ull, 12377068451947562770ull,
  2730551723369862503ull, 6147762876389095070ull}},
{{11532364850688671031ull, 10859649546507065559ull,
  12636561691067103937ull, 7684703595486368837ull}},
{{14125257059321501251ull, 18316496012635385734ull,
  10203694066130633912ull, 4802939747178980523ull}},
{{8433199287297100755ull, 4448875942084680552ull,
  8142931564235904487ull, 6003674683973725654ull}},
{{10541499109121375944ull, 949408909178462786ull, 955292418440104801ull,
  7504593354967157068ull}},
{{11200122961628247869ull, 12122595614305009001ull,
  9820429798379841308ull, 4690370846854473167ull}},
{{165095646753146124ull, 15153244517881261252ull,
  7663851229547413731ull, 5862963558568091459ull}},
{{206369558441432655ull, 14329869628924188661ull,
  4968128018506879260ull, 7328704448210114324ull}},
{{4869647966479178723ull, 17912337036155235826ull,
  6210160023133599075ull, 9160880560262642905ull}},
{{7655215997476874606ull, 8889367638383328439ull,
  15410565060526969182ull, 5725550350164151815ull}},
{{4957333978418705354ull, 1888337511124384741ull,
  14651520307231323574ull, 7156937937705189769ull}},
{{10808353491450769596ull, 11583793925760256734ull,
  4479342328756990755ull, 8946172422131487212ull}},
{{2143534913729343094ull, 4934028194386466507ull,
  12022960992327895030ull, 5591357763832179507ull}},
{{16514476697443842579ull, 15390907279837858941ull,
  10417015221982480883ull, 6989197204790224384ull}},
{{6808037816522639511ull, 14626948081369935773ull,
  13021269027478101104ull, 8736496505987780480ull}},
{{6560866644540343647ull, 9141842550856209858ull,
  8138293142173813190ull, 5460310316242362800ull}},
{{17424455342530205366ull, 2203931151715486514ull,
  10172866427717266488ull, 6825387895302953500ull}},
{{12557197141307980900ull, 2754913939644358143ull,
  12716083034646583110ull, 8531734869128691875ull}},
{{14765777240958569919ull, 15556879267559887551ull,
  5641708887440420491ull, 5332334293205432422ull}},
{{13845535532770824494ull, 14834413066022471535ull,
  16275508146155301422ull, 6665417866506790527ull}},
{{12695233397536142714ull, 9319644295673313611ull,
  15732699164266738874ull, 8331772333133488159ull}},
{{5628677864246395244ull, 10436463703223208911ull,
  16750466005307793652ull, 5207357708208430099ull}},
{{2424161311880606151ull, 13045579629029011139ull,
  16326396488207354161ull, 6509197135260537624ull}},
{{16865259695132921401ull, 2471916481004100211ull,
  1961251536549641086ull, 8136496419075672031ull}},
{{8234944300244381924ull, 15380005855909726344ull,
  8143311237984607534ull, 5085310261922295019ull}},
{{10293680375305477404ull, 10001635283032382122ull,
  5567453029053371514ull, 6356637827402868774ull}},
{{3643728432277070947ull, 3278672066935701845ull,
  16182688323171490201ull, 7945797284253585967ull}},
{{4583173279386863294ull, 13578385087903283413ull,
  17031709229623263231ull, 4966123302658491229ull}},
{{10340652617660967022ull, 12361295341451716362ull,
  7454578481746915327ull, 6207654128323114037ull}},
{{3702443735221432969ull, 10839933158387257549ull,
  13929909120611032063ull, 7759567660403892546ull}},
{{4619870343727089558ull, 13692487251633117824ull,
  13317879218809282943ull, 4849729787752432841ull}},
{{5774837929658861947ull, 12503923046114009376ull,
  2812290968229439967ull, 6062162234690541052ull}},
{{7218547412073577434ull, 11018217789215123816ull,
  3515363710286799959ull, 7577702793363176315ull}},
{{4511592132545985896ull, 13803915145900534241ull,
  18338003383425107638ull, 4736064245851985196ull}},
{{10251176184109870274ull, 8031521895520891993ull,
  4475760155571832932ull, 5920080307314981496ull}},
{{17425656248564725747ull, 10039402369401114991ull,
  5594700194464791165ull, 7400100384143726870ull}},
{{17808564182994035448ull, 8580469490089390821ull,
  17331745676822658190ull, 4625062740089829293ull}},
{{8425647173460380598ull, 1502214825756962719ull,
  7829624040746159026ull, 5781328425112286617ull}},
{{5920372948398087843ull, 11101140569050979207ull,
  14398716069360086686ull, 7226660531390358271ull}},
{{2788780167070221900ull, 4653053674458948201ull,
  13386709068272720454ull, 9033325664237947839ull}},
{{13272202650487358448ull, 16743216601819006337ull,
  15284222195311532139ull, 5645828540148717399ull}},
{{2755195257827034347ull, 16317334733846370018ull,
  14493591725712027270ull, 7057285675185896749ull}},
{{12667366109138568742ull, 11173296380453186714ull,
  4281931601857870376ull, 8821607093982370937ull}},
{{12528789836638993368ull, 6983310237783241696ull,
  14205422297229638745ull, 5513504433738981835ull}},
{{15660987295798741710ull, 13340823815656440024ull,
  13145091853109660527ull, 6891880542173727294ull}},
{{1129490046038875521ull, 12064343751143162127ull,
  7207992779532299851ull, 8614850677717159118ull}},
{{7623460306415379057ull, 5234371835250782377ull,
  18340053542489851119ull, 5384281673573224448ull}},
{{14141011401446611725ull, 1931278775636090067ull,
  4478322854402762283ull, 6730352091966530561ull}},
{{13064578233380876752ull, 16249156524827276296ull,
  10209589586430840757ull, 8412940114958163201ull}},
{{8165361395863047970ull, 12461565837230741637ull,
  17910208537587745233ull, 5258087571848852000ull}},
{{14818387763256197867ull, 1741899241256263334ull,
  3941016598275129926ull, 6572609464811065001ull}},
{{9299612667215471525ull, 11400746088425104976ull,
  9537956766271300311ull, 8215761831013831251ull}},
{{5812257917009669703ull, 14042995332906772466ull,
  3655379969705868742ull, 5134851144383644532ull}},
{{16488694433116862937ull, 8330372129278689774ull,
  4569224962132335928ull, 6418563930479555665ull}},
{{11387496004541302863ull, 10412965161598362218ull,
  10323217221092807814ull, 8023204913099444581ull}},
{{11728871021265702194ull, 1896417207571588482ull,
  8757853772396698836ull, 5014503070687152863ull}},
{{5437716739727351934ull, 2370521509464485603ull,
  6335631197068485641ull, 6268128838358941079ull}},
{{2185459906231802013ull, 7574837905257994908ull,
  3307852977908219147ull, 7835161047948676349ull}},
{{10589284478249652067ull, 2428430681572552865ull,
  4373251120406330919ull, 4896975654967922718ull}},
{{17848291616239452987ull, 16870596407247854793ull,
  14689935937362689456ull, 6121219568709903397ull}},
{{8475306465017152522ull, 2641501435350266876ull,
  4527361866421198109ull, 7651524460887379247ull}},
{{14520438577490496134ull, 3956781406307610749ull,
  9747130194154330674ull, 4782202788054612029ull}},
{{4315490166580956456ull, 14169348794739289245ull,
  16795598761120301246ull, 5977753485068265036ull}},
{{10006048726653583474ull, 8488313956569335748ull,
  2547754377690824942ull, 7472191856335331296ull}},
{{15477152491013265479ull, 693510204428446938ull,
  1592346486056765589ull, 4670119910209582060ull}},
{{10123068576911806041ull, 5478573773962946577ull,
  1990433107570956986ull, 5837649887761977575ull}},
{{17265521739567145455ull, 16071589254308459029ull,
  16323099439745859944ull, 7297062359702471968ull}},
{{7746844119176768107ull, 1642742494176022171ull,
  1957130225972773315ull, 9121327949628089961ull}},
{{2535934565271786115ull, 17167615123355871521ull,
  12752421437301453081ull, 5700829968517556225ull}},
{{7781604225017120547ull, 7624460848912675689ull,
  2105468741344652640ull, 7126037460646945282ull}},
{{14338691299698788588ull, 9530576061140844611ull,
  11855207963535591608ull, 8907546825808681602ull}},
{{6655839053098048916ull, 5956610038213027882ull,
  12021190995637132659ull, 5567216766130426001ull}},
{{17543170853227336953ull, 2834076529338896948ull,
  1191430689264252112ull, 6959020957663032502ull}},
{{3482219492824619575ull, 3542595661673621186ull,
  10712660398435090948ull, 8698776197078790627ull}},
{{6788073201442775138ull, 11437494325400789049ull,
  4389569739808237890ull, 5436735123174244142ull}},
{{13096777520230856827ull, 5073495869896210503ull,
  14710334211615073171ull, 6795918903967805177ull}},
{{11759285881861183129ull, 1730183818942875225ull,
  4552859709236677752ull, 8494898629959756472ull}},
{{432024648522157600ull, 1081364886839297016ull, 2845537318272923595ull,
  5309311643724847795ull}},
{{540030810652697000ull, 15186764163831284982ull,
  17391979703123318205ull, 6636639554656059743ull}},
{{9898410550170647058ull, 5148397149506942515ull,
  17128288610476759853ull, 8295799443320074679ull}},
{{3880663584642960459ull, 5523591227655533024ull,
  17622709409189056764ull, 5184874652075046674ull}},
{{4850829480803700574ull, 6904489034569416280ull,
  12805014724631545147ull, 6481093315093808343ull}},
{{6063536851004625717ull, 4018925274784382446ull,
  11394582387362043530ull, 8101366643867260429ull}},
{{17624768587160054785ull, 7123514315167626932ull,
  9427457001314971158ull, 5063354152417037768ull}},
{{3584216660240516866ull, 18127764930814309474ull,
  11784321251643713947ull, 6329192690521297210ull}},
{{13703642862155421890ull, 18048020145090498938ull,
  5507029527699866626ull, 7911490863151621513ull}},
{{13176462807274526585ull, 15891698609108949740ull,
  14971108500880886401ull, 4944681789469763445ull}},
{{16470578509093158232ull, 6029565206104023463ull,
  4878827570818944290ull, 6180852236837204307ull}},
{{15976537117939059886ull, 16760328544484805137ull,
  1486848445096292458ull, 7726065296046505384ull}},
{{3067806671070830573ull, 15086891358730391115ull,
  929280278185182786ull, 4828790810029065865ull}},
{{17669816394120701928ull, 9635242161558213085ull,
  5773286366158866387ull, 6035988512536332331ull}},
{{8252212437368713697ull, 7432366683520378453ull,
  2604921939271195080ull, 7544985640670415414ull}},
{{7463475782569140013ull, 4645229177200236533ull,
  15463134267326660637ull, 4715616025419009633ull}},
{{13941030746638812920ull, 10418222489927683570ull,
  5493859778876162084ull, 5894520031773762042ull}},
{{8202916396443740342ull, 13022778112409604463ull,
  16090696760449978413ull, 7368150039717202552ull}},
{{5641959477127287524ull, 2443414585229841867ull,
  1666626876852921401ull, 9210187549646503191ull}},
{{1220381663990860750ull, 13056349161837120927ull,
  7959170825674157731ull, 5756367218529064494ull}},
{{15360535135270739650ull, 11708750433869013254ull,
  725591495237921356ull, 7195459023161330618ull}},
{{9977296882233648754ull, 14635938042336266568ull,
  10130361405902177503ull, 8994323778951663272ull}},
{{6235810551396030472ull, 16064990304101248461ull,
  6331475878688860939ull, 5621452361844789545ull}},
{{12406449207672425993ull, 15469551861699172672ull,
  12526030866788464078ull, 7026815452305986931ull}},
{{15508061509590532492ull, 10113567790269190032ull,
  11045852565058192194ull, 8783519315382483664ull}},
{{9692538443494082807ull, 10932665887345631674ull,
  6903657853161370121ull, 5489699572114052290ull}},
{{2892301017512827701ull, 18277518377609427497ull,
  17852944353306488459ull, 6862124465142565362ull}},
{{8227062290318422530ull, 18235211953584396467ull,
  13092808404778334766ull, 8577655581428206703ull}},
{{2836070922235320130ull, 6785321452562859888ull,
  15100534280627541085ull, 5361034738392629189ull}},
{{3545088652794150162ull, 13093337834130962764ull,
  5040609795502262644ull, 6701293422990786487ull}},
{{4431360815992687702ull, 16366672292663703455ull,
  1689076225950440401ull, 8376616778738483109ull}},
{{9687129537636511670ull, 3311641155273732803ull,
  3361515650432719203ull, 5235385486711551943ull}},
{{7497225903618251684ull, 17974609499374329716ull,
  18036952618323062715ull, 6544231858389439928ull}},
{{9371532379522814604ull, 17856575855790524241ull,
  4099446699194276778ull, 8180289822986799911ull}},
{{17386422783270228888ull, 15772045928296465554ull,
  9479683214637504842ull, 5112681139366749944ull}},
{{12509656442233010302ull, 10491685373515806135ull,
  11849604018296881053ull, 6390851424208437430ull}},
{{11025384534363874973ull, 17726292735322145573ull,
  5588632986016325508ull, 7988564280260546788ull}},
{{9196708343191115810ull, 1855560922721565175ull,
  12716267653114979251ull, 4992852675162841742ull}},
{{6884199410561506859ull, 16154509208684120181ull,
  6671962529538948255ull, 6241065843953552178ull}},
{{13216935281629271477ull, 15581450492427762322ull,
  17563325198778461127ull, 7801332304941940222ull}},
{{12872270569445682578ull, 16655935585408433307ull,
  6365392230809150300ull, 4875832690588712639ull}},
{{11478652193379715318ull, 2373175408050990018ull,
  3345054270084049972ull, 6094790863235890799ull}},
{{5124943204869868339ull, 2966469260063737523ull,
  18016375892887226177ull, 7618488579044863498ull}},
{{897246493829973760ull, 13383258333608305712ull,
  15871920951481904264ull, 4761555361903039686ull}},
{{1121558117287467200ull, 16729072917010382140ull,
  10616529152497604522ull, 5951944202378799608ull}},
{{1401947646609334000ull, 11687969109408201867ull,
  13270661440622005653ull, 7439930252973499510ull}},
{{17017118343626691414ull, 9610823702593820118ull,
  3682477381961365629ull, 4649956408108437194ull}},
{{12048025892678588460ull, 16625215646669663052ull,
  13826468764306482844ull, 5812445510135546492ull}},
{{15060032365848235574ull, 2334775484627527199ull,
  17283085955383103556ull, 7265556887669433115ull}},
{{14213354438882906564ull, 2918469355784408999ull,
  16992171425801491541ull, 9081946109586791394ull}},
{{15800875551942898459ull, 4129886356578949576ull,
  15231793159553320117ull, 5676216318491744621ull}},
{{1304350366219071457ull, 9774043964151074875ull,
  5204683394159486434ull, 7095270398114680777ull}},
{{15465496013056003033ull, 2994182918334067785ull,
  11117540261126745947ull, 8869087997643350971ull}},
{{2748405980518920040ull, 18012265388454650030ull,
  4642619653990522264ull, 5543179998527094357ull}},
{{12658879512503425858ull, 4068587661858760921ull,
  10414960585915540735ull, 6928974998158867946ull}},
{{1988541335347118610ull, 474048558896063248ull, 3795328695539650111ull,
  8661218747698584933ull}},
{{1242838334591949132ull, 7213809376951121386ull,
  4677923443925975271ull, 5413261717311615583ull}},
{{10776919955094712222ull, 4405575702761513828ull,
  1235718286480081185ull, 6766577146639519479ull}},
{{13471149943868390278ull, 10118655646879280189ull,
  15379705913382265193ull, 8458221433299399348ull}},
{{10725311724131437876ull, 17853374825368019878ull,
  388944159009139937ull, 5286388395812124593ull}},
{{4183267618309521537ull, 8481660476427861136ull,
  5097866217188812826ull, 6607985494765155741ull}},
{{5229084522886901921ull, 1378703558680050612ull,
  10984018789913403937ull, 8259981868456444676ull}},
{{12491549863659089509ull, 12390904770243501392ull,
  16088383780550653268ull, 5162488667785277922ull}},
{{15614437329573861886ull, 15488630962804376740ull,
  10887107688833540777ull, 6453110834731597403ull}},
{{1071302588257775741ull, 5525730648223307214ull,
  8997198592614538068ull, 8066388543414496754ull}},
{{14504622172943273550ull, 12676953691994342816ull,
  10234935138811474196ull, 5041492839634060471ull}},
{{18130777716179091938ull, 15846192114992928520ull,
  8181982905086954841ull, 6301866049542575589ull}},
{{4216728071514313306ull, 5972682088458996939ull,
  14839164649786081456ull, 7877332561928219486ull}},
{{329612035482751864ull, 3732926305286873087ull, 4662791887688913006ull,
  4923332851205137179ull}},
{{14247073099635603542ull, 13889529918463367166ull,
  1216803841183753353ull, 6154166064006421474ull}},
{{8585469337689728620ull, 3526854342797045246ull,
  10744376838334467500ull, 7692707580008026842ull}},
{{754232317628692484ull, 11427656001102929087ull,
  11326921542386430091ull, 4807942237505016776ull}},
{{14777848452318029316ull, 9672883982951273454ull,
  14158651927983037614ull, 6009927796881270970ull}},
{{9248938528542760837ull, 2867732941834316010ull,
  8474942873124021210ull, 7512409746101588713ull}},
{{10392272598766613428ull, 6404019107073835410ull,
  16826054341770983016ull, 4695256091313492945ull}},
{{3766968711603490976ull, 8005023883842294263ull,
  7197509871931565058ull, 5869070114141866182ull}},
{{97024871076975816ull, 782907817948092021ull, 18220259376769232131ull,
  7336337642677332727ull}},
{{4732967107273607674ull, 14813692827717278738ull,
  18163638202534152259ull, 9170422053346665909ull}},
{{7569790460473392701ull, 6952715008109605259ull,
  13658116885797539114ull, 5731513783341666193ull}},
{{4850552057164352972ull, 17914265796991782382ull,
  3237588051964760180ull, 7164392229177082742ull}},
{{15286562108310217022ull, 3946088172530176361ull,
  13270357101810726034ull, 8955490286471353427ull}},
{{2636572290052803783ull, 7077991126258748130ull,
  5988130179418009819ull, 5597181429044595892ull}},
{{12519087399420780537ull, 4235802889396047258ull,
  7485162724272512274ull, 6996476786305744865ull}},
{{6425487212421199863ull, 14518125648599834881ull,
  13968139423768028246ull, 8745595982882181081ull}},
{{15545144553831719674ull, 4462142511947508896ull,
  1812558112213935798ull, 5465997489301363176ull}},
{{984686618580097977ull, 14801050176789161929ull,
  2265697640267419747ull, 6832496861626703970ull}},
{{5842544291652510375ull, 13889626702559064507ull,
  12055494087189050492ull, 8540621077033379962ull}},
{{1345747173069125033ull, 17904388725954191125ull,
  12146369822920544461ull, 5337888173145862476ull}},
{{6293869984763794195ull, 8545427852160575194ull,
  15182962278650680577ull, 6672360216432328095ull}},
{{17090709517809518551ull, 15293470833628106896ull,
  14367016829885962817ull, 8340450270540410119ull}},
{{10681693448630949095ull, 2640890243376484954ull,
  15896914546319808617ull, 5212781419087756324ull}},
{{4128744773933910560ull, 7912798822647994097ull,
  1424399109190209155ull, 6515976773859695406ull}},
{{9772616985844776104ull, 5279312509882604717ull,
  11003870923342537252ull, 8144970967324619257ull}},
{{8413728625366679017ull, 12522942355531403756ull,
  18406634373157555542ull, 5090606854577887035ull}},
{{10517160781708348771ull, 6430305907559478887ull,
  18396606948019556524ull, 6363258568222358794ull}},
{{8534764958708048060ull, 8037882384449348609ull,
  13772386648169669847ull, 7954073210277948493ull}},
{{16863443145260999798ull, 11941205517921924736ull,
  10913584664319737606ull, 4971295756423717808ull}},
{{2632559857866698131ull, 5703134860547630113ull,
  13641980830399672008ull, 6214119695529647260ull}},
{{7902385840760760568ull, 7128918575684537641ull,
  17052476037999590010ull, 7767649619412059075ull}},
{{16468206196543945115ull, 9067260128230223929ull,
  8351954514536049804ull, 4854781012132536922ull}},
{{6750199690397767682ull, 11334075160287779912ull,
  1216571106315286447ull, 6068476265165671153ull}},
{{8437749612997209602ull, 9555907931932336986ull,
  6132399901321495963ull, 7585595331457088941ull}},
{{9885279526550643905ull, 3666599448244016664ull,
  6138592947539628929ull, 4740997082160680588ull}},
{{12356599408188304882ull, 9194935328732408734ull,
  7673241184424536161ull, 5926246352700850735ull}},
{{6222377223380605294ull, 16105355179342898822ull,
  4979865462103282297ull, 7407807940876063419ull}},
{{17724043819895042021ull, 3148317959448229907ull,
  806572904600857484ull, 4629879963047539637ull}},
{{17543368756441414622ull, 3935397449310287384ull,
  5619902149178459759ull, 5787349953809424546ull}},
{{3482466871842216661ull, 307560793210471327ull,
  16248249723327850507ull, 7234187442261780682ull}},
{{18188141645084934539ull, 14219509046795252870ull,
  11086940117305037325ull, 9042734302827225853ull}},
{{6755902509750696183ull, 11193036163460726996ull,
  9235180582529342280ull, 5651708939267016158ull}},
{{8444878137188370228ull, 13991295204325908745ull,
  2320603691306902042ull, 7064636174083770198ull}},
{{15167783689912850689ull, 8265746968552610123ull,
  12124126650988403361ull, 8830795217604712747ull}},
{{7174021796981837729ull, 16695306901413851087ull,
  5271736147654058148ull, 5519247011002945467ull}},
{{4355841227799909257ull, 2422389553057762243ull,
  1977984166140184782ull, 6899058763753681834ull}},
{{833115516322498667ull, 12251358978176978612ull,
  11695852244530006785ull, 8623823454692102292ull}},
{{9744069234556337475ull, 739570333719529776ull,
  16533279689686030049ull, 5389889659182563932ull}},
{{12180086543195421844ull, 5536148935576800124ull,
  2219855538397985945ull, 6737362073978204916ull}},
{{15225108178994277305ull, 11531872187898388059ull,
  2774819422997482431ull, 8421702592472756145ull}},
{{7209849602657729364ull, 14124949145077574393ull,
  13263477185441896279ull, 5263564120295472590ull}},
{{13623998021749549609ull, 13044500412919580087ull,
  7355974444947594541ull, 6579455150369340738ull}},
{{12418311508759549107ull, 2470567460867311397ull,
  18418340093039268985ull, 8224318937961675922ull}},
{{10067287702188412144ull, 13073319709110539383ull,
  16123148576576931019ull, 5140199336226047451ull}},
{{7972423609308127276ull, 11729963617960786325ull,
  15542249702293775870ull, 6425249170282559314ull}},
{{14577215530062546998ull, 5439082485596207098ull,
  10204440091012444030ull, 8031561462853199143ull}},
{{13722445724716479778ull, 17234484608779793148ull,
  13295304084523859374ull, 5019725914283249464ull}},
{{17153057155895599723ull, 12319733724119965627ull,
  16619130105654824218ull, 6274657392854061830ull}},
{{16829635426442111749ull, 6176295118295181226ull,
  11550540595213754465ull, 7843321741067577288ull}},
{{15130208159953707747ull, 15389399495002958026ull,
  7219087872008596540ull, 4902076088167235805ull}},
{{9689388163087358876ull, 790005295044145917ull,
  13635545858438133580ull, 6127595110209044756ull}},
{{16723421222286586499ull, 987506618805182396ull,
  17044432323047666975ull, 7659493887761305945ull}},
{{1228766227074340754ull, 7534720664394320854ull,
  3735241174263710003ull, 4787183679850816216ull}},
{{10759329820697701750ull, 4806714812065513163ull,
  4669051467829637504ull, 5983979599813520270ull}},
{{8837476257444739284ull, 6008393515081891454ull,
  15059686371641822688ull, 7479974499766900337ull}},
{{911736642475574149ull, 3755245946926182159ull, 2494774954635057324ull,
  4674984062354312711ull}},
{{14974728858376631398ull, 4694057433657727698ull,
  16953526748575985367ull, 5843730077942890888ull}},
{{9495039036116013439ull, 1255885773644771719ull,
  2745164362010430093ull, 7304662597428613611ull}},
{{7257112776717628895ull, 6181543235483352553ull,
  17266513507795201328ull, 9130828246785767013ull}},
{{16064910531516987819ull, 3863464522177095345ull,
  13097413951585694782ull, 5706767654241104383ull}},
{{6246080109114071062ull, 14052702689576144990ull,
  11760081421054730573ull, 7133459567801380479ull}},
{{17030972173247364635ull, 3730820306688017525ull,
  10088415757891025313ull, 8916824459751725599ull}},
{{12950200617493296849ull, 13860977737748480713ull,
  13222788876322972676ull, 5573015287344828499ull}},
{{2352692716584457350ull, 17326222172185600892ull,
  11916800076976327941ull, 6966269109181035624ull}},
{{2940865895730571687ull, 7822719659949837403ull,
  14896000096220409927ull, 8707836386476294530ull}},
{{17978942249327464968ull, 11806728815109730232ull,
  13921686078565144108ull, 5442397741547684081ull}},
{{4026933737949779594ull, 14758411018887162791ull,
  3567049542924266423ull, 6802997176934605102ull}},
{{421981154009836589ull, 13836327755181565585ull,
  13682183965510108837ull, 8503746471168256377ull}},
{{11792953267324617628ull, 10953547856202172442ull,
  1633835950802736167ull, 5314841544480160236ull}},
{{5517819547300996227ull, 9080248801825327649ull,
  2042294938503420209ull, 6643551930600200295ull}},
{{11508960452553633188ull, 15961997020709047465ull,
  16387926728411438973ull, 8304439913250250368ull}},
{{275571255204938887ull, 12282091147156848618ull,
  10242454205257149358ull, 5190274945781406480ull}},
{{9567836105860949416ull, 6129241897091284964ull,
  12803067756571436698ull, 6487843682226758100ull}},
{{11959795132326186770ull, 16884924408218882013ull,
  16003834695714295872ull, 8109804602783447625ull}},
{{9780714966917560683ull, 10553077755136801258ull,
  3084867657180353064ull, 5068627876739654766ull}},
{{3002521671792175046ull, 13191347193921001573ull,
  13079456608330217138ull, 6335784845924568457ull}},
{{8364838108167606712ull, 7265811955546476158ull,
  2514262705130607711ull, 7919731057405710572ull}},
{{616337799177366291ull, 11458661499857629455ull,
  10794786227561405627ull, 4949831910878569107ull}},
{{14605480304253871576ull, 9711640856394648914ull,
  8881796766024369130ull, 6187289888598211384ull}},
{{9033478343462563661ull, 2916179033638535335ull,
  11102245957530461413ull, 7734112360747764230ull}},
{{12563452992305184145ull, 4128454905237778536ull,
  2327217705029150479ull, 4833820225467352644ull}},
{{15704316240381480181ull, 548882613119835266ull,
  2909022131286438099ull, 6042275281834190805ull}},
{{10407023263622074418ull, 14521161321681957795ull,
  8247963682535435527ull, 7552844102292738506ull}},
{{4198546530550102559ull, 15993254853692305478ull,
  9766663320012035108ull, 4720527563932961566ull}},
{{14471555200042404007ull, 1544824493405830231ull,
  2984957113160268078ull, 5900659454916201958ull}},
{{13477757981625617104ull, 11154402653612063597ull,
  12954568428305110905ull, 7375824318645252447ull}},
{{3012139421749857668ull, 107945261732915785ull,
  11581524516954000728ull, 9219780398306565559ull}},
{{13411802184662130803ull, 67465788583072365ull,
  14155981850737332311ull, 5762362748941603474ull}},
{{2929694675545499791ull, 13919390291011004169ull,
  8471605276566889580ull, 7202953436177004343ull}},
{{8273804362859262643ull, 17399237863763755211ull,
  5977820577281224071ull, 9003691795221255429ull}},
{{2865284717573345200ull, 17792052692493428863ull,
  6041980870014458996ull, 5627307372013284643ull}},
{{17416663952248845212ull, 3793321791907234462ull,
  2940790069090685842ull, 7034134215016605804ull}},
{{12547457903456280707ull, 13965024276738818886ull,
  3675987586363357302ull, 8792667768770757255ull}},
{{3230475171232787538ull, 4116454154534373900ull,
  9215021269118180170ull, 5495417355481723284ull}},
{{4038093964040984422ull, 14368939730022743183ull,
  11518776586397725212ull, 6869271694352154105ull}},
{{435931436623842624ull, 17961174662528428979ull, 563412677714992803ull,
  8586589617940192632ull}},
{{16413358212385759304ull, 8919891154866574159ull,
  352132923571870502ull, 5366618511212620395ull}},
{{15905011747054811226ull, 1926491906728441891ull,
  14275224209747001840ull, 6708273139015775493ull}},
{{15269578665391126128ull, 2408114883410552364ull,
  4008972206901588588ull, 8385341423769719367ull}},
{{320114629014678022ull, 10728443838986371036ull,
  9423136656954574723ull, 5240838389856074604ull}},
{{400143286268347528ull, 8798868780305575891ull,
  11778920821193218404ull, 6551047987320093255ull}},
{{14335237163117598122ull, 10998585975381969863ull,
  10111965008064135101ull, 8188809984150116569ull}},
{{15877052254589580682ull, 9179959243827425116ull,
  17849193176108554198ull, 5118006240093822855ull}},
{{1399571244527424237ull, 2251577017929505588ull,
  17699805451708304844ull, 6397507800117278569ull}},
{{1749464055659280296ull, 2814471272411881985ull,
  8289698759353217343ull, 7996884750146598212ull}},
{{12622630080855519945ull, 8676573572898508096ull,
  14404433761450536647ull, 4998052968841623882ull}},
{{15778287601069399931ull, 6234030947695747216ull,
  8782170164958395001ull, 6247566211052029853ull}},
{{1276115427627198298ull, 12404224703047071925ull,
  15589398724625381655ull, 7809457763815037316ull}},
{{3103415151480692888ull, 14670169467045501809ull,
  520002166036087726ull, 4880911102384398323ull}},
{{8490954957778254014ull, 9114339796952101453ull,
  14485060762827273370ull, 6101138877980497903ull}},
{{15225379715650205422ull, 2169552709335351008ull,
  13494639935106703809ull, 7626423597475622379ull}},
{{9515862322281378389ull, 12885185489403064140ull,
  6128306950227995928ull, 4766514748422263987ull}},
{{11894827902851722986ull, 16106481861753830175ull,
  3048697669357607006ull, 5958143435527829984ull}},
{{10256848860137265828ull, 10909730290337511911ull,
  3810872086697008758ull, 7447679294409787480ull}},
{{13328059565226872999ull, 2206895413033557040ull,
  2381795054185630474ull, 4654799559006117175ull}},
{{16660074456533591248ull, 11981991303146722108ull,
  16812301873014201804ull, 5818499448757646468ull}},
{{2378348996957437444ull, 14977489128933402636ull,
  2568633267558200639ull, 7273124310947058086ull}},
{{2972936246196796805ull, 14110175392739365391ull,
  12434163621302526607ull, 9091405388683822607ull}},
{{8775614181514079860ull, 15736388648103185225ull,
  14688881290955160985ull, 5682128367927389129ull}},
{{15581203745319987728ull, 5835427754846817819ull,
  4526043558411787520ull, 7102660459909236412ull}},
{{14864818663222596756ull, 7294284693558522274ull,
  5657554448014734400ull, 8878325574886545515ull}},
{{13902197682941510877ull, 4558927933474076421ull,
  1230128520795515048ull, 5548953484304090947ull}},
{{3542689048394724884ull, 5698659916842595527ull,
  15372718706276557522ull, 6936191855380113683ull}},
{{18263419365775569817ull, 16346696932908020216ull,
  14604212364418308998ull, 8670239819225142104ull}},
{{11414637103609731136ull, 5604999564640124731ull,
  9127632727761443124ull, 5418899887015713815ull}},
{{9656610361084776016ull, 7006249455800155914ull,
  6797854891274416001ull, 6773624858769642269ull}},
{{2847390914501194211ull, 13369497838177582797ull,
  13109004632520407905ull, 8467031073462052836ull}},
{{4085462330776940334ull, 1438407121219907392ull,
  17416499932180030749ull, 5291894420913783022ull}},
{{5106827913471175418ull, 6409694919952272144ull,
  12547252878370262628ull, 6614868026142228778ull}},
{{6383534891838969272ull, 8012118649940340180ull,
  6460694061108052477ull, 8268585032677785973ull}},
{{13213081344254131603ull, 7313417165426406564ull,
  6343776797406226750ull, 5167865645423616233ull}},
{{16516351680317664504ull, 18365143493637784013ull,
  12541407015185171341ull, 6459832056779520291ull}},
{{6810381545114916918ull, 9121371311765066305ull,
  11065072750554076273ull, 8074790070974400364ull}},
{{15785703511765292834ull, 17230072115921636200ull,
  16139042505951073478ull, 5046743794359000227ull}},
{{1285385315997064426ull, 12314218108047269443ull,
  15562117114011453944ull, 6308429742948750284ull}},
{{15441789700278494244ull, 15392772635059086803ull,
  1005902318804765814ull, 7885537178685937856ull}},
{{7345275553460364951ull, 5008796878484541348ull, 628688949252978634ull,
  4928460736678711160ull}},
{{9181594441825456189ull, 15484368134960452493ull,
  785861186566223292ull, 6160575920848388950ull}},
{{16088679070709208140ull, 908716094991014000ull,
  10205698520062554924ull, 7700719901060486187ull}},
{{10055424419193255087ull, 9791319596224159558ull,
  4072718565825402875ull, 4812949938162803867ull}},
{{3345908487136793051ull, 7627463476852811544ull, 479212188854365690ull,
  6016187422703504834ull}},
{{4182385608920991314ull, 310957309211238622ull, 9822387272922732921ull,
  7520234278379381042ull}},
{{16449049060857783283ull, 11723563364325493898ull,
  10750678064004095979ull, 4700146423987113151ull}},
{{11337939289217453296ull, 10042768186979479469ull,
  8826661561577732070ull, 5875183029983891439ull}},
{{337366056239652908ull, 3330088196869573529ull, 6421640933544777184ull,
  7343978787479864299ull}},
{{5033393588726954039ull, 4162610246086966911ull,
  3415365148503583576ull, 9179973484349830374ull}},
{{10063400020595428130ull, 2601631403804354319ull,
  15969661273096903447ull, 5737483427718643983ull}},
{{7967564007316897259ull, 17087097310037606611ull,
  15350390572943741404ull, 7171854284648304979ull}},
{{5347768990718733670ull, 2912127563837456648ull,
  14576302197752288852ull, 8964817855810381224ull}},
{{3342355619199208544ull, 11043451764253186213ull,
  9110188873595180532ull, 5603011159881488265ull}},
{{8789630542426398583ull, 13804314705316482766ull,
  15999422110421363569ull, 7003763949851860331ull}},
{{1763666141178222421ull, 3420335326363439746ull,
  15387591619599316558ull, 8754704937314825414ull}},
{{5713977356663776917ull, 15972767634259313553ull,
  5005558743822184944ull, 5471690585821765884ull}},
{{11754157714257109051ull, 1519215469114590325ull,
  6256948429777731181ull, 6839613232277207355ull}},
{{857639087539222601ull, 6510705354820625811ull, 3209499518794776072ull,
  8549516540346509194ull}},
{{16676925494207871790ull, 4069190846762891131ull,
  6617623217674122949ull, 5343447837716568246ull}},
{{16234470849332451833ull, 9698174576881001818ull,
  17495401058947429494ull, 6679309797145710307ull}},
{{11069716524810788983ull, 2899346184246476465ull,
  17257565305256898964ull, 8349137246432137884ull}},
{{1043800365661259ull, 11035463402008823599ull, 1562606278930786044ull,
  5218210779020086178ull}},
{{13836362805739240285ull, 13794329252511029498ull,
  11176629885518258363ull, 6522763473775107722ull}},
{{8072081470319274549ull, 12631225547211398969ull,
  4747415320043047146ull, 8153454342218884653ull}},
{{16574265965018016353ull, 12506201985434512259ull,
  5272977584240598418ull, 5095908963886802908ull}},
{{16106146437845132537ull, 6409380444938364516ull,
  6591221980300748023ull, 6369886204858503635ull}},
{{1685938973596864055ull, 3400039537745567742ull,
  3627341456948547125ull, 7962357756073129544ull}},
{{14888769913780203747ull, 4430867720304673790ull,
  2267088410592841953ull, 4976473597545705965ull}},
{{9387590355370478875ull, 10150270668808230142ull,
  7445546531668440345ull, 6220591996932132456ull}},
{{2511115907358322786ull, 17299524354437675582ull,
  9306933164585550431ull, 7775739996165165570ull}},
{{15404505497381115454ull, 17729731749164629094ull,
  10428519246293356923ull, 4859837497603228481ull}},
{{10032259834871618509ull, 17550478668028398464ull,
  17647335076294084058ull, 6074796872004035601ull}},
{{12540324793589523136ull, 12714726298180722272ull,
  8224110790085441361ull, 7593496090005044502ull}},
{{7837702995993451960ull, 1029174908721869564ull, 528383225376012947ull,
  4745935056253152814ull}},
{{9797128744991814950ull, 15121526691184500667ull,
  9883851068574791991ull, 5932418820316441017ull}},
{{7634724912812380783ull, 14290222345553237930ull,
  16966499854145877893ull, 7415523525395551271ull}},
{{9383389088935125894ull, 11237231975184467658ull,
  17521591436482255539ull, 4634702203372219544ull}},
{{2505864324314131559ull, 9434853950553196669ull,
  3455245221893267808ull, 5793377754215274431ull}},
{{7744016423820052353ull, 11793567438191495836ull,
  18154114582648748472ull, 7241722192769093038ull}},
{{9680020529775065441ull, 14741959297739369795ull,
  13469271191456159782ull, 9052152740961366298ull}},
{{3744169821895721949ull, 4602038542659718218ull,
  13029980513087487768ull, 5657595463100853936ull}},
{{13903584314224428244ull, 5752548178324647772ull,
  16287475641359359710ull, 7071994328876067420ull}},
{{17379480392780535305ull, 16414057259760585523ull,
  1912600477989648021ull, 8839992911095084276ull}},
{{8556332236274140614ull, 12564628796564059904ull,
  10418747335598305821ull, 5524995569434427672ull}},
{{10695415295342675767ull, 1870727940422911168ull,
  13023434169497882277ull, 6906244461793034590ull}},
{{13369269119178344708ull, 6950095943956026864ull,
  7055920675017577038ull, 8632805577241293238ull}},
{{8355793199486465443ull, 18178868020254680502ull,
  18245008477168149360ull, 5395503485775808273ull}},
{{1221369462503305996ull, 4276840951608799012ull,
  8971202541178022989ull, 6744379357219760342ull}},
{{1526711828129132494ull, 9957737207938386669ull,
  1990631139617752928ull, 8430474196524700428ull}},
{{3260037901794401761ull, 6223585754961491668ull,
  10467516499115871388ull, 5269046372827937767ull}},
{{4075047377243002201ull, 7779482193701864585ull,
  8472709605467451331ull, 6586307966034922209ull}},
{{9705495239981140656ull, 5112666723699942827ull,
  15202573025261702068ull, 8232884957543652761ull}},
{{3760091515774518958ull, 12418788739167240075ull,
  2584079113147481936ull, 5145553098464782976ull}},
{{88428376290760793ull, 15523485923959050094ull, 3230098891434352420ull,
  6431941373080978720ull}},
{{9333907507218226799ull, 957613331239261001ull, 4037623614292940526ull,
  8039926716351223400ull}},
{{17362907238079861510ull, 14433566387306701837ull,
  2523514758933087828ull, 5024954197719514625ull}},
{{7868575992317663175ull, 18041957984133377297ull,
  7766079467093747689ull, 6281192747149393281ull}},
{{14447406008824466873ull, 8717389424884557909ull,
  14319285352294572516ull, 7851490933936741601ull}},
{{11335471764728985748ull, 14671740427407624501ull,
  2032024317543025966ull, 4907181833710463501ull}},
{{334281650629068472ull, 9116303497404754819ull, 7151716415356170362ull,
  6133977292138079376ull}},
{{14252910118568499302ull, 2172007334901167715ull,
  8939645519195212953ull, 7667471615172599220ull}},
{{6602225814891618112ull, 12886719630381699582ull,
  14810650486351783903ull, 4792169759482874512ull}},
{{17476154305469298448ull, 11496713519549736573ull,
  66569034230178263ull, 5990212199353593141ull}},
{{8010134826554459348ull, 9759205881009782813ull,
  4694897311215110733ull, 7487765249191991426ull}},
{{7312177275810231045ull, 8405346684844808210ull,
  7545996837936832112ull, 4679853280744994641ull}},
{{18363593631617564614ull, 10506683356056010262ull,
  14044182065848428044ull, 5849816600931243301ull}},
{{13731120002667179959ull, 13133354195070012828ull,
  3720169527028371343ull, 7312270751164054127ull}},
{{17163900003333974949ull, 11805006725410128131ull,
  38525890358076275ull, 9140338438955067659ull}},
{{8421594492870040391ull, 5072286194167636130ull,
  16164979745969655336ull, 5712711524346917286ull}},
{{1303621079232774681ull, 6340357742709545163ull,
  10982852645607293362ull, 7140889405433646608ull}},
{{15464584404323132063ull, 17148819215241707261ull,
  13728565807009116702ull, 8926111756792058260ull}},
{{11971208261915651492ull, 6106325991098679134ull,
  17803725666235473747ull, 5578819847995036412ull}},
{{5740638290539788556ull, 3021221470445961014ull,
  3807913009084790568ull, 6973524809993795516ull}},
{{16399169900029511503ull, 3776526838057451267ull,
  4759891261355988210ull, 8716906012492244395ull}},
{{7943638178304750738ull, 6972015292213294946ull, 669089029133798679ull,
  5448066257807652747ull}},
{{706175686026162614ull, 4103333096839230779ull,
  14671419341699412061ull, 6810082822259565933ull}},
{{14717777662814866979ull, 9740852389476426377ull,
  4504216121842101364ull, 8512603527824457417ull}},
{{2281082011618210006ull, 15311404780277542294ull,
  14344350122219783112ull, 5320377204890285885ull}},
{{12074724551377538316ull, 692511901637376251ull,
  4095379597492565179ull, 6650471506112857357ull}},
{{10481719670794534991ull, 14700697932328884026ull,
  9730910515293094377ull, 8313089382641071696ull}},
{{11162760812673972273ull, 2270407180064470660ull,
  6081819072058183986ull, 5195680864150669810ull}},
{{13953451015842465341ull, 12061381011935364133ull,
  16825645876927505790ull, 6494601080188337262ull}},
{{3606755714520917965ull, 5853354228064429359ull,
  11808685309304606430ull, 8118251350235421578ull}},
{{9171751349216655584ull, 17493404447822432061ull,
  11992114336742766922ull, 5073907093897138486ull}},
{{16076375204948207384ull, 12643383522923264268ull,
  5766770884073682845ull, 6342383867371423108ull}},
{{1648724932475707614ull, 1969171348371916624ull,
  7208463605092103557ull, 7927979834214278885ull}},
{{1030453082797317259ull, 3536575101946141842ull,
  6811132762396258675ull, 4954987396383924303ull}},
{{10511438390351422382ull, 18255776932714841014ull,
  3902229934567935439ull, 6193734245479905379ull}},
{{3915925951084502169ull, 18208035147466163364ull,
  266101399782531395ull, 7742167806849881724ull}},
{{11670825756282589664ull, 9074178957952658150ull,
  9389685411718857930ull, 4838854879281176077ull}},
{{5365160158498461271ull, 2119351660586046880ull,
  16348792783075960317ull, 6048568599101470096ull}},
{{6706450198123076589ull, 7260875594159946504ull,
  1989246905135398780ull, 7560710748876837621ull}},
{{4191531373826922868ull, 13761419283204742373ull,
  3549122324923318189ull, 4725444218048023513ull}},
{{9851100235711041489ull, 3366716048723764254ull,
  9048088924581535641ull, 5906805272560029391ull}},
{{3090503257784026054ull, 8820081079332093222ull,
  6698425137299531647ull, 7383506590700036739ull}},
{{15766622591397179996ull, 12430079702223640119ull,
  1880672701598513327ull, 4614691619187522962ull}},
{{15096592220819087091ull, 10925913609352162245ull,
  11574212913852917467ull, 5768364523984403702ull}},
{{5035682220741695151ull, 9045705993262814903ull,
  5244394105461371026ull, 7210455654980504628ull}},
{{1682916757499731035ull, 2083760454723742821ull,
  6555492631826713783ull, 9013069568725630785ull}},
{{3357665982651025849ull, 8219879311843421119ull,
  15626397940960165874ull, 5633168480453519240ull}},
{{18032140533595946023ull, 1051477102949500590ull,
  1086253352490655727ull, 7041460600566899051ull}},
{{13316803630140156721ull, 15149404433969039450ull,
  15192874745895483370ull, 8801825750708623813ull}},
{{12934688287264985855ull, 14080063789658037560ull,
  11801389725398371058ull, 5501141094192889883ull}},
{{16168360359081232318ull, 8376707700217771142ull,
  10140051138320575919ull, 6876426367741112354ull}},
{{10987078411996764589ull, 5859198606844826024ull,
  3451691886045944091ull, 8595532959676390443ull}},
{{6866924007497977869ull, 1356156120064322313ull,
  18298208493274572721ull, 5372208099797744026ull}},
{{13195341027799860240ull, 6306881168507790795ull,
  13649388579738440093ull, 6715260124747180033ull}},
{{11882490266322437395ull, 12495287479062126398ull,
  3226677669390886404ull, 8394075155933975042ull}},
{{2814870398024135468ull, 17032926711268604807ull,
  6628359561796691906ull, 5246296972458734401ull}},
{{17353646052812333047ull, 12067786352230980200ull,
  12897135470673252787ull, 6557871215573418001ull}},
{{3245313492305864693ull, 10473046921861337347ull,
  2286361283059402272ull, 8197339019466772502ull}},
{{18169221997187023097ull, 6545654326163335841ull,
  15264033857194290132ull, 5123336887166732813ull}},
{{8876469441201615159ull, 8182067907704169802ull,
  5244984266210698953ull, 6404171108958416017ull}},
{{1872214764647243141ull, 14839270903057600157ull,
  11167916351190761595ull, 8005213886198020021ull}},
{{3475977237118220915ull, 6968701305197306146ull,
  9285790728707919949ull, 5003258678873762513ull}},
{{13568343583252551952ull, 13322562649924020586ull,
  16218924429312287840ull, 6254073348592203141ull}},
{{7737057442210914132ull, 16653203312405025733ull,
  6438597481358196088ull, 7817591685740253927ull}},
{{7141503910595515285ull, 10408252070253141083ull,
  10941652453489954411ull, 4885994803587658704ull}},
{{4315193869817006202ull, 8398629069389038450ull,
  13677065566862443014ull, 6107493504484573380ull}},
{{14617364374126033560ull, 1274914299881522254ull,
  17096331958578053768ull, 7634366880605716725ull}},
{{4524166715401383071ull, 796821437425951409ull,
  12991050483324977557ull, 4771479300378572953ull}},
{{10266894412679116743ull, 5607712815209827165ull,
  2403755048874058234ull, 5964349125473216192ull}},
{{17445304034276283833ull, 16233013055867059764ull,
  3004693811092572792ull, 7455436406841520240ull}},
{{1679942984567901588ull, 10145633159916912353ull,
  1877933631932857995ull, 4659647754275950150ull}},
{{6711614749137264888ull, 8070355431468752537ull,
  11570789076770848302ull, 5824559692844937687ull}},
{{13001204454848969014ull, 864572252481164863ull,
  9851800327536172474ull, 7280699616056172109ull}},
{{11639819550133823364ull, 10304087352456231887ull,
  16926436427847603496ull, 9100874520070215136ull}},
{{14192416246474721458ull, 6440054595285144929ull,
  10579022767404752185ull, 5688046575043884460ull}},
{{3905462252811238111ull, 12661754262533819066ull,
  13223778459255940231ull, 7110058218804855575ull}},
{{14105199852868823447ull, 11215506809739885928ull,
  11918037055642537385ull, 8887572773506069469ull}},
{{8815749908043014654ull, 92162728446346849ull, 9754616168990279818ull,
  5554732983441293418ull}},
{{15631373403481156222ull, 9338575447412709369ull,
  2969898174383073964ull, 6943416229301616773ull}},
{{5704158699069281565ull, 11673219309265886712ull,
  8324058736406230359ull, 8679270286627020966ull}},
{{3565099186918300978ull, 14213291095932261051ull,
  590850691826506070ull, 5424543929141888104ull}},
{{18291432038930039935ull, 8543241833060550505ull,
  738563364783132588ull, 6780679911427360130ull}},
{{9029231993380386206ull, 10679052291325688132ull,
  10146576242833691543ull, 8475849889284200162ull}},
{{14866642032717517187ull, 13591936709719636938ull,
  10953296170198445118ull, 5297406180802625101ull}},
{{9359930504042120676ull, 7766548850294770365ull,
  18303306231175444302ull, 6621757726003281376ull}},
{{16311599148480038749ull, 484814026013687148ull,
  4432388715259753762ull, 8277197157504101721ull}},
{{971377430945248410ull, 4914694784685942372ull,
  14299457993105815861ull, 5173248223440063575ull}},
{{1214221788681560513ull, 10755054499284815869ull,
  13262636472954881922ull, 6466560279300079469ull}},
{{6129463254279338545ull, 4220446087251244028ull,
  2743237535911438691ull, 8083200349125099337ull}},
{{13054286570779362399ull, 331935795318333565ull,
  13243738506013118942ull, 5052000218203187085ull}},
{{2482800158192039286ull, 9638291781002692765ull,
  2719615077234234965ull, 6315000272753983857ull}},
{{7715186216167437011ull, 16659550744680753860ull,
  8011204864970181610ull, 7893750340942479821ull}},
{{14045363421959423940ull, 15023905233852859066ull,
  7312846049820057458ull, 4933593963089049888ull}},
{{8333332240594504117ull, 9556509505461298025ull,
  9141057562275071823ull, 6166992453861312360ull}},
{{15028351319170518051ull, 7333950863399234627ull,
  11426321952843839779ull, 7708740567326640450ull}},
{{7086876565267879830ull, 2277876280410827690ull,
  11753137238954787766ull, 4817962854579150281ull}},
{{18081967743439625595ull, 12070717387368310420ull,
  856363493411320995ull, 6022453568223937852ull}},
{{4155715605589980378ull, 10476710715783000122ull,
  1070454366764151244ull, 7528066960279922315ull}},
{{7209008271921125640ull, 15771316234219150884ull,
  16809935043723452191ull, 4705041850174951446ull}},
{{9011260339901407050ull, 15102459274346550701ull,
  11789046767799539431ull, 5881302312718689308ull}},
{{15875761443304146717ull, 14266388074505800472ull,
  14736308459749424289ull, 7351627890898361635ull}},
{{1397957730420631780ull, 3997927037850086879ull,
  13808699556259392458ull, 9189534863622952044ull}},
{{7791252609153976718ull, 7110390417083692203ull,
  17853809259516896094ull, 5743459289764345027ull}},
{{5127379743015082994ull, 18111360058209391062ull,
  17705575555968732213ull, 7179324112205431284ull}},
{{15632596715623629550ull, 8804142017479575115ull,
  3685225371251363651ull, 8974155140256789106ull}},
{{7464529938051074517ull, 3196745751711040495ull,
  6914951875459490186ull, 5608846962660493191ull}},
{{4718976404136455242ull, 13219304226493576427ull,
  4032003825896974828ull, 7011058703325616489ull}},
{{1287034486743181149ull, 16524130283116970534ull,
  9651690800798606439ull, 8763823379157020611ull}},
{{14639454609496651930ull, 17245110454589188439ull,
  3726463741285435072ull, 5477389611973137882ull}},
{{13687632243443427009ull, 3109643994526933933ull,
  13881451713461569649ull, 6846737014966422352ull}},
{{3274482249022120049ull, 8498741011586055321ull,
  17351814641826962061ull, 8558421268708027940ull}},
{{13575766451707294791ull, 7617556141454978527ull,
  1621512114287075480ull, 5349013292942517463ull}},
{{12358022046206730584ull, 9521945176818723159ull,
  15861948198141008062ull, 6686266616178146828ull}},
{{10835841539331025326ull, 2679059434168628141ull,
  1380691173966708462ull, 8357833270222683536ull}},
{{9078243971295584781ull, 15509470201637556300ull,
  862931983729192788ull, 5223645793889177210ull}},
{{11347804964119480976ull, 940093678337393759ull,
  10302037016516266794ull, 6529557242361471512ull}},
{{9573070186721963316ull, 10398489134776518007ull,
  12877546270645333492ull, 8161946552951839390ull}},
{{12900697894342308929ull, 15722427746090099562ull,
  3436780400725945528ull, 5101216595594899619ull}},
{{6902500331073110353ull, 1206290608903072837ull,
  18131033556189595623ull, 6376520744493624523ull}},
{{13239811432268775845ull, 15342921316411004758ull,
  18052105926809606624ull, 7970650930617030654ull}},
{{3663196126740596999ull, 9589325822756877974ull,
  6670880185828616236ull, 4981656831635644159ull}},
{{13802367195280522057ull, 11986657278446097467ull,
  3726914213858382391ull, 6227071039544555199ull}},
{{12641272975673264667ull, 10371635579630233930ull,
  46956748895590085ull, 7783838799430693999ull}},
{{12512481628223178321ull, 8788115246482590158ull,
  6946876995700825659ull, 4864899249644183749ull}},
{{6417229998424197093ull, 6373458039675849794ull,
  13295282263053419978ull, 6081124062055229686ull}},
{{17244909534885022174ull, 17190194586449588050ull,
  7395730791961999164ull, 7601405077569037108ull}},
{{15389754477730526763ull, 1520499579676216723ull,
  13845703781831025286ull, 4750878173480648192ull}},
{{14625507078735770550ull, 11123996511450046712ull,
  17307129727288781607ull, 5938597716850810240ull}},
{{18281883848419713187ull, 9293309620885170486ull,
  3187168085401425393ull, 7423247146063512801ull}},
{{6814491386834932838ull, 17337533559121701314ull,
  13521195099444360630ull, 4639529466289695500ull}},
{{17741486270398441855ull, 12448544912047350834ull,
  16901493874305450788ull, 5799411832862119375ull}},
{{12953485801143276511ull, 15560681140059188543ull,
  16515181324454425581ull, 7249264791077649219ull}},
{{11580171233001707735ull, 5615793369791821967ull,
  16032290637140644073ull, 9061580988847061524ull}},
{{14155136048267149190ull, 15039085902188358489ull,
  796809611358126737ull, 5663488118029413453ull}},
{{3858862005051772776ull, 4963799322453284400ull,
  5607698032625046326ull, 7079360147536766816ull}},
{{4823577506314715970ull, 15428121189921381308ull,
  7009622540781307907ull, 8849200184420958520ull}},
{{12238107978301473289ull, 7336732734487169365ull,
  4381014087988317442ull, 5530750115263099075ull}},
{{1462576917594677900ull, 18394287954963737515ull,
  864581591558008898ull, 6913437644078873844ull}},
{{15663279202275511086ull, 13769487906849896085ull,
  1080726989447511123ull, 8641797055098592305ull}},
{{12095392510635888381ull, 6300086932567491101ull,
  12204669414473164212ull, 5401123159436620190ull}},
{{1284182583012696764ull, 7875108665709363877ull,
  6032464731236679457ull, 6751403949295775238ull}},
{{6216914247193258859ull, 14455571850564092750ull,
  16763952950900625129ull, 8439254936619719047ull}},
{{17720629459777950499ull, 2117203378961476112ull,
  17394999621953972562ull, 5274534335387324404ull}},
{{3704042751012886508ull, 11869876260556620949ull,
  3297005453732914086ull, 6593167919234155506ull}},
{{9241739457193496039ull, 5613973288841000378ull,
  13344628854020918416ull, 8241459899042694382ull}},
{{10387773179173322928ull, 3508733305525625236ull,
  3728707015335686106ull, 5150912436901683989ull}},
{{12984716473966653660ull, 13609288668761807353ull,
  9272569787596995536ull, 6438640546127104986ull}},
{{2395837537176153363ull, 17011610835952259192ull,
  2367340197641468612ull, 8048300682658881233ull}},
{{1497398460735095852ull, 1408884735615386187ull,
  13008802669594387643ull, 5030187926661800770ull}},
{{15706806131201033527ull, 15596163974801396445ull,
  7037631300138208745ull, 6287734908327250963ull}},
{{5798449608719128197ull, 5660146913219581845ull,
  4185353106745373028ull, 7859668635409063704ull}},
{{5929874014663149075ull, 12760963857617014461ull,
  2615845691715858142ull, 4912292897130664815ull}},
{{12024028536756324248ull, 6727832785166492268ull,
  17104865169926986390ull, 6140366121413331018ull}},
{{15030035670945405310ull, 17633163018312891143ull,
  12157709425553957179ull, 7675457651766663773ull}},
{{16311301321981960175ull, 8714883877231863012ull,
  9904411400184917189ull, 4797161032354164858ull}},
{{1942382578767898602ull, 15505290864967216670ull,
  3157142213376370678ull, 5996451290442706073ull}},
{{11651350260314649061ull, 10158241544354245029ull,
  8558113785147851252ull, 7495564113053382591ull}},
{{9587936921910349615ull, 15572273002076178951ull,
  12266350143358488888ull, 4684727570658364119ull}},
{{7373235133960549115ull, 1018597178885672073ull,
  10721251660770723207ull, 5855909463322955149ull}},
{{13828229935878074298ull, 15108304528889253803ull,
  18013250594390791912ull, 7319886829153693936ull}},
{{12673601401420204968ull, 438636587402015638ull,
  4069819169278938275ull, 9149858536442117421ull}},
{{3309314857460240201ull, 16415048931622117438ull,
  4849479990013030373ull, 5718661585276323388ull}},
{{13360015608680076059ull, 6683753109245483085ull,
  6061849987516287967ull, 7148326981595404235ull}},
{{2864961455567931362ull, 3743005368129465953ull,
  2965626465967972055ull, 8935408726994255294ull}},
{{13319815955798426861ull, 9256907382721998076ull,
  15688574596512146246ull, 5584630454371409558ull}},
{{16649769944748033577ull, 2347762191547721787ull,
  10387346208785407000ull, 6980788067964261948ull}},
{{16200526412507654067ull, 2934702739434652234ull,
  12984182760981758750ull, 8725985084955327435ull}},
{{14737015026244671696ull, 15669247267428821358ull,
  5809271216399905266ull, 5453740678097079647ull}},
{{9197896745951063812ull, 10363187047431250890ull,
  2649903002072493679ull, 6817175847621349559ull}},
{{2273998895584053956ull, 8342297790861675709ull,
  17147436807872780811ull, 8521469809526686948ull}},
{{3727092318953727675ull, 2908093110074853366ull,
  1493775968065712199ull, 5325918630954179343ull}},
{{13882237435546935402ull, 17470174442875730419ull,
  15702278015364303960ull, 6657398288692724178ull}},
{{12741110776006281348ull, 3390973979885111408ull,
  10404475482350604143ull, 8321747860865905223ull}},
{{7963194235003925843ull, 9036887765069276486ull,
  13420326204110209445ull, 5201092413041190764ull}},
{{730620756900131495ull, 15907795724763983512ull,
  16775407755137761806ull, 6501365516301488455ull}},
{{913275946125164369ull, 10661372619100203582ull,
  16357573675494814354ull, 8126706895376860569ull}},
{{14405855521610391443ull, 11275043905365015142ull,
  3305954519543177115ull, 5079191809610537856ull}},
{{8783947365158213495ull, 9482118863278881024ull,
  4132443149428971394ull, 6348989762013172320ull}},
{{10979934206447766869ull, 2629276542243825472ull,
  5165553936786214243ull, 7936237202516465400ull}},
{{6862458879029854293ull, 17784198903398248584ull,
  3228471210491383901ull, 4960148251572790875ull}},
{{8578073598787317866ull, 8395190573965647018ull,
  17870647068396393589ull, 6200185314465988593ull}},
{{1499219961629371525ull, 15105674235884446677ull,
  8503250780213328274ull, 7750231643082485742ull}},
{{3242855485232051155ull, 14052732415855167077ull,
  702845719205942267ull, 4843894776926553589ull}},
{{8665255374967451848ull, 12954229501391570942ull,
  5490243167434815738ull, 6054868471158191986ull}},
{{1608197181854539002ull, 6969414839884687870ull,
  16086175996148295481ull, 7568585588947739982ull}},
{{14840181293941250588ull, 15885099320996399678ull,
  5442173979165296771ull, 4730365993092337489ull}},
{{9326854580571787427ull, 15244688132818111694ull,
  11414403492384008868ull, 5912957491365421861ull}},
{{2435196188859958476ull, 609116092313088002ull, 432946310197847374ull,
  7391196864206777327ull}},
{{6133683636464861952ull, 14215755612977843713ull,
  7188120471514736464ull, 4619498040129235829ull}},
{{12278790564008465343ull, 17769694516222304641ull,
  13596836607820808484ull, 5774372550161544786ull}},
{{1513430149728417967ull, 3765374071568329186ull,
  7772673722921234798ull, 7217965687701930983ull}},
{{11115159724015298267ull, 13930089626315187290ull,
  5104156135224155593ull, 9022457109627413729ull}},
{{11558660845936949321ull, 1788776988805910200ull,
  14719312630583567006ull, 5639035693517133580ull}},
{{14448326057421186651ull, 11459343272862163558ull,
  18399140788229458757ull, 7048794616896416975ull}},
{{8837035534921707506ull, 489121035795540736ull,
  18387239966859435543ull, 8810993271120521219ull}},
{{5523147209326067191ull, 7223229675013294816ull,
  9186181970073453262ull, 5506870794450325762ull}},
{{6903934011657583989ull, 18252409130621394328ull,
  2259355425737040769ull, 6883588493062907203ull}},
{{8629917514571979986ull, 8980453357994579198ull,
  16659252337453464674ull, 8604485616328634003ull}},
{{782012428180099587ull, 10224469367173999903ull,
  8106189701694721469ull, 5377803510205396252ull}},
{{14812573590507288196ull, 17392272727394887782ull,
  10132737127118401836ull, 6722254387756745315ull}},
{{9292344951279334437ull, 3293596835534058112ull,
  8054235390470614392ull, 8402817984695931644ull}},
{{5807715594549584023ull, 2058498022208786320ull,
  14257269155898909803ull, 5251761240434957277ull}},
{{7259644493186980029ull, 16408180583043146612ull,
  3986528389591473541ull, 6564701550543696597ull}},
{{9074555616483725036ull, 6675167673521769553ull,
  9594846505416729831ull, 8205876938179620746ull}},
{{17200812306370797908ull, 11089508823592187826ull,
  10608465084312844048ull, 5128673086362262966ull}},
{{12277643346108721577ull, 13861886029490234783ull,
  4037209318536279252ull, 6410841357952828708ull}},
{{10735368164208514067ull, 17327357536862793479ull,
  5046511648170349065ull, 8013551697441035885ull}},
{{13627134130271403148ull, 3912069432898164068ull,
  5459912789320162118ull, 5008469810900647428ull}},
{{17033917662839253935ull, 14113458827977480893ull,
  6824890986650202647ull, 6260587263625809285ull}},
{{7457339023266903706ull, 13030137516544463213ull,
  13142799751740141213ull, 7825734079532261606ull}},
{{6966679898755508769ull, 10449678957053983460ull,
  3602563826410200354ull, 4891083799707663504ull}},
{{8708349873444385961ull, 3838726659462703517ull,
  4503204783012750443ull, 6113854749634579380ull}},
{{15497123360232870355ull, 186722305900991492ull,
  5629005978765938054ull, 7642318437043224225ull}},
{{462330063290768164ull, 13951759496470283395ull,
  15047343782797181043ull, 4776449023152015140ull}},
{{14412970634395623917ull, 12828013352160466339ull,
  362435654786924688ull, 5970561278940018926ull}},
{{13404527274567141992ull, 16035016690200582924ull,
  9676416605338431668ull, 7463201598675023657ull}},
{{17601201583459239553ull, 798513394520588519ull,
  17576975424404989553ull, 4664500999171889785ull}},
{{17389815960896661537ull, 5609827761578123553ull,
  8136161225224073229ull, 5830626248964862232ull}},
{{7902211895838663209ull, 11623970720400042346ull,
  10170201531530091536ull, 7288282811206077790ull}},
{{654392832943553204ull, 14529963400500052933ull,
  3489379877557838612ull, 9110353514007597238ull}},
{{2714838529803414704ull, 18304599162167308891ull,
  16015920478755812844ull, 5693970946254748273ull}},
{{17228606217536432092ull, 4434004878999584497ull,
  6184842543162602344ull, 7117463682818435342ull}},
{{7700699716638376403ull, 5542506098749480622ull,
  16954425215808028738ull, 8896829603523044177ull}},
{{201251304471597348ull, 8075752330145813293ull, 3678986732238936105ull,
  5560518502201902611ull}},
{{4863250149016884589ull, 14706376431109654520ull,
  18433791470580833843ull, 6950648127752378263ull}},
{{6079062686271105736ull, 13771284520459680246ull,
  18430553319798654400ull, 8688310159690472829ull}},
{{17634472234201604797ull, 8607052825287300153ull,
  13824938834087852952ull, 5430193849806545518ull}},
{{8208032237469842285ull, 10758816031609125192ull,
  8057801505755040382ull, 6787742312258181898ull}},
{{10260040296837302856ull, 4225148002656630682ull,
  848879845339024670ull, 8484677890322727373ull}},
{{11024211203950702189ull, 16475775556942557888ull,
  2836392912550584370ull, 5302923681451704608ull}},
{{13780264004938377736ull, 11371347409323421552ull,
  3545491140688230463ull, 6628654601814630760ull}},
{{17225330006172972170ull, 9602498243226889036ull,
  4431863925860288079ull, 8285818252268288450ull}},
{{1542459217003331799ull, 12919090429657887504ull,
  7381600972090067953ull, 5178636407667680281ull}},
{{1928074021254164748ull, 2313804981790195668ull,
  13838687233539972846ull, 6473295509584600351ull}},
{{2410092526567705935ull, 12115628264092520393ull,
  12686673023497578153ull, 8091619386980750439ull}},
{{13035522875173285969ull, 654738637416743389ull,
  14846699667327068202ull, 5057262116862969024ull}},
{{2459345538684443750ull, 10041795333625705045ull,
  111630510449283636ull, 6321577646078711281ull}},
{{7685867941782942591ull, 12552244167032131306ull,
  4751224156488992449ull, 7901972057598389101ull}},
{{9415353482041727024ull, 927623576754000210ull, 5275358107019314233ull,
  4938732535998993188ull}},
{{2545819815697382971ull, 5771215489369888167ull,
  6594197633774142791ull, 6173415669998741485ull}},
{{17017332824903892426ull, 2602333343284972304ull,
  12854433060645066393ull, 7716769587498426856ull}},
{{10635833015564932766ull, 13155673385621577450ull,
  8034020662903166495ull, 4822980992186516785ull}},
{{4071419232601390150ull, 11832905713599583909ull,
  14654211847056346023ull, 6028726240233145981ull}},
{{9700960059179125591ull, 10179446123572091982ull,
  4482706753538268817ull, 7535907800291432477ull}},
{{1451414018559565591ull, 17891368873301027249ull,
  5107534730175111962ull, 4709942375182145298ull}},
{{6425953541626844892ull, 13140839054771508253ull,
  15607790449573665761ull, 5887427968977681622ull}},
{{12644127945460944019ull, 2590990763182221604ull,
  10286366025112306394ull, 7359284961222102028ull}},
{{15805159931826180024ull, 12462110490832552813ull,
  12857957531390382992ull, 9199106201527627535ull}},
{{12184067966605056467ull, 7788819056770345508ull,
  14953752484760071226ull, 5749441375954767209ull}},
{{15230084958256320584ull, 512651784108156077ull,
  4857132550667925321ull, 7186801719943459012ull}},
{{5202548142538237018ull, 5252500748562583001ull,
  6071415688334906651ull, 8983502149929323765ull}},
{{14780807635154867896ull, 976969958637920423ull,
  6100477814423010609ull, 5614688843705827353ull}},
{{13864323525516196966ull, 5832898466724788433ull,
  12237283286456151165ull, 7018361054632284191ull}},
{{3495346351613082496ull, 11902809101833373446ull,
  10684918089642801052ull, 8772951318290355239ull}},
{{16019649525040340272ull, 16662627725500634211ull,
  13595602833667832513ull, 5483094573931472024ull}},
{{15412875887873037436ull, 6993226601593629052ull,
  16994503542084790642ull, 6853868217414340030ull}},
{{819350786131745179ull, 17964905288846812124ull,
  12019757390751212494ull, 8567335271767925038ull}},
{{9735466278187116545ull, 6616379787101869673ull,
  2900662350792119905ull, 5354584544854953149ull}},
{{16781018866161283585ull, 12882160752304724995ull,
  8237513956917537785ull, 6693230681068691436ull}},
{{16364587564274216577ull, 2267642885098742532ull,
  10296892446146922232ull, 8366538351335864295ull}},
{{1004495190816609553ull, 1417276803186714083ull,
  13353086806482908251ull, 5229086469584915184ull}},
{{15090677043802925653ull, 15606654059265556315ull,
  16691358508103635313ull, 6536358086981143980ull}},
{{14251660286326269162ull, 5673259518799781682ull,
  2417454061419992526ull, 8170447608726429976ull}},
{{13518973697381306130ull, 17380845254532027263ull,
  1510908788387495328ull, 5106529755454018735ull}},
{{12287031103299244759ull, 3279312494455482463ull,
  15723694040766532873ull, 6383162194317523418ull}},
{{10747102860696668045ull, 8710826636496740983ull,
  10431245514103390283ull, 7978952742896904273ull}},
{{13634468315576499384ull, 3138423638596769162ull,
  18048743492383088687ull, 4986845464310565170ull}},
{{7819713357615848422ull, 17758087603528125165ull,
  13337557328624085050ull, 6233556830388206463ull}},
{{14386327715447198431ull, 12974237467555380648ull,
  12060260642352718409ull, 7791946037985258079ull}},
{{8991454822154499020ull, 1191369389581031049ull,
  14455191929111530862ull, 4869966273740786299ull}},
{{15851004546120511679ull, 10712583773831064619ull,
  13457303892962025673ull, 6087457842175982874ull}},
{{15202069664223251694ull, 18002415735716218678ull,
  7598257829347756283ull, 7609322302719978593ull}},
{{4889607521712144405ull, 8945666825608942722ull,
  16278126189410817437ull, 4755826439199986620ull}},
{{15335381438994956314ull, 15793769550438566306ull,
  1900913663053970180ull, 5944783048999983276ull}},
{{9945854761888919584ull, 1295467864338656267ull,
  2376142078817462726ull, 7430978811249979095ull}},
{{3910316216966880788ull, 14644725470493823879ull,
  8402617826901996059ull, 4644361757031236934ull}},
{{276209252781213081ull, 13694220819689891945ull,
  1279900246772719266ull, 5805452196289046168ull}},
{{4956947584403904256ull, 7894403987757589123ull,
  1599875308465899083ull, 7256815245361307710ull}},
{{1584498462077492416ull, 5256318966269598500ull,
  11223216172437149662ull, 9071019056701634637ull}},
{{10213683575653208568ull, 17120257409200662774ull,
  9320353116986912490ull, 5669386910438521648ull}},
{{3543732432711734902ull, 12176949724646052660ull,
  11650441396233640613ull, 7086733638048152060ull}},
{{4429665540889668627ull, 1386129100525402113ull,
  14563051745292050767ull, 8858417047560190075ull}},
{{14297756009124512652ull, 7783859715469458176ull,
  6796064331593837777ull, 5536510654725118797ull}},
{{17872195011405640815ull, 14341510662764210624ull,
  13106766432919685125ull, 6920638318406398496ull}},
{{3893499690547499403ull, 4091830273173099569ull,
  16383458041149606407ull, 8650797898007998120ull}},
{{13962652352660656887ull, 9474922948374269086ull,
  10239661275718504004ull, 5406748686254998825ull}},
{{8229943403971045300ull, 11843653685467836358ull,
  17411262613075517909ull, 6758435857818748531ull}},
{{1064057218109030817ull, 969509051552631736ull,
  17152392247917009483ull, 8448044822273435664ull}},
{{665035761318144261ull, 16746844221716252499ull,
  10720245154948130926ull, 5280028013920897290ull}},
{{14666352756929844038ull, 11710183240290539815ull,
  4176934406830387850ull, 6600035017401121613ull}},
{{13721254927734917144ull, 5414357013508398961ull,
  9832854026965372717ull, 8250043771751402016ull}},
{{1658255302193241359ull, 5689816142656443303ull,
  6145533766853357948ull, 5156277357344626260ull}},
{{15907877183023715411ull, 7112270178320554128ull,
  7681917208566697435ull, 6445346696680782825ull}},
{{1438102405070092647ull, 4278651704473304757ull,
  14214082529135759698ull, 8056683370850978531ull}},
{{3204657012382501857ull, 7285843333723203377ull,
  6577958571496155859ull, 5035427106781861582ull}},
{{8617507283905515225ull, 4495618148726616317ull,
  17445820251224970632ull, 6294283883477326977ull}},
{{15383570123309281935ull, 5619522685908270396ull,
  7972217258749049578ull, 7867854854346658722ull}},
{{391359290213525401ull, 8123887697120056902ull, 9594321805145543890ull,
  4917409283966661701ull}},
{{9712571149621682560ull, 931487584545295319ull,
  16604588274859317767ull, 6146761604958327126ull}},
{{7529027918599715295ull, 14999417535963782861ull,
  11532363306719371400ull, 7683452006197908908ull}},
{{7011485458338516012ull, 9374635959977364288ull,
  16431099103554382933ull, 4802157503873693067ull}},
{{8764356822923145015ull, 16329980968399093264ull,
  15927187861015590762ull, 6002696879842116334ull}},
{{10955446028653931268ull, 11189104173644090772ull,
  10685612789414712645ull, 7503371099802645418ull}},
{{16070525804763482851ull, 9299033117741250684ull,
  11290194011811583307ull, 4689606937376653386ull}},
{{1641413182244801947ull, 7012105378749175452ull,
  4889370477909703326ull, 5862008671720816733ull}},
{{2051766477806002434ull, 17988503760291245123ull,
  10723399115814517061ull, 7327510839651020916ull}},
{{16399766152539666754ull, 8650571645081892691ull,
  13404248894768146327ull, 9159388549563776145ull}},
{{7944010836123597770ull, 12324136305817264788ull,
  1460126531589009598ull, 5724617843477360091ull}},
{{9930013545154497212ull, 6181798345416805177ull,
  15660216219768425710ull, 7155772304346700113ull}},
{{17024202949870509419ull, 16950619968625782279ull,
  5740212219428368425ull, 8944715380433375142ull}},
{{17557655871310150243ull, 3676608452750032068ull,
  17422690692424893978ull, 5590447112770859463ull}},
{{3500325765428136188ull, 13819132602792315894ull,
  17166677347103729568ull, 6988058890963574329ull}},
{{13598779243639946042ull, 17273915753490394867ull,
  7623288628597498248ull, 8735073613704467912ull}},
{{6193394018061272325ull, 10796197345931496792ull,
  4764555392873436405ull, 5459421008565292445ull}},
{{7741742522576590406ull, 18106932700841758894ull,
  10567380259519183410ull, 6824276260706615556ull}},
{{453806116365962199ull, 13410293839197422810ull,
  13209225324398979263ull, 8530345325883269445ull}},
{{4895314841156114279ull, 15298962677139471112ull,
  10561608836963055991ull, 5331465828677043403ull}},
{{6119143551445142848ull, 14512017327996950986ull,
  8590325027776432085ull, 6664332285846304254ull}},
{{16872301476161204368ull, 4304963604714025020ull,
  1514534247865764299ull, 8330415357307880318ull}},
{{1321816385745976922ull, 384759243732571686ull,
  14781641960198266399ull, 5206509598317425198ull}},
{{10875642519037246961ull, 14316007109947878319ull,
  9253680413393057190ull, 6508136997896781498ull}},
{{8982867130369170797ull, 8671636850580072091ull,
  2343728479886545680ull, 8135171247370976873ull}},
{{3308448947267037796ull, 5419773031612545057ull,
  12994045345997560810ull, 5084482029606860545ull}},
{{8747247202511185149ull, 15998088326370457129ull,
  2407498627214787300ull, 6355602537008575682ull}},
{{15545745021566369340ull, 1550866334253519795ull,
  12232745320873259934ull, 7944503171260719602ull}},
{{7410247629265286886ull, 14804349514190613584ull,
  12257151843973175362ull, 4965314482037949751ull}},
{{9262809536581608607ull, 9282064855883491172ull,
  10709753786539081299ull, 6206643102547437189ull}},
{{11578511920727010759ull, 6990895051426976061ull,
  17998878251601239528ull, 7758303878184296486ull}},
{{9542412959668075676ull, 4369309407141860038ull,
  6637612888823386801ull, 4848939923865185304ull}},
{{2704644162730318787ull, 10073322777354712952ull,
  8297016111029233501ull, 6061174904831481630ull}},
{{3380805203412898484ull, 17203339490120779094ull,
  1147898101931766068ull, 7576468631039352038ull}},
{{15948061307415225265ull, 1528715144470711125ull,
  14552494368989517505ull, 4735292894399595023ull}},
{{6100018578986867869ull, 6522579949015776811ull,
  13578931942809508977ull, 5919116117999493779ull}},
{{3013337205306196932ull, 12764910954697108918ull,
  12361978910084498317ull, 7398895147499367224ull}},
{{15718393808598536795ull, 10283912355899387025ull,
  7726236818802811448ull, 4624309467187104515ull}},
{{5812934205466007281ull, 12854890444874233782ull,
  5046110005076126406ull, 5780386833983880644ull}},
{{16489539793687284909ull, 6845241019238016419ull,
  6307637506345158008ull, 7225483542479850805ull}},
{{16000238723681718232ull, 8556551274047520524ull,
  12496232901358835414ull, 9031854428099813506ull}},
{{776777165446298087ull, 736158527852312424ull, 12421831581776660038ull,
  5644909017562383441ull}},
{{970971456807872609ull, 10143570196670166338ull,
  1692231421938661335ull, 7056136271952979302ull}},
{{10437086357864616569ull, 8067776727410320018ull,
  11338661314278102477ull, 8820170339941224127ull}},
{{11134864992092773260ull, 7348203463845143963ull,
  14004192349064895904ull, 5512606462463265079ull}},
{{9306895221688578671ull, 9185254329806429954ull,
  12893554417903731976ull, 6890758078079081349ull}},
{{2410246990255947531ull, 11481567912258037443ull,
  2281884967097501258ull, 8613447597598851687ull}},
{{17647305433405824871ull, 11787665963588661305ull,
  8343707132077020142ull, 5383404748499282304ull}},
{{8224073736475117376ull, 5511210417631050824ull,
  10429633915096275178ull, 6729255935624102880ull}},
{{10280092170593896720ull, 16112385058893589338ull,
  13037042393870343972ull, 8411569919530128600ull}},
{{11036743625048573354ull, 846868624953717528ull,
  8148151496168964983ull, 5257231199706330375ull}},
{{13795929531310716693ull, 14893643836474310622ull,
  5573503351783818324ull, 6571538999632912969ull}},
{{8021539877283620058ull, 170310721883336662ull,
  11578565208157160810ull, 8214423749541141211ull}},
{{401776404874874632ull, 4718130219604473318ull, 4930760245884531554ull,
  5134014843463213257ull}},
{{9725592542948369098ull, 15121034811360367455ull,
  10775136325783052346ull, 6417518554329016571ull}},
{{7545304660258073469ull, 9677921477345683511ull,
  8857234388801427529ull, 8021898192911270714ull}},
{{11633344440302377774ull, 17577915969409521954ull,
  10147457511428280109ull, 5013686370569544196ull}},
{{5318308513523196410ull, 8137336906479738731ull,
  12684321889285350137ull, 6267107963211930245ull}},
{{2036199623476607608ull, 14783357151527061318ull,
  2020344306324523959ull, 7833884954014912807ull}},
{{15107682819955043467ull, 16157127247345495179ull,
  8180244219093909330ull, 4896178096259320504ull}},
{{14272917506516416430ull, 10973037022327093166ull,
  10225305273867386663ull, 6120222620324150630ull}},
{{8617774846290744729ull, 9104610259481478554ull,
  3558259555479457521ull, 7650278275405188288ull}},
{{9997795297359103360ull, 17219596458244393856ull,
  2223912222174660950ull, 4781423922128242680ull}},
{{12497244121698879200ull, 12301123535950716512ull,
  2779890277718326188ull, 5976779902660303350ull}},
{{15621555152123599000ull, 15376404419938395640ull,
  12698234884002683543ull, 7470974878325379187ull}},
{{9763471970077249375ull, 16527781790102579131ull,
  5630553793287983262ull, 4669359298953361992ull}},
{{7592653944169173815ull, 11436355200773448106ull,
  7038192241609979078ull, 5836699123691702490ull}},
{{267445393356691460ull, 5072071964112034325ull,
  18021112338867249656ull, 7295873904614628112ull}},
{{4945992760123252229ull, 6340089955140042906ull,
  4079646349874510454ull, 9119842380768285141ull}},
{{7702931493504420547ull, 17797614277244690528ull,
  4855621977885262985ull, 5699901487980178213ull}},
{{9628664366880525684ull, 8411959791273699448ull,
  10681213490783966636ull, 7124876859975222766ull}},
{{12035830458600657105ull, 10514949739092124310ull,
  4128144826625182487ull, 8906096074969028458ull}},
{{2910708018198022787ull, 13489372614573659550ull,
  7191776535068126958ull, 5566310046855642786ull}},
{{12861757059602304291ull, 7638343731362298629ull,
  18213092705689934506ull, 6957887558569553482ull}},
{{2242138269220716652ull, 324557627348097479ull,
  13542993845257642325ull, 8697359448211941853ull}},
{{8318865445904029764ull, 2508691526306254876ull,
  10770214162499720405ull, 5435849655132463658ull}},
{{10398581807380037204ull, 7747550426310206499ull,
  4239395666269874698ull, 6794812068915579573ull}},
{{8386541240797658601ull, 461065996032982316ull, 9910930601264731277ull,
  8493515086144474466ull}},
{{14464960312353312434ull, 2594009256734307899ull,
  10806017644217844952ull, 5308446928840296541ull}},
{{13469514372014252638ull, 3242511570917884874ull,
  18119208073699694094ull, 6635558661050370676ull}},
{{7613520928163039990ull, 13276511500502131901ull,
  4202266018415066001ull, 8294448326312963346ull}},
{{7064293589315593946ull, 1380290660172750582ull,
  7238102279936804155ull, 5184030203945602091ull}},
{{18053739023499268240ull, 15560421380498101939ull,
  4435941831493617289ull, 6480037754932002614ull}},
{{17955487760946697396ull, 5615468670340463712ull,
  14768299326221797420ull, 8100047193665003267ull}},
{{11222179850591685873ull, 12733039955817565628ull,
  6924344069674929435ull, 5062529496040627042ull}},
{{14027724813239607341ull, 11304613926344569131ull,
  17878802123948437602ull, 6328161870050783802ull}},
{{12922969998122121272ull, 4907395371075935606ull,
  13125130618080771195ull, 7910202337563479753ull}},
{{3465170230398937891ull, 761279097708765802ull, 1285677608659400141ull,
  4943876460977174846ull}},
{{13554834824853448172ull, 5563284890563345156ull,
  10830469047679025984ull, 6179845576221468557ull}},
{{16943543531066810215ull, 6954106113204181445ull,
  18149772328026170384ull, 7724806970276835696ull}},
{{12895557716130450336ull, 4346316320752613403ull,
  11343607705016356490ull, 4828004356423022310ull}},
{{11507761126735675016ull, 14656267437795542562ull,
  4956137594415669804ull, 6035005445528777888ull}},
{{5161329371564817962ull, 18320334297244428203ull,
  6195171993019587255ull, 7543756806910972360ull}},
{{919987848014317275ull, 18367737963418849483ull,
  3871982495637242034ull, 4714848004319357725ull}},
{{14985042865300060305ull, 13736300417418786045ull,
  9451664137973940447ull, 5893560005399197156ull}},
{{4896245526342911669ull, 12558689503346094653ull,
  11814580172467425559ull, 7366950006748996445ull}},
{{10731992926356027491ull, 11086675860755230412ull,
  933167160302118237ull, 9208687508436245557ull}},
{{15930867615827292990ull, 9235015422185712959ull,
  2889072484402517850ull, 5755429692772653473ull}},
{{15301898501356728333ull, 2320397240877365391ull,
  8223026623930535217ull, 7194287115965816841ull}},
{{14515687108268522512ull, 7512182569524094643ull,
  14890469298340556925ull, 8992858894957271051ull}},
{{6766461433454132618ull, 7000957115166253104ull,
  7000700302249154126ull, 5620536809348294407ull}},
{{8458076791817665773ull, 17974568430812592188ull,
  4139189359384054753ull, 7025671011685368009ull}},
{{10572595989772082216ull, 8633152483233576523ull,
  9785672717657456346ull, 8782088764606710011ull}},
{{4302029484393857433ull, 10007406320448373231ull,
  3810202439322216264ull, 5488805477879193757ull}},
{{765850837064933887ull, 12509257900560466539ull,
  9374439067580158234ull, 6861006847348992196ull}},
{{14792371601613331071ull, 6413200338845807365ull,
  11718048834475197793ull, 8576258559186240245ull}},
{{11551075260222025872ull, 15537465257847099363ull,
  9629623530760692572ull, 5360161599491400153ull}},
{{9827158056850144435ull, 975087498599322588ull,
  16648715431878253620ull, 6700201999364250191ull}},
{{12283947571062680544ull, 1218859373249153235ull,
  16199208271420429121ull, 8375252499205312739ull}},
{{5371624222700481388ull, 12291002154349190532ull,
  7818662160424074248ull, 5234532812003320462ull}},
{{6714530278375601735ull, 15363752692936488165ull,
  549955663675317002ull, 6543166015004150578ull}},
{{13004848866396890073ull, 9981318829315834398ull,
  9910816616448922061ull, 8178957518755188222ull}},
{{3516344523070668392ull, 8544167277536090451ull,
  1582574366853188384ull, 5111848449221992639ull}},
{{18230488709120499201ull, 10680209096920113063ull,
  15813276013848649192ull, 6389810561527490798ull}},
{{18176424867973236098ull, 13350261371150141329ull,
  10543222980456035682ull, 7987263201909363498ull}},
{{4442736514842190705ull, 12955599375396226235ull,
  11201200381212410205ull, 4992039501193352186ull}},
{{941734625125350477ull, 2359441163963119082ull, 4778128439660736949ull,
  6240049376491690233ull}},
{{10400540318261463905ull, 7560987473381286756ull,
  10584346568003309090ull, 7800061720614612791ull}},
{{15723709735768190749ull, 9337303189290692126ull,
  13532745632643150037ull, 4875038575384132994ull}},
{{10431265132855462628ull, 16283315005040753062ull,
  7692560003949161738ull, 6093798219230166243ull}},
{{3815709379214552476ull, 11130771719446165520ull,
  5004013986509064269ull, 7617247774037707804ull}},
{{2384818362009095298ull, 9262575333867547402ull,
  12350880778422940976ull, 4760779858773567377ull}},
{{12204394989366144930ull, 11578219167334434252ull,
  1603542917746512508ull, 5950974823466959222ull}},
{{15255493736707681163ull, 14472773959168042815ull,
  11227800684037916443ull, 7438718529333699027ull}},
{{16452212613083382583ull, 6739640715266332807ull,
  4711532418310003825ull, 4649199080833561892ull}},
{{15953579747926840324ull, 13036236912510303913ull,
  5889415522887504781ull, 5811498851041952365ull}},
{{6106916629626386693ull, 2460238085355716180ull,
  11973455422036768881ull, 7264373563802440456ull}},
{{7633645787032983367ull, 7686983625122033129ull,
  14966819277545961101ull, 9080466954753050570ull}},
{{16300243662964084364ull, 7110207774914964657ull,
  13965948066893613592ull, 5675291846720656606ull}},
{{6540246523422941743ull, 8887759718643705822ull,
  8234063046762241182ull, 7094114808400820758ull}},
{{17398680191133452987ull, 1886327611449856469ull,
  1069206771598025670ull, 8867643510501025948ull}},
{{13180018128672102069ull, 15014012812438324005ull,
  9891626269103541851ull, 5542277194063141217ull}},
{{2639964605557963874ull, 14155829997120517103ull,
  16976218854806815218ull, 6927846492578926521ull}},
{{17135013812229618555ull, 8471415459545870570ull,
  7385215513226355311ull, 8659808115723658152ull}},
{{15321069651070899501ull, 12212163689857250962ull,
  4615759695766472069ull, 5412380072327286345ull}},
{{9927965026983848568ull, 1430146557039399991ull,
  10381385638135477991ull, 6765475090409107931ull}},
{{7798270265302422806ull, 15622741251581413701ull,
  8365046029241959584ull, 8456843863011384914ull}},
{{7179761925027708206ull, 9764213282238383563ull,
  9839839786703612644ull, 5285527414382115571ull}},
{{4363016387857247353ull, 12205266602797979454ull,
  7688113714952127901ull, 6606909267977644464ull}},
{{14677142521676334999ull, 1421525198215310605ull,
  9610142143690159877ull, 8258636584972055580ull}},
{{11479057085261403327ull, 3194296258098263080ull,
  15229710876661125731ull, 5161647865607534737ull}},
{{14348821356576754158ull, 17827928377904992562ull,
  5202080540544243451ull, 6452059832009418422ull}},
{{8712654658866166890ull, 17673224453953852799ull,
  15725972712535080122ull, 8065074790011773027ull}},
{{12362938189432436162ull, 15657451302148545903ull,
  7522889936120731124ull, 5040671743757358142ull}},
{{10841986718363157299ull, 1125070053976130763ull,
  180240383296138098ull, 6300839679696697678ull}},
{{8940797379526558719ull, 10629709604324939262ull,
  9448672515974948430ull, 7876049599620872097ull}},
{{976312343776711296ull, 2031882484275699135ull,
  17434635368552812529ull, 4922530999763045060ull}},
{{15055448485003052832ull, 7151539123772011822ull,
  3346550136981464045ull, 6153163749703806326ull}},
{{9595938569399040231ull, 13551109923142402682ull,
  13406559708081605864ull, 7691454687129757907ull}},
{{10609147624301788049ull, 8469443701964001676ull,
  6073256808337309713ull, 4807159179456098692ull}},
{{13261434530377235061ull, 15198490645882389999ull,
  7591571010421637141ull, 6008948974320123365ull}},
{{11965107144544155922ull, 5163055252070823787ull,
  14101149781454434331ull, 7511186217900154206ull}},
{{5172348956126403499ull, 921066523330570915ull, 4201532594981633553ull,
  4694491386187596379ull}},
{{1853750176730616470ull, 5763019172590601548ull, 640229725299654037ull,
  5868114232734495474ull}},
{{2317187720913270588ull, 11815459984165639839ull,
  10023659193479343354ull, 7335142790918119342ull}},
{{16731542706423751946ull, 5545952943352273990ull,
  3306201954994403385ull, 9168928488647649178ull}},
{{5845528173087457063ull, 14995435635663641004ull,
  6678062240298890019ull, 5730580305404780736ull}},
{{7306910216359321328ull, 14132608526152163351ull,
  8347577800373612524ull, 7163225381755975920ull}},
{{4521951752021763756ull, 17665760657690204189ull,
  10434472250467015655ull, 8954031727194969900ull}},
{{5132062854227296300ull, 17958629438697459474ull,
  15744917193396660592ull, 5596269829496856187ull}},
{{15638450604638896183ull, 4001542724662272726ull,
  15069460473318437837ull, 6995337286871070234ull}},
{{10324691218943844420ull, 9613614424255228812ull,
  9613453554793271488ull, 8744171608588837793ull}},
{{15676304048694678571ull, 6008509015159518007ull,
  17537623517814264440ull, 5465107255368023620ull}},
{{14983694042440960309ull, 7510636268949397509ull,
  3475285323558278934ull, 6831384069210029526ull}},
{{4894559497769036674ull, 164923299331971079ull,
  13567478691302624476ull, 8539230086512536907ull}},
{{9976628713746729778ull, 9326449098937257732ull,
  6173831172850446345ull, 5337018804070335567ull}},
{{12470785892183412222ull, 16269747392098960069ull,
  3105602947635670027ull, 6671273505087919459ull}},
{{1753424309947101565ull, 15725498221696312183ull,
  17717061739826751246ull, 8339091881359899323ull}},
{{8013419221358020335ull, 5216750370132807210ull,
  8767320578178025577ull, 5211932425849937077ull}},
{{793401989842749610ull, 11132623981093396917ull,
  15570836741149919875ull, 6514915532312421346ull}},
{{5603438505730824917ull, 9304093957939358242ull,
  10240173889582624036ull, 8143644415390526683ull}},
{{8113835084509153477ull, 15038430760566874709ull,
  4094265671775446070ull, 5089777759619079177ull}},
{{14753979874063829750ull, 9574666413853817578ull,
  9729518108146695492ull, 6362222199523848971ull}},
{{9219102805725011380ull, 11968333017317271973ull,
  7550211616755981461ull, 7952777749404811214ull}},
{{8067782262791826064ull, 9786051145036988935ull, 107196242045100509ull,
  4970486093378007009ull}},
{{5473041810062394676ull, 16844249949723624073ull,
  4745681320983763540ull, 6213107616722508761ull}},
{{11452988281005381249ull, 2608568363444978475ull,
  10543787669657092330ull, 7766384520903135951ull}},
{{4852274666414669329ull, 6242041245580499451ull,
  13507396321176764562ull, 4853990325564459969ull}},
{{1453657314590948757ull, 17025923593830400122ull,
  3049187346188791990ull, 6067487906955574962ull}},
{{11040443680093461754ull, 12059032455433224344ull,
  13034856219590765796ull, 7584359883694468702ull}},
{{6900277300058413597ull, 16760267321500541023ull,
  3535099118816840718ull, 4740224927309042939ull}},
{{4013660606645629092ull, 11726962115020900471ull,
  18253931953803214610ull, 5925281159136303673ull}},
{{405389739879648460ull, 5435330606921349781ull, 8982356886971854551ull,
  7406601448920379592ull}},
{{2559211596638474240ull, 10314610656966925469ull,
  5613973054357409094ull, 4629125905575237245ull}},
{{7810700514225480704ull, 3669891284353881028ull,
  11629152336374149272ull, 5786407381969046556ull}},
{{9763375642781850880ull, 4587364105442351285ull,
  14536440420467686590ull, 7233009227461308195ull}},
{{16815905571904701503ull, 14957577168657714914ull,
  13558864507157220333ull, 9041261534326635244ull}},
{{15121627000867826344ull, 11654328739624765773ull,
  17697662353828038516ull, 5650788458954147027ull}},
{{5066975695802619218ull, 14567910924530957217ull,
  17510391923857660241ull, 7063485573692683784ull}},
{{10945405638180661926ull, 4374830600381532809ull,
  3441245831112523686ull, 8829356967115854731ull}},
{{18370093569931383464ull, 16569327180520621717ull,
  18291679708941184967ull, 5518348104447409206ull}},
{{9127558907132065618ull, 16099972957223389243ull,
  13641227599321705401ull, 6897935130559261508ull}},
{{6797762615487694118ull, 6289908141247072842ull,
  17051534499152131752ull, 8622418913199076885ull}},
{{8860287653107196728ull, 3931192588279420526ull,
  12963052071183776297ull, 5389011820749423053ull}},
{{1851987529529220102ull, 9525676753776663562ull,
  2368757033697556659ull, 6736264775936778817ull}},
{{11538356448766300935ull, 7295409923793441548ull,
  7572632310549333728ull, 8420330969920973521ull}},
{{16434844817333713893ull, 4559631202370900967ull,
  16262110240161803340ull, 5262706856200608450ull}},
{{15931870003239754462ull, 5699539002963626209ull,
  11104265763347478367ull, 6578383570250760563ull}},
{{6079779448767529365ull, 2512737735277144858ull,
  9268646185756960055ull, 8222979462813450704ull}},
{{8411548173907093757ull, 8487990112189297392ull,
  5792903866098100034ull, 5139362164258406690ull}},
{{10514435217383867197ull, 1386615603381845932ull,
  16464501869477400851ull, 6424202705323008362ull}},
{{13143044021729833996ull, 15568327559509471127ull,
  11357255299991975255ull, 8030253381653760453ull}},
{{15131931541222228103ull, 16647733752334501310ull,
  9404127571708678486ull, 5018908363533600283ull}},
{{9691542389673009321ull, 11586295153563350830ull,
  7143473446208460204ull, 6273635454417000354ull}},
{{2891055950236485843ull, 14482868941954188538ull,
  18152713844615351063ull, 7842044318021250442ull}},
{{6418595987325191556ull, 15969322116362449692ull,
  15957132171311982318ull, 4901277698763281526ull}},
{{8023244984156489445ull, 10738280608598286307ull,
  10723043177285202090ull, 6126597123454101908ull}},
{{5417370211768223902ull, 4199478723893082076ull,
  13403803971606502613ull, 7658246404317627385ull}},
{{12609228419209915747ull, 4930517211646870249ull,
  1459848454612982277ull, 4786404002698517116ull}},
{{1926477468730230972ull, 10774832532985975716ull,
  1824810568266227846ull, 5983005003373146395ull}},
{{2408096835912788715ull, 4245168629377693837ull,
  16116071265614948520ull, 7478756254216432993ull}},
{{3810903531659186899ull, 2653230393361058648ull,
  3155015513368260969ull, 4674222658885270621ull}},
{{4763629414573983623ull, 7928224010128711214ull,
  8555455410137714115ull, 5842778323606588276ull}},
{{15177908805072255337ull, 5298593994233501113ull,
  10694319262672142644ull, 7303472904508235345ull}},
{{5137327951058155459ull, 6623242492791876392ull,
  17979585096767566209ull, 9129341130635294181ull}},
{{3210829969411347162ull, 15668741604063392505ull,
  13543083694693422832ull, 5705838206647058863ull}},
{{8625223480191571857ull, 1139182931369689015ull,
  12317168599939390637ull, 7132297758308823579ull}},
{{6169843331812076917ull, 6035664682639499173ull,
  10784774731496850392ull, 8915372197886029474ull}},
{{6161995091596242025ull, 3772290426649686983ull,
  11352170225612919399ull, 5572107623678768421ull}},
{{3090807846067914627ull, 103677014884720825ull, 355154726733985537ull,
  6965134529598460527ull}},
{{8475195826012281188ull, 4741282287033288935ull,
  14279001463699645633ull, 8706418161998075658ull}},
{{12214526418898757599ull, 14492516475464275344ull,
  13536061933239666424ull, 5441511351248797286ull}},
{{15268158023623446998ull, 18115645594330344180ull,
  7696705379694807222ull, 6801889189060996608ull}},
{{638453455819757132ull, 13421184956058154418ull,
  9620881724618509028ull, 8502361486326245760ull}},
{{5010719428314736112ull, 17611612634391122319ull,
  6013051077886568142ull, 5313975928953903600ull}},
{{1651713266966032235ull, 12791143756134127091ull,
  7516313847358210178ull, 6642469911192379500ull}},
{{15899699638989704006ull, 6765557658312883055ull,
  9395392309197762723ull, 8303087388990474375ull}},
{{16854841302009646860ull, 1922630527231857957ull,
  12789649220889683558ull, 5189429618119046484ull}},
{{7233493572229894863ull, 11626660195894598255ull,
  15987061526112104447ull, 6486787022648808105ull}},
{{4430180946859980674ull, 9921639226440859915ull,
  6148768852357966847ull, 8108483778311010132ull}},
{{463020082573793970ull, 13118553544166619303ull,
  13066352569578505087ull, 5067802361444381332ull}},
{{14413833158499406174ull, 11786505911780886224ull,
  16332940711973131359ull, 6334752951805476665ull}},
{{18017291448124257717ull, 10121446371298719876ull,
  6581117834684250487ull, 7918441189756845832ull}},
{{2037435118222885266ull, 13243433009702781779ull,
  4113198646677656554ull, 4949025743598028645ull}},
{{16381851953060770294ull, 7330919225273701415ull,
  9753184326774458597ull, 6186282179497535806ull}},
{{15865628922898574963ull, 13775335050019514673ull,
  2968108371613297438ull, 7732852724371919758ull}},
{{2998489049170527496ull, 3997898387834808767ull,
  15690125787540474611ull, 4833032952732449848ull}},
{{17583169366745323082ull, 385686966366123054ull,
  1165913160716041648ull, 6041291190915562311ull}},
{{12755589671576878044ull, 482108707957653818ull,
  15292449506177215772ull, 7551613988644452888ull}},
{{12583929563162936682ull, 9524689979328309444ull,
  9557780941360759857ull, 4719758742902783055ull}},
{{15729911953953670852ull, 16517548492587774709ull,
  7335540158273561917ull, 5899698428628478819ull}},
{{5827331887159924853ull, 6811877560452554675ull,
  4557739179414564493ull, 7374623035785598524ull}},
{{2672478840522518162ull, 13126532968993081248ull,
  5697173974268205616ull, 9218278794731998155ull}},
{{1670299275326573852ull, 8204083105620675780ull,
  1254890724703934558ull, 5761424246707498847ull}},
{{2087874094158217315ull, 1031731845171068917ull,
  15403671461162081910ull, 7201780308384373558ull}},
{{7221528636125159547ull, 10513036843318611954ull,
  10031217289597826579ull, 9002225385480466948ull}},
{{9125141416005612621ull, 4264805017860438519ull,
  15492882842853417420ull, 5626390865925291842ull}},
{{6794740751579627872ull, 5331006272325548149ull,
  10142731516711995967ull, 7032988582406614803ull}},
{{13105111957901922744ull, 2052071821979547282ull,
  8066728377462607055ull, 8791235728008268504ull}},
{{12802380992116089619ull, 8200073916378298907ull,
  5041705235914129409ull, 5494522330005167815ull}},
{{11391290221717724120ull, 14861778413900261538ull,
  1690445526465273857ull, 6868152912506459769ull}},
{{5015740740292379342ull, 4742164962093163211ull,
  6724742926508980226ull, 8585191140633074711ull}},
{{828994953469043137ull, 7575539119735614911ull,
  11120493356709194497ull, 5365744462895671694ull}},
{{14871301747118467633ull, 14081109918096906542ull,
  4677244659031717313ull, 6707180578619589618ull}},
{{9365755147043308733ull, 3766329342338969466ull,
  15069927860644422450ull, 8383975723274487022ull}},
{{10465282985329455862ull, 6965641857389243820ull,
  4807018894475376127ull, 5239984827046554389ull}},
{{13081603731661819828ull, 4095366303309166871ull,
  10620459636521608063ull, 6549981033808192986ull}},
{{11740318646149886881ull, 507521860709070685ull,
  4052202508797234271ull, 8187476292260241233ull}},
{{9643542163057373253ull, 7234730190584251034ull,
  14061841614066741179ull, 5117172682662650770ull}},
{{2831055666966940758ull, 4431726719802925889ull,
  8353929980728650666ull, 6396465853328313463ull}},
{{8150505602136063851ull, 14763030436608433169ull,
  5830726457483425428ull, 7995582316660391829ull}},
{{16623281047403509667ull, 3521986025494922ull, 5950047045140834845ull,
  4997238947912744893ull}},
{{11555729272399611276ull, 4616088500959256557ull,
  12049244824853431460ull, 6246548684890931116ull}},
{{609603535217350382ull, 5770110626199070697ull,
  15061556031066789325ull, 7808185856113663895ull}},
{{11910217255579313749ull, 5912162150588113137ull,
  16331001547057825184ull, 4880116160071039934ull}},
{{1052713514191978474ull, 7390202688235141422ull,
  11190379896967505672ull, 6100145200088799918ull}},
{{10539263929594748901ull, 9237753360293926777ull,
  4764602834354606282ull, 7625181500110999898ull}},
{{18116255002065187823ull, 10385281868611092139ull,
  7589562789899016830ull, 4765738437569374936ull}},
{{18033632734154096875ull, 3758230298909089366ull,
  9486953487373771038ull, 5957173046961718670ull}},
{{13318668880837845285ull, 13921159910491137516ull,
  2635319822362437989ull, 7446466308702148338ull}},
{{17547540087378429112ull, 11006567953270654899ull,
  6258760907403911647ull, 4654041442938842711ull}},
{{17322739090795648485ull, 9146523923160930720ull,
  3211765115827501655ull, 5817551803673553389ull}},
{{3206679789785008991ull, 6821468885523775497ull,
  8626392413211764973ull, 7271939754591941736ull}},
{{8620035755658649142ull, 13138522125332107275ull,
  10782990516514706216ull, 9089924693239927170ull}},
{{3081679338072961762ull, 8211576328332567047ull,
  11351055091249079289ull, 5681202933274954481ull}},
{{17687157227873365914ull, 14876156428843096712ull,
  353760808779185399ull, 7101503666593693102ull}},
{{3662202461132155777ull, 13983509517626482987ull,
  9665573047828757557ull, 8876879583242116377ull}},
{{18429777602703455025ull, 11045536457730245818ull,
  17570198200961443233ull, 5548049739526322735ull}},
{{13813849966524542973ull, 18418606590590195177ull,
  17351061732774416137ull, 6935062174407903419ull}},
{{3432254402873515004ull, 9188200182955580260ull,
  17077141147540632268ull, 8668827718009879274ull}},
{{11368531038650722686ull, 14965997151202013470ull,
  15284899235640283071ull, 5418017323756174546ull}},
{{4987291761458627549ull, 14095810420575128934ull,
  9882752007695578031ull, 6772521654695218183ull}},
{{15457486738678060244ull, 13008077007291523263ull,
  7741753991192084635ull, 8465652068369022729ull}},
{{16578458239314869509ull, 5824205120343508087ull,
  16367811290563522657ull, 5291032542730639205ull}},
{{16111386780716198982ull, 11891942418856773013ull,
  6624706057922239609ull, 6613790678413299007ull}},
{{6304175420613085015ull, 1029869968288802555ull,
  3669196553975411608ull, 8267238348016623759ull}},
{{1634266628669484183ull, 643668730180501597ull, 9210776873875714111ull,
  5167023967510389849ull}},
{{6654519304264243132ull, 14639643968007790708ull,
  16125157110772030542ull, 6458779959387987311ull}},
{{8318149130330303915ull, 9076182923154962577ull,
  15544760370037650274ull, 8073474949234984139ull}},
{{16728058252524909707ull, 10284300345399239514ull,
  7409632222059837469ull, 5045921843271865087ull}},
{{11686700778801361326ull, 17467061450176437297ull,
  4650354259147408932ull, 6307402304089831359ull}},
{{773317918219537945ull, 3387082739010995006ull, 1201256805506873262ull,
  7884252880112289199ull}},
{{14318381754169374928ull, 15951984767164035590ull,
  7668314531082877644ull, 4927658050070180749ull}},
{{8674605155856942852ull, 1493236885245492872ull,
  14197079182280984960ull, 6159572562587725936ull}},
{{10843256444821178564ull, 1866546106556866090ull,
  17746348977851231200ull, 7699465703234657420ull}},
{{11388721296440624507ull, 1166591316598041306ull,
  1868096074302243692ull, 4812166064521660888ull}},
{{5012529583696004826ull, 1458239145747551633ull,
  2335120092877804615ull, 6015207580652076110ull}},
{{10877347998047393936ull, 15657856987466603253ull,
  12142272152952031576ull, 7519009475815095137ull}},
{{9104185507993315162ull, 9786160617166627033ull, 671391067953937879ull,
  4699380922384434461ull}},
{{15991917903419031856ull, 7621014753030895887ull,
  5450924853369810253ull, 5874226152980543076ull}},
{{15378211360846401916ull, 14137954459716007763ull,
  6813656066712262816ull, 7342782691225678845ull}},
{{14611078182630614491ull, 17672443074645009704ull,
  13128756101817716424ull, 9178478364032098556ull}},
{{9131923864144134057ull, 11045276921653131065ull,
  17428844600490848573ull, 5736548977520061597ull}},
{{16026590848607555476ull, 18418282170493801735ull,
  7950997695331397004ull, 7170686221900076997ull}},
{{15421552542332056440ull, 4576108639407700553ull,
  14550433137591634160ull, 8963357777375096246ull}},
{{2720941311316453419ull, 2860067899629812846ull,
  4482334692567383446ull, 5602098610859435154ull}},
{{12624548676000342582ull, 12798456911392041865ull,
  14826290402564005115ull, 7002623263574293942ull}},
{{1945627789718264515ull, 11386385120812664428ull,
  9309490966350230586ull, 8753279079467867428ull}},
{{10439389405428691130ull, 11728176718935303171ull,
  15041803890823669924ull, 5470799424667417142ull}},
{{8437550738358476009ull, 14660220898669128964ull,
  9578882826674811597ull, 6838499280834271428ull}},
{{10546938422948095011ull, 4490218068054247493ull,
  11973603533343514497ull, 8548124101042839285ull}},
{{8897679523556253334ull, 14335601338602374443ull,
  9789345217553390512ull, 5342577563151774553ull}},
{{6510413386017928763ull, 17919501673252968054ull,
  16848367540369126044ull, 6678221953939718191ull}},
{{17361388769377186762ull, 3952633017856658451ull,
  16448773407034019652ull, 8347777442424647739ull}},
{{8545024971647047774ull, 11693767673015187340ull,
  7974640370182568330ull, 5217360901515404837ull}},
{{10681281214558809718ull, 5393837554414208367ull,
  14579986481155598317ull, 6521701126894256046ull}},
{{8739915499771124243ull, 11353982961445148363ull,
  9001611064589722088ull, 8152126408617820058ull}},
{{3156604178143258700ull, 7096239350903217727ull,
  10237692933795964209ull, 5095079005386137536ull}},
{{17780813277961237087ull, 13481985207056410062ull,
  12797116167244955261ull, 6368848756732671920ull}},
{{13002644560596770551ull, 3017423453538348866ull,
  15996395209056194077ull, 7961060945915839900ull}},
{{12738338868800369499ull, 4191732667675161993ull,
  774374968805345490ull, 4975663091197399938ull}},
{{2087865530718298161ull, 14463037871448728300ull,
  10191340747861457670ull, 6219578863996749922ull}},
{{2609831913397872701ull, 8855425302456134567ull,
  3515803897972046280ull, 7774473579995937403ull}},
{{8548673973514752294ull, 5534640814035084104ull,
  18338278500728386589ull, 4859045987497460876ull}},
{{10685842466893440368ull, 11529987035971243034ull,
  4476104052200931620ull, 6073807484371826096ull}},
{{4133931046762024652ull, 14412483794964053793ull,
  5595130065251164525ull, 7592259355464782620ull}},
{{14112921950294735168ull, 11313645381066227572ull,
  12720328327636753636ull, 4745162097165489137ull}},
{{17641152437868418959ull, 14142056726332784465ull,
  2065352354263778333ull, 5931452621456861422ull}},
{{8216382492053359987ull, 3842512852633816870ull,
  11805062479684498725ull, 7414315776821076777ull}},
{{523553039105962088ull, 4707413542109829496ull, 460635022161729847ull,
  4633947360513172986ull}},
{{654441298882452610ull, 1272580909209898966ull, 9799165814556938117ull,
  5792434200641466232ull}},
{{10041423660457841570ull, 6202412154939761611ull,
  12248957268196172646ull, 7240542750801832790ull}},
{{7940093557144914059ull, 16976387230529477822ull,
  6087824548390439999ull, 9050678438502290988ull}},
{{350872454788183383ull, 17527771046722005495ull,
  13028262379598800807ull, 5656674024063931867ull}},
{{14273648623767392940ull, 17298027789975118964ull,
  11673641956071113105ull, 7070842530079914834ull}},
{{17842060779709241175ull, 7787476682186734993ull,
  5368680408234115574ull, 8838553162599893543ull}},
{{4233758959677193879ull, 255486907939321467ull,
  10272954282787404090ull, 5524095726624933464ull}},
{{680512681169104444ull, 9542730671778927642ull,
  12841192853484255112ull, 6905119658281166830ull}},
{{10074012888316156363ull, 11928413339723659552ull,
  6828119030000543082ull, 8631399572851458538ull}},
{{6296258055197597727ull, 12066944355754675124ull,
  8879260412177727330ull, 5394624733032161586ull}},
{{7870322568996997159ull, 5860308407838568097ull,
  1875703478367383355ull, 6743280916290201983ull}},
{{14449589229673634353ull, 2713699491370822217ull,
  16179687403241392906ull, 8429101145362752478ull}},
{{2113464240904939615ull, 6307748200534151790ull,
  5500618608598482662ull, 5268188215851720299ull}},
{{11865202337985950326ull, 17108057287522465545ull,
  2264087242320715423ull, 6585235269814650374ull}},
{{996444867200274196ull, 16773385590975694028ull,
  12053481089755670087ull, 8231544087268312967ull}},
{{9846150078854947180ull, 17400895022000890623ull,
  14450954708738375660ull, 5144715054542695604ull}},
{{7696001580141296071ull, 3304374703791561663ull,
  18063693385922969576ull, 6430893818178369505ull}},
{{5008315956749232185ull, 4130468379739452079ull,
  8744558677121548258ull, 8038617272722961882ull}},
{{10047726500609351972ull, 7193228755764545453ull,
  10077035191628355565ull, 5024135795451851176ull}},
{{17171344144189077869ull, 13603221963133069720ull,
  12596293989535444456ull, 6280169744314813970ull}},
{{3017436106526795720ull, 17004027453916337151ull,
  6521995450064529762ull, 7850212180393517463ull}},
{{8803426594220329181ull, 15239203177125098623ull,
  10993776183931412957ull, 4906382612745948414ull}},
{{6392597224348023572ull, 5213945916124209567ull,
  4518848193059490389ull, 6132978265932435518ull}},
{{3379060512007641561ull, 11129118413582649863ull,
  14871932278179138794ull, 7666222832415544397ull}},
{{9029441847645857832ull, 11567385026916544068ull,
  11600800683075655698ull, 4791389270259715248ull}},
{{11286802309557322290ull, 5235859246790904277ull,
  14501000853844569623ull, 5989236587824644060ull}},
{{273444831664489150ull, 1933138040061242443ull,
  18126251067305712029ull, 7486545734780805075ull}},
{{16311804084286163383ull, 3514054284251970478ull,
  9023063907852376066ull, 4679091084238003172ull}},
{{11166383068502928421ull, 13615939892169738906ull,
  11278829884815470082ull, 5848863855297503965ull}},
{{4734606798773884718ull, 7796552828357397825ull, 263479300737173891ull,
  7311079819121879957ull}},
{{10529944516894743801ull, 5134005017019359377ull,
  4941035144348855268ull, 9138849773902349946ull}},
{{18110430369127684636ull, 12432125172491875418ull,
  7699832983645422446ull, 5711781108688968716ull}},
{{13414665924554829987ull, 6316784428760068465ull,
  9624791229556778058ull, 7139726385861210895ull}},
{{2933274350411373771ull, 17119352572804861390ull,
  7419303018518584668ull, 8924657982326513619ull}},
{{15668354524289272319ull, 1476223321148262560ull,
  2331221377360421466ull, 5577911238954071012ull}},
{{1138699081652038783ull, 11068651188290104009ull,
  2914026721700526832ull, 6972389048692588765ull}},
{{6035059870492436382ull, 13835813985362630011ull,
  8254219420553046444ull, 8715486310865735956ull}},
{{1466069409844078787ull, 17870755777706419565ull,
  14382259174700429835ull, 5447178944291084972ull}},
{{6444272780732486388ull, 17726758703705636552ull,
  17977823968375537294ull, 6808973680363856215ull}},
{{8055340975915607985ull, 12935076342777269882ull,
  17860593942042033714ull, 8511217100454820269ull}},
{{9646274128374642895ull, 12696108732663181580ull,
  13468714222989965023ull, 5319510687784262668ull}},
{{12057842660468303618ull, 11258449897401589071ull,
  16835892778737456279ull, 6649388359730328335ull}},
{{10460617307157991618ull, 9461376353324598435ull,
  16433179954994432445ull, 8311735449662910419ull}},
{{4232042807760050810ull, 8219203230041567974ull,
  7964894462657826326ull, 5194834656039319012ull}},
{{14513425546554839320ull, 1050632000697184159ull,
  9956118078322282908ull, 6493543320049148765ull}},
{{13530095914766161246ull, 1313290000871480199ull,
  17056833616330241539ull, 8116929150061435956ull}},
{{15373838974369932635ull, 16961707315040532788ull,
  1437148973351625153ull, 5073080718788397473ull}},
{{770554644252864178ull, 7367076088518502274ull, 6408122235116919346ull,
  6341350898485496841ull}},
{{10186565342170856030ull, 18432217147502903650ull,
  12621838812323537086ull, 7926688623106871051ull}},
{{10978289357284172923ull, 6908449698761926877ull,
  5582806248488516727ull, 4954180389441794407ull}},
{{18334547715032604057ull, 4023876105025020692ull,
  2366821792183258005ull, 6192725486802243009ull}},
{{4471440570081203456ull, 9641531149708663770ull,
  7570213258656460410ull, 7740906858502803761ull}},
{{7406336374728140064ull, 10637642986995302760ull,
  16260598332728757516ull, 4838066786564252350ull}},
{{9257920468410175080ull, 13297053733744128450ull,
  11102375879056171087ull, 6047583483205315438ull}},
{{2349028548657943042ull, 12009631148752772659ull,
  4654597811965438051ull, 7559479354006644298ull}},
{{17609043907407072065ull, 5200176458756788959ull,
  7520809650905786686ull, 4724674596254152686ull}},
{{17399618865831452177ull, 15723592610300762007ull,
  177640026777457549ull, 5905843245317690858ull}},
{{17137837563861927318ull, 5819432707593788797ull,
  9445422070326597745ull, 7382304056647113572ull}},
{{13016991486627398526ull, 15166360488314587758ull,
  15126760830808899398ull, 4613940035404445982ull}},
{{7047867321429472349ull, 9734578573538458890ull,
  9685079001656348440ull, 5767425044255557478ull}},
{{18033206188641616244ull, 12168223216923073612ull,
  2882976715215659742ull, 7209281305319446848ull}},
{{4094763662092468689ull, 5986906984299066208ull,
  3603720894019574678ull, 9011601631649308560ull}},
{{2559227288807792931ull, 17576874920469080092ull,
  2252325558762234173ull, 5632251019780817850ull}},
{{3199034111009741163ull, 8136035595304186403ull,
  12038778985307568525ull, 7040313774726022312ull}},
{{17833850694044340166ull, 14781730512557620907ull,
  15048473731634460656ull, 8800392218407527890ull}},
{{8840313674564018652ull, 9238581570348513067ull,
  14016982100698925814ull, 5500245136504704931ull}},
{{6438706074777635411ull, 2324854926080865526ull,
  12909541607446269364ull, 6875306420630881164ull}},
{{17271754630326820071ull, 2906068657601081907ull,
  16136927009307836705ull, 8594133025788601455ull}},
{{8489003634740568593ull, 13345507957069145952ull,
  17003108408458479796ull, 5371333141117875909ull}},
{{10611254543425710741ull, 16681884946336432440ull,
  7418827455290936033ull, 6714166426397344887ull}},
{{13264068179282138426ull, 7017298127638376838ull,
  4661848300686282138ull, 8392708032996681109ull}},
{{3678356593623948612ull, 8997497348201373428ull,
  5219498197142620288ull, 5245442520622925693ull}},
{{4597945742029935765ull, 11246871685251716785ull,
  11136058764855663264ull, 6556803150778657116ull}},
{{10359118195964807611ull, 14058589606564645981ull,
  13920073456069579080ull, 8196003938473321395ull}},
{{8780291881691698709ull, 8786618504102903738ull,
  6394202900829792973ull, 5122502461545825872ull}},
{{1751992815259847578ull, 15594959148556017577ull,
  7992753626037241216ull, 6403128076932282340ull}},
{{6801677037502197376ull, 1046954861985470355ull,
  9990942032546551521ull, 8003910096165352925ull}},
{{1945205139225179408ull, 12183561834809388732ull,
  8550181779555288652ull, 5002443810103345578ull}},
{{2431506424031474260ull, 15229452293511735915ull,
  1464355187589335007ull, 6253054762629181973ull}},
{{16874441085321506537ull, 14425129348462281989ull,
  6442130002914056663ull, 7816318453286477466ull}},
{{12852368687539635538ull, 15933234870430008099ull,
  8638017270248673318ull, 4885199033304048416ull}},
{{11453774840997156518ull, 10693171551182734316ull,
  10797521587810841648ull, 6106498791630060520ull}},
{{14317218551246445648ull, 13366464438978417895ull,
  13496901984763552060ull, 7633123489537575650ull}},
{{15865790622170110386ull, 17577412311216286992ull,
  13047249758904607941ull, 4770702180960984781ull}},
{{1385494204003086367ull, 8136707333738195029ull,
  2474004143348596215ull, 5963377726201230977ull}},
{{6343553773431245862ull, 5559198148745355882ull,
  7704191197613133173ull, 7454222157751538721ull}},
{{8576407126821916568ull, 5780341852179541378ull,
  16344334544576677993ull, 4658888848594711700ull}},
{{1497136871672619902ull, 11837113333651814627ull,
  1983674107011295875ull, 5823611060743389626ull}},
{{15706479144872938589ull, 10184705648637380379ull,
  11702964670618895652ull, 7279513825929237032ull}},
{{15021412912663785332ull, 12730882060796725474ull,
  14628705838273619565ull, 9099392282411546290ull}},
{{14000069088842253737ull, 10262644297211647373ull,
  13754627167348400132ull, 5687120176507216431ull}},
{{3665028305770653459ull, 12828305371514559217ull,
  12581597940758112261ull, 7108900220634020539ull}},
{{9192971400640704728ull, 2200323659111035309ull,
  11115311407520252423ull, 8886125275792525674ull}},
{{8051450134614134407ull, 8292731314585478924ull,
  11558755648127545668ull, 5553828297370328546ull}},
{{10064312668267668009ull, 10365914143231848655ull,
  5225072523304656277ull, 6942285371712910683ull}},
{{7968704816907197107ull, 17569078697467198723ull,
  1919654635703432442ull, 8677856714641138354ull}},
{{2674597501353304240ull, 15592360204344387106ull,
  5811470165742033180ull, 5423660446650711471ull}},
{{12566618913546406108ull, 1043706181720932266ull,
  2652651688750153572ull, 6779575558313389339ull}},
{{6484901605078231826ull, 1304632727151165333ull,
  17150872666219855677ull, 8474469447891736673ull}},
{{6358906512387588844ull, 3121238463683172285ull,
  3801766388746327942ull, 5296543404932335421ull}},
{{12560319158911873958ull, 13124920116458741164ull,
  9363894004360297831ull, 6620679256165419276ull}},
{{15700398948639842448ull, 11794464127146038551ull,
  11704867505450372289ull, 8275849070206774095ull}},
{{16730278370540983386ull, 454011051825192238ull,
  14233071218547564537ull, 5172405668879233809ull}},
{{11689475926321453425ull, 5179199833208878202ull,
  3956280967902291959ull, 6465507086099042262ull}},
{{5388472871047040973ull, 1862313773083709849ull,
  14168723246732640757ull, 8081883857623802827ull}},
{{14897010590472870368ull, 3469789117391012607ull,
  6549609019994206521ull, 5051177411014876767ull}},
{{14009577219663700056ull, 8948922415166153663ull,
  3575325256565370247ull, 6313971763768595959ull}},
{{12900285506152237166ull, 6574467000530304175ull,
  18304214625988876521ull, 7892464704710744948ull}},
{{14980207468986230085ull, 15638256921399909869ull,
  2216762104388272017ull, 4932790440444215593ull}},
{{4890201280950623894ull, 5712763096467723625ull,
  7382638648912727926ull, 6165988050555269491ull}},
{{10724437619615667771ull, 16364325907439430339ull,
  4616612292713522003ull, 7707485063194086864ull}},
{{4396930503046098405ull, 7921860682935950010ull,
  2885382682945951252ull, 4817178164496304290ull}},
{{14719535165662398814ull, 9902325853669937512ull,
  12830100390537214873ull, 6021472705620380362ull}},
{{18399418957077998518ull, 16989593335514809794ull,
  6814253451316742783ull, 7526840882025475453ull}},
{{16111322866601136978ull, 17536024862337837977ull,
  6564751416286658191ull, 4704275551265922158ull}},
{{6304095527969257510ull, 17308345059494909568ull,
  17429311307213098547ull, 5880344439082402697ull}},
{{7880119409961571888ull, 17023745305941249056ull,
  7951581078734209472ull, 7350430548853003372ull}},
{{9850149262451964859ull, 2832937558717009704ull,
  9939476348417761841ull, 9188038186066254215ull}},
{{6156343289032478037ull, 13299801020266600825ull,
  13129701745402183006ull, 5742523866291408884ull}},
{{12307115129717985451ull, 7401379238478475223ull,
  16412127181752728758ull, 7178154832864261105ull}},
{{10772207893720093909ull, 28352011243318221ull, 6680100921908747236ull,
  8972693541080326382ull}},
{{9038472942788752645ull, 9241092043881849696ull,
  18010121131475130734ull, 5607933463175203988ull}},
{{11298091178485940807ull, 2327993017997536312ull,
  4065907340634361802ull, 7009916828969004986ull}},
{{14122613973107426008ull, 12133363309351696198ull,
  14305756212647728060ull, 8762396036211256232ull}},
{{4214947714764753351ull, 16806724105199585932ull,
  8941097632904830037ull, 5476497522632035145ull}},
{{5268684643455941689ull, 7173347076217318703ull,
  15788058059558425451ull, 6845621903290043931ull}},
{{1974169785892539207ull, 4354997826844260475ull,
  15123386556020643910ull, 8557027379112554914ull}},
{{17374757180678694669ull, 16556931697059826508ull,
  14063802615940290347ull, 5348142111945346821ull}},
{{3271702402138816720ull, 16084478602897395232ull,
  3744695214643199222ull, 6685177639931683527ull}},
{{4089628002673520899ull, 10882226216766968232ull, 69182999876611124ull,
  8356472049914604409ull}},
{{2556017501670950562ull, 16024763422334130953ull,
  11572454420991351712ull, 5222795031196627755ull}},
{{7806707895516076107ull, 1584210204208112075ull,
  9853882007811801737ull, 6528493788995784694ull}},
{{5146698850967707229ull, 6591948773687527998ull,
  3093980472909976363ull, 8160617236244730868ull}},
{{17051744837136980730ull, 1814124974341011046ull,
  11157109832423511035ull, 5100385772652956792ull}},
{{12091309009566450105ull, 16102714273208427520ull,
  13946387290529388793ull, 6375482215816195990ull}},
{{15114136261958062631ull, 6293334786228370688ull,
  8209612076306960184ull, 7969352769770244988ull}},
{{9446335163723789145ull, 3933334241392731680ull,
  14354379584546625923ull, 4980845481106403117ull}},
{{11807918954654736431ull, 304981783313526696ull,
  4107916425401118692ull, 6226056851383003897ull}},
{{14759898693318420538ull, 381227229141908370ull,
  9746581550178786269ull, 7782571064228754871ull}},
{{13836622701751400741ull, 2544110027427386683ull,
  13009142496502823274ull, 4864106915142971794ull}},
{{12684092358761863022ull, 12403509571139009162ull,
  7038056083773753284ull, 6080133643928714743ull}},
{{6631743411597552969ull, 15504386963923761453ull,
  4185884086289803701ull, 7600167054910893429ull}},
{{6450682641462164558ull, 11996084861666044860ull,
  4922020563144821265ull, 4750104409319308393ull}},
{{8063353301827705697ull, 1160048021800392363ull,
  10764211722358414486ull, 5937630511649135491ull}},
{{5467505608857244217ull, 10673432064105266262ull,
  8843578634520630203ull, 7422038139561419364ull}},
{{17252249060817941348ull, 4365052030852097461ull,
  14750608683430169685ull, 4638773837225887102ull}},
{{7730253270740262973ull, 10068001056992509731ull,
  9214888817432936298ull, 5798467296532358878ull}},
{{5051130569997940812ull, 3361629284385861356ull,
  2295238984936394565ull, 7248084120665448598ull}},
{{6313913212497426015ull, 8813722623909714599ull,
  12092420768025269014ull, 9060105150831810747ull}},
{{10863724785451973115ull, 896890621516183720ull,
  5251919970802099182ull, 5662565719269881717ull}},
{{13579655981814966394ull, 10344485313750005458ull,
  11176585981930011881ull, 7078207149087352146ull}},
{{7751197940413932184ull, 17542292660614894727ull,
  4747360440557739043ull, 8847758936359190183ull}},
{{11762027740399789471ull, 8658089903670615252ull,
  9884629302989668758ull, 5529849335224493864ull}},
{{14702534675499736839ull, 1599240342733493257ull,
  12355786628737085948ull, 6912311669030617330ull}},
{{4543110289092507337ull, 1999050428416866572ull,
  6221361249066581627ull, 8640389586288271663ull}},
{{12062815967537592894ull, 17390307582256399271ull,
  10805879808307695372ull, 5400243491430169789ull}},
{{10466833940994603213ull, 3291140404110947473ull,
  18119035778812007120ull, 6750304364287712236ull}},
{{17695228444670641920ull, 4113925505138684341ull,
  4202050649805457284ull, 8437880455359640296ull}},
{{13365360787132845152ull, 11794575477566453521ull,
  2626281656128410802ull, 5273675284599775185ull}},
{{2871642928633892728ull, 5519847310103291094ull,
  7894538088587901407ull, 6592094105749718981ull}},
{{12812925697647141718ull, 2288123119201725963ull,
  14479858629162264663ull, 8240117632187148726ull}},
{{5702235551815769622ull, 8347605977142160583ull,
  4438225624799027510ull, 5150073520116967954ull}},
{{2516108421342324123ull, 1211135434572924921ull,
  14771154067853560196ull, 6437591900146209942ull}},
{{7756821545105293058ull, 1513919293216156151ull,
  9240570547962174437ull, 8046989875182762428ull}},
{{11765542493331890018ull, 3252042567473791546ull,
  14998728629331134831ull, 5029368671989226517ull}},
{{5483556079810086714ull, 17900111264624403145ull,
  4913352731381754826ull, 6286710839986533147ull}},
{{11466131118189996296ull, 13151767043925728123ull,
  1530004895799805629ull, 7858388549983166434ull}},
{{4860488939655053733ull, 10525697411667274029ull,
  5567939078302266422ull, 4911492843739479021ull}},
{{10687297192996205070ull, 3933749727729316728ull,
  11571609866305220932ull, 6139366054674348776ull}},
{{13359121491245256338ull, 4917187159661645910ull,
  14464512332881526165ull, 7674207568342935970ull}},
{{3737764913600897307ull, 5379084984002222646ull,
  13652006226478341757ull, 4796379730214334981ull}},
{{13895578178855897442ull, 11335542248430166211ull,
  3229949727815763484ull, 5995474662767918727ull}},
{{12757786705142483899ull, 14169427810537707764ull,
  17872495215051868067ull, 7494343328459898408ull}},
{{17196988727568828245ull, 6550049372372373400ull,
  11170309509407417542ull, 4683964580287436505ull}},
{{3049491835751483690ull, 17410933752320242559ull,
  127828831477108215ull, 5854955725359295632ull}},
{{17646922849971518324ull, 17151981171972915294ull,
  159786039346385269ull, 7318694656699119540ull}},
{{12835281525609622097ull, 7604918409683980406ull,
  199732549182981587ull, 9148368320873899425ull}},
{{3410364935078625907ull, 2447230996838793802ull,
  11654047889307833252ull, 5717730200546187140ull}},
{{13486328205703058191ull, 3059038746048492252ull,
  14567559861634791565ull, 7147162750682733925ull}},
{{16857910257128822739ull, 8435484450988003219ull,
  4374391771761325744ull, 8933953438353417407ull}},
{{8230350901491820260ull, 5272177781867502012ull,
  9651523884991910446ull, 5583720898970885879ull}},
{{10287938626864775325ull, 15813594264189153323ull,
  7452718837812500153ull, 6979651123713607349ull}},
{{8248237265153581252ull, 5931934774954277942ull,
  13927584565693013096ull, 8724563904642009186ull}},
{{543462272293600379ull, 3707459234346423714ull,
  13316426371985521089ull, 5452852440401255741ull}},
{{9902699877221776281ull, 9246010061360417546ull,
  2810474909699737649ull, 6816065550501569677ull}},
{{3155002809672444544ull, 16169198595127909837ull,
  8124779655552059965ull, 8520081938126962096ull}},
{{4277719765258971792ull, 12411592131168637600ull,
  5077987284720037478ull, 5325051211329351310ull}},
{{5347149706573714740ull, 6291118127106021192ull,
  15570856142754822656ull, 6656314014161689137ull}},
{{6683937133217143425ull, 7863897658882526490ull,
  5628512123161364608ull, 8320392517702111422ull}},
{{8789146726688102545ull, 4914936036801579056ull,
  17352878132258016592ull, 5200245323563819638ull}},
{{10986433408360128181ull, 6143670046001973820ull,
  12467725628467744932ull, 6500306654454774548ull}},
{{13733041760450160226ull, 7679587557502467275ull,
  15584657035584681165ull, 8125383318068468185ull}},
{{6277308091067656189ull, 7105585232652735999ull,
  2822881619599343872ull, 5078364573792792616ull}},
{{3234949095407182332ull, 8881981540815919999ull,
  3528602024499179840ull, 6347955717240990770ull}},
{{17878744424541141627ull, 11102476926019899998ull,
  13634124567478750608ull, 7934944646551238462ull}},
{{6562529246910825613ull, 6939048078762437499ull,
  3909641836246831226ull, 4959340404094524039ull}},
{{3591475540211144113ull, 17897182135307822682ull,
  275366276881151128ull, 6199175505118155049ull}},
{{13712716462118705949ull, 3924733595425226736ull,
  4955893864528826815ull, 7748969381397693811ull}},
{{8570447788824191218ull, 9370487524781848566ull, 791590656116822807ull,
  4843105863373558632ull}},
{{1489687699175463214ull, 7101423387549922804ull, 989488320146028509ull,
  6053882329216948290ull}},
{{1862109623969329018ull, 13488465252864791409ull,
  10460232437037311444ull, 7567352911521185362ull}},
{{12693033561049300396ull, 17653662819895270438ull,
  11149331291575707556ull, 4729595569700740851ull}},
{{6642919914456849687ull, 3620334451159536432ull,
  9324978096042246542ull, 5911994462125926064ull}},
{{8303649893071062109ull, 13748790100804196348ull,
  11656222620052808177ull, 7389993077657407580ull}},
{{14413153220024189626ull, 1675464785361540861ull,
  16508511174387780919ull, 4618745673535879737ull}},
{{4181383469748073321ull, 15929389036984089789ull,
  6800580912702562436ull, 5773432091919849672ull}},
{{9838415355612479555ull, 1464992222520560620ull,
  8500726140878203046ull, 7216790114899812090ull}},
{{12298019194515599443ull, 11054612315005476583ull,
  1402535639242977999ull, 9020987643624765113ull}},
{{14603791024213331508ull, 13826661724519504720ull,
  12405799820595331009ull, 5638117277265478195ull}},
{{18254738780266664385ull, 3448269100367217188ull,
  10895563757316775858ull, 7047646596581847744ull}},
{{4371679401623778866ull, 13533708412313797294ull,
  13619454696645969822ull, 8809558245727309680ull}},
{{16567357681297025503ull, 3846881739268735404ull,
  8512159185403731139ull, 5505973903579568550ull}},
{{2262453027911730263ull, 196916155658531352ull, 1416826944899888116ull,
  6882467379474460688ull}},
{{2828066284889662828ull, 246145194573164190ull, 1771033681124860145ull,
  8603084224343075860ull}},
{{15602599483338202980ull, 11683055792676697378ull,
  10330268087557813398ull, 5376927640214422412ull}},
{{10279877317317977917ull, 5380447703991095915ull,
  12912835109447266748ull, 6721159550268028015ull}},
{{8238160628220084492ull, 6725559629988869894ull,
  11529357868381695531ull, 8401449437835035019ull}},
{{537164374210164904ull, 1897631759529349732ull, 4900005658524865755ull,
  5250905898646896887ull}},
{{671455467762706129ull, 16207097754693850877ull,
  1513321054728694289ull, 6563632373308621109ull}},
{{5451005353130770566ull, 6423814138085149884ull,
  6503337336838255766ull, 8204540466635776386ull}},
{{12630250382561507412ull, 17849941891585382389ull,
  8676271853951297757ull, 5127837791647360241ull}},
{{1952754922919720552ull, 8477369309199564275ull,
  15457025835866510101ull, 6409797239559200301ull}},
{{16276001708931814402ull, 15208397654926843247ull,
  5486224239550973914ull, 8012246549449000377ull}},
{{17090030095723465858ull, 14116934552756664933ull,
  14958105195787828456ull, 5007654093405625235ull}},
{{7527479564372168610ull, 17646168190945831167ull,
  14085945476307397666ull, 6259567616757031544ull}},
{{4797663437037822858ull, 12834338201827513151ull,
  17607431845384247083ull, 7824459520946289430ull}},
{{9916068675789721143ull, 5715618366928501767ull,
  6392958884937766523ull, 4890287200591430894ull}},
{{7783399826309763524ull, 2532836940233239305ull,
  17214570643026983962ull, 6112859000739288617ull}},
{{14340935801314592309ull, 12389418212146324939ull,
  7683155248501566240ull, 7641073750924110772ull}},
{{6657241866607926241ull, 7743386382591453087ull,
  14025344067168254708ull, 4775671094327569232ull}},
{{3709866314832519898ull, 9679232978239316359ull,
  17531680083960318385ull, 5969588867909461540ull}},
{{25646875113261968ull, 16710727241226533353ull, 3467856031240846365ull,
  7461986084886826926ull}},
{{11545244343014258490ull, 12750047534980277297ull,
  16002468074807692690ull, 4663741303054266828ull}},
{{596497373485659401ull, 6714187381870570814ull, 1556341019800064247ull,
  5829676628817833536ull}},
{{9968993753711850059ull, 3781048208910825613ull,
  1945426274750080309ull, 7287095786022291920ull}},
{{17072928210567200477ull, 9337996279565919920ull,
  2431782843437600386ull, 9108869732527864900ull}},
{{10670580131604500298ull, 10447933693156087854ull,
  10743236314003276049ull, 5693043582829915562ull}},
{{4114853127650849565ull, 17671603134872497722ull,
  4205673355649319253ull, 7116304478537394453ull}},
{{14366938446418337764ull, 8254445863308458440ull,
  9868777712989036971ull, 8895380598171743066ull}},
{{8979336529011461103ull, 2853185655354092573ull,
  10779672089045536011ull, 5559612873857339416ull}},
{{15835856679691714282ull, 17401540124474779428ull,
  13474590111306920013ull, 6949516092321674270ull}},
{{1348076775905091237ull, 7916867100311310574ull,
  7619865602278874209ull, 8686895115402092838ull}},
{{14677606040222845735ull, 16477256983763038868ull,
  150729982996908476ull, 5429309447126308024ull}},
{{18347007550278557169ull, 2149827155994246969ull,
  188412478746135596ull, 6786636808907885030ull}},
{{9098701382566032749ull, 2687283944992808712ull,
  9458887635287445303ull, 8483296011134856287ull}},
{{5686688364103770468ull, 8597081493261587301ull,
  12829333799695735170ull, 5302060006959285179ull}},
{{11720046473557100989ull, 1522979829722208318ull,
  11424981231192281059ull, 6627575008699106474ull}},
{{5426686055091600428ull, 15738782842434924110ull,
  5057854502135575515ull, 8284468760873883093ull}},
{{17226736839714413980ull, 7530896267308133616ull,
  5467002073048428649ull, 5177792975546176933ull}},
{{3086676975933465859ull, 14025306352562554925ull,
  11445438609737923715ull, 6472241219432721166ull}},
{{8470032238344220227ull, 12919946922275805752ull,
  5083426225317628836ull, 8090301524290901458ull}},
{{5293770148965137642ull, 17298338863277154403ull,
  7788827409250905926ull, 5056438452681813411ull}},
{{2005526667779034149ull, 12399551542241667196ull,
  5124348243136244504ull, 6320548065852266764ull}},
{{2506908334723792686ull, 15499439427802083995ull,
  6405435303920305630ull, 7900685082315333455ull}},
{{17707718773698228093ull, 5075463623948914592ull,
  10920926092591272875ull, 4937928176447083409ull}},
{{3687904393413233500ull, 1732643511508755337ull,
  18262843634166478998ull, 6172410220558854261ull}},
{{9221566510193929779ull, 11389176426240719979ull,
  8993496487425935035ull, 7715512775698567827ull}},
{{3457636059657512160ull, 4812392257186756035ull,
  3315092295427515445ull, 4822195484811604892ull}},
{{18157103129854053912ull, 10627176339910832947ull,
  4143865369284394306ull, 6027744356014506115ull}},
{{18084692893890179485ull, 4060598388033765376ull,
  568145693178104979ull, 7534680445018132644ull}},
{{11302933058681362179ull, 232030983307409408ull,
  9578463095091091420ull, 4709175278136332902ull}},
{{14128666323351702723ull, 290038729134261760ull,
  2749706832009088467ull, 5886469097670416128ull}},
{{17660832904189628404ull, 14197606466699990912ull,
  3437133540011360583ull, 7358086372088020160ull}},
{{3629297056527483889ull, 13135322064947600737ull,
  4296416925014200729ull, 9197607965110025200ull}},
{{13797525706398147191ull, 1292047262951168604ull,
  2685260578133875456ull, 5748504978193765750ull}},
{{17246907132997683988ull, 1615059078688960755ull,
  12579947759522120128ull, 7185631222742207187ull}},
{{16946947897819717081ull, 2018823848361200944ull,
  11113248680975262256ull, 8982039028427758984ull}},
{{10591842436137323176ull, 1261764905225750590ull,
  6945780425609538910ull, 5613774392767349365ull}},
{{4016431008316878162ull, 10800578168386964046ull,
  13293911550439311541ull, 7017217990959186706ull}},
{{14243910797250873510ull, 18112408728911092961ull,
  7394017401194363618ull, 8771522488698983383ull}},
{{1984915220640714088ull, 15931941473996821005ull,
  11538789903387559117ull, 5482201555436864614ull}},
{{7092830044228280514ull, 6079868787213862544ull,
  5200115342379673089ull, 6852751944296080768ull}},
{{8866037555285350642ull, 12211522002444716084ull,
  6500144177974591361ull, 8565939930370100960ull}},
{{14764645508908119959ull, 714672223886865696ull,
  4062590111234119601ull, 5353712456481313100ull}},
{{9062812425598333ull, 5505026298285970025ull, 5078237639042649501ull,
  6692140570601641375ull}},
{{4623014533959385820ull, 11492968891284850435ull,
  1736111030375923972ull, 8365175713252051719ull}},
{{583541074510922186ull, 16406477593907807330ull,
  8002598421626034338ull, 5228234820782532324ull}},
{{9952798379993428540ull, 11284724955529983354ull,
  10003248027032542923ull, 6535293525978165405ull}},
{{3217625938137009867ull, 9494220175985091289ull,
  17115746052218066558ull, 8169116907472706756ull}},
{{13540231257404100927ull, 1322201591563294151ull,
  1473969245781515791ull, 5105698067170441723ull}},
{{12313603053327738255ull, 15487810044736281401ull,
  15677519612509058450ull, 6382122583963052153ull}},
{{1556945761377509106ull, 10136390519065575944ull,
  5761841460354159351ull, 7977653229953815192ull}},
{{973091100860943192ull, 13252773102057066821ull,
  3601150912721349594ull, 4986033268721134495ull}},
{{5828049894503566893ull, 7342594340716557718ull,
  18336496696183850705ull, 6232541585901418118ull}},
{{16508434404984234425ull, 13789928944323085051ull,
  13697248833375037573ull, 7790676982376772648ull}},
{{8011928493901452564ull, 10924548599415622109ull,
  8560780520859398483ull, 4869173113985482905ull}},
{{14626596635804203608ull, 9043999730842139732ull,
  15312661669501636008ull, 6086466392481853631ull}},
{{18283245794755254510ull, 11304999663552674665ull,
  14529141068449657106ull, 7608082990602317039ull}},
{{4509499594080952213ull, 11677310808147809570ull,
  15998242195422117547ull, 4755051869126448149ull}},
{{14860246529455966074ull, 9984952491757374058ull,
  6162744688995483222ull, 5943814836408060187ull}},
{{9351936124965181785ull, 3257818577841941765ull,
  3091744842816966124ull, 7429768545510075234ull}},
{{8150803087316932568ull, 11259508648005989411ull,
  6544026545187991731ull, 4643605340943797021ull}},
{{5576817840718777806ull, 9462699791580098860ull,
  12791719199912377568ull, 5804506676179746276ull}},
{{6971022300898472257ull, 11828374739475123575ull,
  15989648999890471960ull, 7255633345224682845ull}},
{{4102091857695702417ull, 14785468424343904469ull,
  6152003194580926238ull, 9069541681530853557ull}},
{{4869650420273507963ull, 4629231746787552389ull,
  6150845005826772851ull, 5668463550956783473ull}},
{{10698749043769272857ull, 1174853665057052582ull,
  12300242275710853968ull, 7085579438695979341ull}},
{{4150064267856815263ull, 1468567081321315728ull,
  1540244789356403748ull, 8856974298369974177ull}},
{{2593790167410509540ull, 10141226462680598138ull,
  12491868039416222102ull, 5535608936481233860ull}},
{{12465609746117912733ull, 3453161041495971864ull,
  15614835049270277628ull, 6919511170601542325ull}},
{{15582012182647390916ull, 4316451301869964830ull,
  5683485756305683323ull, 8649388963251927907ull}},
{{5127071595727231419ull, 391939054455034067ull, 1246335588477358125ull,
  5405868102032454942ull}},
{{1797153476231651369ull, 5101609836496180488ull,
  10781291522451473464ull, 6757335127540568677ull}},
{{2246441845289564211ull, 6377012295620225610ull,
  18088300421491729734ull, 8446668909425710846ull}},
{{6015712171733365536ull, 17820690740044804718ull,
  6693501745004943179ull, 5279168068391069279ull}},
{{16743012251521482728ull, 17664177406628617993ull,
  3755191162828791070ull, 6598960085488836599ull}},
{{7093707259119689698ull, 12856849721430996684ull, 82302935108600934ull,
  8248700106861045749ull}},
{{13656939073804581869ull, 3423845057466985023ull,
  2357282343656569536ull, 5155437566788153593ull}},
{{12459487823828339433ull, 4279806321833731279ull,
  7558288947998099824ull, 6444296958485191991ull}},
{{10962673761358036387ull, 5349757902292164099ull,
  4836175166570236876ull, 8055371198106489989ull}},
{{4545828091635078790ull, 12566970725787378370ull,
  5328452488320091999ull, 5034606998816556243ull}},
{{14905657151398624295ull, 11097027388806835058ull,
  2048879591972727095ull, 6293258748520695304ull}},
{{9408699402393504561ull, 9259598217581155919ull,
  2561099489965908869ull, 7866573435650869130ull}},
{{12797966154137022207ull, 8093091895201916401ull,
  6212373199656080947ull, 4916608397281793206ull}},
{{2162399637389114046ull, 5504678850575007598ull,
  16988838536424876992ull, 6145760496602241507ull}},
{{11926371583591168366ull, 6880848563218759497ull,
  16624362152103708336ull, 7682200620752801884ull}},
{{536453212103398373ull, 4300530352011724686ull, 1166854308210041902ull,
  4801375387970501178ull}},
{{9893938551984023774ull, 14599034976869431665ull,
  10681939922117328185ull, 6001719234963126472ull}},
{{16979109208407417621ull, 4413735665804625869ull,
  13352424902646660232ull, 7502149043703908090ull}},
{{12917786264468329965ull, 2758584791127891168ull,
  12956951582581550549ull, 4688843152314942556ull}},
{{16147232830585412457ull, 8059917007337251864ull,
  16196189478226938186ull, 5861053940393678195ull}},
{{1737296964522213955ull, 851524222316789023ull,
  15633550829356284829ull, 7326317425492097744ull}},
{{16006679260934931155ull, 5676091296323374182ull,
  1095194462985804420ull, 9157896781865122181ull}},
{{5392488519656944068ull, 12770929097056884672ull,
  2990339548579821714ull, 5723685488665701363ull}},
{{6740610649571180085ull, 6740289334466330032ull,
  17572982491006940855ull, 7154606860832126703ull}},
{{8425763311963975106ull, 3813675649655524636ull,
  17354542095331288165ull, 8943258576040158379ull}},
{{14489474106832260250ull, 4689390290248396849ull,
  8540745800368361151ull, 5589536610025098987ull}},
{{4276784578258161600ull, 1250051844383108158ull,
  6064246232033063535ull, 6986920762531373734ull}},
{{14569352759677477808ull, 15397622860761048909ull,
  16803679826896105226ull, 8733650953164217167ull}},
{{11411688484012117582ull, 14235200306403043472ull,
  17419828919451147622ull, 5458531845727635729ull}},
{{14264610605015146977ull, 8570628346149028532ull,
  7939728094031770816ull, 6823164807159544662ull}},
{{17830763256268933722ull, 10713285432686285665ull,
  701288080684937712ull, 8528956008949430828ull}},
{{4226698007527001720ull, 6695803395428928541ull,
  9661677087282861878ull, 5330597505593394267ull}},
{{9895058527836140054ull, 17593126281140936484ull,
  7465410340676189443ull, 6663246881991742834ull}},
{{12368823159795175068ull, 17379721832998782701ull,
  108390888990460996ull, 8329058602489678543ull}},
{{10036357484085678369ull, 1638954108769463380ull,
  6985273333260119979ull, 5205661626556049089ull}},
{{12545446855107097962ull, 15883750691243992937ull,
  13343277685002537877ull, 6507077033195061361ull}},
{{1846750513601708740ull, 6019630308772827460ull,
  2844039050971008635ull, 8133846291493826702ull}},
{{10377591107855843771ull, 1456425933769323210ull,
  15612582462139044109ull, 5083653932183641688ull}},
{{3748616847965028905ull, 6432218435639041917ull,
  1068984003964253520ull, 6354567415229552111ull}},
{{9297457078383674035ull, 8040273044548802396ull,
  15171288060237480612ull, 7943209269036940138ull}},
{{15034282710844572080ull, 14248542689697777305ull,
  14093741056075813286ull, 4964505793148087586ull}},
{{4957795333273551388ull, 8587306325267445824ull,
  8393804283239990800ull, 6205632241435109483ull}},
{{6197244166591939235ull, 10734132906584307280ull,
  5880569335622600596ull, 7757040301793886854ull}},
{{3873277604119962022ull, 15932205103469967858ull,
  17510413890046289084ull, 4848150188621179283ull}},
{{14064969042004728336ull, 1468512305627908206ull,
  17276331344130473452ull, 6060187735776474104ull}},
{{8357839265651134611ull, 1835640382034885258ull,
  3148670106453540199ull, 7575234669720592631ull}},
{{9835335559459347036ull, 8064804266412885142ull,
  8885447844174544480ull, 4734521668575370394ull}},
{{3070797412469407987ull, 10081005333016106428ull,
  1883437768363404792ull, 5918152085719212993ull}},
{{3838496765586759984ull, 12601256666270133035ull,
  6965983228881643894ull, 7397690107149016241ull}},
{{93217469278031038ull, 3264099397991445243ull, 15882954564119497194ull,
  4623556316968135150ull}},
{{13951579891879702510ull, 13303496284344082361ull,
  10630321168294595684ull, 5779445396210168938ull}},
{{3604416809567464425ull, 16629370355430102952ull,
  4064529423513468797ull, 7224306745262711173ull}},
{{4505521011959330531ull, 6951654889005464978ull,
  9692347797819223901ull, 9030383431578388966ull}},
{{7427636650901969486ull, 6650627314842109563ull,
  1446031355209627034ull, 5643989644736493104ull}},
{{4672859795200073953ull, 17536656180407412762ull,
  1807539194012033792ull, 7054987055920616380ull}},
{{15064446780854868250ull, 3474076151799714336ull,
  2259423992515042241ull, 8818733819900770475ull}},
{{9415279238034292656ull, 13700512640943291220ull,
  17553041059817759064ull, 5511708637437981546ull}},
{{11769099047542865820ull, 17125640801179114025ull,
  12717929287917423022ull, 6889635796797476933ull}},
{{876315754146418563ull, 12183678964619116724ull,
  2062353554614615066ull, 8612044745996846167ull}},
{{9771069383196287410ull, 12226485371314335856ull,
  8206499999275216272ull, 5382527966248028854ull}},
{{12213836728995359262ull, 15283106714142919820ull,
  1034752962239244532ull, 6728159957810036068ull}},
{{15267295911244199078ull, 657139318969098159ull,
  1293441202799055666ull, 8410199947262545085ull}},
{{16459588972168706280ull, 5022398092783074253ull,
  3114243760963103743ull, 5256374967039090678ull}},
{{6739428159928719138ull, 1666311597551454913ull,
  13116176738058655487ull, 6570468708798863347ull}},
{{13035971218338286826ull, 15917947552221482353ull,
  11783534904145931454ull, 8213085885998579184ull}},
{{1229952983820347410ull, 5337031201711038567ull,
  7364709315091207159ull, 5133178678749111990ull}},
{{15372499285057597975ull, 2059602983711410304ull,
  18429258680718784757ull, 6416473348436389987ull}},
{{768880032612445853ull, 7186189748066650785ull,
  18424887332471093042ull, 8020591685545487484ull}},
{{12009765066451248418ull, 9103054610969044644ull,
  2292182545939657343ull, 5012869803465929678ull}},
{{15012206333064060522ull, 6767132245283917901ull,
  12088600219279347487ull, 6266087254332412097ull}},
{{4930199861047911941ull, 3847229288177509473ull,
  1275692218817020647ull, 7832609067915515122ull}},
{{14610589959223414723ull, 9322047332752025276ull,
  5408993655188025808ull, 4895380667447196951ull}},
{{18263237449029268404ull, 11652559165940031595ull,
  2149556050557644356ull, 6119225834308996189ull}},
{{18217360792859197601ull, 14565698957425039494ull,
  7298631081624443349ull, 7649032292886245236ull}},
{{6774164477109610597ull, 11409404857604343636ull,
  13785016462870052901ull, 4780645183053903272ull}},
{{8467705596387013246ull, 426698016723265833ull,
  17231270578587566127ull, 5975806478817379090ull}},
{{15196318013911154461ull, 14368430576186246003ull,
  12315716186379681850ull, 7469758098521723863ull}},
{{7191855749480777586ull, 13591955128543791656ull,
  14614851644128383012ull, 4668598811576077414ull}},
{{8989819686850971983ull, 16989943910679739570ull,
  9045192518305702957ull, 5835748514470096768ull}},
{{2013902571708939170ull, 7402371833067510751ull,
  11306490647882128697ull, 7294685643087620960ull}},
{{16352436269918337675ull, 13864650809761776342ull,
  14133113309852660871ull, 9118357053859526200ull}},
{{5608586650271573143ull, 15582935783742192070ull,
  8833195818657913044ull, 5698973158662203875ull}},
{{16234105349694242237ull, 1031925655968188471ull,
  6429808754895003402ull, 7123716448327754844ull}},
{{15680945668690414892ull, 10513279106815011397ull,
  8037260943618754252ull, 8904645560409693555ull}},
{{12106434052145203259ull, 15794171478614157931ull,
  2717445080548027455ull, 5565403475256058472ull}},
{{10521356546754116170ull, 15131028329840309510ull,
  3396806350685034319ull, 6956754344070073090ull}},
{{3928323646587869405ull, 14302099393872998984ull,
  13469379975211068707ull, 8695942930087591362ull}},
{{2455202279117418378ull, 6632969111956930413ull,
  13030048502934305846ull, 5434964331304744601ull}},
{{7680688867324160876ull, 17514583426800938824ull,
  2452502573385718595ull, 6793705414130930752ull}},
{{9600861084155201095ull, 17281543265073785626ull,
  3065628216732148244ull, 8492131767663663440ull}},
{{10612224196024388589ull, 1577592503816340208ull,
  1916017635457592653ull, 5307582354789789650ull}},
{{13265280245030485736ull, 6583676648197813164ull,
  11618394081176766624ull, 6634477943487237062ull}},
{{16581600306288107170ull, 8229595810247266455ull,
  5299620564616182472ull, 8293097429359046328ull}},
{{17281029219071148837ull, 5143497381404541534ull,
  3312262852885114045ull, 5183185893349403955ull}},
{{12377914486984160238ull, 11041057745183064822ull,
  17975386621388556268ull, 6478982366686754943ull}},
{{6249021071875424490ull, 13801322181478831028ull,
  17857547258308307431ull, 8098727958358443679ull}},
{{13129010206776916114ull, 15543355391065351248ull,
  18078496064083774000ull, 5061704973974027299ull}},
{{16411262758471145143ull, 982450165122137444ull,
  17986434061677329597ull, 6327131217467534124ull}},
{{2067334374379379813ull, 5839748724830059710ull,
  4036298503387110380ull, 7908914021834417656ull}},
{{15127142039269276095ull, 12873214989873563126ull,
  2522686564616943987ull, 4943071263646511035ull}},
{{9685555512231819311ull, 11479832718914566004ull,
  16988416261053343696ull, 6178839079558138793ull}},
{{12106944390289774138ull, 14349790898643207505ull,
  7400462271034515908ull, 7723548849447673492ull}},
{{649311216290026981ull, 18191991348506780499ull,
  13848660956251348250ull, 4827218030904795932ull}},
{{14646697075644697438ull, 13516617148778699815ull,
  17310826195314185313ull, 6034022538630994915ull}},
{{13696685326128483893ull, 3060713380691211057ull,
  17026846725715343738ull, 7542528173288743644ull}},
{{1642899301189220577ull, 6524631881359394815ull,
  1418407166717314028ull, 4714080108305464778ull}},
{{15888682181768689433ull, 8155789851699243518ull,
  10996380995251418343ull, 5892600135381830972ull}},
{{10637480690356085984ull, 5583051296196666494ull,
  13745476244064272929ull, 7365750169227288715ull}},
{{4073478826090331671ull, 11590500138673221022ull,
  12570159286652953257ull, 9207187711534110894ull}},
{{16380982321588621007ull, 326533559029681282ull,
  3244663535730707882ull, 5754492319708819309ull}},
{{11252855865131000450ull, 9631538985641877411ull,
  8667515438090772756ull, 7193115399636024136ull}},
{{9454383812986362659ull, 12039423732052346764ull,
  10834394297613465945ull, 8991394249545030170ull}},
{{15132361919971252470ull, 607110804891634871ull,
  11383182454435804120ull, 5619621405965643856ull}},
{{14303766381536677683ull, 758888506114543589ull,
  14228978068044755150ull, 7024526757457054820ull}},
{{4044649921638683392ull, 10171982669497955295ull,
  17786222585055943937ull, 8780658446821318525ull}},
{{9445435228665258976ull, 17886704214504691819ull,
  13422232124873658912ull, 5487911529263324078ull}},
{{7195108017404185816ull, 3911636194421313158ull,
  7554418119237297833ull, 6859889411579155098ull}},
{{18217257058610008078ull, 9501231261454029351ull,
  219650612191846483ull, 8574861764473943873ull}},
{{18303314689272336905ull, 3632426529195074392ull,
  11666496678688373812ull, 5359288602796214920ull}},
{{4432399287880869515ull, 4540533161493842991ull,
  14583120848360467265ull, 6699110753495268650ull}},
{{928813091423698990ull, 10287352470294691643ull,
  9005529023595808273ull, 8373888441869085813ull}},
{{16721409246635669533ull, 17958810340002652036ull,
  7934298648961074122ull, 5233680276168178633ull}},
{{2455017484585035300ull, 13225140888148539238ull,
  14529559329628730557ull, 6542100345210223291ull}},
{{12292143892586069933ull, 2696368054903510335ull,
  13550263143608525293ull, 8177625431512779114ull}},
{{14600118960507375564ull, 3991073043528387911ull,
  13080600483182716212ull, 5111015894695486946ull}},
{{13638462682206831551ull, 4988841304410484889ull,
  7127378567123619457ull, 6388769868369358683ull}},
{{3213020297476375727ull, 10847737648940494016ull,
  4297537190477136417ull, 7985962335461698354ull}},
{{2008137685922734829ull, 18309051076656278520ull,
  7297646762475598164ull, 4991226459663561471ull}},
{{2510172107403418537ull, 4439569772110796534ull,
  4510372434667109802ull, 6239033074579451839ull}},
{{12361087171109048979ull, 14772834251993271475ull,
  1026279524906499348ull, 7798791343224314799ull}},
{{5419836472729461660ull, 9649370641018864ull, 7558953730707643949ull,
  4874244589515196749ull}},
{{6774795590911827075ull, 4623747731728661484ull,
  14060378181811942840ull, 6092805736893995936ull}},
{{8468494488639783843ull, 5779684664660826855ull,
  17575472727264928550ull, 7616007171117494920ull}},
{{12210338083040946758ull, 17447360970695180496ull,
  10984670454540580343ull, 4760004481948434325ull}},
{{15262922603801183448ull, 17197515194941587716ull,
  18342524086603113333ull, 5950005602435542906ull}},
{{631909181041927693ull, 7661835938394820934ull,
  13704783071399115859ull, 7437507003044428633ull}},
{{14230001293433368521ull, 2482804452283069131ull,
  1647960391983365556ull, 4648441876902767896ull}},
{{13175815598364322747ull, 3103505565353836414ull,
  2059950489979206945ull, 5810552346128459870ull}},
{{7246397461100627625ull, 8491067975119683422ull,
  11798310149328784489ull, 7263190432660574837ull}},
{{18281368863230560339ull, 15225520987326992181ull,
  912829631378816899ull, 9078988040825718547ull}},
{{13731698548732794164ull, 7210107607865676161ull,
  16711419584107618226ull, 5674367525516074091ull}},
{{3329565130633828993ull, 18236006546686871010ull,
  16277588461707134878ull, 7092959406895092614ull}},
{{13385328450147062049ull, 13571636146503812954ull,
  11123613540279142790ull, 8866199258618865768ull}},
{{12977516299769301685ull, 3870586573137495192ull,
  6952258462674464244ull, 5541374536636791105ull}},
{{16221895374711627106ull, 4838233216421868990ull,
  13302009096770468209ull, 6926718170795988881ull}},
{{11053997181534758074ull, 10659477538954724142ull,
  2792453315680921549ull, 8658397713494986102ull}},
{{2297062220031835893ull, 8968016471060396541ull,
  15580341377582739680ull, 5411498570934366313ull}},
{{7483013793467182770ull, 11210020588825495676ull,
  5640368666696260888ull, 6764373213667957892ull}},
{{9353767241833978462ull, 14012525736031869595ull,
  7050460833370326110ull, 8455466517084947365ull}},
{{3540261516932542587ull, 4146142566592530593ull,
  6712381030070147771ull, 5284666573178092103ull}},
{{9037012914593066138ull, 570992189813275337ull, 3778790269160296810ull,
  6605833216472615129ull}},
{{15907952161668720576ull, 9937112274121369979ull,
  9335173854877758916ull, 8257291520590768911ull}},
{{7636627091829256408ull, 15434067208180632045ull,
  12752012686939681178ull, 5160807200369230569ull}},
{{14157469883213958414ull, 10069211973371014248ull,
  2104957803392437761ull, 6451009000461538212ull}},
{{17696837354017448017ull, 17198200985141155714ull,
  2631197254240547201ull, 8063761250576922765ull}},
{{15672209364688292915ull, 3831346588072140465ull,
  3950341293114035953ull, 5039850781610576728ull}},
{{5755203650578202432ull, 9400869253517563486ull,
  4937926616392544941ull, 6299813477013220910ull}},
{{16417376600077528847ull, 16362772585324342261ull,
  15395780307345456984ull, 7874766846266526137ull}},
{{12566703384262149482ull, 10226732865827713913ull,
  2704833664449828759ull, 4921729278916578836ull}},
{{1873321175045523140ull, 8171730063857254488ull,
  3381042080562285949ull, 6152161598645723545ull}},
{{2341651468806903925ull, 14826348598248956014ull,
  8837988619130245340ull, 7690201998307154431ull}},
{{15298590223286478665ull, 43095837050821700ull,
  12441271914597485194ull, 4806376248941971519ull}},
{{676493705398546716ull, 9277241833168302934ull,
  10939903874819468588ull, 6007970311177464399ull}},
{{10068989168602959202ull, 11596552291460378667ull,
  9063193825096947831ull, 7509962888971830499ull}},
{{3987275221163155550ull, 14165374209803818523ull,
  3358653131471898442ull, 4693726805607394062ull}},
{{372408008026556533ull, 8483345725399997346ull,
  13421688451194648861ull, 5867158507009242577ull}},
{{9688882046887971474ull, 15215868175177384586ull,
  2942052508711147364ull, 7333948133761553222ull}},
{{2887730521755188535ull, 573091145262179117ull,
  12900937672743710014ull, 9167435167201941527ull}},
{{4110674585310686786ull, 14193240021071025660ull,
  14980615073105900614ull, 5729646979501213454ull}},
{{5138343231638358483ull, 8518177989484006267ull,
  9502396804527599960ull, 7162058724376516818ull}},
{{1811243021120560199ull, 10647722486855007834ull,
  2654623968804724142ull, 8952573405470646023ull}},
{{5743712906627738029ull, 2043140535856991992ull,
  8576669008144034445ull, 5595358378419153764ull}},
{{7179641133284672536ull, 7165611688248627894ull,
  10720836260180043056ull, 6994197973023942205ull}},
{{18197923453460616478ull, 8957014610310784867ull,
  18012731343652441724ull, 8742747466279927756ull}},
{{9067859149199191347ull, 14821506168299016350ull,
  2034585052928000269ull, 5464217166424954848ull}},
{{2111451899644213375ull, 4691824655091606726ull,
  2543231316160000337ull, 6830271458031193560ull}},
{{11862686911410042527ull, 10476466837291896311ull,
  3179039145200000421ull, 8537839322538991950ull}},
{{14331708347272358436ull, 8853634782521129146ull,
  15821957521032163975ull, 5336149576586869968ull}},
{{8691263397235672236ull, 6455357459724023529ull,
  1330702827580653353ull, 6670186970733587461ull}},
{{15475765264971978199ull, 12680882843082417315ull,
  6275064552903204595ull, 8337733713416984326ull}},
{{7366510281393792423ull, 5619708767712816870ull,
  17756973400846666584ull, 5211083570885615203ull}},
{{18431509888597016336ull, 7024635959641021087ull,
  17584530732630945326ull, 6513854463607019004ull}},
{{18427701342318882516ull, 18004166986406052167ull,
  3533919342079130041ull, 8142318079508773756ull}},
{{18434842366590383429ull, 4335075338862700748ull,
  11432071625654232084ull, 5088948799692983597ull}},
{{4596808884528427670ull, 5418844173578375936ull, 455031476785626393ull,
  6361185999616229497ull}},
{{5746011105660534587ull, 11385241235400357824ull,
  5180475364409420895ull, 7951482499520286871ull}},
{{3591256941037834117ull, 14033304799766305496ull,
  10155326130396969915ull, 4969676562200179294ull}},
{{4489071176297292646ull, 12929944981280493966ull,
  3470785626141436586ull, 6212095702750224118ull}},
{{14834711007226391616ull, 6939059189745841649ull,
  13561854069531571541ull, 7765119628437780147ull}},
{{2354165351875412904ull, 6642755002804844983ull,
  6170315784243538261ull, 4853199767773612592ull}},
{{16777764745126429842ull, 12915129771933444132ull,
  7712894730304422826ull, 6066499709717015740ull}},
{{2525461857698485686ull, 6920540178062029358ull,
  9641118412880528533ull, 7583124637146269675ull}},
{{15413471716343717266ull, 6631180620502462300ull,
  3719855998836636381ull, 4739452898216418547ull}},
{{820095571720094967ull, 12900661794055465780ull, 38133980118407572ull,
  5924316122770523184ull}},
{{1025119464650118708ull, 16125827242569332225ull, 47667475148009465ull,
  7405395153463153980ull}},
{{12169914711474793953ull, 3161112998964750784ull,
  9253164208822281724ull, 4628371970914471237ull}},
{{15212393389343492441ull, 3951391248705938480ull,
  16178141279455240059ull, 5785464963643089046ull}},
{{568747662969813935ull, 327553042455035197ull, 10999304562464274266ull,
  7231831204553861308ull}},
{{5322620597139655322ull, 9632813339923569804ull,
  13749130703080342832ull, 9039789005692326635ull}},
{{12550009910067060385ull, 6020508337452231127ull,
  6287363680211520318ull, 5649868128557704147ull}},
{{11075826369156437577ull, 16749007458670064717ull,
  3247518581837012493ull, 7062335160697130184ull}},
{{9724906163383259ull, 7101201268055417185ull, 4059398227296265617ull,
  8827918950871412730ull}},
{{11535293112420584297ull, 15967465838603105500ull,
  7148809910487553914ull, 5517449344294632956ull}},
{{14419116390525730371ull, 10735960261399106067ull,
  8936012388109442393ull, 6896811680368291195ull}},
{{13412209469729775060ull, 18031636345176270488ull,
  6558329466709415087ull, 8621014600460363994ull}},
{{8382630918581109413ull, 18187301743376250911ull,
  8710641935120772333ull, 5388134125287727496ull}},
{{5866602629798998862ull, 8899069123938149927ull,
  10888302418900965417ull, 6735167656609659370ull}},
{{2721567268821360673ull, 15735522423350075313ull,
  4387005986771430963ull, 8418959570762074213ull}},
{{13230194589081820181ull, 7528858505380103118ull,
  5047721750945838304ull, 5261849731726296383ull}},
{{7314371199497499418ull, 9411073131725128898ull,
  1697966170254909976ull, 6577312164657870479ull}},
{{18366336036226650080ull, 11763841414656411122ull,
  15957515768100801182ull, 8221640205822338098ull}},
{{16090646041069044204ull, 2740714865732869047ull,
  14585133373490388643ull, 5138525128638961311ull}},
{{15501621532908917351ull, 17260951637448250021ull,
  13619730698435597899ull, 6423156410798701639ull}},
{{5541968860853982977ull, 16964503528382924623ull,
  12412977354617109470ull, 8028945513498377049ull}},
{{10381259565674821217ull, 5991128686811939985ull,
  840581818994611563ull, 5018090945936485656ull}},
{{17588260475520914425ull, 2877224840087537077ull,
  1050727273743264454ull, 6272613682420607070ull}},
{{8150267539118979319ull, 12819903086964197155ull,
  10536781129033856375ull, 7840767103025758837ull}},
{{2788074202735668122ull, 14929968456993705078ull,
  8891331214859854186ull, 4900479439391099273ull}},
{{12708464790274360961ull, 9439088534387355539ull,
  15725850037002205637ull, 6125599299238874091ull}},
{{11273894969415563297ull, 16410546686411582328ull,
  15045626527825369142ull, 7656999124048592614ull}},
{{7046184355884727061ull, 5644905660579851051ull,
  4791830561463467810ull, 4785624452530370384ull}},
{{4196044426428520922ull, 16279504112579589622ull,
  5989788201829334762ull, 5982030565662962980ull}},
{{14468427569890426960ull, 11126008103869711219ull,
  7487235252286668453ull, 7477538207078703725ull}},
{{6736924221967822898ull, 9259598074132263464ull,
  6985365041892861735ull, 4673461379424189828ull}},
{{8421155277459778623ull, 6962811574237941426ull,
  8731706302366077169ull, 5841826724280237285ull}},
{{1303072059969947470ull, 13315200486224814687ull,
  15526318896384984365ull, 7302283405350296606ull}},
{{15463898130244598050ull, 2808942552498854646ull,
  10184526583626454649ull, 9127854256687870758ull}},
{{5053250312975485877ull, 13284804141380253914ull,
  1753643096339146251ull, 5704908910429919224ull}},
{{15539934928074133155ull, 11994319158297929488ull,
  2192053870423932814ull, 7131136138037399030ull}},
{{978174586383114827ull, 5769526911017636053ull,
  11963439374884691826ull, 8913920172546748787ull}},
{{2917202125703140719ull, 8217640337813410437ull,
  5171306600089238439ull, 5571200107841717992ull}},
{{8258188675556313803ull, 5660364403839375142ull,
  6464133250111548049ull, 6964000134802147490ull}},
{{1099363807590616445ull, 11687141523226606832ull,
  17303538599494210869ull, 8705000168502684362ull}},
{{687102379744135279ull, 9610306461230323222ull,
  15426397643111269697ull, 5440625105314177726ull}},
{{10082250011534944906ull, 16624569094965291931ull,
  10059625017034311313ull, 6800781381642722158ull}},
{{7991126495991293228ull, 6945653313424451202ull,
  3351159234438113334ull, 8500976727053402698ull}},
{{9606140078421946172ull, 18176091376172445713ull,
  6706160539951208737ull, 5313110454408376686ull}},
{{16619361116454820619ull, 8885056164933393429ull,
  17606072711793786730ull, 6641388068010470857ull}},
{{6939143340286362061ull, 1882948169311965979ull,
  8172532834460069701ull, 8301735085013088572ull}},
{{2031121578465282337ull, 3482685615033672689ull,
  14331205058392319371ull, 5188584428133180357ull}},
{{7150587991508990825ull, 18188415074074254573ull,
  4078948267708235501ull, 6485730535166475447ull}},
{{13549921007813626435ull, 8900460787310654504ull,
  486999316207906473ull, 8107163168958094309ull}},
{{8468700629883516522ull, 17092003038137628825ull,
  2610217581843635497ull, 5066976980598808943ull}},
{{15197561805781783556ull, 7529945742389872319ull,
  17097830032586708084ull, 6333721225748511178ull}},
{{14385266238799841541ull, 9412432177987340399ull,
  12148915503878609297ull, 7917151532185638973ull}},
{{15908320426890982819ull, 17411985157310557509ull,
  9898915199137824762ull, 4948219707616024358ull}},
{{6050342478331564812ull, 12541609409783421079ull,
  3150271962067505145ull, 6185274634520030448ull}},
{{2951242079487068111ull, 1841953706947112637ull,
  3937839952584381432ull, 7731593293150038060ull}},
{{4150369308893111522ull, 1151221066841945398ull,
  11684522007220014203ull, 4832245808218773787ull}},
{{14411333672971165210ull, 15274084388834595459ull,
  9993966490597629849ull, 6040307260273467234ull}},
{{13402481072786568608ull, 5257547430761080612ull,
  3269086076392261504ull, 7550384075341834043ull}},
{{17599922707346381188ull, 3285967144225675382ull,
  18184079862241021104ull, 4718990047088646276ull}},
{{12776531347328200677ull, 4107458930282094228ull,
  4283355754091724764ull, 5898737558860807846ull}},
{{15970664184160250846ull, 5134323662852617785ull,
  14577566729469431763ull, 7373421948576009807ull}},
{{6128272174918149846ull, 1806218560138384328ull,
  13610272393409401800ull, 9216777435720012259ull}},
{{3830170109323843654ull, 1128886600086490205ull,
  6200577236667182173ull, 5760485897325007662ull}},
{{9399398655082192471ull, 6022794268535500660ull,
  16974093582688753524ull, 7200607371656259577ull}},
{{11749248318852740589ull, 7528492835669375825ull,
  7382558923078778193ull, 9000759214570324472ull}},
{{425751171641881012ull, 16234523068361829651ull,
  4614099326924236370ull, 5625474509106452795ull}},
{{14367247019834514977ull, 11069781798597511255ull,
  1155938140227907559ull, 7031843136383065994ull}},
{{13347372756365755817ull, 9225541229819501165ull,
  10668294712139660257ull, 8789803920478832492ull}},
{{10647950981942291338ull, 17295178314705657988ull,
  15891056231942063468ull, 5493627450299270307ull}},
{{13309938727427864172ull, 3172228819672520869ull,
  15252134271500191432ull, 6867034312874087884ull}},
{{2802365354002666503ull, 3965286024590651087ull, 618423765665687674ull,
  8583792891092609856ull}},
{{8669007373892748421ull, 7089989783796544833ull, 386514853541054796ull,
  5364870556932881160ull}},
{{15447945235793323430ull, 8862487229745681041ull,
  483143566926318495ull, 6706088196166101450ull}},
{{5474873489459490575ull, 6466423018754713398ull,
  9827301495512673927ull, 8382610245207626812ull}},
{{17256853986194345322ull, 10959043414362777729ull,
  15365435471550197012ull, 5239131403254766757ull}},
{{7736009427460767940ull, 13698804267953472162ull,
  5371736284155582553ull, 6548914254068458447ull}},
{{446639747471184117ull, 3288447279659676491ull, 2102984336767090288ull,
  8186142817585573059ull}},
{{16420050906665347737ull, 2055279549787297806ull,
  17455266274975289094ull, 5116339260990983161ull}},
{{11301691596476908863ull, 11792471474088898066ull,
  7984024788436947655ull, 6395424076238728952ull}},
{{4903742458741360271ull, 10128903324183734679ull,
  9980030985546184569ull, 7994280095298411190ull}},
{{9982368064354432026ull, 17859779623683303934ull,
  1625833347538977451ull, 4996425059561506994ull}},
{{3254588043588264224ull, 17713038511176742014ull,
  11255663721278497622ull, 6245531324451883742ull}},
{{13291607091340106088ull, 12917926102116151709ull,
  4846207614743346220ull, 7806914155564854678ull}},
{{10613097441301260257ull, 17297075850677370626ull,
  16863937814496755099ull, 4879321347228034173ull}},
{{4042999764771799513ull, 17009658794919325379ull,
  7244864212838780162ull, 6099151684035042717ull}},
{{442063687537361487ull, 12038701456794380916ull,
  13667766284475863107ull, 7623939605043803396ull}},
{{9499661841565626738ull, 5218345401282794120ull,
  17765725964652190250ull, 4764962253152377122ull}},
{{11874577301957033422ull, 15746303788458268458ull,
  12983785418960462004ull, 5956202816440471403ull}},
{{5619849590591515969ull, 1236135661863283957ull,
  11618045755273189602ull, 7445253520550589254ull}},
{{5818249003333391433ull, 5384270807091940377ull,
  2649592578618355597ull, 4653283450344118284ull}},
{{11884497272594127195ull, 11342024527292313375ull,
  3311990723272944496ull, 5816604312930147855ull}},
{{10243935572315271090ull, 14177530659115391719ull,
  17975046459373344332ull, 7270755391162684818ull}},
{{8193233446966700958ull, 17721913323894239649ull,
  13245436037361904607ull, 9088444238953356023ull}},
{{16649985950422657859ull, 17993724855074981636ull,
  15195926550992272235ull, 5680277649345847514ull}},
{{2365738364318770708ull, 17880470050416339142ull,
  9771536151885564486ull, 7100347061682309393ull}},
{{12180544992253239193ull, 13127215526165648119ull,
  16826106208284343512ull, 8875433827102886741ull}},
{{14530369647799356352ull, 8204509703853530074ull,
  12822159389391408647ull, 5547146141939304213ull}},
{{8939590022894419631ull, 5643951111389524689ull,
  2192641181457097097ull, 6933932677424130267ull}},
{{15786173547045412443ull, 11666624907664293765ull,
  16575859532103535083ull, 8667415846780162833ull}},
{{12172201476117076729ull, 4985797558076489651ull,
  3442383179923627571ull, 5417134904237601771ull}},
{{10603565826718958007ull, 1620560929168224160ull,
  18138037030186698176ull, 6771418630297002213ull}},
{{13254457283398697509ull, 2025701161460280200ull,
  8837488232451209008ull, 8464273287871252767ull}},
{{8284035802124185943ull, 1266063225912675125ull,
  12440959172923087486ull, 5290170804919532979ull}},
{{14966730771082620333ull, 10805951069245619714ull,
  10939512947726471453ull, 6612713506149416224ull}},
{{9485041426998499608ull, 18119124854984412547ull,
  13674391184658089316ull, 8265891882686770280ull}},
{{3622307882660368303ull, 2101080997510482034ull,
  8546494490411305823ull, 5166182426679231425ull}},
{{13751256890180236187ull, 16461409302170266254ull,
  15294804131441520182ull, 6457728033349039281ull}},
{{7965699075870519426ull, 11353389590858057010ull,
  5283447109019736516ull, 8072160041686299102ull}},
{{9590247940846462545ull, 16319240531141061439ull,
  17137212498419499034ull, 5045100026053936938ull}},
{{7376123907630690277ull, 11175678627071550991ull,
  12198143586169597985ull, 6306375032567421173ull}},
{{4608468866110974942ull, 134540228557275027ull, 1412621427429833770ull,
  7882968790709276467ull}},
{{574450032105665387ull, 4695773661275684796ull,
  17023789456639503770ull, 4926855494193297791ull}},
{{718062540132081734ull, 15093089113449381803ull,
  16668050802371991808ull, 6158569367741622239ull}},
{{14732636230447265879ull, 419617318102175637ull,
  16223377484537601857ull, 7698211709677027799ull}},
{{11513740653243235127ull, 11791475869882329533ull,
  17057139955477083016ull, 4811382318548142374ull}},
{{557117761271880196ull, 14739344837352911917ull,
  12098052907491577962ull, 6014227898185177968ull}},
{{5308083220017238149ull, 9200809009836364088ull,
  15122566134364472453ull, 7517784872731472460ull}},
{{3317552012510773843ull, 8056348640361421507ull, 228231797123019475ull,
  4698615545457170288ull}},
{{17981998070920631016ull, 5458749782024388979ull,
  285289746403774344ull, 5873269431821462860ull}},
{{17865811570223400866ull, 6823437227530486224ull,
  356612183004717930ull, 7341586789776828575ull}},
{{3885520389069699467ull, 17752668571267883589ull,
  14280823284038061124ull, 9176983487221035718ull}},
{{4734293252382256119ull, 1872045820187651435ull,
  4313828534096400299ull, 5735614679513147324ull}},
{{1306180547050432244ull, 16175115330516728006ull,
  5392285667620500373ull, 7169518349391434155ull}},
{{10856097720667816113ull, 6383836107863746295ull,
  2128671066098237563ull, 8961897936739292694ull}},
{{13702590103058466927ull, 1684054558201147482ull,
  15165477471593562189ull, 5601186210462057933ull}},
{{7904865591968307851ull, 6716754216178822257ull,
  5121788784209789024ull, 7001482763077572417ull}},
{{14492768008387772717ull, 8395942770223527821ull,
  11013921998689624184ull, 8751853453846965521ull}},
{{11363823014456051900ull, 5247464231389704888ull,
  18412916295249484875ull, 5469908408654353450ull}},
{{14204778768070064875ull, 1947644270809743206ull,
  13792773332207080286ull, 6837385510817941813ull}},
{{8532601423232805286ull, 11657927375366954816ull,
  3405908609976686645ull, 8546731888522427267ull}},
{{5332875889520503304ull, 9592047618818040712ull,
  18269593945731286817ull, 5341707430326517041ull}},
{{6666094861900629130ull, 16601745541949938794ull,
  9001934376881944809ull, 6677134287908146302ull}},
{{17555990614230562220ull, 6917123872155259780ull,
  2029045934247655204ull, 8346417859885182878ull}},
{{1749122097039325580ull, 13546574456951813171ull,
  15103211764186948214ull, 5216511162428239298ull}},
{{16021460676581320687ull, 7709846034334990655ull,
  9655642668378909460ull, 6520638953035299123ull}},
{{15415139827299262954ull, 9637307542918738319ull,
  7457867317046248921ull, 8150798691294123904ull}},
{{16551991419703121203ull, 17552532260392681209ull,
  4661167073153905575ull, 5094249182058827440ull}},
{{6854931219346737791ull, 17328979307063463608ull,
  5826458841442381969ull, 6367811477573534300ull}},
{{8568664024183422239ull, 7826166078547165798ull,
  7283073551802977462ull, 7959764346966917875ull}},
{{743728996687250995ull, 279667780664590720ull, 2246077960663166962ull,
  4974852716854323672ull}},
{{929661245859063744ull, 9572956762685514208ull, 2807597450828958702ull,
  6218565896067904590ull}},
{{1162076557323829680ull, 2742823916502116952ull,
  12732868850390974186ull, 7773207370084880737ull}},
{{726297848327393550ull, 6325950966241210999ull, 1040514003853277010ull,
  4858254606303050461ull}},
{{14742930365691405650ull, 17130810744656289556ull,
  5912328523243984166ull, 6072818257878813076ull}},
{{18428662957114257062ull, 12190141393965586137ull,
  7390410654054980208ull, 7591022822348516345ull}},
{{4600385320555328808ull, 7618838371228491336ull,
  16148221704852832390ull, 4744389263967822715ull}},
{{5750481650694161010ull, 300175927180838362ull,
  15573591112638652584ull, 5930486579959778394ull}},
{{16411474100222477070ull, 375219908976047952ull,
  10243616853943539922ull, 7413108224949722993ull}},
{{10257171312639048169ull, 4846198461537417874ull,
  17931475579783182211ull, 4633192640593576870ull}},
{{3598092103944034403ull, 1446062058494384439ull,
  13190972437874201956ull, 5791490800741971088ull}},
{{18332673185212206716ull, 1807577573117980548ull,
  16488715547342752445ull, 7239363500927463860ull}},
{{4469097407805706779ull, 6871157984824863590ull,
  2164150360468888940ull, 9049204376159329826ull}},
{{16628243935160730449ull, 13517845777370315551ull,
  5964279993720443491ull, 5655752735099581141ull}},
{{16173618900523525157ull, 12285621203285506535ull,
  12067036010577942268ull, 7069690918874476426ull}},
{{15605337607227018542ull, 15357026504106883169ull,
  5860422976367652027ull, 8837113648593095533ull}},
{{2835806976875804733ull, 7292298555853108029ull,
  5968607369443476469ull, 5523196030370684708ull}},
{{8156444739522143820ull, 13727059213243772940ull,
  7460759211804345586ull, 6903995037963355885ull}},
{{10195555924402679775ull, 7935451979699940367ull,
  13937635033182819887ull, 8629993797454194856ull}},
{{13289751480392756715ull, 11877186514953544585ull,
  8711021895739262429ull, 5393746123408871785ull}},
{{2777131295208782182ull, 1011425088409767020ull,
  15500463388101465941ull, 6742182654261089731ull}},
{{3471414119010977728ull, 5875967378939596679ull,
  14763893216699444522ull, 8427728317826362164ull}},
{{9087162852022942936ull, 8284165630264635828ull, 4061223582377018ull,
  5267330198641476353ull}},
{{11358953565028678670ull, 1131835000976018977ull,
  4616762547905359177ull, 6584162748301845441ull}},
{{363633901003684625ull, 6026479769647411626ull,
  10382639203309086875ull, 8230203435377306801ull}},
{{4838957206554690795ull, 1460706846815938314ull,
  18018364548136649057ull, 5143877147110816750ull}},
{{15272068545048139302ull, 6437569576947310796ull,
  13299583648316035513ull, 6429846433888520938ull}},
{{643341607600622511ull, 12658647989611526400ull,
  7401107523540268583ull, 8037308042360651173ull}},
{{402088504750389069ull, 14829184021148285856ull,
  6931535211426361816ull, 5023317526475406983ull}},
{{502610630937986337ull, 89735952725805704ull, 4052732995855564367ull,
  6279146908094258729ull}},
{{628263288672482921ull, 13947227996189420842ull,
  9677602263246843362ull, 7848933635117823411ull}},
{{5004350573847689730ull, 13328703516045775930ull,
  3742658405315583149ull, 4905583521948639632ull}},
{{15478810254164387970ull, 2825821339775056200ull,
  4678323006644478937ull, 6131979402435799540ull}},
{{901768743995933346ull, 8143962693146208155ull, 5847903758305598671ull,
  7664974253044749425ull}},
{{16704506529493316006ull, 12007505710857461952ull,
  15184154895009468929ull, 4790608908152968390ull}},
{{2433889088157093391ull, 1174324083289663729ull,
  9756821581907060354ull, 5988261135191210488ull}},
{{7654047378623754642ull, 10691277140966855469ull,
  12196026977383825442ull, 7485326418989013110ull}},
{{7089622620853540604ull, 11293734231531672572ull,
  3010830842437502997ull, 4678329011868133194ull}},
{{8862028276066925755ull, 282109734132427003ull,
  12986910589901654555ull, 5847911264835166492ull}},
{{6465849326656269289ull, 14187695222947697466ull,
  16233638237377068193ull, 7309889081043958115ull}},
{{17305683695175112419ull, 3899560973402458120ull,
  15680361778293947338ull, 9137361351304947644ull}},
{{10816052309484445262ull, 7048911626803924229ull,
  576854074578941278ull, 5710850844565592278ull}},
{{18131751405282944482ull, 18034511570359681094ull,
  9944439630078452405ull, 7138563555706990347ull}},
{{13441317219748904794ull, 8708081407667437656ull,
  7818863519170677603ull, 8923204444633737934ull}},
{{8400823262343065496ull, 3136707870578454583ull, 275103681054285598ull,
  5577002777896086209ull}},
{{5889343059501443966ull, 13144256875077844037ull,
  4955565619745244901ull, 6971253472370107761ull}},
{{11973364842804192862ull, 2595263038565141334ull,
  10806143043108944031ull, 8714066840462634701ull}},
{{2871667008325232635ull, 8539568426744295190ull,
  9059682411156783971ull, 5446291775289146688ull}},
{{12812955797261316601ull, 6062774515002981083ull,
  11324603013945979964ull, 6807864719111433360ull}},
{{11404508728149257848ull, 7578468143753726354ull,
  14155753767432474955ull, 8509830898889291700ull}},
{{11739503973520674059ull, 2430699580632385019ull,
  18070718141500072655ull, 5318644311805807312ull}},
{{10062693948473454670ull, 16873432531072644986ull,
  4141653603165539202ull, 6648305389757259141ull}},
{{3354995398737042529ull, 11868418626986030425ull,
  9788753022384311907ull, 8310381737196573926ull}},
{{13626087170279121341ull, 5111918632652575063ull,
  1506284620562807038ull, 5193988585747858704ull}},
{{12420922944421513772ull, 15613270327670494637ull,
  1882855775703508797ull, 6492485732184823380ull}},
{{1691095625244728503ull, 5681529854305954585ull,
  2353569719629385997ull, 8115607165231029225ull}},
{{12586149811846425074ull, 5856799168154915567ull,
  13000196120836836008ull, 5072254478269393265ull}},
{{11121001246380643439ull, 7320998960193644459ull,
  2415187095763881298ull, 6340318097836741582ull}},
{{9289565539548416394ull, 18374620737096831382ull,
  12242355906559627430ull, 7925397622295926977ull}},
{{1194292443790372343ull, 6872451942258131710ull, 733943413958685288ull,
  4953373513934954361ull}},
{{10716237591592741236ull, 8590564927822664637ull,
  5529115285875744514ull, 6191716892418692951ull}},
{{18006983007918314449ull, 1514834122923554988ull,
  2299708088917292739ull, 7739646115523366189ull}},
{{2030992343094170723ull, 17087672391323079532ull,
  3743160564787001913ull, 4837278822202103868ull}},
{{2538740428867713403ull, 7524532433871685703ull,
  4678950705983752392ull, 6046598527752629835ull}},
{{17008483591366805466ull, 9405665542339607128ull,
  1237002364052302586ull, 7558248159690787294ull}},
{{10630302244604253417ull, 10490226982389642359ull,
  14608184532814852828ull, 4723905099806742058ull}},
{{8676191787327928867ull, 13112783727987052949ull,
  9036858629163790227ull, 5904881374758427573ull}},
{{15456925752587298987ull, 11779293641556428282ull,
  15907759304882125688ull, 7381101718448034466ull}},
{{14272264613794449771ull, 7362058525972767676ull,
  14554035583978716459ull, 4613188574030021541ull}},
{{17840330767243062214ull, 4590887139038571691ull,
  4357486424691231862ull, 5766485717537526927ull}},
{{17688727440626439863ull, 14961980960652990422ull,
  835172012436651923ull, 7208107146921908659ull}},
{{12887537263928274021ull, 14090790182388850124ull,
  14879023070827978616ull, 9010133933652385823ull}},
{{17278082826809947071ull, 8806743863993031327ull,
  16216918446908568491ull, 5631333708532741139ull}},
{{16985917515085045935ull, 6396743811563901255ull,
  15659462040208322710ull, 7039167135665926424ull}},
{{16620710875428919514ull, 17219301801309652377ull,
  1127583476550851771ull, 8798958919582408031ull}},
{{3470415269501992841ull, 8456220616604838784ull,
  7622268700485364213ull, 5499349324739005019ull}},
{{4338019086877491051ull, 15181961789183436384ull,
  4916149857179317362ull, 6874186655923756274ull}},
{{5422523858596863813ull, 9754080199624519672ull,
  15368559358328922511ull, 8592733319904695342ull}},
{{3389077411623039883ull, 13013829152406406651ull,
  4993663580528188665ull, 5370458324940434589ull}},
{{18071404819810963566ull, 2432228385225844601ull,
  10853765494087623736ull, 6713072906175543236ull}},
{{8754197969481540746ull, 3040285481532305752ull,
  13567206867609529670ull, 8391341132719429045ull}},
{{5471373730925962966ull, 15735236481239854807ull,
  10785347301469649995ull, 5244588207949643153ull}},
{{2227531145230065804ull, 15057359583122430605ull,
  18093370145264450398ull, 6555735259937053941ull}},
{{7396099949964970158ull, 9598327442048262448ull,
  8781654626298399286ull, 8194669074921317427ull}},
{{4622562468728106349ull, 1387268632852776126ull,
  3182691132222805602ull, 5121668171825823392ull}},
{{15001575122764908744ull, 10957457827920745965ull,
  3978363915278507002ull, 6402085214782279240ull}},
{{4916910848173972218ull, 4473450248046156649ull,
  4972954894098133753ull, 8002606518477849050ull}},
{{14602284326177202397ull, 14325121451097317665ull,
  7719782827238721499ull, 5001629074048655656ull}},
{{4417797352439339284ull, 13294715795444259178ull,
  9649728534048401874ull, 6252036342560819570ull}},
{{14745618727403949912ull, 7395022707450548164ull,
  2838788630705726535ull, 7815045428201024463ull}},
{{18439383741482244503ull, 11539418219797674458ull,
  8691771921832160940ull, 4884403392625640289ull}},
{{13825857639998029821ull, 14424272774747093073ull,
  15476400920717589079ull, 6105504240782050361ull}},
{{3447263994715373564ull, 13418654950006478438ull,
  5510443095614822637ull, 7631880300977562952ull}},
{{15989598051979272190ull, 10692502352967742975ull,
  3444026934759264148ull, 4769925188110976845ull}},
{{15375311546546702333ull, 13365627941209678719ull,
  8916719686876468089ull, 5962406485138721056ull}},
{{14607453414755990013ull, 2871976871229934687ull,
  11145899608595585112ull, 7453008106423401320ull}},
{{16047187411863575614ull, 1794985544518709179ull,
  6966187255372240695ull, 4658130066514625825ull}},
{{15447298246402081613ull, 16078789985930550186ull,
  13319420087642688772ull, 5822662583143282281ull}},
{{10085750771147826209ull, 1651743408703636117ull,
  2814217054271197254ull, 7278328228929102852ull}},
{{17218874482362170665ull, 11288051297734320954ull,
  3517771317838996567ull, 9097910286161378565ull}},
{{15373482569903744570ull, 13972561088725032452ull,
  4504450082863066806ull, 5686193928850861603ull}},
{{770109138670129096ull, 8242329324051514758ull, 1018876585151445604ull,
  7107742411063577004ull}},
{{10186008460192437178ull, 10302911655064393447ull,
  1273595731439307005ull, 8884678013829471255ull}},
{{13283784315261355092ull, 8745162793628939856ull,
  7713526359790648734ull, 5552923758643419534ull}},
{{16604730394076693865ull, 1708081455181399012ull,
  418535912883535110ull, 6941154698304274418ull}},
{{2309168918886315715ull, 11358473855831524574ull,
  9746541927959194695ull, 8676443372880343022ull}},
{{15278288629586111034ull, 14016575187535784714ull,
  1479902686547108780ull, 5422777108050214389ull}},
{{9874488750127862985ull, 17520718984419730893ull,
  6461564376611273879ull, 6778471385062767986ull}},
{{16954796956087216635ull, 17289212712097275712ull,
  17300327507618868157ull, 8473089231328459982ull}},
{{10596748097554510397ull, 13111600954274491272ull,
  6201018673834404694ull, 5295680769580287489ull}},
{{13245935121943137996ull, 7166129155988338282ull,
  12362959360720393772ull, 6619600961975359361ull}},
{{7334046865574146687ull, 8957661444985422853ull,
  1618641145618328503ull, 8274501202469199202ull}},
{{6889622300197535632ull, 12516067430756971139ull,
  5623336734438843218ull, 5171563251543249501ull}},
{{4000341856819531635ull, 6421712251591438116ull,
  11640856936475941927ull, 6464454064429061876ull}},
{{5000427321024414544ull, 3415454296061909741ull,
  14551071170594927409ull, 8080567580536327345ull}},
{{5431110084853953042ull, 13663873981107163348ull,
  2176890453980747774ull, 5050354737835204591ull}},
{{6788887606067441303ull, 7856470439529178377ull,
  16556171122758098430ull, 6312943422294005738ull}},
{{13097795526011689532ull, 597216012556697163ull,
  11471841866592847230ull, 7891179277867507173ull}},
{{5880279194543612006ull, 14208318063130099439ull,
  9475744175834223470ull, 4931987048667191983ull}},
{{2738662974752127103ull, 8537025542057848491ull,
  7232994201365391434ull, 6164983810833989979ull}},
{{17258386773722322591ull, 1447909890717534805ull,
  4429556733279351389ull, 7706229763542487474ull}},
{{13092334742790145571ull, 3210786690912153205ull,
  7380158976726982522ull, 4816393602214054671ull}},
{{2530360373205518252ull, 13236855400494967315ull,
  4613512702481340248ull, 6020492002767568339ull}},
{{16998008521789061527ull, 16546069250618709143ull,
  1155204859674287406ull, 7525615003459460424ull}},
{{17541284353759245311ull, 5729607263209305310ull,
  722003037296429629ull, 4703509377162162765ull}},
{{12703233405344280830ull, 11773695097439019542ull,
  5514189815047924940ull, 5879386721452703456ull}},
{{6655669719825575229ull, 14717118871798774428ull,
  6892737268809906175ull, 7349233401815879320ull}},
{{8319587149781969037ull, 13784712571321080131ull,
  8615921586012382719ull, 9186541752269849150ull}},
{{2893898959400036696ull, 15532974384716756938ull,
  773264972830351295ull, 5741588595168655719ull}},
{{12840745736104821678ull, 14804531962468558268ull,
  14801639271320102831ull, 7176985743960819648ull}},
{{16050932170131027097ull, 13893978934658309931ull,
  55305015440576923ull, 8971232179951024561ull}},
{{7725989597118197984ull, 6377893824947749755ull,
  11563780680718830337ull, 5607020112469390350ull}},
{{5045800977970359576ull, 12584053299612075098ull,
  5231353814043762113ull, 7008775140586737938ull}},
{{15530623259317725278ull, 1895008569232930160ull,
  15762564304409478450ull, 8760968925733422422ull}},
{{9706639537073578299ull, 5796066374197969254ull,
  5239916671828536127ull, 5475605578583389014ull}},
{{2909927384487197065ull, 2633396949320073664ull,
  15773267876640445967ull, 6844506973229236267ull}},
{{3637409230608996332ull, 17126804241932255792ull,
  15104898827373169554ull, 8555633716536545334ull}},
{{2273380769130622707ull, 15315938669635047774ull,
  4828875748680843067ull, 5347271072835340834ull}},
{{12065097998268054192ull, 14533237318616421813ull,
  15259466722705829642ull, 6684088841044176042ull}},
{{1246314442552904028ull, 8943174611415751459ull,
  9850961366527511245ull, 8355111051305220053ull}},
{{16919847591091422682ull, 7895327141348538613ull,
  8462693863293388480ull, 5221944407065762533ull}},
{{7314751433582114640ull, 9869158926685673267ull,
  15190053347544123504ull, 6527430508832203166ull}},
{{4531753273550255396ull, 12336448658357091584ull,
  9764194647575378572ull, 8159288136040253958ull}},
{{2832345795968909623ull, 16933652448327958048ull,
  1490935636307223703ull, 5099555085025158724ull}},
{{3540432244961137028ull, 16555379541982559656ull,
  1863669545384029629ull, 6374443856281448405ull}},
{{4425540306201421285ull, 6859166372196035858ull,
  6941272950157424941ull, 7968054820351810506ull}},
{{7377648709803276207ull, 6592821991836216363ull,
  8949981612275778492ull, 4980034262719881566ull}},
{{4610374868826707355ull, 8241027489795270454ull,
  1964104978489947307ull, 6225042828399851958ull}},
{{14986340622888160002ull, 5689598343816700163ull,
  11678503259967209942ull, 7781303535499814947ull}},
{{7060619880091406049ull, 17391057020167601314ull,
  4993221528265812261ull, 4863314709687384342ull}},
{{18049146886969033370ull, 7903763219927337930ull,
  15464898947187041135ull, 6079143387109230427ull}},
{{13338061571856515904ull, 5268018006481784509ull,
  14719437665556413515ull, 7598929233886538034ull}},
{{10642131491624016392ull, 986668244837421366ull,
  13811334559400146351ull, 4749330771179086271ull}},
{{4079292327675244682ull, 15068393361328940420ull,
  12652482180822795034ull, 5936663463973857839ull}},
{{5099115409594055852ull, 9612119664806399717ull,
  11203916707601105889ull, 7420829329967322299ull}},
{{5492790140209978860ull, 17536789836572469583ull,
  4696604933036997228ull, 4638018331229576437ull}},
{{2254301656835085671ull, 3474243222006035363ull,
  10482442184723634440ull, 5797522914036970546ull}},
{{16652935126326020800ull, 4342804027507544203ull,
  3879680694049767242ull, 7246903642546213183ull}},
{{16204482889480138096ull, 14651877071239206062ull,
  237914849134821148ull, 9058629553182766479ull}},
{{5516115787497698406ull, 18380795206379279597ull,
  7066225808350345073ull, 5661643470739229049ull}},
{{11506830752799510912ull, 9140935952691935784ull,
  13444468278865319246ull, 7077054338424036311ull}},
{{14383538440999388640ull, 2202797904010143922ull,
  12193899330154261154ull, 8846317923030045389ull}},
{{13601397544052005804ull, 5988434708433727855ull,
  9927030090560107173ull, 5528948701893778368ull}},
{{12390060911637619351ull, 12097229403969547723ull,
  12408787613200133966ull, 6911185877367222960ull}},
{{10875890121119636284ull, 5898164718107158846ull,
  15510984516500167458ull, 8638982346709028700ull}},
{{2185745307272384774ull, 8298038967244362183ull, 470993285957828853ull,
  5399363966693142938ull}},
{{16567239689372644679ull, 14984234727482840632ull,
  9812113644302061874ull, 6749204958366428672ull}},
{{2262305538006254233ull, 9506921372498774983ull,
  12265142055377577343ull, 8436506197958035840ull}},
{{8331469988894990752ull, 12859354885452816220ull,
  7665713784610985839ull, 5272816373723772400ull}},
{{10414337486118738440ull, 11462507588388632371ull,
  9582142230763732299ull, 6591020467154715500ull}},
{{8406235839221035145ull, 9716448467058402560ull,
  11977677788454665374ull, 8238775583943394375ull}},
{{5253897399513146966ull, 1461094273484113696ull,
  14403577645425247715ull, 5149234739964621484ull}},
{{6567371749391433707ull, 15661425897137305832ull,
  18004472056781559643ull, 6436543424955776855ull}},
{{8209214686739292134ull, 14965096352994244386ull,
  17893904052549561650ull, 8045679281194721069ull}},
{{9742445197639445488ull, 13964871239048790645ull,
  13489533042057169983ull, 5028549550746700668ull}},
{{16789742515476694764ull, 12844403030383600402ull,
  16861916302571462479ull, 6285686938433375835ull}},
{{11763806107491092647ull, 11443817769552112599ull,
  16465709359786940195ull, 7857108673041719794ull}},
{{14269907844823014760ull, 4846543096756376422ull,
  14902754368294225526ull, 4910692920651074871ull}},
{{8614012769173992642ull, 15281550907800246336ull,
  14016756941940394003ull, 6138366150813843589ull}},
{{10767515961467490803ull, 14490252616322920016ull,
  3685888122143328792ull, 7672957688517304487ull}},
{{6729697475917181752ull, 9056407885201825010ull,
  9221209103980662351ull, 4795598555323315304ull}},
{{17635493881751252998ull, 6708823838074893358ull,
  11526511379975827939ull, 5994498194154144130ull}},
{{12820995315334290439ull, 3774343779166228794ull,
  5184767188115009116ull, 7493122742692680163ull}},
{{12624808090511319429ull, 11582336898833668804ull,
  934636483358186745ull, 4683201714182925102ull}},
{{15781010113139149286ull, 642863068259922293ull,
  10391667641052509240ull, 5854002142728656377ull}},
{{5891204586141772895ull, 803578835324902867ull,
  17601270569743024454ull, 7317502678410820471ull}},
{{2752319714249828215ull, 10227845581010904392ull,
  17389902193751392663ull, 9146878348013525589ull}},
{{1720199821406142634ull, 13309932515772897101ull,
  13174531880308314366ull, 5716798967508453493ull}},
{{6761935795185066197ull, 7414043607861345568ull,
  2633106795103229246ull, 7145998709385566867ull}},
{{8452419743981332746ull, 44182472971906152ull, 17126441549161200270ull,
  8932498386731958583ull}},
{{5282762339988332966ull, 13862672100889605057ull,
  17621554995866832024ull, 5582811491707474114ull}},
{{11215138943412804112ull, 17328340126112006321ull,
  12803571707978764222ull, 6978514364634342643ull}},
{{183865623983841428ull, 12437053120785232094ull,
  11392778616546067374ull, 8723142955792928304ull}},
{{13949974070272064604ull, 3161472182063382154ull,
  7120486635341292109ull, 5451964347370580190ull}},
{{8214095550985304947ull, 8563526246006615597ull,
  18123980331031390944ull, 6814955434213225237ull}},
{{14879305457159019088ull, 10704407807508269496ull,
  8819917358507074968ull, 8518694292766531547ull}},
{{9299565910724386930ull, 6690254879692668435ull,
  3206605339853227903ull, 5324183932979082217ull}},
{{7012771369978095759ull, 3751132581188447640ull,
  8619942693243922783ull, 6655229916223852771ull}},
{{8765964212472619698ull, 77229708058171646ull, 6163242348127515575ull,
  8319037395279815964ull}},
{{867041614367999408ull, 6965797595177439135ull,
  13075398504434473042ull, 5199398372049884977ull}},
{{14918860073242162971ull, 17930619030826574726ull,
  2509190075260927590ull, 6499247965062356222ull}},
{{9425203054697927906ull, 13189901751678442600ull,
  12359859630930935296ull, 8124059956327945277ull}},
{{5890751909186204942ull, 8243688594799026625ull,
  10030755278545528512ull, 5077537472704965798ull}},
{{11975125904910144081ull, 10304610743498783281ull,
  3315072061327134832ull, 6346921840881207248ull}},
{{1133849325855516389ull, 12880763429373479102ull,
  4143840076658918540ull, 7933652301101509060ull}},
{{14543713883941861455ull, 17273849180213200246ull,
  11813272084766599895ull, 4958532688188443162ull}},
{{8956270318072551011ull, 16980625456839112404ull,
  5543218069103474061ull, 6198165860235553953ull}},
{{11195337897590688764ull, 7390723765766726793ull,
  11540708604806730481ull, 7747707325294442441ull}},
{{79557158353098621ull, 16148417399672674006ull, 295413850363124694ull,
  4842317078309026526ull}},
{{9322818484796149085ull, 10962149712736066699ull,
  9592639349808681676ull, 6052896347886283157ull}},
{{7041837087567798452ull, 13702687140920083374ull,
  16602485205688239999ull, 7566120434857853946ull}},
{{18236206235012037744ull, 15481708490716133964ull,
  14988239271982537903ull, 4728825271786158716ull}},
{{4348513720055495564ull, 14740449594967779552ull,
  288555016268620763ull, 5911031589732698396ull}},
{{5435642150069369455ull, 13813875975282336536ull,
  360693770335775954ull, 7388789487165872995ull}},
{{3397276343793355910ull, 13245358502978848239ull,
  16366334670955717635ull, 4617993429478670621ull}},
{{18081653485023858599ull, 11945012110296172394ull,
  6622860283412483332ull, 5772491786848338277ull}},
{{13378694819425047441ull, 14931265137870215493ull,
  12890261372692992069ull, 7215614733560422846ull}},
{{2888310468999145589ull, 4829023367055605655ull,
  6889454679011464279ull, 9019518416950528558ull}},
{{8722723070765547849ull, 9935668632050835390ull,
  18140967229664328886ull, 5637199010594080348ull}},
{{1680031801602159003ull, 3196213753208768430ull,
  4229464963370859492ull, 7046498763242600436ull}},
{{11323411788857474562ull, 3995267191510960537ull,
  5286831204213574365ull, 8808123454053250545ull}},
{{159603340394839746ull, 4802885003908044288ull,
  14833484548701953738ull, 5505077158783281590ull}},
{{199504175493549682ull, 15226978291739831168ull,
  9318483649022666364ull, 6881346448479101988ull}},
{{249380219366937102ull, 586978790965237344ull, 11648104561278332956ull,
  8601683060598877485ull}},
{{155862637104335689ull, 9590233781208049148ull, 9585908360012652049ull,
  5376051912874298428ull}},
{{194828296380419611ull, 16599478244937449339ull,
  11982385450015815061ull, 6720064891092873035ull}},
{{14078593425757688226ull, 6914289750889647961ull,
  10366295794092380923ull, 8400081113866091294ull}},
{{1881591863457473285ull, 2015588085092336024ull,
  1867248852880350173ull, 5250050696166307059ull}},
{{2351989829321841607ull, 7131171124792807934ull,
  16169119121382601428ull, 6562563370207883823ull}},
{{12163359323507077816ull, 8913963905991009917ull,
  15599712883300863881ull, 8203204212759854779ull}},
{{9907942586405617587ull, 17100442487312850958ull,
  7443977542849345973ull, 5127002632974909237ull}},
{{3161556196152246176ull, 7540495053858899986ull,
  13916657946989070371ull, 6408753291218636546ull}},
{{13175317282045083528ull, 4813932798896237078ull,
  8172450396881562156ull, 8010941614023295683ull}},
{{3622887282850789301ull, 12232080036164923982ull,
  2801938488837282395ull, 5006838508764559802ull}},
{{13751981140418262434ull, 10678414026778767073ull,
  12725795147901378802ull, 6258548135955699752ull}},
{{3354918370240664331ull, 4124645496618683034ull,
  15907243934876723503ull, 7823185169944624690ull}},
{{6708509999827803111ull, 9495432463027758752ull,
  14553713477725340093ull, 4889490731215390431ull}},
{{8385637499784753888ull, 16480976597212086344ull,
  13580455828729287212ull, 6111863414019238039ull}},
{{10482046874730942360ull, 2154476672805556314ull,
  12363883767484221112ull, 7639829267524047549ull}},
{{11162965315134226879ull, 1346547920503472696ull,
  10033270363891332147ull, 4774893292202529718ull}},
{{13953706643917783599ull, 15518242955911504582ull,
  3318215918009389375ull, 5968616615253162148ull}},
{{8218761268042453691ull, 14786117676461992824ull,
  4147769897511736719ull, 7460770769066452685ull}},
{{5136725792526533557ull, 16158852575429827371ull,
  4898199195158529401ull, 4662981730666532928ull}},
{{1809221222230779042ull, 6363507664005120502ull,
  6122748993948161752ull, 5828727163333166160ull}},
{{11484898564643249610ull, 7954384580006400627ull,
  7653436242435202190ull, 7285908954166457700ull}},
{{9744437187376674109ull, 719608688153224976ull, 9566795303044002738ull,
  9107386192708072125ull}},
{{6090273242110421318ull, 5061441448523153514ull,
  8285090073616195663ull, 5692116370442545078ull}},
{{16836213589492802456ull, 1715115792226553988ull,
  1132990555165468771ull, 7115145463053181348ull}},
{{2598522913156451454ull, 15978952795565356198ull,
  1416238193956835963ull, 8893931828816476685ull}},
{{15459134876004945871ull, 7681002488014653671ull,
  3190991880436716429ull, 5558707393010297928ull}},
{{14712232576578794434ull, 14212939128445704993ull,
  3988739850545895536ull, 6948384241262872410ull}},
{{4555232665441329331ull, 17766173910557131242ull,
  14209296850037145228ull, 8685480301578590512ull}},
{{7458706434328218736ull, 1880486657243431218ull,
  8880810531273215768ull, 5428425188486619070ull}},
{{100011006055497612ull, 2350608321554289023ull, 1877641127236743902ull,
  6785531485608273838ull}},
{{13960071812851535726ull, 12161632438797637086ull,
  11570423445900705685ull, 8481914357010342297ull}},
{{4113358864604821925ull, 9906863283462217131ull, 313985626046859197ull,
  5301196473131463936ull}},
{{530012562328639502ull, 16995265122755159318ull, 392482032558573996ull,
  6626495591414329920ull}},
{{9885887739765575186ull, 2797337329734397531ull, 490602540698217496ull,
  8283119489267912400ull}},
{{3872836828139790539ull, 1748335831083998457ull, 306626587936385935ull,
  5176949680792445250ull}},
{{9452732053602126078ull, 16020477844137161783ull,
  9606655271775258226ull, 6471187100990556562ull}},
{{7204229048575269693ull, 10802225268316676421ull,
  2784947052864296975ull, 8088983876238195703ull}},
{{6808486164573237511ull, 13668919820339004619ull,
  8658120935681267465ull, 5055614922648872314ull}},
{{3898921687289158984ull, 3251091720141592062ull,
  1599279132746808524ull, 6319518653311090393ull}},
{{14097024145966224538ull, 4063864650176990077ull,
  6610784934360898559ull, 7899398316638862991ull}},
{{11116483100442584288ull, 9457444434001700654ull,
  11049269611616643455ull, 4937123947899289369ull}},
{{4672231838698454552ull, 7210119524074737914ull,
  18423273032948192223ull, 6171404934874111711ull}},
{{15063661835227843998ull, 4400963386666034488ull,
  18417405272757852375ull, 7714256168592639639ull}},
{{9414788647017402499ull, 9668131144307353411ull,
  18428407323114739590ull, 4821410105370399774ull}},
{{7156799790344365220ull, 2861791893529415956ull,
  13812137117038648680ull, 6026762631712999718ull}},
{{8945999737930456525ull, 3577239866911769945ull,
  8041799359443535042ull, 7533453289641249648ull}},
{{17120464882275005088ull, 6847460935247244119ull,
  5026124599652209401ull, 4708408306025781030ull}},
{{16788895084416368456ull, 13171012187486443053ull,
  15506027786420037559ull, 5885510382532226287ull}},
{{7151060800238296858ull, 11852079215930665913ull,
  14770848714597659045ull, 7356887978165282859ull}},
{{13550512018725258976ull, 980040964631168679ull,
  13851874874819685903ull, 9196109972706603574ull}},
{{15386599039344368716ull, 7530054630535562280ull,
  4045735778334915785ull, 5747568732941627234ull}},
{{786504725470909279ull, 14024254306596840755ull,
  14280541759773420539ull, 7184460916177034042ull}},
{{14818188962120800311ull, 12918631864818663039ull,
  8627305162861999866ull, 8980576145221292553ull}},
{{16178897128966582051ull, 12685830933939052303ull,
  16921280772857219676ull, 5612860090763307845ull}},
{{15611935392780839659ull, 15857288667423815379ull,
  7316542910789360883ull, 7016075113454134807ull}},
{{14903233222548661670ull, 15209924815852381320ull,
  4533992620059313200ull, 8770093891817668509ull}},
{{9314520764092913544ull, 9506203009907738325ull,
  5139588396750764702ull, 5481308682386042818ull}},
{{16254836973543529834ull, 2659381725529897098ull,
  15647857532793231686ull, 6851635852982553522ull}},
{{11095174180074636484ull, 12547599193767147181ull,
  10336449879136763799ull, 8564544816228191903ull}},
{{9240326871760341755ull, 14759778523745548844ull,
  13377810202101559230ull, 5352840510142619939ull}},
{{11550408589700427193ull, 9226351117827160247ull,
  12110576734199561134ull, 6691050637678274924ull}},
{{9826324718698146087ull, 2309566860429174501ull,
  15138220917749451418ull, 8363813297097843655ull}},
{{8447295958400035257ull, 6055165306195621967ull,
  16378917101234488992ull, 5227383310686152284ull}},
{{5947433929572656167ull, 7568956632744527459ull,
  2026902302833559624ull, 6534229138357690356ull}},
{{2822606393538432304ull, 9461195790930659324ull,
  2533627878541949530ull, 8167786422947112945ull}},
{{10987501032816295998ull, 10524933387759049981ull,
  13112732470157188216ull, 5104866514341945590ull}},
{{18346062309447757902ull, 13156166734698812476ull,
  7167543550841709462ull, 6381083142927431988ull}},
{{4485833813100145761ull, 7221836381518739788ull,
  8959429438552136828ull, 7976353928659289985ull}},
{{12027018170042366909ull, 13737019775303988175ull,
  17128858445163555277ull, 4985221205412056240ull}},
{{10422086694125570732ull, 3336216663847821507ull,
  2964328982744892481ull, 6231526506765070301ull}},
{{8415922349229575511ull, 8781956848237164788ull,
  8317097246858503505ull, 7789408133456337876ull}},
{{14483323505123260503ull, 17017938076216697752ull,
  14421557816141340498ull, 4868380083410211172ull}},
{{18104154381404075628ull, 12049050558416096382ull,
  18026947270176675623ull, 6085475104262763965ull}},
{{13406820939900318727ull, 10449627179592732574ull,
  8698626032438680817ull, 7606843880328454957ull}},
{{3767577069010311301ull, 18060232033313927619ull,
  7742484279487869462ull, 4754277425205284348ull}},
{{97785317835501222ull, 13351918004787633716ull, 9678105349359836828ull,
  5942846781506605435ull}},
{{122231647294376527ull, 16689897505984542145ull,
  7485945668272408131ull, 7428558476883256794ull}},
{{11605609825627455089ull, 8125342932026644888ull,
  9290402061097642986ull, 4642849048052035496ull}},
{{14507012282034318862ull, 933306628178530302ull,
  11613002576372053733ull, 5803561310065044370ull}},
{{8910393315688122769ull, 5778319303650550782ull,
  5292881183610291358ull, 7254451637581305463ull}},
{{1914619607755377653ull, 16446271166417964286ull,
  2004415461085476293ull, 9068064546976631829ull}},
{{15031695310129274745ull, 12584762488224921630ull,
  3558602672392116635ull, 5667540341860394893ull}},
{{9566247100806817624ull, 11119267091853764134ull,
  9059939358917533698ull, 7084425427325493616ull}},
{{2734436839153746221ull, 4675711827962429360ull,
  11324924198646917123ull, 8855531784156867020ull}},
{{1709023024471091389ull, 616476883262824398ull,
  16301449661009099010ull, 5534707365098041887ull}},
{{11359650817443640044ull, 9993968140933306305ull,
  15765126057833985858ull, 6918384206372552359ull}},
{{364505466522386342ull, 3269088139311857074ull,
  15094721553865094419ull, 8647980257965690449ull}},
{{4839501935003879368ull, 18184081151565768335ull,
  2516671943524602155ull, 5404987661228556531ull}},
{{1437691400327461306ull, 18118415421029822515ull,
  16980897984687916406ull, 6756234576535695663ull}},
{{15632172305691490344ull, 13424647239432502335ull,
  16614436462432507604ull, 8445293220669619579ull}},
{{16687636718698263321ull, 17613776561500089767ull,
  8078179779806623300ull, 5278308262918512237ull}},
{{16247859879945441248ull, 3570476628165560593ull,
  14709410743185667030ull, 6597885328648140296ull}},
{{6474766794649637848ull, 13686467822061726550ull,
  18386763428982083787ull, 8247356660810175370ull}},
{{17881787301938187367ull, 6248199379574885141ull,
  16103413161541190271ull, 5154597913006359606ull}},
{{8517176072140570496ull, 3198563206041218523ull,
  10905894415071712031ull, 6443247391257949508ull}},
{{6034784071748325216ull, 17833262062833686866ull,
  13632368018839640038ull, 8054059239072436885ull}},
{{8383426063270091164ull, 6534102770843666387ull,
  10826073020988468976ull, 5033787024420273053ull}},
{{5867596560660226051ull, 8167628463554582984ull,
  18144277294662974124ull, 6292233780525341316ull}},
{{7334495700825282564ull, 10209535579443228730ull,
  4233602544619166039ull, 7865292225656676646ull}},
{{9195745831443189507ull, 13298488764793099812ull,
  16481059645669142486ull, 4915807641035422903ull}},
{{11494682289303986883ull, 7399738919136598957ull,
  15989638538659040204ull, 6144759551294278629ull}},
{{533294806347819892ull, 9249673648920748697ull, 6151990118041636543ull,
  7680949439117848287ull}},
{{11862524300035857193ull, 12698575058216549791ull,
  10762522851417104695ull, 4800593399448655179ull}},
{{10216469356617433587ull, 11261532804343299335ull,
  8841467545843992965ull, 6000741749310818974ull}},
{{8158900677344404079ull, 241857950146960457ull, 1828462395450215399ull,
  7500927186638523718ull}},
{{16628527969408722310ull, 7068690246482932141ull,
  14977847052438548336ull, 4688079491649077323ull}},
{{6950601906478739175ull, 8835862808103665177ull,
  14110622797120797516ull, 5860099364561346654ull}},
{{13299938401525811873ull, 11044828510129581471ull,
  8414906459546221087ull, 7325124205701683318ull}},
{{12013236983479876937ull, 9194349619234588935ull,
  1295261037578000551ull, 9156405257127104148ull}},
{{14425802142316004942ull, 12663997539662699940ull,
  10032910185341026152ull, 5722753285704440092ull}},
{{18032252677895006177ull, 15829996924578374925ull,
  12541137731676282690ull, 7153441607130550115ull}},
{{8705257792086594009ull, 10564124118868192849ull,
  11064736146167965459ull, 8941802008913187644ull}},
{{16970001166122591016ull, 4296734565078926578ull,
  16138832128209754220ull, 5588626255570742277ull}},
{{11989129420798462962ull, 5370918206348658223ull,
  6338482104980029063ull, 6985782819463427847ull}},
{{10374725757570690798ull, 2101961739508434875ull,
  3311416612797648425ull, 8732228524329284809ull}},
{{4178360589267987797ull, 12842941133261241557ull,
  13598850429067000025ull, 5457642827705803005ull}},
{{9834636755012372650ull, 2218618361294388234ull,
  3163504981051586320ull, 6822053534632253757ull}},
{{3069923906910690005ull, 2773272951617985293ull,
  8566067244741870804ull, 8527566918290317196ull}},
{{4224545451032875205ull, 10956667631616016616ull,
  14577164064818445060ull, 5329729323931448247ull}},
{{5280681813791094006ull, 13695834539520020770ull,
  13609769062595668421ull, 6662161654914310309ull}},
{{15824224304093643316ull, 3284735119117862250ull,
  3177153272962421815ull, 8327702068642887887ull}},
{{14501826208485914976ull, 8970488477089745762ull,
  8903249823242595490ull, 5204813792901804929ull}},
{{8903910723752617912ull, 1989738559507406395ull,
  15740748297480632267ull, 6506017241127256161ull}},
{{6518202386263384486ull, 16322231254666421706ull,
  5840877316568626621ull, 8132521551409070202ull}},
{{8685562509842003208ull, 12507237543380207518ull,
  8262234341282779542ull, 5082825969630668876ull}},
{{1633581100447728202ull, 6410674892370483590ull,
  10327792926603474428ull, 6353532462038336095ull}},
{{11265348412414436061ull, 8013343615463104487ull,
  8298055139826955131ull, 7941915577547920119ull}},
{{13958371785400104394ull, 2702496750450746352ull,
  12103813490032928813ull, 4963697235967450074ull}},
{{17447964731750130492ull, 7989806956490820844ull,
  5906394825686385208ull, 6204621544959312593ull}},
{{3363211840978111499ull, 9987258695613526056ull,
  11994679550535369414ull, 7755776931199140741ull}},
{{2102007400611319687ull, 1630350666331065881ull,
  9802517728298299836ull, 4847360581999462963ull}},
{{7239195269191537513ull, 2037938332913832351ull,
  7641461141945486891ull, 6059200727499328704ull}},
{{4437308068062033987ull, 16382480971424454151ull,
  9551826427431858613ull, 7574000909374160880ull}},
{{9690846570179853098ull, 12544893616353977796ull,
  5969891517144911633ull, 4733750568358850550ull}},
{{12113558212724816373ull, 1846058965160308533ull,
  16685736433285915350ull, 5917188210448563187ull}},
{{1306889710623856754ull, 11530945743305161475ull,
  16245484523180006283ull, 7396485263060703984ull}},
{{16957707133635768135ull, 4900998080352031969ull,
  10153427826987503927ull, 4622803289412939990ull}},
{{7362075861762546457ull, 1514561582012652058ull,
  3468412746879604101ull, 5778504111766174988ull}},
{{18425966864057958879ull, 6504887995943202976ull,
  4335515933599505126ull, 7223130139707718735ull}},
{{4585714506362896982ull, 17354482031783779529ull,
  807708898571993503ull, 9028912674634648419ull}},
{{14395286612545280374ull, 17764080297505944061ull,
  16645719126103353603ull, 5643070421646655261ull}},
{{4159050210399436756ull, 17593414353455042173ull,
  6972090852347028292ull, 7053838027058319077ull}},
{{9810498781426683848ull, 3545023868109251100ull,
  13326799583861173270ull, 8817297533822898846ull}},
{{15354933775246453213ull, 16050697972850445649ull,
  3717563721485845389ull, 5510810958639311779ull}},
{{5358609163775902805ull, 6228314410780893350ull, 35268633429918833ull,
  6888513698299139724ull}},
{{15921633491574654314ull, 12397079031903504591ull,
  44085791787398541ull, 8610642122873924655ull}},
{{16868549959875240802ull, 10054017404153384321ull,
  6945082647508205944ull, 5381651326796202909ull}},
{{7250629394561887291ull, 12567521755191730402ull,
  13293039327812645334ull, 6727064158495253636ull}},
{{18286658780057134921ull, 6486030157134887194ull,
  16616299159765806668ull, 8408830198119067045ull}},
{{16040847755963097230ull, 13277140885064080304ull,
  12691029984067323119ull, 5255518873824416903ull}},
{{1604315621244319921ull, 11984740087902712477ull,
  11252101461656765995ull, 6569398592280521129ull}},
{{6617080544982787806ull, 10369239091451002692ull,
  230068771788793782ull, 8211748240350651412ull}},
{{13359047377469018187ull, 1869088413729488778ull,
  9367165019222771922ull, 5132342650219157132ull}},
{{7475437184981496925ull, 11559732554016636781ull,
  11708956274028464902ull, 6415428312773946415ull}},
{{13955982499654259060ull, 5226293655666020168ull,
  10024509324108193224ull, 8019285390967433019ull}},
{{8722489062283911913ull, 3266433534791262605ull,
  3959475318353926813ull, 5012053369354645637ull}},
{{15514797346282277795ull, 8694727936916466160ull,
  9561030166369796420ull, 6265066711693307046ull}},
{{946752609143295628ull, 10868409921145582701ull,
  2727915671107469717ull, 7831333389616633808ull}},
{{2897563389928253720ull, 9098599209929683140ull,
  1704947294442168573ull, 4894583368510396130ull}},
{{3621954237410317149ull, 15984935030839491829ull,
  11354556154907486524ull, 6118229210637995162ull}},
{{9139128815190284340ull, 1534424714839813170ull,
  4969823156779582348ull, 7647786513297493953ull}},
{{10323641527921315617ull, 10182387483629659039ull,
  14635354519055708727ull, 4779866570810933720ull}},
{{8292865891474256617ull, 8116298336109685895ull,
  18294193148819635909ull, 5974833213513667150ull}},
{{5754396345915432867ull, 14757058938564495273ull,
  13644369399169769078ull, 7468541516892083938ull}},
{{15125712762265615302ull, 4611475818175421641ull,
  13139416892908493578ull, 4667838448057552461ull}},
{{5072082897549855416ull, 14987716809574052860ull,
  2589213060853453260ull, 5834798060071940577ull}},
{{6340103621937319269ull, 287901938258014459ull, 7848202344494204480ull,
  7293497575089925721ull}},
{{3313443508994261183ull, 359877422822518074ull,
  14421938949045143504ull, 9116871968862407151ull}},
{{6682588211548801143ull, 224923389264073796ull,
  15931240870794296546ull, 5698044980539004469ull}},
{{8353235264436001429ull, 9504526273434868053ull,
  6078993033210706970ull, 7122556225673755587ull}},
{{15053230098972389690ull, 2657285804938809258ull,
  2987055273085995809ull, 8903195282092194484ull}},
{{14019954830285131461ull, 13190018674155225546ull,
  11090281582533523188ull, 5564497051307621552ull}},
{{8301571501001638518ull, 16487523342694031933ull,
  13862851978166903985ull, 6955621314134526940ull}},
{{14988650394679436051ull, 6774346123085376204ull,
  17328564972708629982ull, 8694526642668158675ull}},
{{144534459819871724ull, 18069024382210523840ull,
  8524510098729199786ull, 5434079151667599172ull}},
{{180668074774839655ull, 13362908440908378992ull,
  10655637623411499733ull, 6792598939584498965ull}},
{{225835093468549568ull, 2868577495853310028ull,
  17931233047691762571ull, 8490748674480623706ull}},
{{9364518970272619288ull, 17933761999404176431ull,
  15818706673234739510ull, 5306717921550389816ull}},
{{7093962694413386206ull, 13193830462400444731ull,
  1326639267833872772ull, 6633397401937987271ull}},
{{4255767349589344854ull, 16492288078000555914ull,
  15493357140074504677ull, 8291746752422484088ull}},
{{7271540611920728438ull, 12613523057964041398ull,
  9683348212546565423ull, 5182341720264052555ull}},
{{18312797801755686355ull, 11155217804027663843ull,
  7492499247255818875ull, 6477927150330065694ull}},
{{18279311233767220040ull, 9332336236607191900ull,
  142252022214997786ull, 8097408937912582118ull}},
{{2201197484249736717ull, 10444396166306882842ull,
  13923965569166537328ull, 5060880586195363823ull}},
{{11974868892166946704ull, 13055495207883603552ull,
  12793270943030783756ull, 6326100732744204779ull}},
{{14968586115208683380ull, 16319369009854504440ull,
  11379902660361091791ull, 7907625915930255974ull}},
{{9355366322005427113ull, 17117134658800147131ull,
  2500753144298294465ull, 4942266197456409984ull}},
{{7082521884079395987ull, 7561360268218020202ull,
  3125941430372868082ull, 6177832746820512480ull}},
{{18076524391954020792ull, 228328298417749444ull,
  3907426787966085103ull, 7722290933525640600ull}},
{{2074455708116487187ull, 7060234214152175259ull,
  2442141742478803189ull, 4826431833453525375ull}},
{{16428127690427772695ull, 13436978786117606977ull,
  16887735233380667698ull, 6033039791816906718ull}},
{{6700101557752552157ull, 7572851445792232914ull,
  11886297004871058815ull, 7541299739771133398ull}},
{{8799249492022733002ull, 11650561181261227427ull,
  2817249609617023855ull, 4713312337356958374ull}},
{{6387375846601028349ull, 9951515458149146380ull,
  12744934048876055627ull, 5891640421696197967ull}},
{{7984219808251285436ull, 7827708304259045071ull,
  11319481542667681630ull, 7364550527120247459ull}},
{{5368588741886718891ull, 561263343469030531ull, 9537665909907214134ull,
  9205688158900309324ull}},
{{1049524954465505355ull, 14185847644950307794ull,
  15184413230546784641ull, 5753555099312693327ull}},
{{10535278229936657502ull, 3897251500905721030ull,
  14368830519756092898ull, 7191943874140866659ull}},
{{3945725750566046069ull, 14094936412986927096ull,
  13349352131267728218ull, 8989929842676083324ull}},
{{2466078594103778793ull, 13421021276544217339ull,
  17566717118897105944ull, 5618706151672552077ull}},
{{16917656297911887203ull, 16776276595680271673ull,
  8123338343339218718ull, 7023382689590690097ull}},
{{7312012317107695292ull, 11746973707745563784ull,
  14765858947601411302ull, 8779228361988362621ull}},
{{4570007698192309558ull, 2730172548913589461ull,
  11534504851464576016ull, 5487017726242726638ull}},
{{10324195641167774851ull, 3412715686141986826ull,
  5194759027475944212ull, 6858772157803408298ull}},
{{3681872514604942756ull, 4265894607677483533ull,
  15716820821199706073ull, 8573465197254260372ull}},
{{4607013330841783175ull, 14195399175866896968ull,
  599640976395040487ull, 5358415748283912733ull}},
{{5758766663552228968ull, 13132562951406233306ull,
  5361237238921188513ull, 6698019685354890916ull}},
{{16421830366295062018ull, 2580645633975627920ull,
  6701546548651485642ull, 8372524606693613645ull}},
{{10263643978934413761ull, 6224589539662155354ull,
  6494309602120872478ull, 5232827879183508528ull}},
{{3606182936813241394ull, 17004108961432470001ull,
  8117887002651090597ull, 6541034848979385660ull}},
{{9119414689443939646ull, 7420078146508423789ull,
  10147358753313863247ull, 8176293561224232075ull}},
{{8005477190116156231ull, 11555077869208846724ull,
  4036256211607470577ull, 5110183475765145047ull}},
{{10006846487645195289ull, 608789281228894693ull, 433634246081950318ull,
  6387729344706431309ull}},
{{17120244127983882015ull, 9984358638390894174ull,
  5153728826029825801ull, 7984661680883039136ull}},
{{6088466561562538355ull, 17769439195062778619ull,
  3221080516268641125ull, 4990413550551899460ull}},
{{2998897183525785040ull, 8376740938546309562ull,
  4026350645335801407ull, 6238016938189874325ull}},
{{12971993516262007108ull, 5859240154755499048ull,
  9644624325097139663ull, 7797521172737342906ull}},
{{8107495947663754443ull, 10579554124363268761ull,
  10639576221613100193ull, 4873450732960839316ull}},
{{14746055953007080957ull, 17836128673881473855ull,
  13299470277016375241ull, 6091813416201049145ull}},
{{13820883922831463292ull, 8460102787069678607ull,
  2789279790988305340ull, 7614766770251311432ull}},
{{15555581479410746414ull, 14510936278773324937ull,
  1743299869367690837ull, 4759229231407069645ull}},
{{5609418793981269305ull, 4303612293184492460ull,
  6790810855137001451ull, 5949036539258837056ull}},
{{7011773492476586631ull, 767829348053227671ull, 8488513568921251814ull,
  7436295674073546320ull}},
{{11299887460438948501ull, 14314951397815431006ull,
  5305320980575782383ull, 4647684796295966450ull}},
{{4901487288693909818ull, 13282003228841900854ull,
  15855023262574503787ull, 5809605995369958062ull}},
{{15350231147722163080ull, 11990818017624988163ull,
  10595407041363353926ull, 7262007494212447578ull}},
{{14576102916225315946ull, 5765150485176459396ull,
  4020886764849416600ull, 9077509367765559473ull}},
{{18333436359495598274ull, 3603219053235287122ull,
  14042269274099355135ull, 5673443354853474670ull}},
{{13693423412514722035ull, 18339081871826272615ull,
  8329464555769418110ull, 7091804193566843338ull}},
{{12505093247216014640ull, 13700480302928064961ull,
  1188458657856996830ull, 8864755241958554173ull}},
{{898154251868927294ull, 3951114170902652697ull, 3048629670374316971ull,
  5540472026224096358ull}},
{{5734378833263547021ull, 327206695200927967ull,
  13034159124822672022ull, 6925590032780120447ull}},
{{2556287523152045873ull, 9632380405855935767ull,
  11681012887600952123ull, 8656987540975150559ull}},
{{8515208729611110527ull, 3714394744446265902ull,
  14218162082391676933ull, 5410617213109469099ull}},
{{1420638875159112350ull, 9254679448985220282ull,
  13161016584562208262ull, 6763271516386836374ull}},
{{10999170630803666245ull, 2344977274376749544ull,
  7227898693847984520ull, 8454089395483545468ull}},
{{6874481644252291404ull, 1465610796485468465ull,
  13740808720509766133ull, 5283805872177215917ull}},
{{13204788073742752158ull, 6443699514034223485ull,
  3340952845355043954ull, 6604757340221519897ull}},
{{2670927036896276486ull, 17277996429397555165ull,
  8787877075121192846ull, 8255946675276899871ull}},
{{3975172407273866756ull, 6187061749946084074ull,
  12409952199591827385ull, 5159966672048062419ull}},
{{14192337545947109253ull, 12345513205859992996ull,
  10900754231062396327ull, 6449958340060078024ull}},
{{17740421932433886566ull, 10820205488897603341ull,
  13625942788827995409ull, 8062447925075097530ull}},
{{13393606716984873056ull, 18291843476629471848ull,
  13127900261444885034ull, 5039029953171935956ull}},
{{16742008396231091320ull, 13641432308932064002ull,
  16409875326806106293ull, 6298787441464919945ull}},
{{11704138458434088341ull, 3216732330882916291ull,
  6677286103225469155ull, 7873484301831149932ull}},
{{5009243527307611261ull, 18151358771297680346ull,
  13396675851370694029ull, 4920927688644468707ull}},
{{15484926445989289885ull, 8854140408839936720ull,
  12134158795785979633ull, 6151159610805585884ull}},
{{909413983777060740ull, 15679361529477308805ull,
  15167698494732474541ull, 7688949513506982355ull}},
{{2874226749074356915ull, 12105443965137011955ull,
  7173968549994102636ull, 4805593445941863972ull}},
{{17427841491625109855ull, 15131804956421264943ull,
  8967460687492628295ull, 6006991807427329965ull}},
{{17173115846103999415ull, 14303070177099193275ull,
  15821011877793173273ull, 7508739759284162456ull}},
{{8427354394601305682ull, 2021889833045913941ull,
  9888132423620733296ull, 4692962349552601535ull}},
{{15145879011679020007ull, 2527362291307392426ull,
  7748479511098528716ull, 5866202936940751919ull}},
{{9708976727743999200ull, 3159202864134240533ull,
  5073913370445772991ull, 7332753671175939899ull}},
{{16747906928107386904ull, 17784061635449964378ull,
  1730705694629828334ull, 9165942088969924874ull}},
{{15079127848494504719ull, 6503352503728839832ull,
  5693377077571030613ull, 5728713805606203046ull}},
{{402165736908579283ull, 12740876648088437695ull,
  16340093383818564074ull, 7160892257007753807ull}},
{{14337765226417887816ull, 6702723773255771310ull,
  15813430711345817189ull, 8951115321259692259ull}},
{{4349417248083791981ull, 6495045367498551021ull,
  7577551185377441791ull, 5594447075787307662ull}},
{{10048457578532127880ull, 3507120690945800872ull,
  248566944867026431ull, 6993058844734134578ull}},
{{12560571973165159850ull, 18218958918964414802ull,
  9534080717938558846ull, 8741323555917668222ull}},
{{12462043501655612811ull, 6775163305925371347ull,
  1347114430284211375ull, 5463327222448542639ull}},
{{10965868358642128109ull, 3857268113979326280ull,
  15518951093137427931ull, 6829159028060678298ull}},
{{13707335448302660136ull, 209899124046769946ull,
  10175316829567009106ull, 8536448785075847873ull}},
{{13178770673616550489ull, 4742872970956619120ull,
  17888788064547850451ull, 5335280490672404920ull}},
{{16473463342020688112ull, 1316905195268385996ull,
  3914241006975261448ull, 6669100613340506151ull}},
{{2145085103816308523ull, 1646131494085482496ull, 281115240291688906ull,
  8336375766675632689ull}},
{{1340678189885192827ull, 5640518202230814464ull,
  11704912071250775326ull, 5210234854172270430ull}},
{{1675847737356491034ull, 16274019789643293888ull,
  5407768052208693349ull, 6512793567715338038ull}},
{{2094809671695613792ull, 6507466681771953648ull,
  15983082102115642495ull, 8140991959644172547ull}},
{{1309256044809758620ull, 10984695703748552886ull,
  7683583304608582607ull, 5088119974777607842ull}},
{{10859942092866974083ull, 9119183611258303203ull,
  381107093905952451ull, 6360149968472009803ull}},
{{8963241597656329700ull, 6787293495645491100ull,
  14311441922664604276ull, 7950187460590012253ull}},
{{14825398035389981871ull, 13465430471633207745ull,
  11250494210879071624ull, 4968867162868757658ull}},
{{4696689488955313626ull, 16831788089541509682ull,
  4839745726744063722ull, 6211083953585947073ull}},
{{15094233898048917841ull, 11816363075072111294ull,
  10661368176857467557ull, 7763854941982433841ull}},
{{4822210167853185747ull, 9691069931133763511ull,
  18192570156604386983ull, 4852409338739021150ull}},
{{1416076691389094279ull, 7502151395489816485ull,
  13517340658900707921ull, 6065511673423776438ull}},
{{6381781882663755753ull, 13989375262789658510ull,
  7673303786771109093ull, 7581889591779720548ull}},
{{17823671731947011058ull, 11049202548457230520ull,
  14019186903586718991ull, 4738680994862325342ull}},
{{3832845591224212206ull, 9199817167144150247ull,
  8300611592628622931ull, 5923351243577906678ull}},
{{179370970602877353ull, 6888085440502799905ull, 1152392453931002856ull,
  7404189054472383348ull}},
{{11641321902695268106ull, 4305053400314249940ull,
  9943617320561652593ull, 4627618159045239592ull}},
{{14551652378369085132ull, 9993002768820200329ull,
  12429521650702065741ull, 5784522698806549490ull}},
{{4354507417679192703ull, 17102939479452638316ull,
  6313530026522806368ull, 7230653373508186863ull}},
{{5443134272098990879ull, 2931930275606246279ull,
  3280226514726120057ull, 9038316716885233579ull}},
{{10319487947702951156ull, 13361671468322373684ull,
  18191042636199682699ull, 5648947948053270986ull}},
{{12899359934628688944ull, 12090403316975579201ull,
  13515431258394827566ull, 7061184935066588733ull}},
{{2289141863003697468ull, 5889632109364698194ull,
  3059231017711370746ull, 8826481168833235917ull}},
{{6042399682804698822ull, 8292706086780324275ull,
  4217862395283300668ull, 5516550730520772448ull}},
{{2941313585078485623ull, 10365882608475405344ull,
  5272327994104125835ull, 6895688413150965560ull}},
{{3676641981348107029ull, 8345667242166868776ull,
  6590409992630157294ull, 8619610516438706950ull}},
{{2297901238342566893ull, 604356007926905081ull,
  17954064300676012021ull, 5387256572774191843ull}},
{{7484062566355596521ull, 5367131028336019255ull,
  17830894357417627122ull, 6734070715967739804ull}},
{{4743392189517107747ull, 15932285822274799877ull,
  3841873873062482286ull, 8417588394959674756ull}},
{{5270463127661886294ull, 5345992620494362019ull,
  11624543207518827237ull, 5260992746849796722ull}},
{{1976392891149969963ull, 11294176794045340428ull,
  5307306972543758238ull, 6576240933562245903ull}},
{{2470491113937462454ull, 4894348955701899727ull,
  2022447697252309894ull, 8220301166952807379ull}},
{{8461585973851995890ull, 16894026152595851041ull,
  17404930875278551347ull, 5137688229345504611ull}},
{{15188668485742382766ull, 16505846672317425897ull,
  17144477575670801280ull, 6422110286681880764ull}},
{{5150777551895814746ull, 2185564266687230756ull,
  2983852895878949985ull, 8027637858352350956ull}},
{{12442608006789660024ull, 12895192712747988982ull,
  11088280096779119548ull, 5017273661470219347ull}},
{{6329887971632299222ull, 16118990890934986228ull,
  9248664102546511531ull, 6271592076837774184ull}},
{{7912359964540374027ull, 15537052595241344881ull,
  11560830128183139414ull, 7839490096047217730ull}},
{{16474440023906203527ull, 5098971853598452646ull,
  11837204848541850038ull, 4899681310029511081ull}},
{{11369677993027978601ull, 15597086853852841616ull,
  961448005395148835ull, 6124601637536888852ull}},
{{14212097491284973251ull, 14884672548888664116ull,
  1201810006743936044ull, 7655752046921111065ull}},
{{18105932968907884090ull, 79548306200639264ull,
  12280346300283429788ull, 4784845029325694415ull}},
{{4185672137425303497ull, 99435382750799081ull, 10738746856926899331ull,
  5981056286657118019ull}},
{{9843776190209017275ull, 13959352283720662563ull,
  8811747552731236259ull, 7476320358321397524ull}},
{{3846517109666941845ull, 6418752168111720150ull,
  14730714257311798470ull, 4672700223950873452ull}},
{{14031518423938453114ull, 17246812246994425995ull,
  18413392821639748087ull, 5840875279938591815ull}},
{{12927712011495678488ull, 16946829290315644590ull,
  18405055008622297205ull, 7301094099923239769ull}},
{{6936267977514822302ull, 7348478557612392026ull,
  9171260705495707795ull, 9126367624904049712ull}},
{{8946853504374151843ull, 2286956089294051064ull,
  5732037940934817372ull, 5703979765565031070ull}},
{{11183566880467689804ull, 2858695111617563830ull,
  16388419463023297523ull, 7129974706956288837ull}},
{{4756086563729836446ull, 17408426944804118500ull,
  6650466273496958191ull, 8912468383695361047ull}},
{{12195926139185923587ull, 17797795868143655918ull,
  11074070448576680725ull, 5570292739809600654ull}},
{{6021535637127628676ull, 8412186779897406186ull,
  4619216023866075099ull, 6962865924762000818ull}},
{{16750291583264311653ull, 5903547456444369828ull,
  14997392066687369682ull, 8703582405952501022ull}},
{{1245560202685418975ull, 8301403178705119047ull,
  4761684023252218147ull, 5439739003720313139ull}},
{{15392008308638937431ull, 5765067954954010904ull,
  1340419010637884780ull, 6799673754650391424ull}},
{{793266312089120172ull, 7206334943692513631ull, 1675523763297355975ull,
  8499592193312989280ull}},
{{7413320472696781964ull, 11421488367448902875ull,
  1047202352060847484ull, 5312245120820618300ull}},
{{4654964572443589551ull, 14276860459311128594ull,
  1309002940076059355ull, 6640306401025772875ull}},
{{15042077752409262746ull, 13234389555711522838ull,
  15471311730377237906ull, 8300383001282216093ull}},
{{4789612576828401313ull, 12883179490747089678ull,
  11975412840699467643ull, 5187739375801385058ull}},
{{15210387757890277449ull, 11492288345006474193ull,
  5745894014019558746ull, 6484674219751731323ull}},
{{5177926642080683099ull, 5141988394403316934ull,
  2570681499097060529ull, 8105842774689664154ull}},
{{17071262206582590649ull, 14742957792570542843ull,
  6218361955363050734ull, 5066151734181040096ull}},
{{16727391739800850407ull, 9205325203858402746ull,
  7772952444203813418ull, 6332689667726300120ull}},
{{11685867637896287201ull, 2283284467968227625ull,
  9716190555254766773ull, 7915862084657875150ull}},
{{386138246044097645ull, 3732895801693836218ull, 1460933078606841329ull,
  4947413802911171969ull}},
{{9706044844409897864ull, 9277805770544683176ull,
  6437852366685939565ull, 6184267253638964961ull}},
{{12132556055512372329ull, 16208943231608241874ull,
  12659001476784812360ull, 7730334067048706201ull}},
{{12194533553122620610ull, 10130589519755151171ull,
  994346895349425869ull, 4831458791905441376ull}},
{{10631480922975887858ull, 17274922918121326868ull,
  1242933619186782336ull, 6039323489881801720ull}},
{{13289351153719859823ull, 3146909573942106969ull,
  1553667023983477921ull, 7549154362352252150ull}},
{{1388315443433830534ull, 13496033529782286616ull,
  14806099945271837412ull, 4718221476470157593ull}},
{{1735394304292288167ull, 16870041912227858270ull,
  4672566876307633053ull, 5897776845587696992ull}},
{{11392614917220136016ull, 7252494335002659125ull,
  5840708595384541317ull, 7372221056984621240ull}},
{{405710591243006308ull, 13677303937180711811ull,
  7300885744230676646ull, 9215276321230776550ull}},
{{16394470184022736607ull, 3936628942310556977ull,
  18398111645426336616ull, 5759547700769235343ull}},
{{6658029674746257046ull, 4920786177888196222ull,
  18385953538355532866ull, 7199434625961544179ull}},
{{17545909130287597116ull, 15374354759215021085ull,
  18370755904517028178ull, 8999293282451930224ull}},
{{13272036215643442150ull, 14220657742936776082ull,
  11481722440323142611ull, 5624558301532456390ull}},
{{7366673232699526879ull, 13164136160243582199ull,
  5128781013549152456ull, 7030697876915570488ull}},
{{4596655522447020695ull, 16455170200304477749ull,
  6410976266936440570ull, 8788372346144463110ull}},
{{5178752710743081886ull, 14896167393617686497ull,
  17841918222117439068ull, 5492732716340289443ull}},
{{11085126906856240262ull, 173465168312556505ull,
  17690711759219410932ull, 6865915895425361804ull}},
{{21350578288136615ull, 216831460390695632ull, 3666645625314712049ull,
  8582394869281702256ull}},
{{13344111430085385ull, 11664734708812654530ull, 2291653515821695030ull,
  5363996793301063910ull}},
{{9240052176142382539ull, 5357546349161042354ull,
  12087938931631894596ull, 6704995991626329887ull}},
{{2326693183323202365ull, 6696932936451302943ull,
  10498237646112480341ull, 8381244989532912359ull}},
{{8371712267218083334ull, 6491426094495758291ull,
  13478927556461382069ull, 5238278118458070224ull}},
{{5852954315595216264ull, 12725968636547085768ull,
  16848659445576727586ull, 6547847648072587780ull}},
{{7316192894494020330ull, 6684088758829081402ull,
  2614080233261357867ull, 8184809560090734726ull}},
{{9184306577486150610ull, 1871712465054481924ull,
  15468858201070512379ull, 5115505975056709203ull}},
{{11480383221857688263ull, 16174698636600266117ull,
  14724386732910752569ull, 6394382468820886504ull}},
{{515420972039946616ull, 6383315240468168935ull,
  18405483416138440712ull, 7992978086026108130ull}},
{{7239667135166048491ull, 3989572025292605584ull,
  16115113153513913349ull, 4995611303766317581ull}},
{{9049583918957560614ull, 9598651050043144884ull,
  6308833386610227974ull, 6244514129707896977ull}},
{{11311979898696950767ull, 2774941775699155297ull,
  12497727751690172872ull, 7805642662134871221ull}},
{{152458409044512374ull, 1734338609811972061ull,
  10116922854020051997ull, 4878526663834294513ull}},
{{4802259029733028371ull, 6779609280692352980ull,
  17257839585952452900ull, 6098158329792868141ull}},
{{6002823787166285464ull, 8474511600865441225ull,
  7737241427158402413ull, 7622697912241085177ull}},
{{15280979913047398175ull, 7602412759754594717ull,
  16364990938042471268ull, 4764186195150678235ull}},
{{5266166836027084007ull, 9503015949693243397ull,
  15844552654125701181ull, 5955232743938347794ull}},
{{11194394563461242912ull, 16490455955543942150ull,
  10582318780802350668ull, 7444040929922934743ull}},
{{2384810583735888916ull, 1083162935360188036ull,
  13531478265642551024ull, 4652525581201834214ull}},
{{2981013229669861145ull, 1353953669200235045ull,
  7690975795198412972ull, 5815656976502292768ull}},
{{8337952555514714336ull, 1692442086500293806ull,
  9613719743998016215ull, 7269571220627865960ull}},
{{1199068657538617111ull, 15950610663407530970ull,
  12017149679997520268ull, 9086964025784832450ull}},
{{5361103929389023599ull, 745759627774931048ull,
  12122404568425838072ull, 5679352516115520281ull}},
{{6701379911736279498ull, 932199534718663810ull, 1317947655250133878ull,
  7099190645144400352ull}},
{{17600096926525125181ull, 10388621455253105570ull,
  1647434569062667347ull, 8873988306430500440ull}},
{{15611746597505591142ull, 4187045400319497029ull,
  1029646605664167092ull, 5546242691519062775ull}},
{{5679625191599825216ull, 5233806750399371287ull,
  15122116312362372577ull, 6932803364398828468ull}},
{{2487845471072393615ull, 11153944456426602013ull,
  455901316743414105ull, 8666004205498535586ull}},
{{3860746428633939962ull, 53686257625544402ull, 4896624341392021720ull,
  5416252628436584741ull}},
{{14049305072647200760ull, 67107822031930502ull,
  10732466445167415054ull, 6770315785545730926ull}},
{{8338259303954225142ull, 9307256814394688936ull,
  4192211019604493009ull, 8462894731932163658ull}},
{{5211412064971390714ull, 17346250555065150345ull,
  7231817905680196034ull, 5289309207457602286ull}},
{{11125951099641626296ull, 12459441156976662123ull,
  18263144418955020851ull, 6611636509322002857ull}},
{{9295752856124644966ull, 10962615427793439750ull,
  8993872468411612352ull, 8264545636652503572ull}},
{{1198159516650515200ull, 6851634642370899844ull,
  14844542329612033528ull, 5165341022907814732ull}},
{{1497699395813144000ull, 8564543302963624805ull, 108933838305490294ull,
  6456676278634768416ull}},
{{6483810263193817904ull, 1482307091849755198ull, 136167297881862868ull,
  8070845348293460520ull}},
{{17887439469778299902ull, 10149813969260872806ull,
  85104561176164292ull, 5044278342683412825ull}},
{{13135927300368099070ull, 12687267461576091008ull,
  4718066719897593269ull, 6305347928354266031ull}},
{{16419909125460123837ull, 2024026271687950048ull,
  1285897381444603683ull, 7881684910442832539ull}},
{{10262443203412577398ull, 17405917484300826444ull,
  16944586927898734965ull, 4926053069026770336ull}},
{{12828054004265721748ull, 7922338800093869343ull,
  2733989586163867091ull, 6157566336283462921ull}},
{{11423381486904764280ull, 5291237481689948775ull,
  8029173001132221768ull, 7696957920354328651ull}},
{{14057142456956559531ull, 3307023426056217984ull,
  2712390116493944653ull, 4810598700221455407ull}},
{{17571428071195699414ull, 8745465300997660384ull,
  17225545700899594528ull, 6013248375276819258ull}},
{{3517541015285072652ull, 10931831626247075481ull,
  12308560089269717352ull, 7516560469096024073ull}},
{{13727678180621640167ull, 6832394766404422175ull,
  775321028152491489ull, 4697850293185015046ull}},
{{12547911707349662305ull, 13152179476432915623ull,
  10192523322045390169ull, 5872312866481268807ull}},
{{11073203615759689977ull, 2605166290258980817ull,
  8128968134129349808ull, 7340391083101586009ull}},
{{6446464417448760ull, 3256457862823726022ull, 14772896186089075164ull,
  9175488853876982511ull}},
{{13839087095543069187ull, 11258658201119604571ull,
  16150589143946753833ull, 5734680533673114069ull}},
{{12687172851001448579ull, 238264696117342002ull,
  6353178374651278580ull, 7168350667091392587ull}},
{{6635594026897034916ull, 297830870146677503ull, 3329786949886710321ull,
  8960438333864240734ull}},
{{11064775294451728679ull, 11715359339910143199ull,
  15916174898961357662ull, 5600273958665150458ull}},
{{9219283099637272944ull, 5420827138032903191ull,
  10671846586846921270ull, 7000342448331438073ull}},
{{6912417856119203276ull, 15999405959395904797ull,
  17951494251986039491ull, 8750428060414297591ull}},
{{6626104169288196000ull, 7693785715408746546ull,
  18137212935132356538ull, 5469017537758935994ull}},
{{17506002248465020808ull, 393860107406157374ull,
  13448144132060669865ull, 6836271922198669993ull}},
{{12659130773726500202ull, 5104011152685084622ull,
  2975122109793673619ull, 8545339902748337492ull}},
{{3300270715151674722ull, 884163961214483937ull,
  11082823355475821820ull, 5340837439217710932ull}},
{{8737024412366981307ull, 1105204951518104921ull,
  13853529194344777275ull, 6676046799022138665ull}},
{{15532966533886114537ull, 15216564244679794863ull,
  3481853437648807881ull, 8345058498777673332ull}},
{{16625633111319903442ull, 2592823625283789933ull,
  11399530435385280734ull, 5215661561736045832ull}},
{{6946983333867715590ull, 12464401568459513225ull,
  14249413044231600917ull, 6519576952170057290ull}},
{{13295415185762032392ull, 1745443905292227819ull,
  8588394268434725339ull, 8149471190212571613ull}},
{{6003791481887576293ull, 17231803505303500051ull,
  7673589426985397288ull, 5093419493882857258ull}},
{{2893053333932082462ull, 3093010307919823448ull, 368614746876970803ull,
  6366774367353571573ull}},
{{3616316667415103078ull, 17701320940181943022ull,
  5072454452023601407ull, 7958467959191964466ull}},
{{16095255972416603136ull, 17980854615254796244ull,
  7781970050942138783ull, 4974042474494977791ull}},
{{1672325891811202303ull, 17864382250641107402ull,
  5115776545250285575ull, 6217553093118722239ull}},
{{11313779401618778687ull, 17718791794873996348ull,
  1783034663135469065ull, 7771941366398402799ull}},
{{16294484162866512488ull, 4156715844155165861ull,
  8031925692100750022ull, 4857463353999001749ull}},
{{6533047148300976897ull, 14419266842048733135ull,
  14651593133553325431ull, 6071829192498752186ull}},
{{3554622916948833218ull, 13412397534133528515ull,
  9091119380086880981ull, 7589786490623440233ull}},
{{18362540387588878425ull, 10688591468047149273ull,
  17211164658622770373ull, 4743616556639650145ull}},
{{9118117429203934319ull, 17972425353486324496ull,
  7678897767996299254ull, 5929520695799562682ull}},
{{11397646786504917899ull, 13242159655003129812ull,
  375250173140598260ull, 7411900869749453353ull}},
{{16346901278420349495ull, 17499721821231731940ull,
  11763746404281343672ull, 4632438043593408345ull}},
{{1986882524315885253ull, 3427908202830113310ull, 869624950069515879ull,
  5790547554491760432ull}},
{{11706975192249632374ull, 18119943308819805349ull,
  1087031187586894848ull, 7238184443114700540ull}},
{{798660935029876755ull, 4203185062315205071ull, 1358788984483618561ull,
  9047730553893375675ull}},
{{7416692112034754828ull, 14156205710015472929ull,
  16990144179798119264ull, 5654831596183359796ull}},
{{13882551158470831439ull, 17695257137519341161ull,
  2790936151038097464ull, 7068539495229199746ull}},
{{3518130892806375587ull, 3672327348189624836ull,
  12712042225652397639ull, 8835674369036499682ull}},
{{11422203844858760550ull, 9212733620259597378ull,
  12556712409460136428ull, 5522296480647812301ull}},
{{5054382769218674879ull, 11515917025324496723ull,
  1860832456543006823ull, 6902870600809765377ull}},
{{1706292443095955695ull, 9783210263228233000ull,
  6937726589106146433ull, 8628588251012206721ull}},
{{1066432776934972310ull, 17643721460586115385ull,
  15865294164259811280ull, 5392867656882629200ull}},
{{5944726989596103291ull, 3607907752023092615ull,
  1384873631615212485ull, 6741084571103286501ull}},
{{2819222718567741209ull, 9121570708456253673ull,
  6342778057946403510ull, 8426355713879108126ull}},
{{13291229245173308016ull, 1089295674357770641ull,
  17799294341498665906ull, 5266472321174442578ull}},
{{2778978501184471308ull, 10584991629801989110ull,
  13025745890018556574ull, 6583090401468053223ull}},
{{12697095163335364943ull, 4007867500397710579ull,
  11670496344095807814ull, 8228863001835066529ull}},
{{5629841467870909137ull, 16339975243030732824ull,
  376531187418798027ull, 5143039376146916581ull}},
{{7037301834838636422ull, 15813283035361028126ull,
  5082350002700885438ull, 6428799220183645726ull}},
{{18019999330403071335ull, 10543231757346509349ull,
  15576309540230882606ull, 8035999025229557157ull}},
{{13568342590715613537ull, 1977833829914180439ull,
  12041036471857995581ull, 5022499390768473223ull}},
{{12348742219967129017ull, 7083978305820113453ull,
  10439609571395106572ull, 6278124238460591529ull}},
{{1600869719676747559ull, 8854972882275141817ull,
  17661197982671271119ull, 7847655298075739411ull}},
{{12529758620866436984ull, 12451887079063045491ull,
  8732405729955850497ull, 4904784561297337132ull}},
{{11050512257655658326ull, 1729800793546643152ull,
  10915507162444813122ull, 6130980701621671415ull}},
{{13813140322069572908ull, 11385623028788079748ull,
  9032697934628628498ull, 7663725877027089269ull}},
{{17856584738148258876ull, 11727700411419937746ull,
  7951279218356586763ull, 4789828673141930793ull}},
{{13097358885830547786ull, 10047939495847534279ull,
  14550785041373121358ull, 5987285841427413491ull}},
{{11760012588860796829ull, 3336552332954642041ull,
  13576795283289013794ull, 7484107301784266864ull}},
{{432478840396916162ull, 6697031226524039180ull, 8485497052055633621ull,
  4677567063615166790ull}},
{{540598550496145203ull, 12982975051582436879ull,
  1383499278214766218ull, 5846958829518958488ull}},
{{14510806243402345215ull, 7005346777623270290ull,
  1729374097768457773ull, 7308698536898698110ull}},
{{8915135767398155711ull, 13368369490456475767ull,
  11385089659065348024ull, 9135873171123372637ull}},
{{12489488882264929175ull, 8355230931535297354ull,
  9421524046129536467ull, 5709920731952107898ull}},
{{6388489065976385661ull, 5832352645991733789ull,
  2553533020807144776ull, 7137400914940134873ull}},
{{12597297350897869980ull, 7290440807489667236ull,
  7803602294436318874ull, 8921751143675168591ull}},
{{17096682881165944546ull, 9168211523108429926ull,
  11794780461663781152ull, 5576094464796980369ull}},
{{12147481564602654874ull, 11460264403885537408ull,
  908417521797562728ull, 6970118080996225462ull}},
{{15184351955753318593ull, 14325330504856921760ull,
  10358893939101729218ull, 8712647601245281827ull}},
{{9490219972345824121ull, 13565017583962964004ull,
  4168465702724886809ull, 5445404750778301142ull}},
{{11862774965432280151ull, 3121213924671541293ull,
  14433954165260884320ull, 6806755938472876427ull}},
{{993410651508186476ull, 3901517405839426617ull,
  13430756688148717496ull, 8508444923091095534ull}},
{{12150096703261086308ull, 2438448378649641635ull,
  3782536911665560531ull, 5317778076931934709ull}},
{{10575934860648969981ull, 16883118528594215756ull,
  9339857158009338567ull, 6647222596164918386ull}},
{{13219918575811212476ull, 16492212142315381791ull,
  2451449410656897401ull, 8309028245206147983ull}},
{{15179978137523089653ull, 3390103561306031763ull,
  8449684909301642732ull, 5193142653253842489ull}},
{{14363286653476474163ull, 4237629451632539704ull,
  15173792155054441319ull, 6491428316567303111ull}},
{{17954108316845592703ull, 685350796113286726ull,
  14355554175390663745ull, 8114285395709128889ull}},
{{6609631679601107536ull, 11957559293639273964ull,
  2054692331978082984ull, 5071428372318205556ull}},
{{8262039599501384419ull, 14946949117049092455ull,
  2568365414972603730ull, 6339285465397756945ull}},
{{5715863480949342620ull, 9460314359456589761ull,
  7822142787143142567ull, 7924106831747196181ull}},
{{15101629721661808898ull, 12830225502301450456ull,
  7194682251178158056ull, 4952566769841997613ull}},
{{430293078367709506ull, 16037781877876813071ull,
  13605038832400085474ull, 6190708462302497016ull}},
{{14372924403241800595ull, 10823855310491240530ull,
  17006298540500106843ull, 7738385577878121270ull}},
{{13594763770453513276ull, 4459066559843331379ull,
  6017250569385178873ull, 4836490986173825794ull}},
{{12381768694639503691ull, 10185519218231552128ull,
  16744935248586249399ull, 6045613732717282242ull}},
{{15477210868299379613ull, 8120213004362052256ull,
  11707797023878035941ull, 7557017165896602803ull}},
{{9673256792687112258ull, 7380976136939976612ull,
  5011530130710078511ull, 4723135728685376752ull}},
{{12091570990858890323ull, 4614534152747582861ull,
  6264412663387598139ull, 5903919660856720940ull}},
{{1279405683291449191ull, 1156481672507090673ull,
  7830515829234497674ull, 7379899576070901175ull}},
{{12328843598125625505ull, 5334487063744319574ull,
  11811601420912642902ull, 4612437235044313234ull}},
{{6187682460802256073ull, 15891480866535175276ull,
  5541129739286027819ull, 5765546543805391543ull}},
{{7734603076002820091ull, 15252665064741581191ull,
  2314726155680146870ull, 7206933179756739429ull}},
{{5056567826576137210ull, 9842459294072200681ull,
  7505093713027571492ull, 9008666474695924286ull}},
{{14689569937678555516ull, 15374909095649901233ull,
  78997552214844278ull, 5630416546684952679ull}},
{{4526904366816030683ull, 9995264332707600734ull,
  13933804995550719060ull, 7038020683356190848ull}},
{{14882002495374814162ull, 12494080415884500917ull,
  17417256244438398825ull, 8797525854195238560ull}},
{{11607094568822952803ull, 891271232286731217ull,
  10885785152773999266ull, 5498453658872024100ull}},
{{673810155746527292ull, 10337461077213189830ull,
  13607231440967499082ull, 6873067073590030125ull}},
{{10065634731537934923ull, 3698454309661711479ull,
  3173981245927210141ull, 8591333841987537657ull}},
{{13208550734852291183ull, 4617376952752263626ull,
  13512953324772976098ull, 5369583651242211035ull}},
{{7287316381710588171ull, 14995093227795105341ull,
  12279505637538832218ull, 6711979564052763794ull}},
{{13720831495565623117ull, 9520494497889105868ull,
  6126010010068764465ull, 8389974455065954743ull}},
{{17798891721583290256ull, 17479524107249160927ull,
  10746285283934059646ull, 5243734034416221714ull}},
{{17636928633551724916ull, 12626033097206675351ull,
  4209484568062798750ull, 6554667543020277143ull}},
{{17434474773512268241ull, 6559169334653568381ull,
  650169691651110534ull, 8193334428775346429ull}},
{{13202389742658861603ull, 17934538889440643950ull,
  2712199066495638035ull, 5120834017984591518ull}},
{{7279615141468801196ull, 17806487593373417034ull,
  12613620869974323352ull, 6401042522480739397ull}},
{{18322890963690777303ull, 3811365418007219676ull,
  1931968032185740479ull, 8001303153100924247ull}},
{{2228434815451960006ull, 9299632413895594154ull,
  8125009047757169655ull, 5000814470688077654ull}},
{{12008915556169725816ull, 7012854498942104788ull,
  932889272841686261ull, 6251018088360097068ull}},
{{15011144445212157269ull, 13377754142105018889ull,
  1166111591052107826ull, 7813772610450121335ull}},
{{2464436250616516438ull, 12972782357243024710ull,
  7646348772048649247ull, 4883607881531325834ull}},
{{12303917350125421355ull, 11604291928126392983ull,
  334563928206035751ull, 6104509851914157293ull}},
{{10768210669229388789ull, 9893678891730603325ull,
  5029890928684932593ull, 7630637314892696616ull}},
{{9035974677482061946ull, 17712764353400096838ull,
  3143681830428082870ull, 4769148321807935385ull}},
{{2071596309997801624ull, 12917583404895345240ull,
  8541288306462491492ull, 5961435402259919231ull}},
{{2589495387497252030ull, 16146979256119181550ull,
  6064924364650726461ull, 7451794252824899039ull}},
{{15453492672467946231ull, 12397705044288182420ull,
  10708106755547785894ull, 4657371408015561899ull}},
{{870121766875381172ull, 6273759268505452218ull, 8773447426007344464ull,
  5821714260019452374ull}},
{{10311024245449002273ull, 7842199085631815272ull,
  1743437245654404772ull, 7277142825024315468ull}},
{{12888780306811252842ull, 9802748857039769090ull,
  2179296557068005965ull, 9096428531280394335ull}},
{{12667173710184420930ull, 8432561044863549633ull,
  8279589375808585584ull, 5685267832050246459ull}},
{{1998909082448362451ull, 10540701306079437042ull,
  5737800701333344076ull, 7106584790062808074ull}},
{{11722008389915228871ull, 13175876632599296302ull,
  16395622913521455903ull, 8883230987578510092ull}},
{{2714569225269630141ull, 15152451923015642045ull,
  1023892284096134131ull, 5552019367236568808ull}},
{{8004897550014425580ull, 14328878885342164652ull,
  1279865355120167664ull, 6940024209045711010ull}},
{{10006121937518031974ull, 17911098606677705815ull,
  10823203730754985388ull, 8675030261307138762ull}},
{{13171355238589851840ull, 1971064592318790326ull,
  11376188350149253772ull, 5421893913316961726ull}},
{{7240822011382538992ull, 2463830740398487908ull,
  4996863400831791407ull, 6777367391646202158ull}},
{{9051027514228173740ull, 16914846480780273597ull,
  15469451287894515066ull, 8471709239557752697ull}},
{{7962735205606302540ull, 15183465068915058902ull,
  2750878027292990060ull, 5294818274723595436ull}},
{{730046970153102366ull, 532587262434272012ull, 3438597534116237576ull,
  6618522843404494295ull}},
{{912558712691377958ull, 665734078042840015ull, 18133304972927460682ull,
  8273153554255617868ull}},
{{7487878223073193080ull, 5027769817204162913ull,
  2109943571224887118ull, 5170720971409761168ull}},
{{13971533797268879254ull, 15508084308359979449ull,
  2637429464031108897ull, 6463401214262201460ull}},
{{3629359191303935355ull, 5550047330167810600ull,
  3296786830038886122ull, 8079251517827751825ull}},
{{2268349494564959597ull, 8080465599782269529ull,
  13589706814842773586ull, 5049532198642344890ull}},
{{7447122886633587400ull, 877209962873061103ull, 7763761481698691175ull,
  6311915248302931113ull}},
{{4697217589864596346ull, 14931570508873490091ull,
  14316387870550751872ull, 7889894060378663891ull}},
{{629917984451678765ull, 9332231568045931307ull, 6641899409880525968ull,
  4931183787736664932ull}},
{{14622455535846762168ull, 11665289460057414133ull,
  8302374262350657460ull, 6163979734670831165ull}},
{{4443011364526288997ull, 14581611825071767667ull,
  14989653846365709729ull, 7704974668338538956ull}},
{{471039093615236672ull, 2195978363028772936ull, 145161617123792773ull,
  4815609167711586848ull}},
{{588798867019045839ull, 7356658972213354074ull, 181452021404740966ull,
  6019511459639483560ull}},
{{9959370620628583107ull, 18419195752121468400ull,
  226815026755926207ull, 7524389324549354450ull}},
{{6224606637892864442ull, 18429526372716999606ull,
  4753445410149841783ull, 4702743327843346531ull}},
{{17004130334220856360ull, 18425221947468861603ull,
  1330120744259914325ull, 5878429159804183164ull}},
{{16643476899348682546ull, 9196469379053913292ull,
  1662650930324892907ull, 7348036449755228955ull}},
{{2357602050476301567ull, 6883900705390003712ull,
  15913371718188279846ull, 9185045562194036193ull}},
{{1473501281547688480ull, 18137495996150916032ull,
  3028328296226593047ull, 5740653476371272621ull}},
{{1841876601934610599ull, 18060183976761257136ull,
  8397096388710629213ull, 7175816845464090776ull}},
{{2302345752418263249ull, 8740171915669407708ull,
  10496370485888286517ull, 8969771056830113470ull}},
{{10662338132116190339ull, 7768450456507073769ull,
  1948545535252791169ull, 5606106910518820919ull}},
{{17939608683572625827ull, 14322249089061230115ull,
  16270739974348152673ull, 7007633638148526148ull}},
{{17812824836038394380ull, 4067753306044373932ull,
  1891680894225639226ull, 8759542047685657686ull}},
{{1909643485669220680ull, 7154031834705121612ull,
  15017358614173188228ull, 5474713779803536053ull}},
{{2387054357086525850ull, 8942539793381402015ull,
  4936640212434321573ull, 6843392224754420067ull}},
{{16818876001640321024ull, 15789860760154140422ull,
  1559114247115514062ull, 8554240280943025084ull}},
{{5900111482597812736ull, 5256976956668949860ull,
  10197818441301972097ull, 5346400175589390677ull}},
{{7375139353247265920ull, 11182907214263575229ull,
  17358959070054853025ull, 6683000219486738346ull}},
{{13830610209986470304ull, 143575962547305324ull,
  12475326800713790474ull, 8353750274358422933ull}},
{{17867503418096319748ull, 4701420995019453731ull,
  10102922259659812998ull, 5221093921474014333ull}},
{{17722693254193011781ull, 15100148280629092972ull,
  17240338843002154151ull, 6526367401842517916ull}},
{{3706622494031713110ull, 14263499332358978312ull,
  3103679480043141073ull, 8157959252303147396ull}},
{{2316639058769820694ull, 1997158055083279589ull,
  11163171711881738979ull, 5098724532689467122ull}},
{{7507484841889663771ull, 16331505624136263198ull,
  4730592602997397915ull, 6373405665861833903ull}},
{{160984015507303906ull, 15802696011742941094ull,
  1301554735319359490ull, 7966757082327292379ull}},
{{13935673064974228654ull, 14488371025766726087ull,
  16954372774070457345ull, 4979223176454557736ull}},
{{12807905312790397913ull, 4275405726926243897ull,
  2746221893878520066ull, 6224028970568197171ull}},
{{2174823585705833679ull, 14567629195512580680ull,
  17267835422630313794ull, 7780036213210246463ull}},
{{1359264741066146049ull, 13716454265622750829ull,
  17709926166785027977ull, 4862522633256404039ull}},
{{6310766944760070466ull, 3310509776746274824ull,
  17525721690053897068ull, 6078153291570505049ull}},
{{7888458680950088082ull, 4138137220932843530ull,
  8072094057285207623ull, 7597691614463131312ull}},
{{9541972694021192955ull, 9503864790724109062ull,
  5045058785803254764ull, 4748557259039457070ull}},
{{2704093830671715386ull, 11879830988405136328ull,
  15529695519108844263ull, 5935696573799321337ull}},
{{3380117288339644233ull, 10238102717079032506ull,
  5577061343603891617ull, 7419620717249151672ull}},
{{6724259323639665550ull, 17928029244242865076ull,
  3485663339752432260ull, 4637262948280719795ull}},
{{8405324154549581937ull, 3963292481594029729ull,
  18192137229972704038ull, 5796578685350899743ull}},
{{15118341211614365325ull, 14177487638847312969ull,
  18128485519038492143ull, 7245723356688624679ull}},
{{5062868459235792944ull, 13110173530131753308ull,
  18048920880370727275ull, 9057154195860780849ull}},
{{12387664823877146398ull, 5888015447118651865ull,
  4363046522590622691ull, 5660721372412988031ull}},
{{1649522974564269286ull, 2748333290470926928ull, 842122134810890460ull,
  7075901715516235039ull}},
{{2061903718205336607ull, 3435416613088658660ull,
  14887710723795776787ull, 8844877144395293798ull}},
{{10512061860733111187ull, 18288036447676269326ull,
  4693133183944972587ull, 5528048215247058624ull}},
{{3916705289061613176ull, 18248359541167948754ull,
  5866416479931215734ull, 6910060269058823280ull}},
{{14119253648181792278ull, 13587077389605160134ull,
  7333020599914019668ull, 8637575336323529100ull}},
{{4212847511686232270ull, 17715295405358000892ull,
  13806509911801038100ull, 5398484585202205687ull}},
{{5266059389607790337ull, 3697375182987949499ull,
  12646451371323909722ull, 6748105731502757109ull}},
{{1970888218582350018ull, 13845091015589712682ull,
  1973006158872723440ull, 8435132164378446387ull}},
{{5843491155041356665ull, 8653181884743570426ull,
  17374029913791309814ull, 5271957602736528991ull}},
{{16527735980656471639ull, 1593105319074687224ull,
  17105851373811749364ull, 6589947003420661239ull}},
{{2212925902111037933ull, 1991381648843359031ull,
  16770628198837298801ull, 8237433754275826549ull}},
{{8300607716460480564ull, 12773828576595569154ull,
  12787485633487005702ull, 5148396096422391593ull}},
{{1152387608720824897ull, 6743913683889685635ull,
  2149298986576593416ull, 6435495120527989492ull}},
{{15275542566183194834ull, 8429892104862107043ull,
  2686623733220741770ull, 8044368900659986865ull}},
{{7241371094650802819ull, 9880368583966204806ull,
  13208354879331433366ull, 5027730562912491790ull}},
{{18275085905168279332ull, 3127088693102980199ull,
  7287071562309515900ull, 6284663203640614738ull}},
{{18232171363032961261ull, 3908860866378725249ull,
  18332211489741670683ull, 7855829004550768422ull}},
{{4477578074254518932ull, 137195032273009329ull, 6845946162661156273ull,
  4909893127844230264ull}},
{{10208658611245536569ull, 4783179808768649565ull,
  8557432703326445341ull, 6137366409805287830ull}},
{{17372509282484308615ull, 10590660779388199860ull,
  1473418842303280868ull, 7671708012256609788ull}},
{{1634446264697917077ull, 15842535023972400721ull,
  10144258813294326350ull, 4794817507660381117ull}},
{{6654743849299784250ull, 10579796743110725093ull,
  17292009535045295842ull, 5993521884575476396ull}},
{{12930115830052118216ull, 4001373892033630558ull,
  3168267845097068187ull, 7491902355719345496ull}},
{{3469636375355185981ull, 195015673307325147ull, 1980167403185667617ull,
  4682438972324590935ull}},
{{18172103524476146188ull, 4855455610061544337ull,
  16310267309264248233ull, 5853048715405738668ull}},
{{8880071350313019023ull, 10681005531004318326ull,
  1941090062870758675ull, 7316310894257173336ull}},
{{1876717151036497971ull, 8739570895328010004ull,
  2426362578588448344ull, 9145388617821466670ull}},
{{10396320256252587040ull, 5462231809580006252ull,
  15351534666899943927ull, 5715867886138416668ull}},
{{12995400320315733800ull, 2216103743547619911ull,
  742674259915378293ull, 7144834857673020836ull}},
{{11632564381967279346ull, 7381815697861912793ull,
  928342824894222866ull, 8931043572091276045ull}},
{{352823711088467735ull, 9225320829591083400ull, 2886057274772583243ull,
  5581902232557047528ull}},
{{441029638860584669ull, 6919965018561466346ull, 3607571593465729054ull,
  6977377790696309410ull}},
{{9774659085430506644ull, 17873328310056608740ull,
  13732836528686937125ull, 8721722238370386762ull}},
{{15332533965248842461ull, 13476673202999074414ull,
  13194708848856723607ull, 5451076398981491726ull}},
{{9942295419706277268ull, 12234155485321455114ull,
  7270014024216128701ull, 6813845498726864658ull}},
{{3204497237778070777ull, 1457636301369655181ull,
  18310889567124936685ull, 8517306873408580822ull}},
{{4308653782824988188ull, 3216865697569728440ull,
  6832619961025697524ull, 5323316795880363014ull}},
{{5385817228531235234ull, 4021082121962160550ull,
  17764146988136897713ull, 6654145994850453767ull}},
{{15955643572518819851ull, 9638038670880088591ull,
  17593497716743734237ull, 8317682493563067209ull}},
{{16889806260465344263ull, 8329617178513749321ull,
  4078407045323752042ull, 5198551558476917006ull}},
{{7277199770299516617ull, 1188649436287410844ull,
  14321380843509465861ull, 6498189448096146257ull}},
{{9096499712874395771ull, 6097497813786651459ull,
  4066667999104668614ull, 8122736810120182822ull}},
{{3379469311332803405ull, 17645994188898820874ull,
  16376725554722581595ull, 5076710506325114263ull}},
{{13447708676020780064ull, 17445806717696138188ull,
  15859220924975839090ull, 6345888132906392829ull}},
{{16809635845025975080ull, 12583886360265396927ull,
  5988968100937635151ull, 7932360166132991037ull}},
{{17423551430782316281ull, 14782458002806954935ull,
  6048948072299715921ull, 4957725103833119398ull}},
{{17167753270050507447ull, 4643014448226529957ull,
  16784557127229420710ull, 6197156379791399247ull}},
{{7624633532280970597ull, 15027140097137938255ull,
  16369010390609387983ull, 7746445474739249059ull}},
{{11682924985316688479ull, 16309491588352293265ull,
  7924788484917173537ull, 4841528421712030662ull}},
{{768598176363696887ull, 6551806430158202870ull, 682613569291691114ull,
  6051910527140038328ull}},
{{10184119757309396917ull, 17413130074552529395ull,
  853266961614613892ull, 7564888158925047910ull}},
{{4059231839104679121ull, 1659834259740555064ull,
  14368349906291297395ull, 4728055099328154943ull}},
{{5074039798880848901ull, 15909850879957857542ull,
  13348751364436733839ull, 5910068874160193679ull}},
{{15565921785455836934ull, 15275627581519934023ull,
  12074253187118529395ull, 7387586092700242099ull}},
{{16646230143550979940ull, 7241424229236264812ull,
  5240565232735386920ull, 4617241307937651312ull}},
{{2361043605729173309ull, 9051780286545331016ull,
  6550706540919233650ull, 5771551634922064140ull}},
{{2951304507161466636ull, 2091353321326887962ull,
  8188383176149042063ull, 7214439543652580175ull}},
{{12912502670806609103ull, 16449249706940773664ull,
  5623792951758914674ull, 9018049429565725219ull}},
{{8070314169254130690ull, 14892467085265371444ull,
  1209027585635627719ull, 5636280893478578262ull}},
{{10087892711567663362ull, 14003897838154326401ull,
  10734656518899310457ull, 7045351116848222827ull}},
{{17221551907886967106ull, 3669814242410744289ull,
  8806634630196750168ull, 8806688896060278534ull}},
{{3845940914788272586ull, 2293633901506715181ull, 892460625445580951ull,
  5504180560037674084ull}},
{{9419112161912728636ull, 16702100432165557688ull,
  1115575781806976188ull, 6880225700047092605ull}},
{{11773890202390910795ull, 2430881466497395494ull,
  6006155745686108140ull, 8600282125058865756ull}},
{{2746995358066931343ull, 10742672953415647992ull,
  12977219377908593395ull, 5375176328161791097ull}},
{{3433744197583664178ull, 8816655173342172086ull,
  2386466167103578032ull, 6718970410202238872ull}},
{{13515552283834356031ull, 11020818966677715107ull,
  2983082708879472540ull, 8398713012752798590ull}},
{{6141377168182778568ull, 16111383891028347750ull,
  15699484748331834049ull, 5249195632970499118ull}},
{{16900093497083249017ull, 6304171808503270975ull,
  10400983898560016754ull, 6561494541213123898ull}},
{{16513430852926673367ull, 17103586797483864527ull,
  3777857836345245134ull, 8201868176516404873ull}},
{{17238423310720252711ull, 6078055730000027425ull,
  13890376193784247969ull, 5126167610322753045ull}},
{{7712971083118152176ull, 12209255680927422186ull,
  3527912186948146249ull, 6407709512903441307ull}},
{{417841817042914412ull, 1426511545877114021ull,
  18244948288967346524ull, 8009636891129301633ull}},
{{2566994144865515460ull, 10114941753027972071ull,
  4485563652963509721ull, 5006023056955813521ull}},
{{17043800736364058037ull, 17255363209712352992ull,
  10218640584631775055ull, 6257528821194766901ull}},
{{2858006846745520930ull, 16957517993713053337ull,
  17384986749217106723ull, 7821911026493458626ull}},
{{13315469325284420341ull, 8292605736856964383ull,
  15477302736688079606ull, 4888694391558411641ull}},
{{12032650638178137523ull, 1142385134216429671ull,
  5511570365577935796ull, 6110867989448014552ull}},
{{10429127279295283999ull, 1427981417770537089ull,
  6889462956972419745ull, 7638584986810018190ull}},
{{18047419595628022260ull, 12421703432175055440ull,
  18140972403389926052ull, 4774115616756261368ull}},
{{4112530420825476208ull, 15527129290218819301ull,
  4229471430527855949ull, 5967644520945326711ull}},
{{9752349044459233164ull, 5573853557491360414ull, 675153269732432033ull,
  7459555651181658389ull}},
{{1483532134359632824ull, 15012873519500570019ull,
  2727813802796463972ull, 4662222281988536493ull}},
{{15689473223231704742ull, 319347825666160907ull,
  8021453271922967870ull, 5827777852485670616ull}},
{{15000155510612243023ull, 9622556818937476942ull,
  10026816589903709837ull, 7284722315607088270ull}},
{{9526822351410527971ull, 16639882042099234082ull,
  3310148700524861488ull, 9105902894508860338ull}},
{{10565949988058967886ull, 10399926276312021301ull,
  6680528956255426334ull, 5691189309068037711ull}},
{{17819123503501097761ull, 3776535808535250818ull,
  3738975176891895014ull, 7113986636335047139ull}},
{{13050532342521596393ull, 13944041797523839331ull,
  62032952687480863ull, 8892483295418808924ull}},
{{5850739704862303794ull, 15632555151093481438ull,
  9262142632284451347ull, 5557802059636755577ull}},
{{16536796667932655551ull, 14929007920439463893ull,
  16189364308782952088ull, 6947252574545944471ull}},
{{6835937779633655726ull, 214515826839778251ull,
  15625019367551302207ull, 8684065718182430589ull}},
{{1966618103057340877ull, 7051601419415943263ull,
  12071480113933257831ull, 5427541073864019118ull}},
{{16293330684103839808ull, 4202815755842541174ull,
  5865978105561796481ull, 6784426342330023898ull}},
{{11143291318275023952ull, 9865205713230564372ull,
  16555844668807021409ull, 8480532927912529872ull}},
{{16187929110776665778ull, 17694968616837572492ull,
  10347402918004388380ull, 5300333079945331170ull}},
{{1788167314761280607ull, 3671966697337414000ull,
  3710881610650709668ull, 6625416349931663963ull}},
{{2235209143451600758ull, 4589958371671767500ull, 26915994885999181ull,
  8281770437414579954ull}},
{{10620377751512026282ull, 5174566991508548639ull,
  4628508515231137392ull, 5176106523384112471ull}},
{{8663786170962644948ull, 6468208739385685799ull,
  1173949625611533836ull, 6470133154230140589ull}},
{{6218046695275918281ull, 8085260924232107249ull,
  6079123050441805199ull, 8087666442787675736ull}},
{{15415494230615918686ull, 11970817105286148886ull,
  3799451906526128249ull, 5054791526742297335ull}},
{{10045995751415122549ull, 1128463326325522396ull,
  137628864730272408ull, 6318489408427871669ull}},
{{12557494689268903187ull, 1410579157906902995ull,
  4783722099340228414ull, 7898111760534839586ull}},
{{5542591171579370540ull, 14716670028973978084ull,
  7601512330515030662ull, 4936319850334274741ull}},
{{6928238964474213175ull, 9172465499362696797ull,
  14113576431571176232ull, 6170399812917843426ull}},
{{13271984724020154372ull, 11465581874203370996ull,
  8418598502609194482ull, 7712999766147304283ull}},
{{17518362489367372291ull, 11777674689804494776ull,
  2955781054917052599ull, 4820624853842065177ull}},
{{3451209037999663747ull, 10110407343828230567ull,
  8306412337073703653ull, 6025781067302581471ull}},
{{18149069352781743396ull, 17249695198212676112ull,
  5771329402914741662ull, 7532226334128226839ull}},
{{11343168345488589623ull, 6169373480455534666ull,
  10524609904462795395ull, 4707641458830141774ull}},
{{4955588395005961220ull, 3100030832142030429ull,
  3932390343723718436ull, 5884551823537677218ull}},
{{10806171512184839429ull, 3875038540177538036ull,
  14138859966509423853ull, 7355689779422096522ull}},
{{13507714390231049286ull, 9455484193649310449ull,
  8450202921282004008ull, 9194612224277620653ull}},
{{1524792466253323948ull, 5909677621030819031ull,
  7587219835014946457ull, 5746632640173512908ull}},
{{15741048638098818647ull, 11998783044715911692ull,
  9484024793768683071ull, 7183290800216891135ull}},
{{1229566723913971693ull, 10386792787467501712ull,
  7243344973783465935ull, 8979113500271113919ull}},
{{768479202446232308ull, 13409274519808270426ull,
  11444619636255748065ull, 5611945937669446199ull}},
{{10183971039912566193ull, 2926535094478174320ull,
  9694088526892297178ull, 7014932422086807749ull}},
{{12729963799890707741ull, 12881540904952493708ull,
  16729296677042759376ull, 8768665527608509686ull}},
{{17179599411786468147ull, 8050963065595308567ull,
  5844124404724336706ull, 5480415954755318554ull}},
{{16862813246305697279ull, 840331795139359901ull,
  16528527542760196691ull, 6850519943444148192ull}},
{{7243458502599957887ull, 14885472799206363589ull,
  2213915354740694247ull, 8563149929305185241ull}},
{{6833004573338667631ull, 16220949527145059099ull,
  12912912142781403664ull, 5351968705815740775ull}},
{{3929569698245946635ull, 1829442835221772258ull,
  11529454160049366677ull, 6689960882269675969ull}},
{{14135334159662209102ull, 6898489562454603226ull,
  576759644779544634ull, 8362451102837094962ull}},
{{13446269868216268593ull, 8923241994961514920ull,
  4972160796414603300ull, 5226531939273184351ull}},
{{16807837335270335741ull, 11154052493701893650ull,
  1603514977090866221ull, 6533164924091480439ull}},
{{11786424632233143868ull, 107507561845203351ull,
  15839451776645746489ull, 8166456155114350548ull}},
{{14284044422786796774ull, 11596407272221721854ull,
  676285323548815747ull, 5104035096946469093ull}},
{{8631683491628720159ull, 9883823071849764414ull,
  5457042672863407588ull, 6380043871183086366ull}},
{{1566232327681124390ull, 12354778839812205518ull,
  16044675377934035293ull, 7975054838978857957ull}},
{{14813953260082866456ull, 10027579784096322400ull,
  12333765120422466010ull, 4984409274361786223ull}},
{{70697501394031454ull, 3311102693265627193ull, 10805520382100694609ull,
  6230511592952232779ull}},
{{4700057895169927222ull, 8750564385009421895ull,
  8895214459198480357ull, 7788139491190290974ull}},
{{9855065212122286370ull, 7774945749844582636ull, 947823018571662319ull,
  4867587181993931859ull}},
{{12318831515152857962ull, 5106996168878340391ull,
  15019836828496741611ull, 6084483977492414823ull}},
{{10786853375513684548ull, 1772059192670537585ull,
  14163110017193539110ull, 7605604971865518529ull}},
{{18270998405764522603ull, 14942595050701249702ull,
  1934414733104880087ull, 4753503107415949081ull}},
{{13615375970350877446ull, 14066557794949174224ull,
  7029704434808488013ull, 5941878884269936351ull}},
{{17019219962938596807ull, 3748139188404304068ull,
  4175444525083222113ull, 7427348605337420439ull}},
{{1413640439981847196ull, 13871802038821159803ull,
  9527181855818095676ull, 4642092878335887774ull}},
{{15602108605259472707ull, 17339752548526449753ull,
  2685605282917843787ull, 5802616097919859718ull}},
{{5667577701292177172ull, 17063004667230674288ull,
  12580378640502080542ull, 7253270122399824647ull}},
{{7084472126615221465ull, 12105383797183567052ull,
  11113787282200212774ull, 9066587652999780809ull}},
{{13651167115989289224ull, 2954178854812341503ull, 28588023734051128ull,
  5666617283124863006ull}},
{{12452272876559223626ull, 3692723568515426879ull,
  9259107066522339718ull, 7083271603906078757ull}},
{{10953655077271641628ull, 13839276497499059407ull,
  16185569851580312551ull, 8854089504882598446ull}},
{{13763563450935857874ull, 15567076838577993985ull,
  5504295138810307440ull, 5533805940551624029ull}},
{{3369396258387658630ull, 1012101974512940866ull,
  11492054941940272205ull, 6917257425689530036ull}},
{{13435117359839349095ull, 5876813486568563986ull,
  14365068677425340256ull, 8646571782111912545ull}},
{{13008634368326981089ull, 3673008429105352491ull,
  2060638895749755804ull, 5404107363819945341ull}},
{{11649106941981338457ull, 4591260536381690614ull,
  7187484638114582659ull, 6755134204774931676ull}},
{{5338011640621897263ull, 1127389652049725364ull,
  8984355797643228324ull, 8443917755968664595ull}},
{{12559629312243461597ull, 9927990569385854160ull,
  3309379364313323750ull, 5277448597480415372ull}},
{{15699536640304326997ull, 3186616174877541892ull,
  4136724205391654688ull, 6596810746850519215ull}},
{{1177676726670857130ull, 3983270218596927366ull, 559219238312180456ull,
  8246013433563149019ull}},
{{14571106009451449418ull, 2489543886623079603ull,
  16490413088440970449ull, 5153758395976968136ull}},
{{13602196493386923869ull, 7723615876706237408ull,
  2166272286841661445ull, 6442197994971210171ull}},
{{17002745616733654836ull, 14266205864310184664ull,
  16542898413834240518ull, 8052747493714012713ull}},
{{10626716010458534273ull, 4304692646766477511ull,
  3421782481005318468ull, 5032967183571257946ull}},
{{8671708994645779937ull, 5380865808458096889ull,
  13500600138111423893ull, 6291208979464072432ull}},
{{15451322261734612825ull, 11337768279000009015ull,
  16875750172639279866ull, 7864011224330090540ull}},
{{16574605441225214872ull, 11697791192802393538ull,
  1323971821044774108ull, 4915007015206306588ull}},
{{11494884764676742781ull, 14622238991002991923ull,
  1654964776305967635ull, 6143758769007883235ull}},
{{9756919937418540573ull, 13666112720326352000ull,
  15903764025664623256ull, 7679698461259854043ull}},
{{6098074960886587858ull, 8541320450203970000ull,
  7634009506826695583ull, 4799811538287408777ull}},
{{7622593701108234822ull, 6064964544327574596ull,
  14154197901960757383ull, 5999764422859260971ull}},
{{9528242126385293528ull, 2969519661982080341ull,
  13081061359023558825ull, 7499705528574076214ull}},
{{8260994338204502407ull, 13385164834807269973ull,
  3563977330962336361ull, 4687315955358797634ull}},
{{14937928941183015913ull, 2896397988226923754ull,
  13678343700557696260ull, 5859144944198497042ull}},
{{9449039139623994083ull, 3620497485283654693ull,
  7874557588842344517ull, 7323931180248121303ull}},
{{16422984942957380507ull, 9137307875031956270ull,
  5231510967625542742ull, 9154913975310151629ull}},
{{5652679570920974913ull, 1099131403467584765ull,
  5575537363979658166ull, 5721821234568844768ull}},
{{11677535482078606546ull, 10597286291189256764ull,
  6969421704974572707ull, 7152276543211055960ull}},
{{14596919352598258182ull, 8634921845559183051ull,
  8711777131218215884ull, 8940345679013819950ull}},
{{6817231586160217412ull, 14620198190329265215ull,
  833174688583997023ull, 5587716049383637469ull}},
{{3909853464272883861ull, 13663561719484193615ull,
  5653154379157384183ull, 6984645061729546836ull}},
{{275630811913716922ull, 12467766130927854115ull,
  7066442973946730229ull, 8730806327161933545ull}},
{{16313170321941930740ull, 10098196841043602773ull,
  15945741904785176153ull, 5456753954476208465ull}},
{{6556404847145249713ull, 17234432069731891371ull,
  6097119325699306479ull, 6820942443095260582ull}},
{{3583820040504174237ull, 16931354068737476310ull,
  16844771193978908907ull, 8526178053869075727ull}},
{{16074945580597272611ull, 8276253283747228741ull,
  17445511023877899923ull, 5328861283668172329ull}},
{{6258623920464427051ull, 5733630586256648023ull,
  7971830724565211192ull, 6661076604585215412ull}},
{{3211593882153145910ull, 7167038232820810029ull,
  9964788405706513990ull, 8326345755731519265ull}},
{{4313089185559410146ull, 18314456950795169980ull,
  17757207799635041003ull, 5203966097332199540ull}},
{{5391361481949262682ull, 18281385170066574571ull,
  3749765675834249638ull, 6504957621665249426ull}},
{{2127515834009190448ull, 13628359425728442406ull,
  13910579131647587856ull, 8131197027081561782ull}},
{{15164755451537907742ull, 8517724641080276503ull,
  4082425938852354506ull, 5081998141925976114ull}},
{{14344258295994996774ull, 1423783764495569821ull,
  14326404460420218941ull, 6352497677407470142ull}},
{{4095264814711582255ull, 6391415724046850181ull,
  8684633538670497868ull, 7940622096759337678ull}},
{{4865383518408432862ull, 13218006864384057171ull,
  816209943241673263ull, 4962888810474586049ull}},
{{1470043379583153173ull, 11910822562052683560ull,
  5631948447479479483ull, 6203611013093232561ull}},
{{1837554224478941466ull, 10276842184138466546ull,
  11651621577776737258ull, 7754513766366540701ull}},
{{5760157408726726321ull, 11034712383513929495ull,
  9588106495324154738ull, 4846571103979087938ull}},
{{2588510742481019997ull, 4570018442537636061ull,
  2761761082300417615ull, 6058213879973859923ull}},
{{7847324446528662900ull, 1100837034744657172ull,
  17287259408157685731ull, 7572767349967324903ull}},
{{14127949815935190120ull, 16828924211211268396ull,
  17722066157739635437ull, 4732979593729578064ull}},
{{17659937269918987650ull, 7201097208731921783ull,
  3705838623464992681ull, 5916224492161972581ull}},
{{17463235568971346659ull, 13613057529342290133ull,
  9243984297758628755ull, 7395280615202465726ull}},
{{13220365239820785614ull, 6202317946625237381ull,
  1165804167671755068ull, 4622050384501541079ull}},
{{2690398494493818305ull, 7752897433281546727ull,
  15292313264871857547ull, 5777562980626926348ull}},
{{17198056173399436594ull, 5079435773174545504ull,
  668647507380270318ull, 7221953725783657936ull}},
{{3050826143039744126ull, 15572666753322957689ull,
  835809384225337897ull, 9027442157229572420ull}},
{{13435981385468309839ull, 2815387693185766699ull,
  9745752901995611994ull, 5642151348268482762ull}},
{{12183290713407999394ull, 12742606653336984182ull,
  2958819090639739184ull, 7052689185335603453ull}},
{{6005741354905223435ull, 15928258316671230228ull,
  8310209881727061884ull, 8815861481669504316ull}},
{{12976960383670540455ull, 731789411064743084ull,
  14417253212934189486ull, 5509913426043440197ull}},
{{16221200479588175569ull, 10138108800685704663ull,
  4186508460885573145ull, 6887391782554300247ull}},
{{15664814581057831557ull, 17284322019284518733ull,
  621449557679578527ull, 8609239728192875309ull}},
{{12096352122374838675ull, 17720230289693906064ull,
  2694248982763430531ull, 5380774830120547068ull}},
{{15120440152968548344ull, 17538601843689994676ull,
  3367811228454288164ull, 6725968537650683835ull}},
{{453806117501133814ull, 3476508230902941730ull,
  18044822090850023918ull, 8407460672063354793ull}},
{{4895314841865596538ull, 16007875699596502293ull,
  4360484779140183092ull, 5254662920039596746ull}},
{{10730829570759383576ull, 1563100550786076250ull,
  14673978010780004674ull, 6568328650049495932ull}},
{{4190164926594453662ull, 11177247725337371121ull,
  18342472513475005842ull, 8210410812561869915ull}},
{{14148068125190003299ull, 11597465846763244854ull,
  9158202311708184699ull, 5131506757851168697ull}},
{{8461713119632728315ull, 9885146290026668164ull,
  16059438908062618778ull, 6414383447313960871ull}},
{{10577141399540910394ull, 3133060825678559397ull,
  15462612616650885569ull, 8017979309142451089ull}},
{{8916556383926762949ull, 13487378062117569383ull,
  2746603857765721624ull, 5011237068214031931ull}},
{{6534009461481065782ull, 16859222577646961729ull,
  17268312877489315742ull, 6264046335267539913ull}},
{{12779197845278720131ull, 11850656185203926353ull,
  7750333041579480966ull, 7830057919084424892ull}},
{{1069469625658118226ull, 2794974097325066067ull,
  14067330187841951412ull, 4893786199427765557ull}},
{{15171895087354811494ull, 3493717621656332583ull,
  3749104679520275553ull, 6117232749284706947ull}},
{{14353182840766126464ull, 8978833045497803633ull, 74694830972956537ull,
  7646540936605883684ull}},
{{2053210247837747184ull, 17140985699504597031ull,
  9270056306212873643ull, 4779088085378677302ull}},
{{16401570865079347692ull, 16814546105953358384ull,
  2364198345911316246ull, 5973860106723346628ull}},
{{2055219507639632999ull, 11794810595586922173ull,
  2955247932389145308ull, 7467325133404183285ull}},
{{3590355201488464576ull, 16595128659096602166ull,
  4152872966956909769ull, 4667078208377614553ull}},
{{13711316038715356528ull, 6908852768588588995ull,
  9802777227123525116ull, 5833847760472018191ull}},
{{12527459029966807756ull, 8636065960735736244ull,
  7641785515477018491ull, 7292309700590022739ull}},
{{15659323787458509695ull, 6183396432492282401ull,
  4940545875918885210ull, 9115387125737528424ull}},
{{2869548339520486704ull, 8476308788735064405ull,
  3087841172449303256ull, 5697116953585955265ull}},
{{8198621442827996284ull, 10595385985918830506ull,
  8471487483989016974ull, 7121396191982444081ull}},
{{1024904766680219546ull, 4020860445543762325ull,
  15201045373413659122ull, 8901745239978055101ull}},
{{2946408488388831169ull, 7124723796892239357ull,
  11806496367597230903ull, 5563590774986284438ull}},
{{8294696628913426865ull, 4294218727687911292ull,
  5534748422641762821ull, 6954488468732855548ull}},
{{10368370786141783581ull, 9979459428037277019ull,
  6918435528302203526ull, 8693110585916069435ull}},
{{4174388732124920786ull, 1625476124095910233ull,
  2018179195975183252ull, 5433194116197543397ull}},
{{9829671933583538887ull, 2031845155119887791ull,
  7134410013396366969ull, 6791492645246929246ull}},
{{7675403898552035704ull, 7151492462327247643ull,
  18141384553600234519ull, 8489365806558661557ull}},
{{2491284427381328363ull, 11387211816595611633ull,
  13644208355213840526ull, 5305853629099163473ull}},
{{7725791552654048358ull, 5010642733889738733ull,
  3220202388735136946ull, 6632317036373954342ull}},
{{14268925459244948351ull, 15486675454216949224ull,
  13248625022773696990ull, 8290396295467442927ull}},
{{8918078412028092720ull, 5067486140458205361ull,
  15197919666874642475ull, 5181497684667151829ull}},
{{15759284033462503804ull, 1722671657145368797ull,
  5162341528311139382ull, 6476872105833939787ull}},
{{5864046986545966042ull, 11376711608286486805ull,
  1841240891961536323ull, 8096090132292424734ull}},
{{5970872375804922729ull, 4804601745965360301ull,
  14985833612758123914ull, 5060056332682765458ull}},
{{12075276488183541315ull, 15229124219311476184ull,
  9508919979092879084ull, 6325070415853456823ull}},
{{15094095610229426643ull, 589661200429793614ull,
  7274463955438710952ull, 7906338019816821029ull}},
{{4822123737966003748ull, 368538250268621009ull, 6852382981362888297ull,
  4941461262385513143ull}},
{{10639340690884892589ull, 5072358831263164165ull,
  3953792708276222467ull, 6176826577981891429ull}},
{{17910861882033503640ull, 1728762520651567302ull,
  9553926903772665988ull, 7721033222477364286ull}},
{{6582602657843551871ull, 10303848612262005372ull,
  1359518296430528338ull, 4825645764048352679ull}},
{{8228253322304439839ull, 3656438728472730907ull,
  15534455925820324135ull, 6032057205060440848ull}},
{{5673630634453161895ull, 18405606465873077346ull,
  971325833565853552ull, 7540071506325551061ull}},
{{8157705164960614088ull, 11503504041170673341ull,
  2912921655192352422ull, 4712544691453469413ull}},
{{14808817474628155514ull, 5156008014608565868ull,
  8252838087417828432ull, 5890680864316836766ull}},
{{64277769575642777ull, 6445010018260707336ull, 1092675572417509732ull,
  7363351080396045958ull}},
{{80347211969553471ull, 8056262522825884170ull, 10589216502376662973ull,
  9204188850495057447ull}},
{{4661903025908358824ull, 7341007085979871558ull,
  13535789341626496214ull, 5752618031559410904ull}},
{{15050750819240224337ull, 18399630894329615255ull,
  16919736677033120267ull, 7190772539449263630ull}},
{{14201752505622892517ull, 18387852599484631165ull,
  11926298809436624526ull, 8988465674311579538ull}},
{{11181938325228001776ull, 6880721856250506574ull,
  12065622774325278233ull, 5617791046444737211ull}},
{{4754050869680226411ull, 13212588338740521122ull,
  10470342449479209887ull, 7022238808055921514ull}},
{{15165935623955058822ull, 11904049404998263498ull,
  3864556024994236551ull, 8777798510069901893ull}},
{{14090395783399299668ull, 14357559905764996542ull,
  4721190524835091796ull, 5486124068793688683ull}},
{{8389622692394348777ull, 17946949882206245678ull,
  1289802137616476841ull, 6857655085992110854ull}},
{{1263656328638160163ull, 8598629297475643386ull,
  10835624708875371860ull, 8572068857490138567ull}},
{{5401471223826238006ull, 14597515347777052924ull,
  13689794470688189268ull, 5357543035931336604ull}},
{{6751839029782797507ull, 18246894184721316155ull,
  17112243088360236585ull, 6696928794914170755ull}},
{{3828112768801108980ull, 8973559675619481482ull,
  16778617842022907828ull, 8371160993642713444ull}},
{{7004256498928081017ull, 14831846834116951734ull,
  1263264114409541584ull, 5231975621026695903ull}},
{{17978692660514877079ull, 93064468936638051ull,
  15414138198294090693ull, 6539969526283369878ull}},
{{17861679807216208444ull, 4728016604598185468ull,
  10044300711012837558ull, 8174961907854212348ull}},
{{1940177842655354470ull, 16790068433156029630ull,
  15501059981237799281ull, 5109351192408882717ull}},
{{11648594340173968895ull, 7152527486162873325ull,
  5541266921265085390ull, 6386688990511103397ull}},
{{725684869935297407ull, 18164031394558367465ull,
  11538269670008744641ull, 7983361238138879246ull}},
{{11982768089778030640ull, 4434990593957897809ull,
  2599732525328077497ull, 4989600773836799529ull}},
{{1143402056940374587ull, 10155424260874760166ull,
  7861351675087484775ull, 6237000967295999411ull}},
{{10652624608030244042ull, 8082594307666062303ull,
  5215003575431968065ull, 7796251209119999264ull}},
{{13575419407659984382ull, 16580836488359758699ull,
  3259377234644980040ull, 4872657005699999540ull}},
{{12357588241147592574ull, 2279301536740146758ull,
  4074221543306225051ull, 6090821257124999425ull}},
{{6223613264579714909ull, 16684184976207347160ull,
  9704462947560169217ull, 7613526571406249281ull}},
{{3889758290362321819ull, 3510086582488510119ull,
  17594504388293575521ull, 4758454107128905800ull}},
{{250511844525514369ull, 8999294246538025553ull, 3546386411657417785ull,
  5948067633911132251ull}},
{{4924825824084280865ull, 15860803826599919845ull,
  18268041069853935943ull, 7435084542388915313ull}},
{{5383859149266369493ull, 16830531419266031759ull,
  4499996641017628108ull, 4646927838993072071ull}},
{{2118137918155573962ull, 2591420200372988083ull,
  1013309782844647232ull, 5808659798741340089ull}},
{{16482730452976631164ull, 3239275250466235103ull,
  5878323246983196944ull, 7260824748426675111ull}},
{{15991727047793401051ull, 4049094063082793879ull,
  2736218040301608276ull, 9076030935533343889ull}},
{{16912358432511957513ull, 11754055826281521982ull,
  13239351321256974932ull, 5672519334708339930ull}},
{{11917076003785171083ull, 14692569782851902478ull,
  7325817114716442857ull, 7090649168385424913ull}},
{{5672972967876688046ull, 4530654173282714386ull,
  13768957411822941476ull, 8863311460481781141ull}},
{{8157294123350317933ull, 12055030895156472299ull,
  10911441391603032374ull, 5539569662801113213ull}},
{{5584931635760509512ull, 5845416582090814566ull,
  18250987757931178372ull, 6924462078501391516ull}},
{{16204536581555412698ull, 7306770727613518207ull,
  4366990623704421349ull, 8655577598126739396ull}},
{{17045364391113214793ull, 6872574713972142831ull,
  11952741176670039151ull, 5409735998829212122ull}},
{{16695019470464130587ull, 3979032374037790635ull,
  5717554433982773131ull, 6762169998536515153ull}},
{{16257088319652775329ull, 362104449119850390ull,
  11758629060905854318ull, 8452712498170643941ull}},
{{5548994181355596677ull, 14061373335982070206ull,
  9654986172279852900ull, 5282945311356652463ull}},
{{16159614763549271654ull, 17576716669977587757ull,
  7457046696922428221ull, 6603681639195815579ull}},
{{6364460399154425855ull, 8135837782189820985ull,
  4709622352725647373ull, 8254602048994769474ull}},
{{15507002795539985920ull, 7390741623082332067ull,
  7555199988880917512ull, 5159126280621730921ull}},
{{14772067475997594496ull, 9238427028852915084ull,
  14055686004528534794ull, 6448907850777163651ull}},
{{18340271287441503ull, 2324661749211368048ull, 12957921487233280589ull,
  8061134813471454564ull}},
{{11462669554650940ull, 3758756602470798982ull, 17322072966375576176ull,
  5038209258419659102ull}},
{{9237700373798089483ull, 4698445753088498727ull,
  12429219171114694412ull, 6297761573024573878ull}},
{{6935439448820223949ull, 5873057191360623409ull,
  6313151927038592207ull, 7872201966280717348ull}},
{{15863864701581109728ull, 10588189772241471486ull,
  13169091991253895937ull, 4920126228925448342ull}},
{{10606458840121611352ull, 17846923233729227262ull,
  7237992952212594113ull, 6150157786156810428ull}},
{{4034701513297238382ull, 8473595986879370366ull,
  9047491190265742642ull, 7687697232696013035ull}},
{{16356746501092937701ull, 9907683510226994382ull,
  3348838984702395199ull, 4804810770435008147ull}},
{{11222561089511396318ull, 7772918369356355074ull,
  18021106786160157711ull, 6006013463043760183ull}},
{{4804829325034469590ull, 5104461943268055939ull,
  17914697464272809235ull, 7507516828804700229ull}},
{{697175318932849542ull, 884445705328841010ull, 13502528924384199724ull,
  4692198018002937643ull}},
{{10094841185520837735ull, 1105557131661051262ull,
  12266475137052861751ull, 5865247522503672054ull}},
{{3395179445046271361ull, 15217004469858477790ull,
  6109721884461301380ull, 7331559403129590068ull}},
{{13467346343162615009ull, 574511513613545621ull,
  7637152355576626726ull, 9164449253911987585ull}},
{{10722934473690328333ull, 14194127751290629725ull,
  16302435268303861463ull, 5727780783694992240ull}},
{{18015354110540298320ull, 13130973670685899252ull,
  1931300011670275213ull, 7159725979618740301ull}},
{{4072448564465821284ull, 2578659033075210354ull,
  7025811033015231921ull, 8949657474523425376ull}},
{{7156966371218526206ull, 13140876941740476231ull,
  4391131895634519950ull, 5593535921577140860ull}},
{{4334521945595769854ull, 7202724140320819481ull,
  5488914869543149938ull, 6991919901971426075ull}},
{{10029838450422100221ull, 18226777212255800159ull,
  2249457568501549518ull, 8739899877464282594ull}},
{{13186178059154894494ull, 6780049739232487195ull,
  6017596998740856353ull, 5462437423415176621ull}},
{{11871036555516230214ull, 13086748192467996898ull,
  12133682266853458345ull, 6828046779268970776ull}},
{{5615423657540511959ull, 2523377185302832411ull,
  15167102833566822932ull, 8535058474086213470ull}},
{{1203796776749126023ull, 10800482777669046065ull,
  4867753252551876428ull, 5334411546303883419ull}},
{{6116431989363795432ull, 13500603472086307581ull,
  1473005547262457631ull, 6668014432879854274ull}},
{{12257226005132132194ull, 12264068321680496572ull,
  11064628970932847847ull, 8335018041099817842ull}},
{{16884138290062358430ull, 14582571728691392213ull,
  11527079125260417808ull, 5209386275687386151ull}},
{{7270114807295784325ull, 18228214660864240267ull,
  9797162888148134356ull, 6511732844609232689ull}},
{{4475957490692342502ull, 4338524252370748718ull,
  16858139628612555850ull, 8139666055761540861ull}},
{{16632531486964877776ull, 7323263676159105852ull,
  12842180277096541358ull, 5087291284850963038ull}},
{{2343920284996545604ull, 18377451632053658124ull,
  6829353309515900889ull, 6359114106063703798ull}},
{{2929900356245682005ull, 9136756484784908943ull,
  17760063673749651920ull, 7948892632579629747ull}},
{{8748716750294633109ull, 5710472802990568089ull,
  8794196786879838498ull, 4968057895362268592ull}},
{{15547581956295679290ull, 16361463040592985919ull,
  10992745983599798122ull, 6210072369202835740ull}},
{{14822791426942211209ull, 11228456763886456591ull,
  13740932479499747653ull, 7762590461503544675ull}},
{{16181773669479963862ull, 9323628486642729321ull,
  6282239790473648331ull, 4851619038439715422ull}},
{{6392159031567791115ull, 7042849589876023748ull,
  17076171774946836222ull, 6064523798049644277ull}},
{{7990198789459738893ull, 18026934024199805493ull,
  7510156663401381565ull, 7580654747562055347ull}},
{{7299717252626030761ull, 13572676774338572385ull,
  2388004905412169526ull, 4737909217226284592ull}},
{{13736332584209926355ull, 7742473931068439673ull,
  2985006131765211908ull, 5922386521532855740ull}},
{{3335357674980244231ull, 9678092413835549592ull,
  3731257664706514885ull, 7402983151916069675ull}},
{{2084598546862652645ull, 8354650767860912447ull, 26193031227877851ull,
  4626864469947543547ull}},
{{16440806238860479518ull, 5831627441398752654ull,
  13867799344317011026ull, 5783580587434429433ull}},
{{11327635761720823589ull, 16512906338603216626ull,
  3499691125114100070ull, 7229475734293036792ull}},
{{4936172665296253678ull, 11417760886399244975ull,
  4374613906392625088ull, 9036844667866295990ull}},
{{10002636943451240405ull, 7136100553999528109ull,
  16569191746777554392ull, 5648027917416434993ull}},
{{17114982197741438410ull, 8920125692499410136ull,
  6876431628189779278ull, 7060034896770543742ull}},
{{2946983673467246397ull, 1926785078769486863ull,
  17818911572091999906ull, 8825043620963179677ull}},
{{8759393823558110854ull, 5815926692658317193ull,
  13442662741771193893ull, 5515652263101987298ull}},
{{15560928297875026471ull, 11881594384250284395ull,
  7579956390359216558ull, 6894565328877484123ull}},
{{14839474353916395185ull, 5628620943458079686ull,
  4863259469521632794ull, 8618206661096855154ull}},
{{4662985452770359087ull, 8129574108088687708ull,
  7651223186878408400ull, 5386379163185534471ull}},
{{5828731815962948858ull, 10161967635110859635ull,
  4952342965170622596ull, 6732973953981918089ull}},
{{2674228751526298169ull, 12702459543888574544ull,
  10802114724890666149ull, 8416217442477397611ull}},
{{1671392969703936356ull, 10244880224144053042ull,
  4445478693842972391ull, 5260135901548373507ull}},
{{11312613248984696253ull, 8194414261752678398ull,
  945162348876327585ull, 6575169876935466884ull}},
{{4917394524376094508ull, 14854703845618235902ull,
  1181452936095409481ull, 8218962346169333605ull}},
{{16908429633017222779ull, 2366660875870315582ull,
  3044251094273324878ull, 5136851466355833503ull}},
{{11912165004416752666ull, 12181698131692670286ull,
  17640371923123819809ull, 6421064332944791878ull}},
{{5666834218666165025ull, 1392064609333674146ull,
  12827092867049998954ull, 8026330416180989848ull}},
{{8153457405093741045ull, 5481726399260934245ull,
  8016933041906249346ull, 5016456510113118655ull}},
{{14803507774794564210ull, 16075530035930943614ull,
  5409480283955423778ull, 6270570637641398319ull}},
{{9281012681638429454ull, 10871040508058903710ull,
  2150164336516891819ull, 7838213297051747899ull}},
{{1188946907596630505ull, 4488557308323120867ull,
  17484753774818915051ull, 4898883310657342436ull}},
{{15321241689777951843ull, 999010616976513179ull,
  3409198144814092198ull, 6123604138321678046ull}},
{{14539866093795051900ull, 10472135308075417282ull,
  13484869717872391055ull, 7654505172902097557ull}},
{{13699102327049295341ull, 13462613595188217657ull,
  10733886582883938361ull, 4784065733063810973ull}},
{{3288819853529455465ull, 2993208938703108360ull,
  18029044247032310856ull, 5980082166329763716ull}},
{{4111024816911819331ull, 3741511173378885450ull,
  4089561235080836954ull, 7475102707912204646ull}},
{{7181076528997274986ull, 6950130501789191310ull,
  16391033827207686808ull, 4671939192445127903ull}},
{{18199717698101369540ull, 8687663127236489137ull,
  15877106265582220606ull, 5839923990556409879ull}},
{{8914589067344548213ull, 1636206872190835614ull,
  15234696813550387854ull, 7299904988195512349ull}},
{{1919864297325909458ull, 11268630627093320326ull,
  5208312961655821105ull, 9124881235244390437ull}},
{{15034973241110857124ull, 125365114292243347ull,
  5561038610248582143ull, 5703050772027744023ull}},
{{14182030532961183500ull, 13991764448147467896ull,
  2339612244383339774ull, 7128813465034680029ull}},
{{17727538166201479375ull, 8266333523329559062ull,
  7536201323906562622ull, 8911016831293350036ull}},
{{6468025335448536706ull, 554772433653586510ull,
  13933497864296377447ull, 5569385519558343772ull}},
{{17308403706165446690ull, 14528523597349146849ull,
  17416872330370471808ull, 6961731899447929715ull}},
{{7800446577424644651ull, 18160654496686433562ull,
  17159404394535701856ull, 8702164874309912144ull}},
{{9486965129317790811ull, 11350409060429020976ull,
  10724627746584813660ull, 5438853046443695090ull}},
{{11858706411647238513ull, 14188011325536276220ull,
  4182412646376241267ull, 6798566308054618863ull}},
{{14823383014559048142ull, 13123328138492957371ull,
  616329789542913680ull, 8498207885068273579ull}},
{{6958771374885711137ull, 8202080086558098357ull,
  16526107182960178714ull, 5311379928167670986ull}},
{{13310150237034526825ull, 1029228071342847138ull,
  11434261941845447585ull, 6639224910209588733ull}},
{{7414315759438382723ull, 5898221107605946827ull, 457769372024645769ull,
  8299031137761985917ull}},
{{2328104340435295250ull, 15215603238322186527ull,
  2591948866729097557ull, 5186894461101241198ull}},
{{16745188480826282774ull, 5184445992620569446ull,
  12463308120266147755ull, 6483618076376551497ull}},
{{11708113564178077660ull, 1868871472348323904ull,
  1744077095050520982ull, 8104522595470689372ull}},
{{7317570977611298537ull, 15003102725499866152ull,
  10313420221261351421ull, 5065326622169180857ull}},
{{9146963722014123172ull, 4918820351592668978ull,
  17503461295004077181ull, 6331658277711476071ull}},
{{2210332615662878157ull, 10760211457918224127ull,
  17267640600327708572ull, 7914572847139345089ull}},
{{8298986912430380704ull, 15948504198053665887ull,
  3874746347563736001ull, 4946608029462090681ull}},
{{5762047622110587976ull, 6100572192284918647ull,
  9455118952882057906ull, 6183260036827613351ull}},
{{2590873509210847066ull, 16849087277210924117ull,
  7207212672675184478ull, 7729075046034516689ull}},
{{3925138952470473368ull, 5918993529829439669ull,
  16033722966490460059ull, 4830671903771572930ull}},
{{9518109709015479614ull, 2787055893859411682ull,
  10818781671258299266ull, 6038339879714466163ull}},
{{2674265099414573710ull, 12707191904179040411ull,
  8911791070645486178ull, 7547924849643082704ull}},
{{17812316751629966233ull, 12553680958539288160ull,
  5569869419153428861ull, 4717453031026926690ull}},
{{3818651865827906175ull, 1857043142891946489ull,
  16185708810796561885ull, 5896816288783658362ull}},
{{9385000850712270622ull, 6932989947042321015ull,
  11008763976640926548ull, 7371020360979572953ull}},
{{7119565044962950374ull, 8666237433802901269ull,
  18372640989228546089ull, 9213775451224466191ull}},
{{6755571162315537936ull, 16945613442195283053ull,
  18400429645908923161ull, 5758609657015291369ull}},
{{13056149971321810324ull, 7346958747461940104ull,
  9165479002103990240ull, 7198262071269114212ull}},
{{16320187464152262904ull, 9183698434327425130ull,
  11456848752629987800ull, 8997827589086392765ull}},
{{14811803183522552219ull, 5739811521454640706ull,
  9466373479607436327ull, 5623642243178995478ull}},
{{9291381942548414466ull, 2563078383390912979ull,
  2609594812654519601ull, 7029552803973744348ull}},
{{7002541409758130179ull, 7815533997666029128ull,
  3261993515818149501ull, 8786941004967180435ull}},
{{4376588381098831362ull, 7190551757754962157ull,
  18179647011882201102ull, 5491838128104487771ull}},
{{10082421494800927106ull, 18211561734048478504ull,
  18112872746425363473ull, 6864797660130609714ull}},
{{12603026868501158883ull, 8929394112278434418ull,
  13417718896176928534ull, 8580997075163262143ull}},
{{12488577811240612206ull, 969185301746633607ull,
  15303603337751662190ull, 5363123171977038839ull}},
{{10999036245623377353ull, 10434853664038067817ull,
  14517818153762189833ull, 6703903964971298549ull}},
{{18360481325456609595ull, 17655253098474972675ull,
  4312214636920573579ull, 8379879956214123187ull}},
{{9169457819196687045ull, 8728690177333163970ull, 389291138861664535ull,
  5237424972633826992ull}},
{{2238450237141082998ull, 6299176703239067059ull, 486613923577080669ull,
  6546781215792283740ull}},
{{16633120851708517460ull, 12485656897476221727ull,
  608267404471350836ull, 8183476519740354675ull}},
{{17313229559958905269ull, 17026907597777414387ull,
  16521068192290451936ull, 5114672824837721671ull}},
{{17029850931521243682ull, 2836890423512216368ull,
  16039649221935677017ull, 6393341031047152089ull}},
{{2840569590692002986ull, 8157799047817658365ull,
  6214503472137432559ull, 7991676288808940112ull}},
{{4081199003396195818ull, 12016153432527118334ull,
  3884064670085895349ull, 4994797680505587570ull}},
{{14324870791100020581ull, 1185133735376734205ull,
  14078452874462144995ull, 6243497100631984462ull}},
{{4071030433592862014ull, 15316475224503081469ull,
  8374694056222905435ull, 7804371375789980578ull}},
{{4850237030209232711ull, 7266954006100731966ull,
  9845869803566703801ull, 4877732109868737861ull}},
{{15286168324616316697ull, 13695378526053302861ull,
  16919023272885767655ull, 6097165137335922326ull}},
{{5272652350488232159ull, 12507537139139240673ull,
  11925407054252433761ull, 7621456421669902908ull}},
{{14824622765123614859ull, 899681684320943564ull,
  16676751445762546909ull, 4763410263543689317ull}},
{{84034382694966958ull, 5736288123828567360ull, 7010881251921019924ull,
  5954262829429611647ull}},
{{105042978368708697ull, 7170360154785709200ull, 4151915546473887001ull,
  7442828536787014559ull}},
{{65651861480442936ull, 16010690142809538010ull, 9512476244187261231ull,
  4651767835491884099ull}},
{{9305436863705329478ull, 15401676660084534608ull,
  7278909286806688635ull, 5814709794364855124ull}},
{{11631796079631661847ull, 14640409806678280356ull,
  9098636608508360794ull, 7268387242956068905ull}},
{{14539745099539577309ull, 9077140221493074637ull,
  15984981779062838897ull, 9085484053695086131ull}},
{{11393183696425929770ull, 17202427684501641408ull,
  7684770602700580358ull, 5678427533559428832ull}},
{{14241479620532412213ull, 12279662568772275952ull,
  9605963253375725448ull, 7098034416949286040ull}},
{{17801849525665515266ull, 15349578210965344940ull,
  12007454066719656810ull, 8872543021186607550ull}},
{{1902783916686171233ull, 14205172400280728492ull,
  2892972773272397602ull, 5545339388241629719ull}},
{{2378479895857714042ull, 8533093463496134807ull,
  17451274021872660715ull, 6931674235302037148ull}},
{{16808157925104306264ull, 6054680810942780604ull,
  3367348453631274278ull, 8664592794127546436ull}},
{{1281726666335415607ull, 17619233562121401590ull,
  11327964820374322231ull, 5415370496329716522ull}},
{{10825530369774045317ull, 17412355934224364083ull,
  4936583988613126981ull, 6769213120412145653ull}},
{{8920226943790168742ull, 7930386862498291392ull,
  10782416004193796631ull, 8461516400515182066ull}},
{{5575141839868855464ull, 11874020816702513976ull,
  11350696021048510798ull, 5288447750321988791ull}},
{{6968927299836069330ull, 5619153984023366662ull,
  9576684007883250594ull, 6610559687902485989ull}},
{{17934531161649862470ull, 16247314516883984135ull,
  16582541028281451146ull, 8263199609878107486ull}},
{{18126611003672245900ull, 14766257591479877988ull,
  5752402124248519062ull, 5164499756173817179ull}},
{{4211519680880755759ull, 9234449952495071678ull,
  2578816636883260924ull, 6455624695217271474ull}},
{{14487771637955720506ull, 11543062440618839597ull,
  12446892832958851963ull, 8069530869021589342ull}},
{{11360700282936019269ull, 4908571016173080796ull,
  3167622002171894573ull, 5043456793138493339ull}},
{{14200875353670024086ull, 10747399788643738899ull,
  17794585557997031928ull, 6304320991423116673ull}},
{{13139408173660142203ull, 13434249735804673624ull,
  8408173892214126198ull, 7880401239278895842ull}},
{{8212130108537588877ull, 3784720066450533111ull,
  9866794701061216778ull, 4925250774549309901ull}},
{{5653476617244598192ull, 13954272119917942197ull,
  16945179394753908876ull, 6156563468186637376ull}},
{{11678531789983135644ull, 17442840149897427746ull,
  2734730169732834479ull, 7695704335233296721ull}},
{{11910768387166847682ull, 17819304121326974197ull,
  13238421402151491309ull, 4809815209520810450ull}},
{{1053402428676395890ull, 8439072096376554035ull,
  7324654715834588329ull, 6012269011901013063ull}},
{{15151811091127658574ull, 15160526138898080447ull,
  4544132376365847507ull, 7515336264876266329ull}},
{{16387410959595868465ull, 7169485827597606327ull,
  14369297781297124452ull, 4697085165547666455ull}},
{{15872577681067447677ull, 8961857284497007909ull,
  13349936208194017661ull, 5871356456934583069ull}},
{{6005664046052145885ull, 15814007624048647791ull,
  2852362204960358364ull, 7339195571168228837ull}},
{{2895394039137794452ull, 1320765456351258123ull,
  8177138774627835860ull, 9173994463960286046ull}},
{{17950522338956979196ull, 10048850447074312134ull,
  499025715715009508ull, 5733746539975178779ull}},
{{13214780886841448187ull, 12561063058842890168ull,
  14458840199925925597ull, 7167183174968973473ull}},
{{16518476108551810234ull, 1866270768271448998ull,
  4238492194625243285ull, 8958978968711216842ull}},
{{5712361549417493492ull, 3472262239383349576ull,
  7260743640068164957ull, 5599361855444510526ull}},
{{7140451936771866865ull, 8952013817656574874ull,
  18299301586939982004ull, 6999202319305638157ull}},
{{18148936957819609390ull, 11190017272070718592ull,
  9039068928392813793ull, 8749002899132047697ull}},
{{11343085598637255869ull, 76231767403117264ull,
  17178633126313978381ull, 5468126811957529810ull}},
{{14178856998296569836ull, 4706975727681284484ull,
  12249919371037697168ull, 6835158514946912263ull}},
{{17723571247870712295ull, 5883719659601605605ull,
  10700713195369733556ull, 8543948143683640329ull}},
{{13383075039132889136ull, 12900696824105779311ull,
  18217160793174553232ull, 5339967589802275205ull}},
{{12117157780488723516ull, 16125871030132224139ull,
  8936392936186027828ull, 6674959487252844007ull}},
{{10534761207183516491ull, 1710594713955728558ull,
  6558805151805146882ull, 8343699359066055009ull}},
{{1972539736062309903ull, 5680807714649718253ull,
  15628468265946686561ull, 5214812099416284380ull}},
{{7077360688505275283ull, 11712695661739535720ull,
  1088841258723806585ull, 6518515124270355476ull}},
{{8846700860631594104ull, 805811521892255938ull, 1361051573404758232ull,
  8148143905337944345ull}},
{{10140874056322134219ull, 503632201182659961ull,
  12379872279446443655ull, 5092589940836215215ull}},
{{17287778588830055677ull, 14464598306760488663ull,
  10863154330880666664ull, 6365737426045269019ull}},
{{16998037217610181693ull, 18080747883450610829ull,
  8967256895173445426ull, 7957171782556586274ull}},
{{12929616270220057510ull, 15912153445584019672ull,
  10216221577910791295ull, 4973232364097866421ull}},
{{16162020337775071888ull, 15278505788552636686ull,
  17381962990815877023ull, 6216540455122333026ull}},
{{10979153385364064051ull, 14486446217263407954ull,
  12504081701665070471ull, 7770675568902916283ull}},
{{11473656884279927936ull, 15971557913430711827ull,
  5509208054326975092ull, 4856672230564322677ull}},
{{9730385086922522016ull, 1517703318078838168ull,
  11498196086336106770ull, 6070840288205403346ull}},
{{12162981358653152520ull, 11120501184453323518ull,
  5149373071065357654ull, 7588550360256754183ull}},
{{2990177330730832421ull, 2338627221855939295ull,
  10135887197056930390ull, 4742843975160471364ull}},
{{17572779718695704238ull, 12146656064174699926ull,
  12669858996321162987ull, 5928554968950589205ull}},
{{12742602611514854490ull, 10571634061790987004ull,
  2002265690119290022ull, 7410693711188236507ull}},
{{17187498669051559864ull, 1995585270191978973ull,
  17392317120820413928ull, 4631683569492647816ull}},
{{7649315281032286118ull, 2494481587739973717ull,
  3293652327315965794ull, 5789604461865809771ull}},
{{14173330119717745552ull, 12341474021529742954ull,
  17952123464427120954ull, 7237005577332262213ull}},
{{8493290612792406132ull, 6203470490057402885ull,
  8605096275251737481ull, 9046256971665327767ull}},
{{7614149642208947785ull, 15406384102354346563ull,
  12295714199673417781ull, 5653910607290829854ull}},
{{4906001034333796827ull, 5422922072660769492ull,
  6146270712736996419ull, 7067388259113537318ull}},
{{6132501292917246033ull, 2166966572398573961ull,
  16906210427776021332ull, 8834235323891921647ull}},
{{15362028354141748531ull, 10577726144603884533ull,
  17483910545001095188ull, 5521397077432451029ull}},
{{5367477387395021951ull, 13222157680754855667ull,
  8019830125969205273ull, 6901746346790563787ull}},
{{2097660715816389535ull, 2692639045661405872ull,
  5413101639034118688ull, 8627182933488204734ull}},
{{1311037947385243460ull, 1682899403538378670ull,
  17218246579678487892ull, 5391989333430127958ull}},
{{10862169471086330132ull, 2103624254422973337ull,
  12299436187743334057ull, 6739986666787659948ull}},
{{18189397857285300569ull, 7241216336456104575ull,
  15374295234679167571ull, 8424983333484574935ull}},
{{18285902688444394712ull, 2219917201071371407ull,
  16526463549315561588ull, 5265614583427859334ull}},
{{18245692342128105486ull, 2774896501339214259ull,
  11434707399789676177ull, 6582018229284824168ull}},
{{18195429409232743953ull, 8080306645101405728ull,
  14293384249737095221ull, 8227522786606030210ull}},
{{11372143380770464971ull, 7356034662402072532ull,
  13545051174513072417ull, 5142201741628768881ull}},
{{14215179225963081214ull, 13806729346429978569ull,
  3096255912859176809ull, 6427752177035961102ull}},
{{3933915977171687805ull, 3423353627755309500ull,
  13093691927928746820ull, 8034690221294951377ull}},
{{11682069522587080686ull, 11362968054201844245ull,
  1266028427314384906ull, 5021681388309344611ull}},
{{767528847951687146ull, 4980338030897529499ull,
  15417593589425144845ull, 6277101735386680763ull}},
{{14794469115221772644ull, 10837108557049299777ull,
  14660305968354043152ull, 7846377169233350954ull}},
{{2329014169372526047ull, 6773192848155812361ull,
  13774377248648664874ull, 4903985730770844346ull}},
{{7522953730143045462ull, 17689863097049541259ull,
  7994599523956055284ull, 6129982163463555433ull}},
{{4792006144251418924ull, 3665584797602374958ull,
  14604935423372457010ull, 7662477704329444291ull}},
{{16830061895439300539ull, 6902676516928872252ull,
  6822241630394091679ull, 4789048565205902682ull}},
{{2590833295589574058ull, 4016659627733702412ull,
  17751174074847390407ull, 5986310706507378352ull}},
{{3238541619486967573ull, 409138516239740111ull, 3742223519849686393ull,
  7482888383134222941ull}},
{{8941617539820436589ull, 11784926618718307329ull,
  4644732709119747947ull, 4676805239458889338ull}},
{{15788707943202933640ull, 10119472254970496257ull,
  15029287923254460742ull, 5846006549323611672ull}},
{{5900826873721503338ull, 3425968281858344514ull, 339865830358524312ull,
  7307508186654514591ull}},
{{16599405629006654981ull, 4282460352322930642ull,
  14259890343230319102ull, 9134385233318143238ull}},
{{14986314536556547267ull, 16511595775483995363ull,
  4300745446091561534ull, 5708990770823839524ull}},
{{14121207152268296180ull, 11416122682500218396ull,
  5375931807614451918ull, 7136238463529799405ull}},
{{17651508940335370225ull, 5046781316270497187ull,
  11331600777945452802ull, 8920298079412249256ull}},
{{8726350078495912439ull, 7765924341096448646ull,
  7082250486215908001ull, 5575186299632655785ull}},
{{1684565561265114740ull, 14319091444797948712ull,
  13464499126197272905ull, 6968982874540819731ull}},
{{2105706951581393425ull, 4063806250715272178ull,
  12218937889319203228ull, 8711228593176024664ull}},
{{5927752863165758795ull, 11763250943551820919ull,
  7636836180824502017ull, 5444517870735015415ull}},
{{2798005060529810589ull, 869005624157612437ull, 4934359207603239618ull,
  6805647338418769269ull}},
{{8109192344089651141ull, 10309629067051791354ull,
  10779635027931437426ull, 8507059173023461586ull}},
{{9679931233483419867ull, 11055204185334757500ull,
  11348957910884536295ull, 5316911983139663491ull}},
{{12099914041854274834ull, 9207319213241058971ull,
  9574511370178282465ull, 6646139978924579364ull}},
{{10513206533890455638ull, 16120835034978711618ull,
  11968139212722853081ull, 8307674973655724205ull}},
{{11182440102108922678ull, 3157992869220612905ull,
  9785930017165477128ull, 5192296858534827628ull}},
{{142992072353989635ull, 3947491086525766132ull,
  12232412521456846410ull, 6490371073168534535ull}},
{{178740090442487044ull, 14157735895011983473ull,
  10678829633393670108ull, 8112963841460668169ull}},
{{11640927602595024163ull, 18071956971237265478ull,
  18203483566939513577ull, 5070602400912917605ull}},
{{5327787466389004395ull, 8754888158764418136ull,
  8919296403392228260ull, 6338253001141147007ull}},
{{6659734332986255494ull, 10943610198455522670ull,
  6537434485812897421ull, 7922816251426433759ull}},
{{17997392013398573396ull, 9145599383248395620ull,
  11003425581274142744ull, 4951760157141521099ull}},
{{4049995943038665129ull, 11431999229060494526ull,
  9142595958165290526ull, 6189700196426901374ull}},
{{14285866965653107219ull, 5066626999470842349ull,
  2204872910851837350ull, 7737125245533626718ull}},
{{11234509862746885964ull, 17001699929951440180ull,
  15213103624564562055ull, 4835703278458516698ull}},
{{14043137328433607455ull, 16640438894011912321ull,
  9793007493850926761ull, 6044629098073145873ull}},
{{3718863605259845606ull, 6965490562232726690ull,
  16852945385741046356ull, 7555786372591432341ull}},
{{6935975771714791408ull, 13576803638250229989ull,
  12838933875301847924ull, 4722366482869645213ull}},
{{13281655733070877164ull, 16971004547812787486ull,
  2213609288845146193ull, 5902958103587056517ull}},
{{7378697629483820647ull, 7378697629483820646ull,
  7378697629483820646ull, 7378697629483820646ull}},
{{0ull, 0ull, 0ull, 9223372036854775808ull}},
{{0ull, 0ull, 0ull, 5764607523034234880ull}},
{{0ull, 0ull, 0ull, 7205759403792793600ull}},
{{0ull, 0ull, 0ull, 9007199254740992000ull}},
{{0ull, 0ull, 0ull, 5629499534213120000ull}},
{{0ull, 0ull, 0ull, 7036874417766400000ull}},
{{0ull, 0ull, 0ull, 8796093022208000000ull}},
{{0ull, 0ull, 0ull, 5497558138880000000ull}},
{{0ull, 0ull, 0ull, 6871947673600000000ull}},
{{0ull, 0ull, 0ull, 8589934592000000000ull}},
{{0ull, 0ull, 0ull, 5368709120000000000ull}},
{{0ull, 0ull, 0ull, 6710886400000000000ull}},
{{0ull, 0ull, 0ull, 8388608000000000000ull}},
{{0ull, 0ull, 0ull, 5242880000000000000ull}},
{{0ull, 0ull, 0ull, 6553600000000000000ull}},
{{0ull, 0ull, 0ull, 8192000000000000000ull}},
{{0ull, 0ull, 0ull, 5120000000000000000ull}},
{{0ull, 0ull, 0ull, 6400000000000000000ull}},
{{0ull, 0ull, 0ull, 8000000000000000000ull}},
{{0ull, 0ull, 0ull, 5000000000000000000ull}},
{{0ull, 0ull, 0ull, 6250000000000000000ull}},
{{0ull, 0ull, 0ull, 7812500000000000000ull}},
{{0ull, 0ull, 0ull, 4882812500000000000ull}},
{{0ull, 0ull, 0ull, 6103515625000000000ull}},
{{0ull, 0ull, 0ull, 7629394531250000000ull}},
{{0ull, 0ull, 0ull, 4768371582031250000ull}},
{{0ull, 0ull, 0ull, 5960464477539062500ull}},
{{0ull, 0ull, 0ull, 7450580596923828125ull}},
{{0ull, 0ull, 2305843009213693952ull, 4656612873077392578ull}},
{{0ull, 0ull, 12105675798371893248ull, 5820766091346740722ull}},
{{0ull, 0ull, 5908722711110090752ull, 7275957614183425903ull}},
{{0ull, 0ull, 2774217370460225536ull, 9094947017729282379ull}},
{{0ull, 0ull, 17874786921033498624ull, 5684341886080801486ull}},
{{0ull, 0ull, 13120111614437097472ull, 7105427357601001858ull}},
{{0ull, 0ull, 7176767481191596032ull, 8881784197001252323ull}},
{{0ull, 0ull, 2179636666531053568ull, 5551115123125782702ull}},
{{0ull, 0ull, 11947917870018592768ull, 6938893903907228377ull}},
{{0ull, 0ull, 1099839282241077248ull, 8673617379884035472ull}},
{{0ull, 0ull, 687399551400673280ull, 5421010862427522170ull}},
{{0ull, 0ull, 10082621476105617408ull, 6776263578034402712ull}},
{{0ull, 0ull, 12603276845132021760ull, 8470329472543003390ull}},
{{0ull, 0ull, 3265362009780125696ull, 5293955920339377119ull}},
{{0ull, 0ull, 17916760567507320832ull, 6617444900424221398ull}},
{{0ull, 0ull, 13172578672529375232ull, 8271806125530276748ull}},
{{0ull, 0ull, 17456233707185635328ull, 5169878828456422967ull}},
{{0ull, 0ull, 17208606115554656256ull, 6462348535570528709ull}},
{{0ull, 0ull, 7675699589161156608ull, 8077935669463160887ull}},
{{0ull, 0ull, 11714841270866804736ull, 5048709793414475554ull}},
{{0ull, 0ull, 5420179551728730112ull, 6310887241768094443ull}},
{{0ull, 0ull, 2163538421233524736ull, 7888609052210118054ull}},
{{0ull, 0ull, 15187269568553116672ull, 4930380657631323783ull}},
{{0ull, 0ull, 14372400942264007936ull, 6162975822039154729ull}},
{{0ull, 0ull, 4130443122547846208ull, 7703719777548943412ull}},
{{0ull, 0ull, 11804898988447179688ull, 4814824860968089632ull}},
{{0ull, 0ull, 14756123735558974610ull, 6018531076210112040ull}},
{{0ull, 9223372036854775808ull, 18445154669448718262ull,
  7523163845262640050ull}},
{{0ull, 1152921504606846976ull, 16139907686832836818ull,
  4701977403289150031ull}},
{{0ull, 10664523917613334528ull, 15563198590113658118ull,
  5877471754111437539ull}},
{{0ull, 4107282860161892352ull, 14842312219214684744ull,
  7346839692639296924ull}},
{{0ull, 5134103575202365440ull, 106146200308804314ull,
  9183549615799121156ull}},
{{0ull, 7820500752928866304ull, 9289713412047778504ull,
  5739718509874450722ull}},
{{0ull, 9775625941161082880ull, 2388769728204947322ull,
  7174648137343063403ull}},
{{0ull, 2996160389596577792ull, 16821020215538347865ull,
  8968310171678829253ull}},
{{0ull, 13401815289566330880ull, 12818980643925161367ull,
  5605193857299268283ull}},
{{0ull, 12140583093530525696ull, 11412039786479063805ull,
  7006492321624085354ull}},
{{0ull, 1340670811630993408ull, 5041677696244053949ull,
  8758115402030106693ull}},
{{0ull, 3143762266483064832ull, 5456891569366227670ull,
  5473822126268816683ull}},
{{0ull, 13153074869958606848ull, 2209428443280396683ull,
  6842277657836020854ull}},
{{0ull, 11829657569020870656ull, 11985157590955271662ull,
  8552847072295026067ull}},
{{0ull, 2781849962210656256ull, 5184880485133350837ull,
  5345529420184391292ull}},
{{0ull, 8088998471190708224ull, 6481100606416688546ull,
  6681911775230489115ull}},
{{0ull, 887876052133609472ull, 3489689739593472779ull,
  8352389719038111394ull}},
{{0ull, 16695823597079363584ull, 6792742105673308390ull,
  5220243574398819621ull}},
{{0ull, 11646407459494428672ull, 13102613650519023392ull,
  6525304467998524526ull}},
{{0ull, 14558009324368035840ull, 7154895026294003432ull,
  8156630584998155658ull}},
{{0ull, 9098755827730022400ull, 9083495409861140049ull,
  5097894115623847286ull}},
{{0ull, 15985130803089915904ull, 2130997225471649253ull,
  6372367644529809108ull}},
{{0ull, 6146355448580231168ull, 2663746531839561567ull,
  7965459555662261385ull}},
{{0ull, 10759001183003726336ull, 13194056628468195739ull,
  4978412222288913365ull}},
{{0ull, 8837065460327270016ull, 2657512730303080962ull,
  6223015277861141707ull}},
{{0ull, 1822959788554311712ull, 17156948968161014915ull,
  7778769097326427133ull}},
{{0ull, 17280250932342302484ull, 13028936114314328273ull,
  4861730685829016958ull}},
{{0ull, 7765255610145714393ull, 7062798106038134534ull,
  6077163357286271198ull}},
{{4611686018427387904ull, 483197475827367183ull,
  18051869669402443976ull, 7596454196607838997ull}},
{{9799832789158199296ull, 301998422392104489ull,
  13588261552590221437ull, 4747783872879899373ull}},
{{16861477004875137024ull, 4989184046417518515ull,
  3150268885455613084ull, 5934729841099874217ull}},
{{16465160237666533376ull, 6236480058021898144ull,
  8549522125246904259ull, 7418412301374842771ull}},
{{10290725148541583360ull, 1591957027049992388ull,
  3037608319065621210ull, 4636507688359276732ull}},
{{12863406435676979200ull, 11213318320667266293ull,
  3797010398832026512ull, 5795634610449095915ull}},
{{2244199989314060288ull, 14016647900834082867ull,
  134576980112645236ull, 7244543263061369894ull}},
{{16640308041924739072ull, 17520809876042603583ull,
  9391593261995582353ull, 9055679078826712367ull}},
{{17317721553844043776ull, 4032977144885545383ull,
  12787274816388320827ull, 5659799424266695229ull}},
{{17035465923877666816ull, 429535412679543825ull,
  2149035465203237322ull, 7074749280333369037ull}},
{{7459274349564919808ull, 9760291302704205590ull,
  7297980349931434556ull, 8843436600416711296ull}},
{{50360450050686976ull, 15323554101044904302ull, 4561237718707146597ull,
  5527147875260444560ull}},
{{9286322599418134528ull, 5319384571023966665ull,
  5701547148383933247ull, 6908934844075555700ull}},
{{16219589267700056064ull, 2037544695352570427ull,
  7126933935479916559ull, 8636168555094444625ull}},
{{7831400283098841088ull, 8190994462236438373ull,
  15983548755743417609ull, 5397605346934027890ull}},
{{14400936372300939264ull, 14850429096222935870ull,
  10756063907824496203ull, 6747006683667534863ull}},
{{8777798428521398272ull, 13951350351851281934ull,
  8833393866353232350ull, 8433758354584418579ull}},
{{874437999398486016ull, 4107907951479663305ull, 3215028157257076267ull,
  5271098971615261612ull}},
{{5704733517675495424ull, 523198920922191227ull, 4018785196571345334ull,
  6588873714519077015ull}},
{{2519230878666981376ull, 9877370688007514842ull, 411795477286793763ull,
  8236092143148846269ull}},
{{6186205317594251264ull, 3867513670791002824ull,
  2563215182517940054ull, 5147557589468028918ull}},
{{7732756646992814080ull, 14057764125343529338ull,
  12427391015002200875ull, 6434446986835036147ull}},
{{442573771886241792ull, 12960519138252023769ull,
  10922552750325363190ull, 8043058733543795184ull}},
{{11805823653497370880ull, 3488638442980126951ull,
  6826595468953351994ull, 5026911708464871990ull}},
{{10145593548444325696ull, 13584170090579934497ull,
  17756616373046465800ull, 6283639635581089987ull}},
{{17293677953982795024ull, 16980212613224918121ull,
  17584084447880694346ull, 7854549544476362484ull}},
{{3891019693598165034ull, 15224318901692961730ull,
  1766680743070658158ull, 4909093465297726553ull}},
{{14087146653852482101ull, 9807026590261426354ull,
  6820036947265710602ull, 6136366831622158191ull}},
{{8385561280460826818ull, 3035411200972007135ull,
  3913360165654750349ull, 7670458539527697739ull}},
{{12158504827929098618ull, 4202975009821198411ull,
  140007094320525016ull, 4794036587204811087ull}},
{{10586445016483985368ull, 5253718762276498014ull,
  14010066923182819982ull, 5992545734006013858ull}},
{{4009684233750205902ull, 15790520489700398326ull,
  8289211617123749169ull, 7490682167507517323ull}},
{{16341110701376042401ull, 2951546278421667097ull,
  2874914251488649279ull, 4681676354692198327ull}},
{{6591330321437889289ull, 17524490903309247584ull,
  17428700869642975310ull, 5852095443365247908ull}},
{{8239162901797361611ull, 12682241592281783672ull,
  3339132013344167522ull, 7315119304206559886ull}},
{{10298953627246702013ull, 6629429953497453782ull,
  13397287053534985211ull, 9143899130258199857ull}},
{{1825159998601800855ull, 1837550711722214662ull,
  1455775380818283901ull, 5714936956411374911ull}},
{{11504822035107026876ull, 6908624408080156231ull,
  15654777281305018588ull, 7143671195514218638ull}},
{{9769341525456395691ull, 8635780510100195289ull,
  10345099564776497427ull, 8929588994392773298ull}},
{{17635053499478717067ull, 3091519809598928103ull,
  11077373246412698796ull, 5580993121495483311ull}},
{{17432130855921008430ull, 3864399761998660129ull,
  9235030539588485591ull, 6976241401869354139ull}},
{{7955105514619096825ull, 218813684070937258ull, 6932102156058219085ull,
  8720301752336692674ull}},
{{9583626965064323420ull, 2442601561758029738ull,
  8944249865963774832ull, 5450188595210432921ull}},
{{2756161669475628467ull, 3053251952197537173ull,
  15791998350882106444ull, 6812735744013041151ull}},
{{8056888105271923487ull, 3816564940246921466ull,
  15128311920175245151ull, 8515919680016301439ull}},
{{9647241084222340084ull, 9302882115295407772ull,
  16372723977750610075ull, 5322449800010188399ull}},
{{12059051355277925104ull, 7016916625691871811ull,
  15854218953760874690ull, 6653062250012735499ull}},
{{10462128175670018476ull, 17994517818969615572ull,
  15206087673773705458ull, 8316327812515919374ull}},
{{15762202146648537356ull, 15858259655283397636ull,
  4892118777681178007ull, 5197704882822449609ull}},
{{1256008609601120079ull, 15211138550676859142ull,
  10726834490528860413ull, 6497131103528062011ull}},
{{10793382798856175906ull, 5178865133063910215ull,
  8796857094733687613ull, 8121413879410077514ull}},
{{13663393276926191798ull, 5542633717378637836ull,
  10109721702635942662ull, 5075883674631298446ull}},
{{17079241596157739747ull, 16151664183578073103ull,
  3413780091440152519ull, 6344854593289123058ull}},
{{16737365976769786780ull, 15577894211045203475ull,
  13490597151154966457ull, 7931068241611403822ull}},
{{8155010726267422785ull, 2818654854262170316ull,
  3819937201044466132ull, 4956917651007127389ull}},
{{10193763407834278482ull, 3523318567827712895ull,
  9386607519732970569ull, 6196147063758909236ull}},
{{8130518241365460198ull, 9015834228212029023ull,
  11733259399666213211ull, 7745183829698636545ull}},
{{11999102928494494480ull, 3329053383418824187ull,
  415758097150301401ull, 4840739893561647841ull}},
{{10387192642190730196ull, 8773002747700918138ull,
  5131383639865264655ull, 6050924866952059801ull}},
{{3760618765883636937ull, 6354567416198759769ull,
  11025915568258968723ull, 7563656083690074751ull}},
{{13879601774745742846ull, 1665761625910530903ull,
  13808726257802937308ull, 4727285052306296719ull}},
{{12737816200004790653ull, 2082202032388163629ull,
  12649221803826283731ull, 5909106315382870899ull}},
{{2087212194723824604ull, 16437810595767368249ull,
  11199841236355466759ull, 7386382894228588624ull}},
{{12833722667770860138ull, 17191160649995687011ull,
  6999900772722166724ull, 4616489308892867890ull}},
{{11430467316286187268ull, 3042206738785057148ull,
  17973248002757484214ull, 5770611636116084862ull}},
{{14288084145357734085ull, 13026130460336097243ull,
  13243187966592079459ull, 7213264545145106078ull}},
{{13248419163269779702ull, 11670977056992733650ull,
  7330612921385323516ull, 9016580681431382598ull}},
{{12891947995471000218ull, 16517732697475234339ull,
  18416691131147990909ull, 5635362925894614123ull}},
{{11503248975911362368ull, 6812107816561879212ull,
  18409177895507600733ull, 7044203657368267654ull}},
{{14379061219889202960ull, 13126820789129736919ull,
  13788100332529725108ull, 8805254571710334568ull}},
{{15904442290071833706ull, 17427635030060861382ull,
  8617562707831078192ull, 5503284107318959105ull}},
{{10657180825735016325ull, 3337799713866525112ull,
  15383639403216235645ull, 6879105134148698881ull}},
{{13321476032168770406ull, 8783935660760544294ull,
  5394491198738130844ull, 8598881417685873602ull}},
{{3714236501678093600ull, 14713331824830115992ull,
  7983243017638719681ull, 5374300886053671001ull}},
{{4642795627097617000ull, 4556606725755481278ull,
  14590739790475787506ull, 6717876107567088751ull}},
{{15026866570726797057ull, 14919130444049127405ull,
  13626738719667346478ull, 8397345134458860939ull}},
{{11697634615917942113ull, 4712770509103316724ull,
  6210868690578397597ull, 5248340709036788087ull}},
{{14622043269897427641ull, 10502649154806533809ull,
  3151899844795609092ull, 6560425886295985109ull}},
{{4442496032089620839ull, 13128311443508167262ull,
  8551560824421899269ull, 8200532357869981386ull}},
{{16611618075338176737ull, 10511037661406298490ull,
  9956411533691074947ull, 5125332723668738366ull}},
{{11541150557317945113ull, 8527111058330485209ull,
  3222142380259067876ull, 6406665904585922958ull}},
{{591380141365267679ull, 10658888822913106512ull,
  13251050012178610653ull, 8008332380732403697ull}},
{{369612588353292299ull, 8967648523534385522ull, 1364377229970549802ull,
  5005207737957752311ull}},
{{9685387772296391182ull, 1986188617563206094ull,
  15540529592745350965ull, 6256509672447190388ull}},
{{2883362678515713170ull, 7094421790381395522ull, 978917917222137090ull,
  7820637090558987986ull}},
{{6413787692499708635ull, 9045699637415760105ull,
  5223509716691223585ull, 4887898181599367491ull}},
{{12628920634052023698ull, 15918810565197088035ull,
  1917701127436641577ull, 6109872726999209364ull}},
{{11174464774137641718ull, 6063455151214196332ull,
  2397126409295801972ull, 7637340908749011705ull}},
{{16207412520690801882ull, 13013031506363648515ull,
  13027419051878345992ull, 4773338067968132315ull}},
{{15647579632436114448ull, 16266289382954560644ull,
  11672587796420544586ull, 5966672584960165394ull}},
{{1112730466835591444ull, 11109489691838424998ull,
  5367362708670904925ull, 7458340731200206743ull}},
{{14530514597054408365ull, 9249274066612709575ull,
  10272130720560397434ull, 4661462957000129214ull}},
{{13551457227890622552ull, 2338220546411111161ull,
  3616791363845720985ull, 5826828696250161518ull}},
{{3104263479581114478ull, 7534461701441276856ull,
  13744361241661927039ull, 7283535870312701897ull}},
{{3880329349476393097ull, 4806391108374208166ull,
  3345393496795245087ull, 9104419837890877372ull}},
{{16260263898704909398ull, 9921523470374961959ull,
  11314242972351803987ull, 5690262398681798357ull}},
{{15713643854953748843ull, 7790218319541314545ull,
  307745660157591272ull, 7112827998352247947ull}},
{{5806996763410022342ull, 9737772899426643182ull,
  14219740130479152802ull, 8891034997940309933ull}},
{{17464431032413427676ull, 10697794080569039892ull,
  11193180590763164453ull, 5556896873712693708ull}},
{{3383794716807232979ull, 17983928619138687770ull,
  13991475738453955566ull, 6946121092140867135ull}},
{{13453115432863817032ull, 13256538737068583904ull,
  12877658654640056554ull, 8682651365176083919ull}},
{{8408197145539885645ull, 12897022729095252844ull,
  14966065686791117202ull, 5426657103235052449ull}},
{{10510246431924857056ull, 6897906374514290247ull,
  4872524053206732791ull, 6783321379043815562ull}},
{{8526122021478683416ull, 4010696949715474905ull,
  15314027103363191797ull, 8479151723804769452ull}},
{{16858041309492646895ull, 4812528602785865767ull,
  347894902747219065ull, 5299469827377980908ull}},
{{16460865618438420715ull, 10627346771909720113ull,
  434868628434023831ull, 6624337284222476135ull}},
{{6741023967765862181ull, 8672497446459762238ull,
  14378643840824693501ull, 8280421605278095168ull}},
{{18048198035135827576ull, 7726153913251045350ull,
  8986652400515433438ull, 5175263503298809480ull}},
{{13336875507065008661ull, 434320354709030880ull,
  11233315500644291798ull, 6469079379123511850ull}},
{{16671094383831260826ull, 9766272480241064408ull,
  4818272338950588939ull, 8086349223904389813ull}},
{{10419433989894538017ull, 3798077290936971303ull,
  5317263221057812039ull, 5053968264940243633ull}},
{{8412606468940784617ull, 135910595243826225ull,
  11258265044749652953ull, 6317460331175304541ull}},
{{15127444104603368675ull, 4781574262482170685ull,
  237773250654902479ull, 7896825413969130677ull}},
{{11760495574590799374ull, 9906012941692438534ull,
  2454451290873008001ull, 4935515883730706673ull}},
{{5477247431383723409ull, 16994202195542936072ull,
  7679750132018647905ull, 6169394854663383341ull}},
{{6846559289229654262ull, 7407694689146506378ull,
  14211373683450697786ull, 7711743568329229176ull}},
{{8890785574195921818ull, 9241495199143954390ull,
  8882108552156686116ull, 4819839730205768235ull}},
{{1890109930890126464ull, 11551868998929942988ull,
  6490949671768469741ull, 6024799662757210294ull}},
{{2362637413612658080ull, 604778193380265023ull,
  17337059126565362985ull, 7530999578446512867ull}},
{{8394177411148993156ull, 11907201416931135399ull,
  8529818944889657913ull, 4706874736529070542ull}},
{{5881035745508853541ull, 1048943715881755537ull,
  1438901644257296584ull, 5883593420661338178ull}},
{{11962980700313454830ull, 1311179644852194421ull,
  11021999092176396538ull, 7354491775826672722ull}},
{{1118667820109654825ull, 10862346592920018835ull,
  4554126828365719864ull, 9193114719783340903ull}},
{{16840068452064391930ull, 6788966620575011771ull,
  9763858295369656771ull, 5745696699864588064ull}},
{{16438399546653102009ull, 3874522257291376810ull,
  12204822869212070964ull, 7182120874830735080ull}},
{{11324627396461601703ull, 4843152821614221013ull,
  15256028586515088705ull, 8977651093538418850ull}},
{{9383735132002195016ull, 14556185559577357893ull,
  14146703884999318344ull, 5611031933461511781ull}},
{{16341354933430131674ull, 18195231949471697366ull,
  3848321800966984218ull, 7013789916826889727ull}},
{{11203321629932888785ull, 13520667899984845900ull,
  198716232781342369ull, 8767237396033612159ull}},
{{16225448055562831299ull, 1532888409849446831ull,
  7041726673129420837ull, 5479523372521007599ull}},
{{15670124051026151219ull, 6527796530739196443ull,
  4190472322984388142ull, 6849404215651259499ull}},
{{14975969045355301120ull, 17383117700278771362ull,
  626404385303097273ull, 8561755269564074374ull}},
{{13971666671774451104ull, 3946919535033150245ull,
  14226560796096599508ull, 5351097043477546483ull}},
{{3629525284435900168ull, 4933649418791437807ull,
  13171514976693361481ull, 6688871304346933104ull}},
{{18371964660827038922ull, 10778747791916685162ull,
  16464393720866701851ull, 8361089130433666380ull}},
{{16094163931444287230ull, 4430874360734234274ull,
  1066874038686912849ull, 5225680706521041488ull}},
{{10894332877450583230ull, 10150278969345180747ull,
  1333592548358641061ull, 6532100883151301860ull}},
{{9006230078385841133ull, 17299534730108863838ull,
  1666990685448301326ull, 8165126103939127325ull}},
{{1017207780563762804ull, 6200523187890651995ull,
  3347712187618882281ull, 5103203814961954578ull}},
{{15106567780986867217ull, 12362340003290702897ull,
  13408012271378378659ull, 6379004768702443222ull}},
{{5048151670951420310ull, 10841238985685990718ull,
  7536643302368197516ull, 7973755960878054028ull}},
{{16990152849626801406ull, 15999146402908520006ull,
  13933774100834899255ull, 4983597475548783767ull}},
{{12014319025178725949ull, 15387246985208262104ull,
  12805531607616236165ull, 6229496844435979709ull}},
{{15017898781473407436ull, 5399000676228163918ull,
  2171856454238131495ull, 7786871055544974637ull}},
{{4774500719993491744ull, 10291904450283684305ull,
  3663253293112526136ull, 4866794409715609148ull}},
{{10579811918419252584ull, 12864880562854605381ull,
  4579066616390657670ull, 6083493012144511435ull}},
{{17836450916451453633ull, 6857728666713480918ull,
  1112147252060934184ull, 7604366265180639294ull}},
{{6536095804354770617ull, 4286080416695925574ull,
  14530150087820247577ull, 4752728915737899558ull}},
{{17393491792298239079ull, 9969286539297294871ull,
  8939315572920533663ull, 5940911144672374448ull}},
{{17130178721945410945ull, 7849922155694230685ull,
  11174144466150667079ull, 7426138930840468060ull}},
{{13012204710429575793ull, 11823730374949976034ull,
  16207212328198942732ull, 4641336831775292537ull}},
{{7041883851182193933ull, 14779662968687470043ull,
  6423957354966514703ull, 5801671039719115672ull}},
{{4190668795550354512ull, 13862892692431949650ull,
  8029946693708143379ull, 7252088799648894590ull}},
{{14461708031292718948ull, 12716929847112549158ull,
  814061330280403416ull, 9065110999561118238ull}},
{{4426881501130561438ull, 7948081154445343224ull,
  14343846386707415847ull, 5665694374725698898ull}},
{{5533601876413201798ull, 5323415424629291126ull,
  8706435946529494001ull, 7082117968407123623ull}},
{{16140374382371278055ull, 11265955299214001811ull,
  6271358914734479597ull, 8852647460508904529ull}},
{{7781890979768354833ull, 9347065071222445084ull,
  15448814367777519508ull, 5532904662818065330ull}},
{{9727363724710443541ull, 11683831339028056355ull,
  10087645922867123577ull, 6916130828522581663ull}},
{{7547518637460666522ull, 769731118502906732ull, 7997871385156516568ull,
  8645163535653227079ull}},
{{13940571185267692384ull, 481081949064316707ull,
  11916198643363904711ull, 5403227209783266924ull}},
{{12814027963157227576ull, 14436410491612559596ull,
  14895248304204880888ull, 6754034012229083655ull}},
{{16017534953946534470ull, 18045513114515699495ull,
  14007374361828713206ull, 8442542515286354569ull}},
{{16928488373857665900ull, 6666759678144924280ull,
  1837079948501863898ull, 5276589072053971606ull}},
{{2713866393612530759ull, 17556821634535931159ull,
  11519721972482105680ull, 6595736340067464507ull}},
{{17227391047297827161ull, 3499282969460362332ull,
  9787966447175244197ull, 8244670425084330634ull}},
{{1543747367706366168ull, 4492894865126420410ull,
  10729165047911915527ull, 5152919015677706646ull}},
{{11153056246487733517ull, 1004432562980637608ull,
  4188084273035118601ull, 6441148769597133308ull}},
{{13941320308109666897ull, 5867226722153184914ull,
  5235105341293898251ull, 8051435961996416635ull}},
{{13325011210995929715ull, 1361173692132046619ull,
  966097829094992455ull, 5032147476247760397ull}},
{{12044577995317524239ull, 15536525170447221986ull,
  5819308304796128472ull, 6290184345309700496ull}},
{{5832350457292129491ull, 973912389349475867ull, 7274135380995160591ull,
  7862730431637125620ull}},
{{1339376026593886980ull, 7526224270984504273ull,
  13769706649976751177ull, 4914206519773203512ull}},
{{6285906051669746629ull, 14019466357158018245ull,
  17212133312470938971ull, 6142758149716504390ull}},
{{12469068583014571190ull, 12912646928020134902ull,
  12291794603733897906ull, 7678447687145630488ull}},
{{3181481845956719090ull, 12682090348439972218ull,
  7682371627333686191ull, 4799029804466019055ull}},
{{13200224344300674670ull, 11240926917122577368ull,
  4991278515739719835ull, 5998787255582523819ull}},
{{16500280430375843337ull, 9439472627975833806ull,
  1627412126247261890ull, 7498484069478154774ull}},
{{5700989250557514182ull, 10511356410912284033ull,
  14852190634186702393ull, 4686552543423846733ull}},
{{11737922581624280632ull, 17750881532067742945ull,
  4730180237451214279ull, 5858190679279808417ull}},
{{837345171748187077ull, 17576915896657290778ull,
  10524411315241405753ull, 7322738349099760521ull}},
{{10270053501540009654ull, 8136086815539449760ull,
  17767200162479145096ull, 9153422936374700651ull}},
{{6418783438462506034ull, 5085054259712156100ull,
  8798657092335771733ull, 5720889335234187907ull}},
{{8023479298078132543ull, 10968003843067583029ull,
  6386635346992326762ull, 7151111669042734884ull}},
{{14641035141025053582ull, 4486632766979702978ull,
  7983294183740408453ull, 8938889586303418605ull}},
{{13762332981568046393ull, 5109988488576008313ull,
  7295401874051449235ull, 5586805991439636628ull}},
{{3367858171677894279ull, 1775799592292622488ull,
  9119252342564311544ull, 6983507489299545785ull}},
{{4209822714597367849ull, 2219749490365778110ull,
  16010751446632777334ull, 8729384361624432231ull}},
{{16466197251905518618ull, 15222401486760775030ull,
  16924248681786567689ull, 5455865226015270144ull}},
{{11359374528027122464ull, 5192943803168805076ull,
  2708566778523657996ull, 6819831532519087681ull}},
{{14199218160033903080ull, 6491179753961006345ull,
  7997394491581960399ull, 8524789415648859601ull}},
{{1956982322380107569ull, 10974516373866710822ull,
  16527586603307195009ull, 5327993384780537250ull}},
{{11669599939829910269ull, 18329831485760776431ull,
  11436111217279217953ull, 6659991730975671563ull}},
{{9975313906359999932ull, 9077231301918806827ull,
  9683453003171634538ull, 8324989663719589454ull}},
{{3928728182261306006ull, 10284955582126642171ull,
  1440472108554883682ull, 5203118539824743409ull}},
{{299224209399244603ull, 3632822440803526906ull, 6412276154120992507ull,
  6503898174780929261ull}},
{{9597402298603831562ull, 18376086106286572344ull,
  12627031211078628537ull, 8129872718476161576ull}},
{{5998376436627394726ull, 4567524788788025859ull,
  7891894506924142836ull, 5081170449047600985ull}},
{{2886284527356855504ull, 5709405985985032324ull,
  14476554152082566449ull, 6351463061309501231ull}},
{{3607855659196069380ull, 11748443500908678309ull,
  13484006671675820157ull, 7939328826636876539ull}},
{{4560752796211237315ull, 9648620197281617895ull,
  6121661160583693646ull, 4962080516648047837ull}},
{{1089254976836658739ull, 2837403209747246561ull,
  12263762469157004962ull, 6202600645810059796ull}},
{{5973254739473211328ull, 12770126049038834009ull,
  15329703086446256202ull, 7753250807262574745ull}},
{{15262499258239226840ull, 12593014799076659159ull,
  2663535401387828270ull, 4845781754539109216ull}},
{{14466438054371645646ull, 6517896461991048141ull,
  3329419251734785338ull, 6057227193173886520ull}},
{{4247989512682393345ull, 17370742614343585985ull,
  4161774064668481672ull, 7571533991467358150ull}},
{{14184208491494965601ull, 10856714133964741240ull,
  16436166845699964757ull, 4732208744667098843ull}},
{{17730260614368707001ull, 18182578685883314454ull,
  15933522538697568042ull, 5915260930833873554ull}},
{{12939453731106107943ull, 13504851320499367260ull,
  10693531136517184245ull, 7394076163542341943ull}},
{{17310530618796093273ull, 10746375084525798489ull,
  13600985987964322009ull, 4621297602213963714ull}},
{{7803105218212952879ull, 18044654874084636016ull,
  7777860448100626703ull, 5776622002767454643ull}},
{{9753881522766191098ull, 17944132574178407116ull,
  5110639541698395475ull, 7220777503459318304ull}},
{{12192351903457738873ull, 17818479699295620991ull,
  6388299427122994344ull, 9025971879324147880ull}},
{{14537748967302168652ull, 11136549812059763119ull,
  3992687141951871465ull, 5641232424577592425ull}},
{{13560500190700322911ull, 85629209792540187ull, 9602544945867227236ull,
  7051540530721990531ull}},
{{12338939219948015734ull, 107036512240675234ull,
  7391495163906646141ull, 8814425663402488164ull}},
{{12323523030894897738ull, 2372740829364115973ull,
  13843056514296429646ull, 5509016039626555102ull}},
{{1569345733336458460ull, 12189298073559920775ull,
  8080448606015761249ull, 6886270049533193878ull}},
{{15796740221952736787ull, 1401564536667737256ull,
  877188720664925754ull, 8607837561916492348ull}},
{{9872962638720460492ull, 5487663853844723689ull,
  9771614987270354404ull, 5379898476197807717ull}},
{{16952889316827963519ull, 6859579817305904611ull,
  16826204752515330909ull, 6724873095247259646ull}},
{{16579425627607566495ull, 13186160790059768668ull,
  11809383903789387828ull, 8406091369059074558ull}},
{{1138768980399953251ull, 17464722530642131226ull,
  2769178921440979488ull, 5253807105661921599ull}},
{{10646833262354717372ull, 3384159089593112416ull,
  17296531707083388073ull, 6567258882077401998ull}},
{{13308541577943396715ull, 8841884880418778424ull,
  12397292596999459283ull, 8209073602596752498ull}},
{{8317838486214622947ull, 3220335041048042563ull,
  12359993891552049956ull, 5130671001622970311ull}},
{{5785612089340890780ull, 4025418801310053204ull,
  10838306346012674541ull, 6413338752028712889ull}},
{{7232015111676113475ull, 9643459520064954409ull,
  18159568950943231080ull, 8016673440035891111ull}},
{{16049224490866040682ull, 6027162200040596505ull,
  18267259621980601281ull, 5010420900022431944ull}},
{{6226472558300387140ull, 12145638768478133536ull,
  4387330453766199985ull, 6263026125028039931ull}},
{{7783090697875483925ull, 1346990405315503208ull, 872477048780362078ull,
  7828782656285049914ull}},
{{4864431686172177453ull, 14676927058604353217ull,
  5156984173915114202ull, 4892989160178156196ull}},
{{10692225626142609721ull, 9122786786400665713ull,
  6446230217393892753ull, 6116236450222695245ull}},
{{17976968051105650055ull, 16015169501428220045ull,
  12669473790169753845ull, 7645295562778369056ull}},
{{13541448041154725236ull, 12315323947606331480ull,
  7918421118856096153ull, 4778309726736480660ull}},
{{16926810051443406545ull, 1559096879225750638ull,
  9898026398570120192ull, 5972887158420600825ull}},
{{11935140527449482373ull, 1948871099032188298ull,
  16984219016640038144ull, 7466108948025751031ull}},
{{12071148848083314388ull, 1218044436895117686ull,
  17532665913041105696ull, 4666318092516094394ull}},
{{5865564023249367176ull, 1522555546118897108ull,
  12692460354446606312ull, 5832897615645117993ull}},
{{7331955029061708970ull, 1903194432648621385ull,
  2030517387776094178ull, 7291122019556397492ull}},
{{13776629804754524117ull, 11602365077665552539ull,
  2538146734720117722ull, 9113902524445496865ull}},
{{6304550618757883621ull, 11863164191968358241ull,
  13115556755268543336ull, 5696189077778435540ull}},
{{12492374291874742430ull, 14828955239960447801ull,
  16394445944085679170ull, 7120236347223044425ull}},
{{1780409809561264326ull, 9312822013095783944ull,
  6657999374824935251ull, 8900295434028805532ull}},
{{1112756130975790204ull, 3514670748971171013ull,
  13384621646120360340ull, 5562684646268003457ull}},
{{6002631182147125659ull, 4393338436213963766ull,
  2895719002368286713ull, 6953355807835004322ull}},
{{16726661014538682881ull, 10103359063694842611ull,
  12843020789815134199ull, 8691694759793755402ull}},
{{8148320124872982849ull, 13232128442450358488ull,
  12638574012061846778ull, 5432309224871097126ull}},
{{10185400156091228561ull, 7316788516208172302ull,
  6574845478222532665ull, 6790386531088871408ull}},
{{3508378158259259893ull, 13757671663687603282ull,
  8218556847778165831ull, 8487983163861089260ull}},
{{6804422367339425337ull, 15516073817445833907ull,
  14359970066716129452ull, 5304989477413180787ull}},
{{3893841940746893768ull, 948348198097740768ull,
  13338276564967773912ull, 6631236846766475984ull}},
{{4867302425933617209ull, 1185435247622175960ull,
  16672845706209717390ull, 8289046058458094980ull}},
{{3042064016208510756ull, 14575955085046023687ull,
  1197156529526297560ull, 5180653786536309363ull}},
{{17637638075542802157ull, 18219943856307529608ull,
  15331503717190035662ull, 6475817233170386703ull}},
{{3600303520718951080ull, 13551557783529636203ull,
  14552693628060156674ull, 8094771541462983379ull}},
{{18391090764945202089ull, 13081409633133410530ull,
  6789590508323903969ull, 5059232213414364612ull}},
{{13765491419326726803ull, 2516703986134599451ull,
  8486988135404879962ull, 6324040266767955765ull}},
{{12595178255731020600ull, 12369252019523025122ull,
  15220421187683487856ull, 7905050333459944706ull}},
{{12483672428259275779ull, 7730782512201890701ull,
  14124449260729567814ull, 4940656458412465441ull}},
{{1769532480041931012ull, 440106103397587569ull, 3820503520629796056ull,
  6175820573015581802ull}},
{{6823601618479801669ull, 550132629246984461ull,
  13999001437642020878ull, 7719775716269477252ull}},
{{6570594020763569995ull, 14178890948561529000ull,
  17972747935381038856ull, 4824859822668423282ull}},
{{8213242525954462494ull, 17723613685701911250ull,
  13242562882371522762ull, 6031074778335529103ull}},
{{1043181120588302309ull, 12931145070272613255ull,
  11941517584537015549ull, 7538843472919411379ull}},
{{7569517228008770799ull, 10387808678134077236ull,
  5157605481121940766ull, 4711777170574632112ull}},
{{9461896535010963499ull, 3761388810812820737ull,
  6447006851402425958ull, 5889721463218290140ull}},
{{16439056687191092278ull, 13925108050370801729ull,
  8058758564253032447ull, 7362151829022862675ull}},
{{6713762803706701635ull, 12794699044536114258ull,
  5461762186888902655ull, 9202689786278578344ull}},
{{8807787770744076426ull, 14914215930476153267ull,
  3413601366805564159ull, 5751681116424111465ull}},
{{6398048695002707629ull, 14031083894667803680ull,
  8878687726934343103ull, 7189601395530139331ull}},
{{7997560868753384536ull, 12927168849907366696ull,
  6486673640240540975ull, 8987001744412674164ull}},
{{4998475542970865335ull, 14997009558833186041ull,
  13277543062005113917ull, 5616876090257921352ull}},
{{10859780447140969573ull, 4911203893259318839ull,
  16596928827506392397ull, 7021095112822401690ull}},
{{8963039540498824062ull, 10750690885001536453ull,
  11522788997528214688ull, 8776368891028002113ull}},
{{7907742722025458991ull, 6719181803125960283ull, 284214095814052324ull,
  5485230556892501321ull}},
{{5272992384104435834ull, 8398977253907450354ull,
  4966953638194953309ull, 6856538196115626651ull}},
{{15814612516985320601ull, 15110407585811700846ull,
  1597006029316303732ull, 8570672745144533314ull}},
{{5272446804688437472ull, 220632704277537221ull, 5609814786750077737ull,
  5356670465715333321ull}},
{{11202244524287934743ull, 4887476898774309430ull,
  11623954501864985075ull, 6695838082144166651ull}},
{{4779433618505142621ull, 1497660105040498884ull,
  9918257108903843440ull, 8369797602680208314ull}},
{{12210518048420489946ull, 936037565650311802ull,
  10810596711492290054ull, 5231123501675130196ull}},
{{6039775523670836625ull, 10393418993917665561ull,
  13513245889365362567ull, 6538904377093912745ull}},
{{12161405423015933685ull, 8380087723969694047ull,
  3056499306424539497ull, 8173630471367390932ull}},
{{14518407417026040409ull, 16766769873549528539ull,
  11133684103370112993ull, 5108519044604619332ull}},
{{13536323252855162607ull, 7123404286654746962ull,
  13917105129212641242ull, 6385648805755774165ull}},
{{7697032029214177451ull, 18127627395173209511ull,
  3561323356233637840ull, 7982061007194717707ull}},
{{11728174045899942763ull, 11329767121983255944ull,
  18366728162141881314ull, 4988788129496698566ull}},
{{14660217557374928454ull, 4938836865624294122ull,
  13735038165822575835ull, 6235985161870873208ull}},
{{9101899909863884759ull, 1561860063602979749ull,
  17168797707278219794ull, 7794981452338591510ull}},
{{7994530452878621927ull, 5587848558179250247ull,
  6118812548621499467ull, 4871863407711619694ull}},
{{5381477047670889504ull, 2373124679296674905ull,
  16871887722631650142ull, 6089829259639524617ull}},
{{11338532328015999784ull, 12189777885975619439ull,
  7254801598007398965ull, 7612286574549405772ull}},
{{14004111732651081721ull, 9924454187948456101ull,
  13757623035609400161ull, 4757679109093378607ull}},
{{3670081610531688440ull, 17017253753362958031ull,
  12585342776084362297ull, 5947098886366723259ull}},
{{18422660068446774261ull, 7436509136421533826ull,
  11119992451678064968ull, 7433873607958404074ull}},
{{16125848561206621817ull, 4647818210263458641ull,
  11561681300726178509ull, 4646171004974002546ull}},
{{6322252646226113560ull, 10421458781256711206ull,
  5228729589052947328ull, 5807713756217503183ull}},
{{17126187844637417758ull, 13026823476570889007ull,
  1924225967888796256ull, 7259642195271878979ull}},
{{16796048787369384293ull, 16283529345713611259ull,
  16240340515143159032ull, 9074552744089848723ull}},
{{8191687482892171231ull, 10177205841071007037ull,
  7844369812750780443ull, 5671595465056155452ull}},
{{14851295372042601943ull, 8109821282911370892ull,
  9805462265938475554ull, 7089494331320194315ull}},
{{117375141343700812ull, 913904566784437808ull, 7645141813995706539ull,
  8861867914150242894ull}},
{{73359463339813008ull, 16712091418736131294ull, 166527615319928682ull,
  5538667446343901809ull}},
{{9315071366029542068ull, 11666742236565388309ull,
  4819845537577298757ull, 6923334307929877261ull}},
{{16255525225964315489ull, 748369740424571674ull,
  10636492940399011351ull, 8654167884912346576ull}},
{{14771389284655085085ull, 7385260115406439152ull,
  6647808087749382094ull, 5408854928070216610ull}},
{{17492532109304740ull, 8203107403273133ull, 17533132146541503426ull,
  6761068660087770762ull}},
{{4633551683564018828ull, 9233625921108867224ull,
  12693043146322103474ull, 8451335825109713453ull}},
{{2895969802227511768ull, 10382702219120429919ull,
  10238994975665008623ull, 5282084890693570908ull}},
{{17455020308066553422ull, 8366691755473149494ull,
  12798743719581260779ull, 6602606113366963635ull}},
{{12595403348228415969ull, 5846678675914048964ull,
  11386743631049188070ull, 8253257641708704544ull}},
{{17095499129497535789ull, 17489232227728444314ull,
  7116714769405742543ull, 5158286026067940340ull}},
{{12146001875017143928ull, 17249854266233167489ull,
  8895893461757178179ull, 6447857532584925425ull}},
{{1347444288489266198ull, 16950631814364071458ull,
  15731552845623860628ull, 8059821915731156781ull}},
{{5453838698733179278ull, 1370772847122768853ull,
  12138063537728606845ull, 5037388697331972988ull}},
{{11428984391843862001ull, 6325152077330848970ull,
  15172579422160758556ull, 6296735871664966235ull}},
{{5062858452950051693ull, 7906440096663561213ull,
  14354038259273560291ull, 7870919839581207794ull}},
{{5470129542307476261ull, 2635682051201031806ull,
  13582959930473363086ull, 4919324899738254871ull}},
{{16061033964739121134ull, 12517974600856065565ull,
  12367013894664315953ull, 6149156124672818589ull}},
{{6241234400641737705ull, 1812410195787918245ull,
  1623709313048231230ull, 7686445155841023237ull}},
{{6206614509614780018ull, 14967814427649612615ull,
  3320661329868838470ull, 4804028222400639523ull}},
{{3146582118591087118ull, 9486395997707239961ull,
  17985884717618211800ull, 6005035278000799403ull}},
{{8544913666666246801ull, 11857994997134049951ull,
  17870669878595376846ull, 7506294097500999254ull}},
{{12258100069307486107ull, 2799560854781393315ull,
  6557482655694722625ull, 4691433810938124534ull}},
{{10710939068206969730ull, 8111137086904129548ull,
  17420225356473179089ull, 5864292263672655667ull}},
{{13388673835258712162ull, 14750607377057549839ull,
  17163595677164085957ull, 7330365329590819584ull}},
{{12124156275646002298ull, 4603201166039773587ull,
  3007750522745555831ull, 9162956661988524481ull}},
{{5271754663065057485ull, 9794529756415940348ull,
  13409059122784442154ull, 5726847913742827800ull}},
{{6589693328831321856ull, 3019790158665149627ull,
  16761323903480552693ull, 7158559892178534750ull}},
{{3625430642611764415ull, 8386423716758824938ull,
  11728282842495915058ull, 8948199865223168438ull}},
{{6877580170059740664ull, 9853200841401653490ull,
  2718490758132559007ull, 5592624915764480274ull}},
{{17820347249429451638ull, 7704815033324678958ull,
  12621485484520474567ull, 6990781144705600342ull}},
{{13052062024932038739ull, 5019332773228460794ull,
  6553484818795817401ull, 8738476430882000428ull}},
{{12769224784009912116ull, 14666298029336257756ull,
  13319300048602161683ull, 5461547769301250267ull}},
{{15961530980012390145ull, 13721186518242934291ull,
  12037439042325314200ull, 6826934711626562834ull}},
{{15340227706588099777ull, 17151483147803667864ull,
  5823426766051866942ull, 8533668389533203543ull}},
{{9587642316617562361ull, 6107990948949904511ull,
  10557170756423498695ull, 5333542743458252214ull}},
{{7372866877344565047ull, 3023302667759992735ull,
  3973091408674597561ull, 6666928429322815268ull}},
{{4604397578253318405ull, 8390814353127378823ull,
  4966364260843246951ull, 8333660536653519085ull}},
{{9795277514049405859ull, 12161787998345693620ull,
  5409820672240723296ull, 5208537835408449428ull}},
{{12244096892561757324ull, 15202234997932117025ull,
  6762275840300904120ull, 6510672294260561785ull}},
{{1470063060420032942ull, 556049673705594666ull,
  13064530818803518055ull, 8138340367825702231ull}},
{{5530475431189908493ull, 7265060073707078522ull,
  15082860789393280640ull, 5086462729891063894ull}},
{{16136466325842161424ull, 9081325092133848152ull,
  9630203949886824992ull, 6358078412363829868ull}},
{{1723838833593150164ull, 11351656365167310191ull,
  12037754937358531240ull, 7947598015454787335ull}},
{{7994928298636800709ull, 7094785228229568869ull,
  14441125863490163881ull, 4967248759659242084ull}},
{{14605346391723388790ull, 13480167553714348990ull,
  18051407329362704851ull, 6209060949574052605ull}},
{{9033310952799460179ull, 12238523423715548334ull,
  8729201106421217352ull, 7761326186967565757ull}},
{{1034133327072274708ull, 7649077139822217709ull,
  7761593700726954797ull, 4850828866854728598ull}},
{{5904352677267731289ull, 14173032443205160040ull,
  478620089053917688ull, 6063536083568410748ull}},
{{7380440846584664111ull, 17716290554006450050ull,
  598275111317397110ull, 7579420104460513435ull}},
{{9224461547542802974ull, 6460995577826643377ull,
  16514823009069230858ull, 4737137565287820896ull}},
{{16142262952855891621ull, 17299616509138080029ull,
  2196784687626986956ull, 5921421956609776121ull}},
{{6342770635787700814ull, 3177776562713048421ull,
  7357666877961121600ull, 7401777445762220151ull}},
{{6270074656581006961ull, 1986110351695655263ull,
  11516070826366782856ull, 4626110903601387594ull}},
{{3225907302298870797ull, 2482637939619569079ull,
  5171716496103702762ull, 5782638629501734493ull}},
{{17867442183155752209ull, 12326669461379237156ull,
  11076331638557016356ull, 7228298286877168116ull}},
{{3887558655235138645ull, 15408336826724046446ull,
  13845414548196270445ull, 9035372858596460145ull}},
{{16264782214804125365ull, 11936053525916222980ull,
  1735855064981587172ull, 5647108036622787591ull}},
{{1884233694795605090ull, 14920066907395278726ull,
  16004876886509147677ull, 7058885045778484488ull}},
{{11578664155349282171ull, 4815025578961934695ull,
  1559352034426882981ull, 8823606307223105611ull}},
{{14154194124734383213ull, 5315233996064903136ull,
  17115496086012659527ull, 5514753942014441006ull}},
{{17692742655917979016ull, 2032356476653741016ull,
  12170998070661048601ull, 6893442427518051258ull}},
{{3669184246187922154ull, 7152131614244564175ull,
  5990375551471534943ull, 8616803034397564073ull}},
{{9210769181508533202ull, 11387611286543934465ull,
  15273199765738179099ull, 5385501896498477545ull}},
{{16125147495313054407ull, 9622828089752530177ull,
  5256441651890560162ull, 6731877370623096932ull}},
{{6321376313859154296ull, 2805163075335886914ull,
  6570552064863200203ull, 8414846713278871165ull}},
{{8562546214589359339ull, 17894127986580786985ull,
  6412438049753194078ull, 5259279195799294478ull}},
{{15314868786664087078ull, 13144287946371207923ull,
  17238919599046268406ull, 6574098994749118097ull}},
{{14531899964902720943ull, 7206987896109234096ull,
  7713591443525671796ull, 8217623743436397622ull}},
{{9082437478064200590ull, 13727739471923047118ull,
  209308633776156968ull, 5136014839647748514ull}},
{{2129674810725474929ull, 17159674339903808898ull,
  9485007829074972018ull, 6420018549559685642ull}},
{{11885465550261619469ull, 12226220888024985314ull,
  2632887749488939215ull, 8025023186949607053ull}},
{{12040101987340900073ull, 14558917082656697677ull,
  3951397852644280961ull, 5015639491843504408ull}},
{{1215069428893961379ull, 4363588298038708385ull,
  4939247315805351202ull, 6269549364804380510ull}},
{{6130522804544839627ull, 14677857409403161289ull,
  15397431181611464810ull, 7836936706005475637ull}},
{{15360791798908994527ull, 13785346899304363709ull,
  11929237497720859458ull, 4898085441253422273ull}},
{{5365931693354079447ull, 8008311587275678829ull,
  1076488816868910611ull, 6122606801566777842ull}},
{{11319100635119987212ull, 5398703465667210632ull,
  10568983057940914072ull, 7653258501958472302ull}},
{{7074437896949992008ull, 3374189666042006645ull,
  1993928392785683391ull, 4783286563724045189ull}},
{{13454733389614877914ull, 18052795137834672018ull,
  7104096509409492142ull, 5979108204655056486ull}},
{{7595044700163821584ull, 13342621885438564215ull,
  18103492673616640986ull, 7473885255818820607ull}},
{{11664431965243470346ull, 12950824696826490538ull,
  18232211948651482472ull, 4671178284886762879ull}},
{{5357167919699562125ull, 16188530871033113173ull,
  18178578917386965186ull, 5838972856108453599ull}},
{{11308145918051840560ull, 11012291551936615658ull,
  18111537628306318579ull, 7298716070135566999ull}},
{{4911810360710024891ull, 9153678421493381669ull,
  18027736016955510320ull, 9123395087669458749ull}},
{{5375724484657459509ull, 5721049013433363543ull,
  13573178019810887902ull, 5702121929793411718ull}},
{{2107969587394436483ull, 16374683303646480237ull,
  7743100487908834069ull, 7127652412241764648ull}},
{{7246648002670433507ull, 6633296074275936584ull,
  9678875609886042587ull, 8909565515302205810ull}},
{{4529155001669020942ull, 1839967037208766413ull,
  10660983274606164521ull, 5568478447063878631ull}},
{{10273129770513664082ull, 6911644814938345920ull,
  8714543074830317747ull, 6960598058829848289ull}},
{{12841412213142080102ull, 4027870000245544496ull,
  15504864861965285088ull, 8700747573537310361ull}},
{{8025882633213800064ull, 2517418750153465310ull,
  2773011511087221324ull, 5437967233460818976ull}},
{{808981254662474272ull, 3146773437691831638ull, 3466264388859026655ull,
  6797459041826023720ull}},
{{10234598605182868647ull, 17768524852396953259ull,
  4332830486073783318ull, 8496823802282529650ull}},
{{4090781119025598953ull, 6493642014320707883ull,
  7319705072223502478ull, 5310514876426581031ull}},
{{501790380354610787ull, 17340424554755660662ull,
  4537945321851990193ull, 6638143595533226289ull}},
{{9850610012298039291ull, 7840472638162412115ull,
  10284117670742375646ull, 8297679494416532861ull}},
{{3850788248472580605ull, 288609380424119668ull, 8733416553427678731ull,
  5186049684010333038ull}},
{{4813485310590725757ull, 14195819780812313297ull,
  1693398654929822605ull, 6482562105012916298ull}},
{{10628542656665795100ull, 3909716670733227909ull,
  11340120355517054065ull, 8103202631266145372ull}},
{{8948682169629815889ull, 13972787965276737203ull,
  16310947259052934598ull, 5064501644541340857ull}},
{{6574166693609881958ull, 8242612919741145696ull,
  6553626018534004536ull, 6330627055676676072ull}},
{{8217708367012352447ull, 10303266149676432120ull,
  8192032523167505670ull, 7913283819595845090ull}},
{{5136067729382720280ull, 1827855325120382171ull,
  9731706345407078948ull, 4945802387247403181ull}},
{{1808398643301012445ull, 2284819156400477714ull,
  16776318950186236589ull, 6182252984059253976ull}},
{{11483870340981041365ull, 7467709963927985046ull,
  2523654614023244120ull, 7727816230074067471ull}},
{{2565732944685762949ull, 4667318727454990654ull,
  8494813161405609431ull, 4829885143796292169ull}},
{{12430538217711979494ull, 1222462390891350413ull,
  15230202470184399693ull, 6037356429745365211ull}},
{{1703114716857810656ull, 6139764007041575921ull,
  14426067069303111712ull, 7546695537181706514ull}},
{{12593661744104601420ull, 3837352504400984950ull,
  13627977936741832724ull, 4716684710738566571ull}},
{{6518705143275975967ull, 4796690630501231188ull,
  12423286402499903001ull, 5895855888423208214ull}},
{{8148381429094969958ull, 10607549306553926889ull,
  6305735966270102943ull, 7369819860529010268ull}},
{{14797162804796100352ull, 8647750614765020707ull,
  7882169957837628679ull, 9212274825661262835ull}},
{{6942383743783868768ull, 12322373161869219798ull,
  2620513214434823972ull, 5757671766038289272ull}},
{{17901351716584611768ull, 15402966452336524747ull,
  3275641518043529965ull, 7197089707547861590ull}},
{{17765003627303376806ull, 5418650010138492222ull,
  13317923934409188265ull, 8996362134434826987ull}},
{{6491441248637222600ull, 14915871302405027399ull,
  6017859449792048713ull, 5622726334021766867ull}},
{{3502615542369140346ull, 4809781072724120537ull,
  2910638293812672988ull, 7028407917527208584ull}},
{{8989955446388813336ull, 6012226340905150671ull,
  3638297867265841235ull, 8785509896909010730ull}},
{{12536251181634090191ull, 1451798453852025217ull,
  6885622185468538676ull, 5490943685568131706ull}},
{{1835255921760449027ull, 1814748067315031522ull,
  17830399768690449153ull, 6863679606960164632ull}},
{{11517441939055337091ull, 6880121102571177306ull,
  3841255637153509825ull, 8579599508700205791ull}},
{{11810087230336973586ull, 15829290735175455576ull,
  9318313800862025496ull, 5362249692937628619ull}},
{{14762609037921216983ull, 1339869345259767854ull,
  7036206232650143967ull, 6702812116172035774ull}},
{{9229889260546745420ull, 15509894736856873530ull,
  18018629827667455766ull, 8378515145215044717ull}},
{{10380366806269103792ull, 5081998192108158052ull,
  13567486651505853806ull, 5236571965759402948ull}},
{{12975458507836379740ull, 15575869776989973373ull,
  16959358314382317257ull, 6545714957199253685ull}},
{{2384265079513310963ull, 5634779165955303005ull,
  7364139837695732860ull, 8182143696499067107ull}},
{{3796008683909513304ull, 12745109015576840186ull,
  2296744389346139085ull, 5113839810311916942ull}},
{{13968382891741667438ull, 2096328214188886520ull,
  12094302523537449665ull, 6392299762889896177ull}},
{{17460478614677084297ull, 7232096286163496054ull,
  1282820099139648369ull, 7990374703612370222ull}},
{{6301113115745789782ull, 16049275224920654794ull,
  14636820617244443942ull, 4993984189757731388ull}},
{{17099763431537013035ull, 10838221994296042684ull,
  18296025771555554928ull, 6242480237197164235ull}},
{{2927960215711714678ull, 13547777492870053356ull,
  18258346196017055756ull, 7803100296496455294ull}},
{{11053347171674597482ull, 17690732969898559155ull,
  6799780354083271943ull, 4876937685310284559ull}},
{{9204997946165858948ull, 17501730193945811040ull,
  3888039424176702025ull, 6096172106637855699ull}},
{{11506247432707323685ull, 8042104687150100088ull,
  248363261793489628ull, 7620215133297319624ull}},
{{7191404645442077303ull, 14249687466323588363ull,
  155227038620931017ull, 4762634458310824765ull}},
{{4377569788375208725ull, 3977051277622321742ull,
  4805719816703551676ull, 5953293072888530956ull}},
{{14695334272323786714ull, 4971314097027902177ull,
  6007149770879439595ull, 7441616341110663695ull}},
{{2267054892561284840ull, 801228301428744909ull,
  10671997634440731603ull, 4651010213194164809ull}},
{{7445504634128993954ull, 14836593432068094848ull,
  17951683061478302407ull, 5813762766492706011ull}},
{{9306880792661242443ull, 13934055771657730656ull,
  17827917808420490105ull, 7267203458115882514ull}},
{{11633600990826553054ull, 3582511659289999608ull,
  13061525223670836824ull, 9084004322644853143ull}},
{{7271000619266595659ull, 2239069787056249755ull,
  15080982292435354871ull, 5677502701653033214ull}},
{{4477064755655856669ull, 16633895289102475906ull,
  9627855828689417780ull, 7096878377066291518ull}},
{{14819702981424596644ull, 2345625037668543266ull,
  2811447749006996418ull, 8871097971332864398ull}},
{{13874000381817760807ull, 6077701666970227445ull,
  15592212898411536473ull, 5544436232083040248ull}},
{{3507442421990037297ull, 12208813102140172211ull,
  1043522049304868975ull, 6930545290103800311ull}},
{{18219361082769710333ull, 10649330359247827359ull,
  15139460616913249931ull, 8663181612629750388ull}},
{{18304629704372150814ull, 4349988465316198147ull,
  238790848716005399ull, 5414488507893593993ull}},
{{18269101112037800613ull, 825799563217859780ull,
  4910174579322394653ull, 6768110634866992491ull}},
{{4389632316337699151ull, 5643935472449712630ull,
  1526032205725605412ull, 8460138293583740614ull}},
{{16578578252993225681ull, 12750831707135846201ull,
  14788828183860667094ull, 5287586433489837883ull}},
{{6888164760959368390ull, 6715167597065031944ull,
  13874349211398445964ull, 6609483041862297354ull}},
{{8610205951199210487ull, 8393959496331289930ull,
  8119564477393281647ull, 8261853802327871693ull}},
{{9993064737926894458ull, 12163753712848138062ull,
  7380570807584494981ull, 5163658626454919808ull}},
{{3267958885553842265ull, 1369634085778008866ull,
  9225713509480618727ull, 6454573283068649760ull}},
{{13308320643797078639ull, 15547100662504674794ull,
  11532141886850773408ull, 8068216603835812200ull}},
{{12929386420800562054ull, 9716937914065421746ull,
  7207588679281733380ull, 5042635377397382625ull}},
{{6938360989145926759ull, 12146172392581777183ull,
  13621171867529554629ull, 6303294221746728281ull}},
{{4061265218005020544ull, 1347657435445057767ull,
  3191406779129779575ull, 7879117777183410352ull}},
{{9455819788894219696ull, 7759814924794242960ull,
  1994629236956112234ull, 4924448610739631470ull}},
{{11819774736117774620ull, 476396619138027892ull,
  11716658583049916101ull, 6155560763424539337ull}},
{{14774718420147218275ull, 5207181792349922769ull,
  810765173530231414ull, 7694450954280674172ull}},
{{2316669984950929566ull, 17089546675500865443ull,
  9730100270311170441ull, 4809031846425421357ull}},
{{16730895536470825670ull, 7526875289093918091ull,
  16774311356316350956ull, 6011289808031776696ull}},
{{16301933402161144183ull, 9408594111367397614ull,
  2521145121685887079ull, 7514112260039720871ull}},
{{5577022357923327211ull, 12797900347245705365ull,
  8493244728694761280ull, 4696320162524825544ull}},
{{11582963965831546917ull, 15997375434057131706ull,
  10616555910868451600ull, 5870400203156031930ull}},
{{5255332920434657838ull, 1549975218861863017ull,
  4047322851730788693ull, 7338000253945039913ull}},
{{11180852168970710202ull, 6549155042004716675ull,
  9670839583090873770ull, 9172500317431299891ull}},
{{4682189596392999924ull, 8704907919680335826ull,
  3738431730218102154ull, 5732812698394562432ull}},
{{15076109032346025713ull, 1657762862745643974ull,
  4673039662772627693ull, 7166015872993203040ull}},
{{9621764253577756333ull, 6683889596859442872ull,
  5841299578465784616ull, 8957519841241503800ull}},
{{6013602658486097709ull, 4177430998037151795ull,
  3650812236541115385ull, 5598449900775939875ull}},
{{2905317304680234232ull, 9833474765973827648ull,
  18398573350958557943ull, 6998062375969924843ull}},
{{3631646630850292789ull, 7680157439039896656ull,
  18386530670270809525ull, 8747577969962406054ull}},
{{2269779144281432994ull, 7105941408613629362ull,
  6879895650491868049ull, 5467236231226503784ull}},
{{12060595967206567050ull, 13494112779194424606ull,
  8599869563114835061ull, 6834045289033129730ull}},
{{5852372922153433004ull, 3032582918710867046ull,
  1526464917038768019ull, 8542556611291412163ull}},
{{17492791131628059340ull, 18036265388690149567ull,
  17094941637645087675ull, 5339097882057132601ull}},
{{17254302896107686271ull, 17933645717435299055ull,
  7533618991774195882ull, 6673872352571415752ull}},
{{16956192601707219934ull, 13193685109939348011ull,
  9417023739717744853ull, 8342340440714269690ull}},
{{8291777366853318507ull, 10551896202925786459ull,
  10497325855750978437ull, 5213962775446418556ull}},
{{5753035690139260230ull, 17801556272084620978ull,
  13121657319688723046ull, 6517453469308023195ull}},
{{16414666649528851095ull, 13028573303251000414ull,
  11790385631183515904ull, 8146816836635028994ull}},
{{5647480637528144031ull, 8142858314531875259ull,
  11980677037917085344ull, 5091760522896893121ull}},
{{2447664778482792134ull, 10178572893164844074ull,
  1140788242114192968ull, 6364700653621116402ull}},
{{12282953009958265975ull, 12723216116456055092ull,
  10649357339497517018ull, 7955875817026395502ull}},
{{16900217668078692043ull, 12563696091212422336ull,
  2044162318758560232ull, 4972422385641497189ull}},
{{2678528011388813437ull, 15704620114015527921ull,
  7166888916875588194ull, 6215527982051871486ull}},
{{7959846032663404701ull, 10407403105664634093ull,
  18181983182949261051ull, 7769409977564839357ull}},
{{7280746779628321890ull, 4198783931826702356ull,
  13669582498556982109ull, 4855881235978024598ull}},
{{9100933474535402362ull, 9860165933210765849ull,
  7863606086341451828ull, 6069851544972530748ull}},
{{15987852861596640857ull, 12325207416513457311ull,
  9829507607926814785ull, 7587314431215663435ull}},
{{16909937066138982392ull, 785725607679828963ull,
  3837599245740565289ull, 4742071519509789647ull}},
{{16525735314246340086ull, 5593843028027174108ull,
  185313038748318707ull, 5927589399387237059ull}},
{{2210425069098373491ull, 2380617766606579732ull,
  14066699353717562096ull, 7409486749234046323ull}},
{{10604887705041259240ull, 1487886104129112332ull,
  6485844086859782358ull, 4630929218271278952ull}},
{{13256109631301574050ull, 11083229667016166223ull,
  8107305108574727947ull, 5788661522839098690ull}},
{{11958451020699579658ull, 9242351065342819875ull,
  910759348863634126ull, 7235826903548873363ull}},
{{10336377757447086669ull, 2329566794823749036ull,
  14973507241361706370ull, 9044783629436091703ull}},
{{15683608135259204976ull, 6067665265192231051ull,
  16275971053492148337ull, 5652989768397557314ull}},
{{14992824150646618316ull, 12196267599917676718ull,
  11121591780010409613ull, 7066237210496946643ull}},
{{9517658151453497087ull, 1410276444614932186ull,
  9290303706585624113ull, 8832796513121183304ull}},
{{10560222363085823583ull, 12410637823952802376ull,
  5806439816616015070ull, 5520497820700739565ull}},
{{13200277953857279479ull, 6289925243086227162ull,
  11869735789197406742ull, 6900622275875924456ull}},
{{7276975405466823541ull, 17085778590712559761ull,
  14837169736496758427ull, 8625777844844905570ull}},
{{16077324674485234473ull, 8372768609981655898ull,
  13884917103737861921ull, 5391111153028065981ull}},
{{10873283806251767283ull, 15077646780904457777ull,
  3521088324390163689ull, 6738888941285082477ull}},
{{18203290776242097008ull, 5012000420848408509ull,
  9013046423915092516ull, 8423611176606353096ull}},
{{13682899744365004582ull, 12355872299885031126ull,
  5633154014946932822ull, 5264756985378970685ull}},
{{7880252643601479920ull, 6221468338001513100ull,
  11653128537111053932ull, 6580946231723713356ull}},
{{9850315804501849900ull, 7776835422501891375ull,
  14566410671388817415ull, 8226182789654641695ull}},
{{13073976405454738043ull, 11778051166704763965ull,
  16021535697259092740ull, 5141364243534151059ull}},
{{2507412451536258842ull, 14722563958380954957ull,
  15415233603146478021ull, 6426705304417688824ull}},
{{7745951582847711457ull, 4568146892694029984ull, 822297930223545911ull,
  8033381630522111031ull}},
{{4841219739279819661ull, 9772620835574850596ull,
  7431465234030798050ull, 5020863519076319394ull}},
{{6051524674099774576ull, 2992404007613787437ull, 65959505683721755ull,
  6276079398845399243ull}},
{{12176091861052106123ull, 17575563064799398008ull,
  13917507437386815905ull, 7845099248556749053ull}},
{{7610057413157566327ull, 4067197887858541899ull,
  11004285157580453893ull, 4903187030347968158ull}},
{{4900885748019570005ull, 9695683378250565278ull,
  4531984410120791558ull, 6128983787934960198ull}},
{{15349479221879238314ull, 2896232185958430789ull,
  14888352549505765256ull, 7661229734918700247ull}},
{{11899267522888217898ull, 1810145116224019243ull,
  16222749371082185141ull, 4788268584324187654ull}},
{{10262398385182884469ull, 6874367413707411958ull,
  11055064676997955618ull, 5985335730405234568ull}},
{{3604625944623829778ull, 17816331303989040756ull,
  13818830846247444522ull, 7481669663006543210ull}},
{{11476263252244669419ull, 15746893083420538376ull,
  13248455297332040730ull, 4676043539379089506ull}},
{{14345329065305836774ull, 10460244317420897162ull,
  7337197084810275105ull, 5845054424223861883ull}},
{{8708289294777520160ull, 17686991415203509357ull,
  4559810337585455977ull, 7306318030279827354ull}},
{{15497047636899288103ull, 8273681213722222984ull,
  14923134958836595780ull, 9132897537849784192ull}},
{{9685654773062055065ull, 14394422795431165173ull,
  9326959349272872362ull, 5708060961156115120ull}},
{{16718754484754956735ull, 8769656457434180658ull,
  11658699186591090453ull, 7135076201445143900ull}},
{{11675071069088920111ull, 15573756590220113727ull,
  14573373983238863066ull, 8918845251806429875ull}},
{{14214448445821656925ull, 14345283887314958983ull,
  6802515730310595464ull, 5574278282379018672ull}},
{{13156374538849683252ull, 17931604859143698729ull,
  8503144662888244330ull, 6967847852973773340ull}},
{{2610410118279940353ull, 13191134037074847604ull,
  10628930828610305413ull, 8709809816217216675ull}},
{{10854878360779738529ull, 10550301782385473704ull,
  4337238758667746931ull, 5443631135135760422ull}},
{{13568597950974673161ull, 8576191209554454226ull,
  14644920485189459472ull, 6804538918919700527ull}},
{{7737375401863565643ull, 10720239011943067783ull,
  13694464588059436436ull, 8505673648649625659ull}},
{{11753388653805810383ull, 15923521419319193172ull,
  6253197358323453820ull, 5316046030406016037ull}},
{{14691735817257262979ull, 1457657700439439849ull,
  12428182716331705180ull, 6645057538007520046ull}},
{{4529611716289415012ull, 1822072125549299812ull,
  6311856358559855667ull, 8306321922509400058ull}},
{{12054379359535660190ull, 17279696142964170046ull,
  8556596242527297695ull, 5191451201568375036ull}},
{{5844602162564799430ull, 16987934160277824654ull,
  10695745303159122119ull, 6489314001960468795ull}},
{{16529124740060775095ull, 16623231681919892913ull,
  8757995610521514745ull, 8111642502450585994ull}},
{{3413173934896902579ull, 3471990773558851215ull,
  10085433275003334620ull, 5069776564031616246ull}},
{{18101525473903291935ull, 4339988466948564018ull,
  3383419556899392467ull, 6337220705039520308ull}},
{{13403534805524339111ull, 813299565258317119ull,
  4229274446124240584ull, 7921525881299400385ull}},
{{15294738281093793801ull, 508312228286448199ull,
  14172511574896120125ull, 4950953675812125240ull}},
{{14506736832939854347ull, 5247076303785448153ull,
  17715639468620150156ull, 6188692094765156550ull}},
{{4298362985892654221ull, 6558845379731810192ull,
  12921177298920411887ull, 7735865118456445688ull}},
{{2686476866182908888ull, 11016807389973463226ull,
  8075735811825257429ull, 4834915699035278555ull}},
{{12581468119583411918ull, 18382695255894216936ull,
  5482983746354183882ull, 6043644623794098194ull}},
{{15726835149479264898ull, 13754997033012995362ull,
  16077101719797505661ull, 7554555779742622742ull}},
{{14440957986851928465ull, 10902716154846816053ull,
  5436502556446053134ull, 4721597362339139214ull}},
{{4216139428282746870ull, 4405023156703744259ull,
  16019000232412342226ull, 5901996702923924017ull}},
{{658488266926045683ull, 14729650982734456132ull,
  6188692235233264070ull, 7377495878654905022ull}},
{{823110333657557103ull, 9188691691563294357ull,
  16959237330896355896ull, 9221869848318631277ull}},
{{2820286967749667142ull, 5742932307227058973ull,
  12905366341023916387ull, 5763668655199144548ull}},
{{8137044728114471831ull, 2566979365606435812ull,
  16131707926279895484ull, 7204585818998930685ull}},
{{10171305910143089789ull, 3208724207008044765ull,
  6329576852567705643ull, 9005732273748663357ull}},
{{8662909203053125070ull, 18146353693875885642ull,
  6261828542068509978ull, 5628582671092914598ull}},
{{1605264466961630530ull, 13459570080490081245ull,
  17050657714440413281ull, 7035728338866143247ull}},
{{6618266602129426066ull, 2989404545330437844ull,
  16701636124623128698ull, 8794660423582679059ull}},
{{13359788663185667099ull, 6480063859258911556ull,
  8132679568675761484ull, 5496662764739174412ull}},
{{16699735828982083874ull, 8100079824073639445ull,
  10165849460844701855ull, 6870828455923968015ull}},
{{7039611730945441131ull, 5513413761664661403ull,
  8095625807628489415ull, 8588535569904960019ull}},
{{2093914322627206755ull, 10363412628681495233ull,
  2753923120554111932ull, 5367834731190600012ull}},
{{7229078921711396347ull, 12954265785851869041ull,
  3442403900692639915ull, 6709793413988250015ull}},
{{13648034670566633338ull, 11581146213887448397ull,
  18138062931147963606ull, 8387241767485312518ull}},
{{10835864678317839788ull, 2626530365252267344ull,
  6724603313540089350ull, 5242026104678320324ull}},
{{13544830847897299735ull, 12506534993420109988ull,
  8405754141925111687ull, 6552532630847900405ull}},
{{16931038559871624669ull, 11021482723347749581ull,
  15118878695833777513ull, 8190665788559875506ull}},
{{12887742109133459370ull, 18417641748160813248ull,
  14060985203323498849ull, 5119166117849922191ull}},
{{16109677636416824213ull, 9186994129918852848ull,
  12964545485726985658ull, 6398957647312402739ull}},
{{1690352971811478650ull, 2260370625543790253ull,
  11593995838731344169ull, 7998697059140503424ull}},
{{3362313616595868108ull, 12941946687033338668ull,
  7246247399207090105ull, 4999185661962814640ull}},
{{4202892020744835135ull, 2342375303509509623ull,
  9057809249008862632ull, 6248982077453518300ull}},
{{641929007503656015ull, 2927969129386887029ull,
  11322261561261078290ull, 7811227596816897875ull}},
{{2707048638903478962ull, 6441666724294192297ull,
  4770570466574479979ull, 4882017248010561172ull}},
{{7995496817056736606ull, 3440397386940352467ull,
  5963213083218099974ull, 6102521560013201465ull}},
{{5382685002893532853ull, 13523868770530216392ull,
  12065702372450012871ull, 7628151950016501831ull}},
{{3364178126808458034ull, 15369947009222467101ull,
  14458593010422339900ull, 4767594968760313644ull}},
{{8816908676937960446ull, 765689687818532260ull,
  18073241263027924876ull, 5959493710950392055ull}},
{{11021135846172450557ull, 957112109773165325ull,
  17979865560357518191ull, 7449367138687990069ull}},
{{9194052913071475550ull, 7515724096249310184ull,
  13543258984437142821ull, 4655854461679993793ull}},
{{11492566141339344438ull, 14006341138739025634ull,
  3094015675264264814ull, 5819818077099992242ull}},
{{5142335639819404739ull, 8284554386569006235ull,
  13090891630935106826ull, 7274772596374990302ull}},
{{1816233531346868020ull, 1132320946356481986ull,
  7140242501814107725ull, 9093465745468737878ull}},
{{5746831975519180417ull, 3013543600686495193ull,
  18297709618915981040ull, 5683416090917961173ull}},
{{11795225987826363425ull, 3766929500858118991ull,
  9037078968362812588ull, 7104270113647451467ull}},
{{10132346466355566377ull, 4708661876072648739ull,
  6684662692026127831ull, 8880337642059314334ull}},
{{4026873532258535034ull, 9860442700186487318ull,
  18012972237798493606ull, 5550211026287071458ull}},
{{14256963952177944600ull, 3102181338378333339ull,
  13292843260393341200ull, 6937763782858839323ull}},
{{13209518921795042846ull, 3877726672972916674ull,
  12004368057064288596ull, 8672204728573549154ull}},
{{12867635344549289683ull, 11646951207462848729ull,
  12114416054092568276ull, 5420127955358468221ull}},
{{2249486125404448391ull, 14558689009328560912ull,
  1307962012333546633ull, 6775159944198085277ull}},
{{2811857656755560489ull, 4363303206378537428ull,
  6246638533844321196ull, 8468949930247606596ull}},
{{10980783072327001114ull, 11950436540841361700ull,
  13127521120507476555ull, 5293093706404754122ull}},
{{13725978840408751392ull, 10326359657624314221ull,
  7186029363779569886ull, 6616367133005942653ull}},
{{3322415495228775528ull, 3684577535175616969ull,
  13594222723151850262ull, 8270458916257428316ull}},
{{13605724730586454465ull, 16137919014766924317ull,
  17719761238824682221ull, 5169036822660892697ull}},
{{3172097857950904369ull, 6337340713176491685ull,
  8314643493248689065ull, 6461296028326115872ull}},
{{8576808340866018366ull, 12533361909898002510ull,
  10393304366560861331ull, 8076620035407644840ull}},
{{748819194613873575ull, 5527508184472557617ull, 6495815229100538332ull,
  5047887522129778025ull}},
{{5547710011694729872ull, 6909385230590697021ull,
  12731455054803060819ull, 6309859402662222531ull}},
{{11546323533045800244ull, 4025045519810983372ull,
  11302632800076438120ull, 7887324253327778164ull}},
{{16439824245008400961ull, 2515653449881864607ull,
  16287517536902549633ull, 4929577658329861352ull}},
{{15938094287833113297ull, 7756252830779718663ull,
  1912652847418635425ull, 6161972072912326691ull}},
{{15310931841364003717ull, 14307002056902036233ull,
  16225874114555457993ull, 7702465091140408363ull}},
{{2651803373211420467ull, 2024347257922690790ull,
  7835328312383467294ull, 4814040681962755227ull}},
{{12538126253369051392ull, 11753806109258139295ull,
  5182474372051946213ull, 6017550852453444034ull}},
{{11060971798283926336ull, 857199581290510407ull,
  15701465001919708575ull, 7521938565566805042ull}},
{{13830636401568535816ull, 7453278765947650860ull,
  14425101644627205763ull, 4701211603479253151ull}},
{{17288295501960669770ull, 4704912439007175671ull,
  13419691037356619300ull, 5876514504349066439ull}},
{{16998683359023449308ull, 5881140548758969589ull,
  12162927778268386221ull, 7345643130436333049ull}},
{{7413296143497147923ull, 11963111704376099891ull,
  1368601667553319064ull, 9182053913045416312ull}},
{{2327467080472023500ull, 7476944815235062432ull, 855376042220824415ull,
  5738783695653385195ull}},
{{2909333850590029375ull, 4734495000616440136ull,
  14904278108058194231ull, 7173479619566731493ull}},
{{3636667313237536719ull, 1306432732343162266ull,
  4795289579790579077ull, 8966849524458414367ull}},
{{6884603089200848354ull, 3122363466928170368ull,
  9914585015010193779ull, 5604280952786508979ull}},
{{8605753861501060442ull, 17738012388942376672ull,
  7781545250335354319ull, 7005351190983136224ull}},
{{10757192326876325552ull, 17560829467750582936ull,
  9726931562919192899ull, 8756688988728920280ull}},
{{6723245204297703470ull, 8669675408130420383ull,
  6079332226824495562ull, 5472930617955575175ull}},
{{3792370486944741434ull, 1613722223308249671ull,
  2987479265103231549ull, 6841163272444468969ull}},
{{128777090253538888ull, 6628838797562699993ull, 8346035099806427340ull,
  8551454090555586211ull}},
{{11609700727476931565ull, 13366396285331463303ull,
  2910428928165323135ull, 5344658806597241382ull}},
{{9900439890918776552ull, 12096309338236941225ull,
  12861408197061429727ull, 6680823508246551727ull}},
{{16987235882075858594ull, 10508700654368788627ull,
  11465074227899399255ull, 8351029385308189659ull}},
{{8311179417083717670ull, 13485466936621574748ull,
  4859828383223430582ull, 5219393365817618537ull}},
{{10388974271354647087ull, 7633461633922192627ull,
  10686471497456676132ull, 6524241707272023171ull}},
{{8374531820765920954ull, 9541827042402740784ull,
  8746403353393457261ull, 8155302134090028964ull}},
{{5234082387978700597ull, 8269484910715406942ull,
  14689874132725686596ull, 5097063833806268102ull}},
{{15765975021828151554ull, 10336856138394258677ull,
  9138970629052332437ull, 6371329792257835128ull}},
{{5872410722003025730ull, 17532756191420211251ull,
  11423713286315415546ull, 7964162240322293910ull}},
{{1364413692038197130ull, 15569658638065019936ull,
  2528134785519746812ull, 4977601400201433694ull}},
{{1705517115047746412ull, 1015329223871723304ull,
  12383540518754459324ull, 6222001750251792117ull}},
{{2131896393809683015ull, 1269161529839654130ull,
  1644367593160910443ull, 7777502187814740147ull}},
{{5944121264558439788ull, 16934127020645641495ull,
  17168630810221426690ull, 4860938867384212591ull}},
{{2818465562270661831ull, 11944286738952276061ull,
  16849102494349395459ull, 6076173584230265739ull}},
{{8134767971265715193ull, 10318672405262957172ull,
  16449692099509356420ull, 7595216980287832174ull}},
{{14307602018895847804ull, 15672542290144124040ull,
  5669371543765959858ull, 4747010612679895109ull}},
{{17884502523619809755ull, 10367305825825379242ull,
  11698400448134837727ull, 5933763265849868886ull}},
{{13132256117669986385ull, 8347446263854336149ull,
  5399628523313771351ull, 7417204082312336108ull}},
{{10513503082757435443ull, 12134682942550041949ull,
  12598139863925882902ull, 4635752551445210067ull}},
{{17753564871874182207ull, 5944981641332776628ull,
  11135988811479965724ull, 5794690689306512584ull}},
{{3745212016133176143ull, 7431227051665970786ull,
  13919986014349957155ull, 7243363361633140730ull}},
{{13904887057021245987ull, 4677347796155075578ull,
  8176610481082670636ull, 9054204202041425913ull}},
{{13302240429065666646ull, 12146714409451698044ull,
  16639596596745138907ull, 5658877626275891195ull}},
{{16627800536332083307ull, 10571706993387234651ull,
  16187809727504035730ull, 7073597032844863994ull}},
{{16173064651987716230ull, 3991261704879267506ull,
  11011390122525268855ull, 8841996291056079993ull}},
{{14719851425919710548ull, 9412067593190624047ull,
  18411333872646762794ull, 5526247681910049995ull}},
{{13788128263972250281ull, 2541712454633504251ull,
  18402481322381065589ull, 6907809602387562494ull}},
{{12623474311537924947ull, 7788826586719268218ull,
  13779729616121556178ull, 8634762002984453118ull}},
{{12501357463138590996ull, 9479702635126930540ull,
  4000644991648584707ull, 5396726251865283199ull}},
{{15626696828923238745ull, 7237942275481275271ull,
  389120221133342980ull, 6745907814831603999ull}},
{{14921685017726660527ull, 9047427844351594089ull,
  14321458331698842437ull, 8432384768539504998ull}},
{{2408524108438080974ull, 7960485411933440258ull,
  4339225438884388619ull, 5270240480337190624ull}},
{{12234027172402377025ull, 5338920746489412418ull,
  5424031798605485774ull, 6587800600421488280ull}},
{{6069161928648195473ull, 15897022969966541331ull,
  6780039748256857217ull, 8234750750526860350ull}},
{{1487383196191428219ull, 3018110328588006476ull,
  18072582897942699473ull, 5146719219079287718ull}},
{{1859228995239285273ull, 8384323929162395999ull,
  13367356585573598533ull, 6433399023849109648ull}},
{{16159094299331270304ull, 15092090929880382902ull,
  16709195731966998166ull, 8041748779811387060ull}},
{{5487747918654656036ull, 4820870812747851410ull,
  1219875295624598046ull, 5026092987382116913ull}},
{{16083056935173095853ull, 15249460552789590070ull,
  6136530137958135461ull, 6282616234227646141ull}},
{{10880449132111594008ull, 5226767635704823876ull,
  12282348690875057231ull, 7853270292784557676ull}},
{{16023652744424522063ull, 10184258799956596778ull,
  16899839968651686577ull, 4908293932990348547ull}},
{{10806193893675876771ull, 17342009518373133877ull,
  16513113942387220317ull, 6135367416237935684ull}},
{{18119428385522233867ull, 7842453842684253634ull,
  2194648354274473781ull, 7669209270297419606ull}},
{{15936328759378784071ull, 7207376660891352473ull,
  15206713276703709825ull, 4793255793935887253ull}},
{{6085352893941316377ull, 13620906844541578496ull,
  5173333540597473569ull, 5991569742419859067ull}},
{{7606691117426645471ull, 3191075500394809408ull,
  1854980907319454058ull, 7489462178024823834ull}},
{{4754181948391653420ull, 6606108206174143784ull,
  5771049085502046690ull, 4680913861265514896ull}},
{{5942727435489566774ull, 17481007294572455538ull,
  7213811356877558362ull, 5851142326581893620ull}},
{{16651781331216734276ull, 12627887081360793614ull,
  9017264196096947953ull, 7313927908227367025ull}},
{{11591354627166142037ull, 1949800796418828306ull,
  15883266263548572846ull, 9142409885284208781ull}},
{{11856282660406226677ull, 15053683553043931403ull,
  12232884423931551980ull, 5714006178302630488ull}},
{{10208667307080395442ull, 370360367595362638ull,
  15291105529914439976ull, 7142507722878288110ull}},
{{3537462096995718495ull, 462950459494203298ull, 9890509875538274162ull,
  8928134653597860138ull}},
{{6822599829049711963ull, 4901030055611264965ull,
  10793254690638809255ull, 5580084158498662586ull}},
{{13139935804739527858ull, 1514601551086693302ull,
  4268196326443735761ull, 6975105198123328233ull}},
{{7201547719069634014ull, 6504937957285754532ull,
  9946931426482057605ull, 8718881497654160291ull}},
{{13724339361273297067ull, 6371429232517290534ull,
  3910989132337592051ull, 5449300936033850182ull}},
{{7932052164736845526ull, 3352600522219225264ull,
  14112108452276765872ull, 6811626170042312727ull}},
{{9915065205921056907ull, 4190750652774031580ull,
  13028449546918569436ull, 8514532712552890909ull}},
{{15420287790555436375ull, 11842591194838545545ull,
  10448623976037799849ull, 5321582945345556818ull}},
{{5440301682912131757ull, 968180938266018220ull, 3837407933192474004ull,
  6651978681681946023ull}},
{{6800377103640164696ull, 1210226172832522775ull, 185073898063204601ull,
  8314973352102432529ull}},
{{11167764717416184791ull, 12285606404088796494ull,
  11644886232357972635ull, 5196858345064020330ull}},
{{4736333859915455181ull, 10745321986683607714ull,
  5332735753592689986ull, 6496072931330025413ull}},
{{15143789361749094784ull, 4208280446499733834ull,
  11277605710418250387ull, 8120091164162531766ull}},
{{14076554369520572144ull, 324332269848639694ull,
  2436817550584018588ull, 5075056977601582354ull}},
{{8372320925045939372ull, 405415337310799618ull,
  12269393975084799043ull, 6343821222001977942ull}},
{{1242029119452648407ull, 14341827226920663235ull,
  6113370432001222995ull, 7929776527502472428ull}},
{{16917169264153762919ull, 6657799007611720569ull,
  13044228556855540180ull, 4956110329689045267ull}},
{{7311403524910039936ull, 8322248759514650712ull,
  11693599677642037321ull, 6195137912111306584ull}},
{{9139254406137549920ull, 15014496967820701294ull,
  14616999597052546651ull, 7743922390139133230ull}},
{{1100347985408580796ull, 7078217595674244357ull,
  4523938729730453753ull, 4839951493836958269ull}},
{{5987121000188113899ull, 13459458013020193350ull,
  10266609430590455095ull, 6049939367296197836ull}},
{{16707273287089918182ull, 12212636497847853783ull,
  12833261788238068869ull, 7562424209120247295ull}},
{{17359574832072280720ull, 9938740820368602566ull,
  14938317645289874899ull, 4726515130700154559ull}},
{{12476096503235575092ull, 7811740007033365304ull,
  14061211038184955720ull, 5908143913375193199ull}},
{{15595120629044468864ull, 9764675008791706630ull,
  12964827779303806746ull, 7385179891718991499ull}},
{{5135264374725405136ull, 10714607898922204548ull,
  5797174352851185264ull, 4615737432324369687ull}},
{{6419080468406756420ull, 13393259873652755685ull,
  2634781922636593676ull, 5769671790405462109ull}},
{{12635536603935833429ull, 16741574842065944606ull,
  7905163421723129999ull, 7212089738006827636ull}},
{{6571048718065015979ull, 16315282534155042854ull,
  9881454277153912499ull, 9015112172508534545ull}},
{{17941963504072798699ull, 7891208574633207831ull,
  17705123969289665072ull, 5634445107817834090ull}},
{{17815768361663610469ull, 9864010718291509789ull,
  12908032924757305532ull, 7043056384772292613ull}},
{{8434652396797349375ull, 12330013397864387237ull,
  2299983100664468203ull, 8803820480965365767ull}},
{{7577500757212037311ull, 5400415364451548071ull,
  8355018465556374483ull, 5502387800603353604ull}},
{{4860189928087658735ull, 2138833187137047185ull,
  10443773081945468104ull, 6877984750754192005ull}},
{{10686923428536961323ull, 2673541483921308981ull,
  17666402370859223034ull, 8597480938442740006ull}},
{{8985170152049294779ull, 6282649445878206017ull,
  6429815463359626492ull, 5373425586526712504ull}},
{{15843148708489006377ull, 7853311807347757521ull,
  8037269329199533115ull, 6716781983158390630ull}},
{{5968877830329094260ull, 5204953740757308998ull, 823214624644640586ull,
  8395977478947988288ull}},
{{17565606699237847624ull, 7864782106400706027ull,
  514509140402900366ull, 5247485924342492680ull}},
{{17345322355619921626ull, 607605596146106726ull, 643136425503625458ull,
  6559357405428115850ull}},
{{12458280907670126225ull, 9982879032037409216ull,
  10027292568734307630ull, 8199196756785144812ull}},
{{7786425567293828891ull, 1627613376595992856ull,
  15490429892313718077ull, 5124497972990715507ull}},
{{9733031959117286113ull, 6646202739172378974ull,
  14751351346964759692ull, 6405622466238394384ull}},
{{2942917912041831834ull, 8307753423965473718ull,
  18439189183705949615ull, 8007028082797992980ull}},
{{15674381750308308608ull, 12109874917619502929ull,
  2301121202961442701ull, 5004392551748745613ull}},
{{5757919132603222048ull, 1302285591742214950ull,
  7488087522129191281ull, 6255490689685932016ull}},
{{16420770952608803368ull, 6239543008105156591ull,
  9360109402661489101ull, 7819363362107415020ull}},
{{17180510873021583961ull, 6205557389279416821ull,
  15073440413518206496ull, 4887102101317134387ull}},
{{7640580535994816239ull, 7756946736599271027ull,
  14230114498470370216ull, 6108877626646417984ull}},
{{4939039651566132395ull, 9696183420749088784ull,
  17787643123087962770ull, 7636097033308022480ull}},
{{3086899782228832747ull, 10671800656395568394ull,
  11117276951929976731ull, 4772560645817514050ull}},
{{13081996764640816742ull, 8728064802067072588ull,
  4673224153057695106ull, 5965700807271892563ull}},
{{16352495955801020927ull, 1686708965729064927ull,
  1229844172894730979ull, 7457126009089865704ull}},
{{17137839000016719936ull, 17195094168076523243ull,
  768652608059206861ull, 4660703755681166065ull}},
{{16810612731593512015ull, 7658809654813490342ull,
  5572501778501396481ull, 5825879694601457581ull}},
{{11789893877637114211ull, 14185198086944250832ull,
  11577313241554133505ull, 7282349618251821976ull}},
{{14737367347046392764ull, 3896439553398149828ull,
  14471641551942666882ull, 9102937022814777470ull}},
{{18434226628758771286ull, 7046960739301231546ull,
  4433089951536778897ull, 5689335639259235919ull}},
{{13819411249093688299ull, 13420386942553927337ull,
  929676420993585717ull, 7111669549074044899ull}},
{{3439206006084946661ull, 2940425622910245460ull,
  14997153581524145859ull, 8889586936342556123ull}},
{{11372875790657867472ull, 17978667078814761076ull,
  7067377979238897209ull, 5555991835214097577ull}},
{{14216094738322334339ull, 8638275793236287633ull,
  13445908492476009416ull, 6944989794017621971ull}},
{{3935060367620754212ull, 10797844741545359542ull,
  12195699597167623866ull, 8681237242522027464ull}},
{{16294470785045135095ull, 11360338981893237617ull,
  7622312248229764916ull, 5425773276576267165ull}},
{{6533030426024255156ull, 14200423727366547022ull,
  14139576328714594049ull, 6782216595720333956ull}},
{{17389660069385094753ull, 3915471603926020065ull,
  17674470410893242562ull, 8477770744650417445ull}},
{{3951008515724602365ull, 7058855770881150445ull,
  13352387016021970553ull, 5298606715406510903ull}},
{{9550446663083140860ull, 13435255732028825960ull,
  12078797751600075287ull, 6623258394258138629ull}},
{{11938058328853926075ull, 12182383646608644546ull,
  1263439134217930397ull, 8279072992822673287ull}},
{{12072972473961091701ull, 9919832788344096793ull,
  7707178486527288354ull, 5174420620514170804ull}},
{{1256157537169200914ull, 3176418948575345184ull,
  9633973108159110443ull, 6468025775642713505ull}},
{{1570196921461501143ull, 17805581741001345192ull,
  16654152403626275957ull, 8085032219553391881ull}},
{{981373075913438214ull, 13434331597339534697ull,
  3491316224625340617ull, 5053145137220869926ull}},
{{5838402363319185672ull, 2957856441392254659ull,
  13587517317636451580ull, 6316431421526087407ull}},
{{2686316935721594185ull, 3697320551740318324ull,
  12372710628618176571ull, 7895539276907609259ull}},
{{10902320121680772174ull, 4982335624005000ull, 5427101133672666405ull,
  4934712048067255787ull}},
{{13627900152100965218ull, 4617913937957394154ull,
  2172190398663445102ull, 6168390060084069734ull}},
{{7811503153271430714ull, 14995764459301518501ull,
  11938610035184082185ull, 7710487575105087167ull}},
{{7188032480008338148ull, 2454823759422367207ull,
  14379160299631133222ull, 4819054734440679479ull}},
{{4373354581583034781ull, 12291901736132734817ull,
  13362264356111528623ull, 6023818418050849349ull}},
{{10078379245406181380ull, 10753191151738530617ull,
  2867772389857247067ull, 7529773022563561687ull}},
{{17828202074447333123ull, 4414901460622887683ull,
  8709886771301861273ull, 4706108139102226054ull}},
{{17673566574631778500ull, 10130312844205997508ull,
  1663986427272550783ull, 5882635173877782568ull}},
{{3645214144580171508ull, 8051205036830108982ull,
  2079983034090688479ull, 7353293967347228210ull}},
{{13779889717579990193ull, 5452320277610248323ull,
  11823350829468136407ull, 9191617459184035262ull}},
{{6306588064273799919ull, 10325229201147487058ull,
  2777908249990197350ull, 5744760911990022039ull}},
{{17106607117197025707ull, 3683164464579583014ull,
  17307443367769910400ull, 7180951139987527548ull}},
{{12159886859641506325ull, 4603955580724478768ull,
  3187560136002836384ull, 8976188924984409436ull}},
{{7599929287275941453ull, 2877472237952799230ull,
  11215597121856548548ull, 5610118078115255897ull}},
{{276539572240151009ull, 3596840297440999038ull, 184438347038521973ull,
  7012647597644069872ull}},
{{9569046502154964569ull, 9107736390228636701ull, 230547933798152466ull,
  8765809497055087340ull}},
{{8286497073060546808ull, 10304021262320285842ull,
  9367464495478621099ull, 5478630935659429587ull}},
{{1134749304470907701ull, 8268340559472969399ull,
  7097644600920888470ull, 6848288669574286984ull}},
{{15253494685870798339ull, 1112053662486435940ull,
  8872055751151110588ull, 8560360836967858730ull}},
{{310062141814473154ull, 9918405575908798271ull,
  10156720862896832021ull, 5350225523104911706ull}},
{{14222635732550255154ull, 17009692988313385742ull,
  3472529041766264218ull, 6687781903881139633ull}},
{{8554922628833043135ull, 12038744198536956370ull,
  8952347320635218177ull, 8359727379851424541ull}},
{{9958512661448039863ull, 606686096444515875ull, 7901060084610705313ull,
  5224829612407140338ull}},
{{7836454808382661925ull, 5370043638983032748ull, 652953068908605833ull,
  6531037015508925423ull}},
{{9795568510478327406ull, 11324240567156178839ull,
  14651249391417921003ull, 8163796269386156778ull}},
{{13039759346690036485ull, 4771807345258917822ull,
  13768716888063588531ull, 5102372668366347986ull}},
{{7076327146507769798ull, 1353073163146259374ull,
  7987524073224709856ull, 6377965835457934983ull}},
{{18068780969989488056ull, 1691341453932824217ull,
  5372719073103499416ull, 7972457294322418729ull}},
{{4375459078602348179ull, 1057088408708015136ull,
  14887164466758156895ull, 4982785808951511705ull}},
{{5469323848252935223ull, 15156418566167182632ull,
  4773897528165532406ull, 6228482261189389632ull}},
{{6836654810316169029ull, 9722151170854202482ull,
  5967371910206915508ull, 7785602826486737040ull}},
{{8884595274874993547ull, 15299716518638652359ull,
  3729607443879322192ull, 4866001766554210650ull}},
{{6494058075166354030ull, 677901574588763833ull,
  13885381341703928549ull, 6082502208192763312ull}},
{{12729258612385330442ull, 5459062986663342695ull,
  17356726677129910686ull, 7603127760240954140ull}},
{{14873315660381913382ull, 17246972421946752896ull,
  1624582136351418370ull, 4751954850150596338ull}},
{{144900501767840112ull, 12335343490578665313ull,
  11254099707294048771ull, 5939943562688245422ull}},
{{4792811645637188043ull, 10807493344795943737ull,
  4844252597262785156ull, 7424929453360306778ull}},
{{14524722324591712287ull, 15978055377352240643ull,
  7639343891716628626ull, 4640580908350191736ull}},
{{13544216887312252455ull, 10749197184835524996ull,
  9549179864645785783ull, 5800726135437739670ull}},
{{16930271109140315569ull, 8824810462617018341ull,
  2713102793952456421ull, 7250907669297174588ull}},
{{7327780831143230749ull, 15642699096698660831ull,
  3391378492440570526ull, 9063634586621468235ull}},
{{11497392047105601074ull, 5165000917009275115ull,
  18260512622271214243ull, 5664771616638417646ull}},
{{9760054040454613439ull, 1844565127834205990ull,
  13602268740984241996ull, 7080964520798022058ull}},
{{2976695513713490990ull, 2305706409792757488ull,
  7779463889375526687ull, 8851205650997527573ull}},
{{1860434696070931869ull, 8358595533761555286ull,
  7168007940073398131ull, 5532003531873454733ull}},
{{11548915406943440644ull, 5836558398774556203ull,
  13571695943519135568ull, 6915004414841818416ull}},
{{9824458240251912901ull, 7295697998468195254ull,
  16964619929398919460ull, 8643755518552273020ull}},
{{1528600381730057659ull, 13783183285897397842ull,
  1379515419019548854ull, 5402347199095170638ull}},
{{11134122514017347882ull, 8005607070516971494ull,
  10947766310629211876ull, 6752933998868963297ull}},
{{4694281105666909044ull, 10007008838146214368ull,
  18296393906713902749ull, 8441167498586204121ull}},
{{2933925691041818153ull, 8560223533055077932ull,
  4517717164055107362ull, 5275729686616377576ull}},
{{3667407113802272691ull, 1476907379464071607ull,
  5647146455068884203ull, 6594662108270471970ull}},
{{18419316947535004576ull, 15681192279612253220ull,
  16282305105690881061ull, 8243327635338089962ull}},
{{2288701055354602052ull, 12106588183971352215ull,
  14788126709484188567ull, 5152079772086306226ull}},
{{16695934374475416277ull, 10521549211536802364ull,
  9261786350000459901ull, 6440099715107882783ull}},
{{2423173894384718730ull, 17763622532848390860ull,
  6965546919073186972ull, 8050124643884853479ull}},
{{10737855720845225014ull, 1878892046175468479ull,
  11270995852061823714ull, 5031327902428033424ull}},
{{8810633632629143364ull, 11571987094574111407ull,
  14088744815077279642ull, 6289159878035041780ull}},
{{6401606022359041301ull, 5241611831362863451ull,
  17610931018846599553ull, 7861449847543802225ull}},
{{1695160754760706861ull, 14805222440670259417ull,
  4089302859138042864ull, 4913406154714876391ull}},
{{6730636961878271480ull, 59783977128272655ull, 499942555495165677ull,
  6141757693393595489ull}},
{{3801610183920451446ull, 4686415989837728723ull,
  5236614212796345000ull, 7677197116741994361ull}},
{{70163355736588202ull, 2929009993648580452ull, 14802098929066185385ull,
  4798248197963746475ull}},
{{87704194670735252ull, 8272948510488113469ull, 13890937642905343827ull,
  5997810247454683094ull}},
{{4721316261765806969ull, 5729499619682753932ull,
  8140300016776903976ull, 7497262809318353868ull}},
{{12174194700458405164ull, 3580937262301721207ull,
  14311059547340340793ull, 4685789255823971167ull}},
{{10606057357145618551ull, 9087857596304539413ull,
  13277138415748038087ull, 5857236569779963959ull}},
{{17869257714859411093ull, 6748135976953286362ull,
  11984737001257659705ull, 7321545712224954949ull}},
{{13113200106719488058ull, 13046855989618995857ull,
  1145863196289910919ull, 9151932140281193687ull}},
{{1278221039058598180ull, 15071814021152954267ull,
  7633693525322276180ull, 5719957587675746054ull}},
{{15432834354105411437ull, 393023452731641217ull, 318744869798069418ull,
  7149946984594682568ull}},
{{5455984887349600584ull, 9714651352769327330ull, 398431087247586772ull,
  8937433730743353210ull}},
{{8021676573020888269ull, 15295029132335605389ull,
  4860705447957129636ull, 5585896081714595756ull}},
{{14638781734703498241ull, 672042341709955120ull,
  6075881809946412046ull, 6982370102143244695ull}},
{{18298477168379372801ull, 10063424963992219708ull,
  2983166244005627153ull, 8727962627679055869ull}},
{{2213176193382332193ull, 17818855648563607078ull,
  4170321911717210922ull, 5454976642299409918ull}},
{{11989842278582691049ull, 13050197523849733039ull,
  14436274426501289461ull, 6818720802874262397ull}},
{{10375616829800975907ull, 2477688849530002587ull,
  4210284977844448115ull, 8523401003592827997ull}},
{{4178917509411915990ull, 17689456595452109281ull,
  4937271120366474023ull, 5327125627245517498ull}},
{{9835332905192282891ull, 17500134725887748697ull,
  15394960937312868337ull, 6658907034056896872ull}},
{{16905852149917741518ull, 8040110352077522159ull,
  796957097931533806ull, 8323633792571121091ull}},
{{17483686621339670305ull, 413382951621063445ull,
  16638999250703066293ull, 5202271120356950681ull}},
{{8019550221392424169ull, 5128414707953717211ull,
  6963691008096669154ull, 6502838900446188352ull}},
{{5412751758313142307ull, 15633890421796922322ull,
  8704613760120836442ull, 8128548625557735440ull}},
{{7994655867373101846ull, 14382867532050464355ull,
  5440383600075522776ull, 5080342890973584650ull}},
{{5381633815788989403ull, 17978584415063080444ull,
  16023851536949179278ull, 6350428613716980812ull}},
{{6727042269736236754ull, 13249858481974074747ull,
  1583070347476922482ull, 7938035767146226016ull}},
{{1898558409371454020ull, 12892847569661184621ull,
  989418967173076551ull, 4961272354466391260ull}},
{{6984884030141705428ull, 11504373443649092872ull,
  1236773708966345689ull, 6201590443082989075ull}},
{{8731105037677131785ull, 545408749279202378ull,
  15381025191490095824ull, 7751988053853736343ull}},
{{10068626666975595270ull, 340880468299501486ull,
  16530669772322391746ull, 4844992533658585214ull}},
{{3362411296864718279ull, 9649472622229152666ull,
  11439965178548213874ull, 6056240667073231518ull}},
{{13426386157935673657ull, 2838468740931665024ull,
  5076584436330491535ull, 7570300833841539398ull}},
{{8391491348709796036ull, 8691571990723372496ull,
  17007923327988720921ull, 4731438021150962123ull}},
{{10489364185887245045ull, 15476151006831603524ull,
  16648218141558513247ull, 5914297526438702654ull}},
{{13111705232359056306ull, 14733502740112116501ull,
  11586900640093365751ull, 7392871908048378318ull}},
{{10500658779438104143ull, 16125968240211154669ull,
  2630126881630965690ull, 4620544942530236449ull}},
{{17737509492725018083ull, 10934088263409167528ull,
  7899344620466095017ull, 5775681178162795561ull}},
{{3725142792196720988ull, 18279296347688847315ull,
  14485866794010006675ull, 7219601472703494451ull}},
{{44742471818513330ull, 18237434416183671240ull,
  13495647474085120440ull, 9024501840879368064ull}},
{{27964044886570832ull, 11398396510114794525ull, 8434779671303200275ull,
  5640313650549605040ull}},
{{4646641074535601443ull, 9636309619216105252ull,
  10543474589129000344ull, 7050392063187006300ull}},
{{5808301343169501804ull, 12045387024020131565ull,
  13179343236411250430ull, 8812990078983757875ull}},
{{5936031348694632580ull, 2916680871585194324ull,
  5931246513543337567ull, 5508118799364848672ull}},
{{7420039185868290725ull, 17480909144763656617ull,
  7414058141929171958ull, 6885148499206060840ull}},
{{13886735000762751310ull, 12627764394099794963ull,
  9267572677411464948ull, 8606435624007576050ull}},
{{6373366366263025617ull, 17115724783167147660ull,
  10403918941809553496ull, 5379022265004735031ull}},
{{7966707957828782021ull, 2947911905249382959ull,
  8393212658834553967ull, 6723777831255918789ull}},
{{5346698928858589622ull, 17519947936843892411ull,
  15103201841970580362ull, 8404722289069898486ull}},
{{1035843821322924562ull, 15561653478954820661ull,
  4827815132804224822ull, 5252951430668686554ull}},
{{5906490795081043606ull, 10228694811838750018ull,
  15258140952860056836ull, 6566189288335858192ull}},
{{16606485530706080316ull, 12785868514798437522ull,
  625932117365519429ull, 8207736610419822741ull}},
{{14990739475118688101ull, 10297010830962717403ull,
  2697050582567143595ull, 5129835381512389213ull}},
{{14126738325470972223ull, 8259577520276008850ull,
  7982999246636317398ull, 6412294226890486516ull}},
{{8435050869983939470ull, 1101099863490235255ull,
  9978749058295396748ull, 8015367783613108145ull}},
{{12189435821381044025ull, 9911559451536172842ull,
  17765933207503092727ull, 5009604864758192590ull}},
{{6013422739871529223ull, 7777763295992828149ull,
  12984044472524090101ull, 6262006080947740738ull}},
{{12128464443266799433ull, 14333890138418423090ull,
  7006683553800336818ull, 7827507601184675923ull}},
{{12191976295469137550ull, 13570367354938902335ull,
  2073334211911516559ull, 4892192250740422452ull}},
{{10628284350909034033ull, 12351273175246240015ull,
  2591667764889395699ull, 6115240313425528065ull}},
{{8673669420208904637ull, 10827405450630412115ull,
  7851270724539132528ull, 7644050391781910081ull}},
{{3115200378416871446ull, 6767128406644007572ull,
  16436259248905427590ull, 4777531494863693800ull}},
{{3894000473021089308ull, 17682282545159785273ull,
  2098579987422232871ull, 5971914368579617251ull}},
{{9479186609703749539ull, 17491167163022343687ull,
  16458283039559954801ull, 7464892960724521563ull}},
{{12842020658705925318ull, 4014450449247882948ull,
  7980583890511277799ull, 4665558100452825977ull}},
{{16052525823382406647ull, 406377043132465781ull,
  14587415881566485153ull, 5831947625566032471ull}},
{{6230599223945844597ull, 5119657322342970131ull,
  13622583833530718537ull, 7289934531957540589ull}},
{{3176563011504917842ull, 11011257671356100568ull,
  3193171736631234459ull, 9112418164946925737ull}},
{{1985351882190573652ull, 4576193035383868903ull,
  13524947381462991297ull, 5695261353091828585ull}},
{{16316747908020380776ull, 10331927312657224032ull,
  3071126171546575409ull, 7119076691364785732ull}},
{{1949190811315924354ull, 17526595159248917945ull,
  3838907714433219261ull, 8898845864205982165ull}},
{{12747459303140922482ull, 13259964983744267667ull,
  4705160330734455990ull, 5561778665128738853ull}},
{{11322638110498765198ull, 7351584192825558776ull,
  10493136431845457892ull, 6952223331410923566ull}},
{{14153297638123456497ull, 9189480241031948470ull,
  3893048502952046557ull, 8690279164263654458ull}},
{{4234125005399772407ull, 8049268159858661746ull,
  7044841332772417002ull, 5431424477664784036ull}},
{{14516028293604491317ull, 838213162968551374ull,
  8806051665965521253ull, 6789280597080980045ull}},
{{8921663330150838338ull, 5659452472138077122ull,
  15619250600884289470ull, 8486600746351225056ull}},
{{10187725599771661865ull, 17372215850368461913ull,
  9762031625552680918ull, 5304125466469515660ull}},
{{17346343018141965235ull, 12491897776105801583ull,
  12202539531940851148ull, 6630156833086894575ull}},
{{17071242754250068640ull, 15614872220132251979ull,
  10641488396498676031ull, 8287696041358618219ull}},
{{8363683712192598948ull, 16676824165223739343ull,
  4345087238597978567ull, 5179810025849136387ull}},
{{5842918621813360781ull, 16234344188102286275ull,
  819673029820085305ull, 6474762532311420484ull}},
{{2691962258839313072ull, 6457872179845694132ull,
  1024591287275106632ull, 8093453165389275605ull}},
{{10905848448629346478ull, 4036170112403558832ull,
  2946212563760635597ull, 5058408228368297253ull}},
{{13632310560786683098ull, 9656898658931836444ull,
  8294451723128182400ull, 6323010285460371566ull}},
{{17040388200983353872ull, 12071123323664795555ull,
  1144692617055452192ull, 7903762856825464458ull}},
{{8344399616400902218ull, 7544452077290497222ull,
  5327118904087045524ull, 4939851785515915286ull}},
{{1207127483646351965ull, 9430565096613121528ull,
  15882270666963582713ull, 6174814731894894107ull}},
{{1508909354557939956ull, 16399892389193789814ull,
  15241152315277090487ull, 7718518414868617634ull}},
{{14778126401880876185ull, 17167461770887200489ull,
  14137406215475569458ull, 4824074009292886021ull}},
{{4637599947068931519ull, 12235955176754224804ull,
  3836699714062298111ull, 6030092511616107527ull}},
{{5796999933836164398ull, 10683257952515393101ull,
  184188624150484735ull, 7537615639520134409ull}},
{{5928967967861296701ull, 13594565247963202544ull,
  11644332936162522719ull, 4711009774700084005ull}},
{{7411209959826620876ull, 12381520541526615276ull,
  720358114920989687ull, 5888762218375105007ull}},
{{9264012449783276095ull, 10865214658480881191ull,
  14735505698933400821ull, 7360952772968881258ull}},
{{6968329543801707215ull, 18193204341528489393ull,
  9196010086811975218ull, 9201190966211101573ull}},
{{15884421010944536769ull, 15982438731882693774ull,
  8053349313471178463ull, 5750744353881938483ull}},
{{10632154226825895154ull, 15366362396425979314ull,
  5455000623411585175ull, 7188430442352423104ull}},
{{4066820746677593134ull, 14596266977105086239ull,
  6818750779264481469ull, 8985538052940528880ull}},
{{9459291994314577565ull, 11428509869904372851ull,
  4261719237040300918ull, 5615961283087830550ull}},
{{7212428974465834052ull, 5062265300525690256ull,
  14550521083155151956ull, 7019951603859788187ull}},
{{9015536218082292565ull, 6327831625657112820ull,
  13576465335516552041ull, 8774939504824735234ull}},
{{14858082173156208661ull, 15484109812104165272ull,
  13096976853125232929ull, 5484337190515459521ull}},
{{125858642735709210ull, 5520079209848042879ull, 2536163011124377450ull,
  6855421488144324402ull}},
{{13992381358701800225ull, 16123471049164829406ull,
  12393575800760247620ull, 8569276860180405502ull}},
{{4133552330761237237ull, 853797368873242571ull, 3134298857047766859ull,
  5355798037612753439ull}},
{{555254395024158642ull, 14902304766373716926ull,
  17752931626591872285ull, 6694747547015941798ull}},
{{9917440030634974110ull, 4792822902684982445ull,
  12967792496385064549ull, 8368434433769927248ull}},
{{8504243028360552771ull, 5301357323391807980ull,
  8104870310240665343ull, 5230271521106204530ull}},
{{10630303785450690964ull, 2015010635812372071ull,
  907715850946055871ull, 6537839401382755663ull}},
{{8676193713385975800ull, 16353821350047628801ull,
  14969702868964733550ull, 8172299251728444578ull}},
{{16951836116934704635ull, 5609452325352380096ull,
  13967750311530346373ull, 5107687032330277861ull}},
{{2743051072458829178ull, 11623501425117863025ull,
  3624629834130769254ull, 6384608790412847327ull}},
{{8040499859000924377ull, 5306004744542552973ull,
  18365845347945625280ull, 7980760988016059158ull}},
{{7331155421089271688ull, 3316252965339095608ull,
  6866967324038627896ull, 4987975617510036974ull}},
{{9163944276361589609ull, 4145316206673869510ull,
  17807081191903060678ull, 6234969521887546217ull}},
{{2231558308597211203ull, 14405017295197112696ull,
  8423793434596662135ull, 7793711902359432772ull}},
{{1394723942873257002ull, 15920664837139277291ull,
  14488242933477689642ull, 4871069938974645482ull}},
{{15578462983873734965ull, 10677459009569320805ull,
  8886931629992336245ull, 6088837423718306853ull}},
{{5638020674560004994ull, 17958509780389038911ull,
  15720350555917808210ull, 7611046779647883566ull}},
{{10441291949241084977ull, 15835754631170537223ull,
  5213533079021242227ull, 4756904237279927229ull}},
{{8439928918123968318ull, 15183007270535783625ull,
  11128602367203940688ull, 5946130296599909036ull}},
{{15161597166082348301ull, 532015014460177915ull,
  13910752959004925861ull, 7432662870749886295ull}},
{{7170155219587773736ull, 2638352393251305149ull,
  15611749627019160519ull, 4645414294218678934ull}},
{{13574380042912105074ull, 17132998546846295148ull,
  10291314996919174840ull, 5806767867773348668ull}},
{{16967975053640131343ull, 2969504109848317319ull,
  12864143746148968551ull, 7258459834716685835ull}},
{{16598282798622776274ull, 17546938192592560361ull,
  11468493664258822784ull, 9073074793395857294ull}},
{{3456397721498153315ull, 10966836370370350226ull,
  2556122521734376336ull, 5670671745872410809ull}},
{{13543869188727467452ull, 13708545462962937782ull,
  7806839170595358324ull, 7088339682340513511ull}},
{{7706464449054558507ull, 17135681828703672228ull,
  5146862944816810001ull, 8860424602925641889ull}},
{{14039912317513874875ull, 3792272115298713286ull,
  14746004386578976011ull, 5537765376828526180ull}},
{{8326518360037567786ull, 128654125696003704ull,
  18432505483223720014ull, 6922206721035657725ull}},
{{10408147950046959732ull, 9384189693974780438ull,
  9205573798747486305ull, 8652758401294572157ull}},
{{1893406450351961929ull, 17394333604802707534ull,
  8059326633430872892ull, 5407974000809107598ull}},
{{11590130099794728219ull, 3296172932293832801ull,
  850786254933815308ull, 6759967501011384498ull}},
{{652604569461246561ull, 4120216165367291002ull,
  10286854855522044943ull, 8449959376264230622ull}},
{{5019563874340667005ull, 9492664130995638732ull,
  1817598266273890185ull, 5281224610165144139ull}},
{{6274454842925833756ull, 16477516182171936319ull,
  16107055888124526443ull, 6601530762706430173ull}},
{{3231382535229904291ull, 15985209209287532495ull,
  6298761804873494342ull, 8251913453383037717ull}},
{{8937143112159772038ull, 5379069737377319905ull,
  6242569137259627916ull, 5157445908364398573ull}},
{{15783114908627102952ull, 6723837171721649881ull,
  12414897440001922799ull, 6446807385455498216ull}},
{{5893835580501714977ull, 3793110446224674448ull,
  15518621800002403499ull, 8058509231819372770ull}},
{{3683647237813571861ull, 64851019676727578ull, 14310824643428890091ull,
  5036568269887107981ull}},
{{13827931084121740634ull, 13916121829878073184ull,
  4053472749003948901ull, 6295710337358884977ull}},
{{17284913855152175793ull, 3560094232065427768ull,
  9678526954682324031ull, 7869637921698606221ull}},
{{10803071159470109871ull, 9142587922681974211ull,
  8354922355890146471ull, 4918523701061628888ull}},
{{8892152930910249434ull, 6816548884925079860ull,
  10443652944862683089ull, 6148154626327036110ull}},
{{11115191163637811792ull, 13132372124583737729ull,
  3831194144223578053ull, 7685193282908795138ull}},
{{29465449632550514ull, 10513575587078530033ull, 7006182358567124187ull,
  4803245801817996961ull}},
{{4648517830468076047ull, 8530283465420774637ull,
  13369413966636293138ull, 6004057252272496201ull}},
{{10422333306512482963ull, 1439482294921192488ull,
  2876709403013202711ull, 7505071565340620252ull}},
{{6513958316570301852ull, 7817205461966827161ull,
  11021315413738027502ull, 4690669728337887657ull}},
{{12754133914140265219ull, 548134790603758143ull,
  18388330285599922282ull, 5863337160422359571ull}},
{{11330981374247943619ull, 9908540525109473487ull,
  18373726838572514948ull, 7329171450527949464ull}},
{{9552040699382541620ull, 12385675656386841859ull,
  4520414474506092069ull, 9161464313159936831ull}},
{{3664182427900394561ull, 10046890294455470114ull,
  9742788074207389399ull, 5725915195724960519ull}},
{{13803600071730269009ull, 7946926849641949738ull,
  7566799074331848845ull, 7157393994656200649ull}},
{{8031128052808060453ull, 14545344580479825077ull,
  14070184861342198960ull, 8946742493320250811ull}},
{{7325298042218731735ull, 9090840362799890673ull,
  6488022529125180398ull, 5591714058325156757ull}},
{{13768308571200802573ull, 2140178416645087533ull,
  12721714179833863402ull, 6989642572906445946ull}},
{{3375327658718839504ull, 11898595057661135225ull,
  6678770687937553444ull, 8737053216133057433ull}},
{{13638794832767744450ull, 16659993947892985323ull,
  15703446726029440662ull, 5460658260083160895ull}},
{{12436807522532292658ull, 11601620398011455846ull,
  15017622389109412924ull, 6825822825103951119ull}},
{{6322637366310590015ull, 14502025497514319808ull,
  14160341967959378251ull, 8532278531379938899ull}},
{{3951648353944118760ull, 6757922926732755928ull,
  6544370720760917455ull, 5332674082112461812ull}},
{{4939560442430148449ull, 3835717639988557006ull,
  8180463400951146819ull, 6665842602640577265ull}},
{{15397822589892461369ull, 182961031558308353ull,
  14837265269616321428ull, 8332303253300721581ull}},
{{2706110091041706500ull, 9337722681578718529ull,
  11579133802723894844ull, 5207689533312950988ull}},
{{7994323632229521029ull, 11672153351973398161ull,
  14473917253404868555ull, 6509611916641188735ull}},
{{14604590558714289190ull, 9978505671539359797ull,
  13480710548328697790ull, 8137014895801485919ull}},
{{11433712108410124696ull, 1624880026284711969ull,
  15342973120346517975ull, 5085634309875928699ull}},
{{457082080230492158ull, 15866158088138053674ull,
  14567030382005759564ull, 6357042887344910874ull}},
{{9794724637142891005ull, 1385953536463015476ull,
  8985415940652423648ull, 7946303609181138593ull}},
{{15345074935069082686ull, 866220960289384672ull,
  17145100008976234540ull, 4966439755738211620ull}},
{{734599595126801742ull, 1082776200361730841ull, 2984630937510741559ull,
  6208049694672764526ull}},
{{5529935512335890081ull, 15188528305734327263ull,
  12954160708743202756ull, 7760062118340955657ull}},
{{10373738722851013157ull, 269458154229178731ull,
  1178821415323419867ull, 4850038823963097286ull}},
{{8355487385136378542ull, 14171880748068637126ull,
  10696898806009050641ull, 6062548529953871607ull}},
{{1220987194565697370ull, 3879792879803632696ull,
  8759437489083925398ull, 7578185662442339509ull}},
{{763116996603560856ull, 16259928605159434147ull,
  7780491439891147325ull, 4736366039026462193ull}},
{{14788954301036614782ull, 6489852701167128971ull,
  14337300318291322061ull, 5920457548783077741ull}},
{{13874506857868380573ull, 12724001894886299118ull,
  4086567342581988864ull, 7400571935978847177ull}},
{{4059880767740349955ull, 7952501184303936949ull,
  14083319635182212800ull, 4625357459986779485ull}},
{{9686536978102825347ull, 9940626480379921186ull,
  3769091488695602288ull, 5781696824983474357ull}},
{{2884799185773755876ull, 12425783100474901483ull,
  9323050379296890764ull, 7227121031229342946ull}},
{{17441057037499358557ull, 15532228875593626853ull,
  2430440937266337647ull, 9033901289036678683ull}},
{{13206503657650793050ull, 16625172074887098639ull,
  17659926650287318693ull, 5646188305647924176ull}},
{{11896443553636103408ull, 6946407038326709587ull,
  3628164239149596751ull, 7057735382059905221ull}},
{{10258868423617741356ull, 4071322779480999080ull,
  9146891317364383843ull, 8822169227574881526ull}},
{{6411792764761088348ull, 238733727961930473ull, 1105121054925351998ull,
  5513855767234300954ull}},
{{12626426974378748339ull, 9521789196807188899ull,
  10604773355511465805ull, 6892319709042876192ull}},
{{11171347699546047519ull, 16513922514436374028ull,
  13255966694389332256ull, 8615399636303595240ull}},
{{16205464349071055508ull, 10321201571522733767ull,
  8284979183993332660ull, 5384624772689747025ull}},
{{15645144417911431481ull, 12901501964403417209ull,
  14967909998419053729ull, 6730780965862183781ull}},
{{5721372467107125639ull, 2291819400222107800ull,
  4874829442741653450ull, 8413476207327729727ull}},
{{3575857791941953524ull, 6044073143566205279ull,
  9964297429354615262ull, 5258422629579831079ull}},
{{18304880295209605617ull, 16778463466312532406ull,
  7843685768265881173ull, 6573028286974788849ull}},
{{13657728332157231214ull, 7138021277608501796ull,
  14416293228759739371ull, 8216285358718486061ull}},
{{17759452244453045317ull, 2155420289291619670ull,
  11316026277188531059ull, 5135178349199053788ull}},
{{12975943268711530838ull, 16529333416896688300ull,
  14145032846485663823ull, 6418972936498817235ull}},
{{16219929085889413547ull, 16049980752693472471ull,
  13069605039679691875ull, 8023716170623521544ull}},
{{17054984706321965323ull, 7725394961219726342ull,
  8168503149799807422ull, 5014822606639700965ull}},
{{12095358846047680846ull, 433371664669882120ull,
  14822314955677147182ull, 6268528258299626206ull}},
{{15119198557559601057ull, 9765086617692128458ull,
  9304521657741658169ull, 7835660322874532758ull}},
{{14061185116902138565ull, 17632394182126050046ull,
  1203640017661148451ull, 4897287701796582974ull}},
{{8353109359272897398ull, 17428806709230174654ull,
  10727922058931211372ull, 6121609627245728717ull}},
{{1218014662236345939ull, 3339264312828166702ull,
  18021588592091402120ull, 7652012034057160896ull}},
{{14596317219179879924ull, 2087040195517604188ull,
  11263492870057126325ull, 4782507521285725560ull}},
{{18245396523974849905ull, 7220486262824393139ull,
  14079366087571407906ull, 5978134401607156950ull}},
{{18195059636541174477ull, 18248979865385267232ull,
  8375835572609484074ull, 7472668002008946188ull}},
{{11371912272838234049ull, 16017298434293179924ull,
  14458269269735703354ull, 4670417501255591367ull}},
{{14214890341047792561ull, 10798251006011699097ull,
  13461150568742241289ull, 5838021876569489209ull}},
{{3933554871027576989ull, 18109499775942011776ull,
  2991380155645637899ull, 7297527345711861512ull}},
{{4916943588784471236ull, 18025188701500126816ull,
  3739225194557047374ull, 9121909182139826890ull}},
{{3073089742990294522ull, 6654056920010191356ull,
  6948701765025542513ull, 5701193238837391806ull}},
{{3841362178737868153ull, 12929257168440127099ull,
  17909249243136703949ull, 7126491548546739757ull}},
{{190016704994947287ull, 2326513405267995162ull, 8551503498638716225ull,
  8908114435683424697ull}},
{{4730446459049229959ull, 12983285924360966736ull,
  16873904732717667400ull, 5567571522302140435ull}},
{{5913058073811537448ull, 16229107405451208420ull,
  16480694897469696346ull, 6959464402877675544ull}},
{{7391322592264421810ull, 11063012219959234717ull,
  2154124548127568817ull, 8699330503597094431ull}},
{{6925419629378957583ull, 18443597683542991458ull,
  8263856870220812366ull, 5437081564748184019ull}},
{{17880146573578472787ull, 13831125067573963514ull,
  5718135069348627554ull, 6796351955935230024ull}},
{{13126811180118315176ull, 8065534297612678585ull,
  7147668836685784443ull, 8495439944919037530ull}},
{{1286727959932865129ull, 2735115926794230164ull,
  9078979041356003181ull, 5309649965574398456ull}},
{{1608409949916081411ull, 8030580926920175609ull,
  11348723801695003976ull, 6637062456967998070ull}},
{{6622198455822489668ull, 10038226158650219511ull,
  4962532715263979162ull, 8296328071209997588ull}},
{{11056403062530137899ull, 10885577367583775098ull,
  12324954983894762784ull, 5185205044506248492ull}},
{{4597131791307896565ull, 13606971709479718873ull,
  15406193729868453480ull, 6481506305632810615ull}},
{{10358100757562258610ull, 17008714636849648591ull,
  14646056143908178946ull, 8101882882041013269ull}},
{{13391342001117493488ull, 15242132666458418273ull,
  11459628099156305793ull, 5063676801275633293ull}},
{{2904119446114703147ull, 5217607777790859130ull, 489477068663218530ull,
  6329596001594541617ull}},
{{12853521344498154742ull, 15745381759093349720ull,
  5223532354256411066ull, 7911995001993177021ull}},
{{8033450840311346714ull, 14452549617860731479ull,
  5570550730623950868ull, 4944996876245735638ull}},
{{5430127531961795488ull, 18065687022325914349ull,
  16186560450134714393ull, 6181246095307169547ull}},
{{11399345433379632264ull, 8747050722625229224ull,
  15621514544241005088ull, 7726557619133961934ull}},
{{7124590895862270165ull, 5466906701640768265ull,
  5151760571723240276ull, 4829098511958726209ull}},
{{13517424638255225611ull, 6833633377050960331ull,
  11051386733081438249ull, 6036373139948407761ull}},
{{12285094779391644109ull, 13153727739741088318ull,
  18425919434779185715ull, 7545466424935509701ull}},
{{3066498218692389664ull, 5915236828124486247ull,
  13822042655950685024ull, 4715916515584693563ull}},
{{17668180828647650792ull, 7394046035155607808ull,
  12665867301510968376ull, 5894895644480866954ull}},
{{3638481962100011874ull, 9242557543944509761ull,
  6608962090033934662ull, 7368619555601083693ull}},
{{9159788471052402747ull, 2329824893075861393ull,
  12872888630969806232ull, 9210774444501354616ull}},
{{17254082840476221477ull, 1456140558172413370ull,
  8045555394356128895ull, 5756734027813346635ull}},
{{12344231513740501038ull, 15655233752997680425ull,
  5445258224517773214ull, 7195917534766683294ull}},
{{1595231336893462585ull, 10345670154392324724ull,
  16029944817501992326ull, 8994896918458354117ull}},
{{10220391622413189924ull, 1854357828067815048ull,
  12324558520152439156ull, 5621810574036471323ull}},
{{12775489528016487405ull, 2317947285084768810ull,
  10794012131763161041ull, 7027263217545589154ull}},
{{6745989873165833448ull, 7509120124783348917ull,
  4269143127849175493ull, 8784079021931986443ull}},
{{6522086679942339857ull, 6999043087203287025ull, 362371445692040731ull,
  5490049388707491527ull}},
{{12764294368355312725ull, 4137117840576720877ull,
  14288022362397214626ull, 6862561735884364408ull}},
{{2120309905161977195ull, 14394769337575676905ull,
  17860027952996518282ull, 8578202169855455510ull}},
{{12854408736794705507ull, 13608416854412185969ull,
  6550831452195436022ull, 5361376356159659694ull}},
{{2232952865711218171ull, 7787149031160456654ull,
  17411911352099070836ull, 6701720445199574617ull}},
{{12014563118993798522ull, 9733936288950570817ull,
  7929831134841674833ull, 8377150556499468272ull}},
{{591572921730042221ull, 17612925226662576521ull,
  4956144459276046770ull, 5235719097812167670ull}},
{{5351152170589940680ull, 12792784496473444843ull,
  15418552610949834271ull, 6544648872265209587ull}},
{{2077254194810037945ull, 11379294602164418150ull,
  14661504745259904935ull, 8180811090331511984ull}},
{{15133341927038437428ull, 14029588153993843199ull,
  9163440465787440584ull, 5113006931457194990ull}},
{{14304991390370658881ull, 17536985192492303999ull,
  2230928545379524922ull, 6391258664321493738ull}},
{{13269553219535935697ull, 12697859453760604191ull,
  12012032718579181961ull, 7989073330401867172ull}},
{{15210999789851041667ull, 1018633130959295763ull,
  16730892485966764534ull, 4993170831501166982ull}},
{{14402063718886414179ull, 10496663450553895512ull,
  11690243570603679859ull, 6241463539376458728ull}},
{{18002579648608017724ull, 8509143294764981486ull,
  14612804463254599824ull, 7801829424220573410ull}},
{{6639926261952623174ull, 5318214559228113429ull,
  13744688807961512794ull, 4876143390137858381ull}},
{{12911593845868166871ull, 15871140235889917594ull,
  3345802954669727280ull, 6095179237672322977ull}},
{{6916120270480432781ull, 1392181221152845377ull,
  8793939711764547005ull, 7618974047090403721ull}},
{{15851790215118740248ull, 3175956272434222312ull,
  17025427365921311638ull, 4761858779431502325ull}},
{{1367993695188873694ull, 13193317377397553699ull,
  7446726152119475835ull, 5952323474289377907ull}},
{{15545050174268255829ull, 11879960703319554219ull,
  4696721671721956890ull, 7440404342861722384ull}},
{{7409813349703965942ull, 12036661458002109291ull,
  2935451044826223056ull, 4650252714288576490ull}},
{{4650580668702569523ull, 15045826822502636614ull,
  12892685842887554628ull, 5812815892860720612ull}},
{{15036597872732987711ull, 360539454418744151ull,
  16115857303609443286ull, 7266019866075900765ull}},
{{14184061322488846735ull, 9674046354878205997ull,
  6309763574229640395ull, 9082524832594875957ull}},
{{11170881335769223162ull, 3740435962585184796ull,
  6249445243107219199ull, 5676578020371797473ull}},
{{13963601669711528952ull, 63858934804093091ull,
  12423492572311411903ull, 7095722525464746841ull}},
{{12842816068712023286ull, 13914881723787280076ull,
  1694307660107101166ull, 8869653156830933552ull}},
{{17250132079799790362ull, 4085115058939662143ull,
  1058942287566938229ull, 5543533223019333470ull}},
{{16950979081322350048ull, 9718079842101965583ull,
  10547049896313448594ull, 6929416528774166837ull}},
{{16577037833225549656ull, 2924227765772681171ull,
  17795498388819198647ull, 8661770660967708546ull}},
{{8054805636552274583ull, 8745171381249007588ull,
  15733872511439387058ull, 5413606663104817841ull}},
{{10068507045690343229ull, 1708092189706483677ull,
  5832282584017070111ull, 6767008328881022302ull}},
{{17197319825540316940ull, 15970173292415268308ull,
  16513725266876113446ull, 8458760411101277877ull}},
{{1524952854107922280ull, 5369672289332154789ull,
  12626921301011264856ull, 5286725256938298673ull}},
{{6517877086062290754ull, 6712090361665193486ull,
  1948593570981917358ull, 6608406571172873342ull}},
{{17370718394432639250ull, 17613484988936267665ull,
  11659114000582172505ull, 8260508213966091677ull}},
{{3939169968879317675ull, 4090899090444085435ull,
  9592789259577551768ull, 5162817633728807298ull}},
{{312276442671759190ull, 5113623863055106794ull, 2767614537617163902ull,
  6453522042161009123ull}},
{{9613717590194474795ull, 15615401865673659300ull,
  17294576227303618589ull, 8066902552701261403ull}},
{{15231945530726322555ull, 12065469175259731014ull,
  8503267132851067666ull, 5041814095438288377ull}},
{{9816559876553127386ull, 5858464432219887960ull,
  15240769934491222487ull, 6302267619297860471ull}},
{{12270699845691409232ull, 2711394521847472046ull,
  14439276399686640205ull, 7877834524122325589ull}},
{{3057501385129742866ull, 4000464585368363981ull,
  11330390759017844080ull, 4923646577576453493ull}},
{{8433562749839566487ull, 5000580731710454976ull, 327930393490141388ull,
  6154558221970566867ull}},
{{10541953437299458108ull, 6250725914638068720ull,
  14244971047144840447ull, 7693197777463208583ull}},
{{6588720898312161318ull, 10824232724289874806ull,
  15820635932106607135ull, 4808248610914505364ull}},
{{17459273159744977455ull, 8918604886934955603ull,
  1329050841423707303ull, 6010310763643131706ull}},
{{17212405431253833915ull, 6536570090241306600ull,
  10884685588634409937ull, 7512888454553914632ull}},
{{10757753394533646197ull, 15614571352469286385ull,
  6802928492896506210ull, 4695555284096196645ull}},
{{18058877761594445650ull, 10294842153731832173ull,
  13115346634548020667ull, 5869444105120245806ull}},
{{8738539146710893351ull, 8256866673737402313ull,
  7170811256330250026ull, 7336805131400307258ull}},
{{15534859951816004592ull, 1097711305316977083ull,
  18186886107267588341ull, 9171006414250384072ull}},
{{7403444460671308918ull, 2991912575036804629ull,
  11366803817042242713ull, 5731879008906490045ull}},
{{13865991594266524052ull, 8351576737223393690ull,
  373446716020639679ull, 7164848761133112557ull}},
{{8109117455978379257ull, 5827784903101854209ull,
  5078494413453187503ull, 8956060951416390696ull}},
{{16597413456054956796ull, 10559894592079740736ull,
  3174059008408242189ull, 5597538094635244185ull}},
{{2300022746359144378ull, 17811554258527063825ull,
  8579259778937690640ull, 6996922618294055231ull}},
{{7486714451376318377ull, 3817698749449278165ull,
  6112388705244725397ull, 8746153272867569039ull}},
{{6985039541323892938ull, 4691904727619492805ull,
  10737771968419035229ull, 5466345795542230649ull}},
{{13342985445082254076ull, 10476566927951753910ull,
  18033900978951181940ull, 6832932244427788311ull}},
{{7455359769498041787ull, 13095708659939692388ull,
  17930690205261589521ull, 8541165305534735389ull}},
{{13882971892791051925ull, 1267288884821225886ull,
  13512524387502187403ull, 5338228315959209618ull}},
{{8130342829134039098ull, 15419169161308696070ull,
  7667283447522958445ull, 6672785394949012023ull}},
{{939556499562773065ull, 5438903396353706376ull, 4972418290976310153ull,
  8340981743686265029ull}},
{{587222812226733166ull, 14928529668789536245ull,
  5413604441073887797ull, 5213113589803915643ull}},
{{5345714533710804361ull, 4825604030704756594ull,
  2155319532914971843ull, 6516391987254894554ull}},
{{15905515203993281259ull, 1420319019953557838ull,
  11917521452998490612ull, 8145489984068618192ull}},
{{5329260984068412883ull, 10111071424325749457ull,
  7448450908124056632ull, 5090931240042886370ull}},
{{11273262248512904008ull, 12638839280407186821ull,
  87191598300294982ull, 6363664050053607963ull}},
{{256519755358966297ull, 6575177063654207719ull,
  13944047553157532440ull, 7954580062567009953ull}},
{{7077853874740435792ull, 4109485664783879824ull,
  1797500693082375919ull, 4971612539104381221ull}},
{{8847317343425544740ull, 525171062552461876ull, 6858561884780357803ull,
  6214515673880476526ull}},
{{11059146679281930925ull, 14491521883472741057ull,
  17796574392830223061ull, 7768144592350595657ull}},
{{18441181720619676588ull, 11363044186384157112ull,
  4205329967877807557ull, 4855090370219122286ull}},
{{4604733077065044119ull, 368747177698032679ull,
  14480034496702035255ull, 6068862962773902857ull}},
{{1144230327903917245ull, 14295992027404704561ull,
  4264985065595380356ull, 7586078703467378572ull}},
{{12244359001008418038ull, 18158367053982716158ull,
  11888987702851888530ull, 4741299189667111607ull}},
{{6082076714405746740ull, 13474586780623619390ull,
  10249548610137472759ull, 5926623987083889509ull}},
{{16825967929861959232ull, 12231547457352136333ull,
  17423621781099228853ull, 7408279983854861886ull}},
{{12822072965377418472ull, 9950560170058779160ull,
  6278077594759630129ull, 4630174989909288679ull}},
{{16027591206721773090ull, 17049886231000861854ull,
  3235910975022149757ull, 5787718737386610849ull}},
{{10811116971547440555ull, 7477299733468913606ull,
  8656574737205075101ull, 7234648421733263561ull}},
{{4290524177579524885ull, 13958310685263529912ull,
  15432404439933731780ull, 9043310527166579451ull}},
{{2681577610987203054ull, 17947316215144482003ull,
  7339409765744888410ull, 5652069079479112157ull}},
{{17187030069016167529ull, 13210773232075826695ull,
  13785948225608498417ull, 7065086349348890196ull}},
{{16872101567842821507ull, 2678408484812619657ull,
  17232435282010623022ull, 8831357936686112745ull}},
{{3627534452260681586ull, 15509063358290050998ull,
  3852743023615557532ull, 5519598710428820466ull}},
{{13757790102180627790ull, 939585124153012131ull,
  14039300816374222724ull, 6899498388036025582ull}},
{{12585551609298396834ull, 1174481405191265164ull,
  8325753983613002597ull, 8624372985045031978ull}},
{{17089341792666273829ull, 3039893887458234679ull,
  9815282258185514527ull, 5390233115653144986ull}},
{{16749991222405454383ull, 17634925414604957061ull,
  3045730785877117350ull, 6737791394566431233ull}},
{{7102430972724654266ull, 12820284731401420519ull,
  8418849500773784592ull, 8422239243208039041ull}},
{{11356548385593990772ull, 8012677957125887824ull,
  16790995984052085130ull, 5263899527005024400ull}},
{{14195685481992488465ull, 792475409552583972ull,
  2542000906355554797ull, 6579874408756280501ull}},
{{17744606852490610582ull, 5602280280368117869ull,
  7789187151371831400ull, 8224843010945350626ull}},
{{13396222292020325566ull, 3501425175230073668ull,
  9479927988034782529ull, 5140526881840844141ull}},
{{16745277865025406957ull, 8988467487464979989ull,
  16461596003470866065ull, 6425658602301055176ull}},
{{7096539275999594984ull, 15847270377758612891ull,
  2130250930629030965ull, 8032073252876318971ull}},
{{2129494038286052913ull, 12210386995312827009ull,
  17472307896139002017ull, 5020045783047699356ull}},
{{7273553566284954046ull, 1427925688858870049ull,
  3393640796464200906ull, 6275057228809624196ull}},
{{13703627976283580461ull, 11008279147928363369ull,
  4242050995580251132ull, 7843821536012030245ull}},
{{1647238457536155932ull, 16103546504310002914ull,
  4957124881451350909ull, 4902388460007518903ull}},
{{11282420108774970723ull, 6294375075105339930ull,
  1584720083386800733ull, 6127985575009398629ull}},
{{4879653099113937596ull, 12479654862309062817ull,
  6592586122660888820ull, 7659981968761748286ull}},
{{14578998233014680758ull, 17023156325797940068ull,
  17955424381945219224ull, 4787488730476092678ull}},
{{18223747791268350947ull, 2832201333537873469ull,
  13220908440576748223ull, 5984360913095115848ull}},
{{8944626683803274971ull, 17375309722204505549ull,
  16526135550720935278ull, 7480451141368894810ull}},
{{7896234686590740809ull, 6247882557950428064ull,
  14940520737627972453ull, 4675281963355559256ull}},
{{9870293358238426011ull, 12421539215865422984ull,
  228906848325413950ull, 5844102454194449071ull}},
{{12337866697798032514ull, 6303551982977002922ull,
  14121191615688931150ull, 7305128067743061338ull}},
{{6198961335392764835ull, 17102812015576029461ull,
  8428117482756388129ull, 9131410084678826673ull}},
{{6180193843834171974ull, 3771728482093936557ull,
  16796788472791212341ull, 5707131302924266670ull}},
{{12336928323220102871ull, 9326346621044808600ull,
  11772613554134239618ull, 7133914128655333338ull}},
{{15421160404025128589ull, 2434561239451234942ull,
  5492394905813023715ull, 8917392660819166673ull}},
{{5026539234088317464ull, 17662501839152879503ull,
  14961961862201609581ull, 5573370413011979170ull}},
{{1671488024183008926ull, 8243069243658935667ull,
  9479080290897236169ull, 6966713016264973963ull}},
{{15924418085510924870ull, 14915522573001057487ull,
  7237164345194157307ull, 8708391270331217454ull}},
{{16870290331085409900ull, 7016358598911966977ull,
  18358285771028512029ull, 5442744543957010908ull}},
{{7252804858574598662ull, 13382134267067346626ull,
  4501113140076088420ull, 6803430679946263636ull}},
{{18289378110073024136ull, 16727667833834183282ull,
  5626391425095110525ull, 8504288349932829545ull}},
{{16042547337223027989ull, 12760635405360058503ull,
  15045709686752913838ull, 5315180218708018465ull}},
{{15441498153101397082ull, 6727422219845297321ull,
  4972079053158978586ull, 6643975273385023082ull}},
{{5466814636094582641ull, 17632649811661397460ull,
  15438470853303499040ull, 8304969091731278852ull}},
{{12640131184413889959ull, 11020406132288373412ull,
  425672246459911092ull, 5190605682332049283ull}},
{{15800163980517362448ull, 13775507665360466765ull,
  14367148363357052577ull, 6488257102915061603ull}},
{{5915146920364539348ull, 3384326526418419745ull,
  13347249435768927818ull, 8110321378643827004ull}},
{{15226181871296306853ull, 6726890097438900244ull,
  17565402934210355694ull, 5068950861652391877ull}},
{{585983265410831950ull, 17631984658653401114ull,
  8121695612480780905ull, 6336188577065489847ull}},
{{9955851118618315745ull, 8204922768034587680ull,
  5540433497173588228ull, 7920235721331862309ull}},
{{6222406949136447341ull, 14351448766876393108ull,
  5768613944947186594ull, 4950147325832413943ull}},
{{7778008686420559176ull, 8715938921740715577ull,
  2599081412756595339ull, 6187684157290517429ull}},
{{14334196876453086874ull, 6283237633748506567ull,
  7860537784373132078ull, 7734605196613146786ull}},
{{15876402075424261152ull, 17762081576374980316ull,
  9524522133660595452ull, 4834128247883216741ull}},
{{1398758520570774824ull, 3755857896759173780ull,
  16517338685503132220ull, 6042660309854020926ull}},
{{1748448150713468530ull, 4694822370948967225ull,
  11423301320024139467ull, 7553325387317526158ull}},
{{12621995140264387592ull, 628420972629410563ull,
  2527877306587699263ull, 4720828367073453849ull}},
{{11165807906903096585ull, 14620584271068926916ull,
  7771532651662011982ull, 5901035458841817311ull}},
{{13957259883628870732ull, 9052358301981382837ull,
  5102729796150127074ull, 7376294323552271639ull}},
{{3611516799253924702ull, 2092075840621952739ull,
  1766726226760270939ull, 9220367904440339549ull}},
{{18398099064029560603ull, 17448448464884578125ull,
  3410046900938863288ull, 5762729940275212218ull}},
{{9162565774754787042ull, 3363816507396171041ull,
  13485930663028354919ull, 7203412425344015272ull}},
{{16064893236870871706ull, 18039828689527377513ull,
  16857413328785443648ull, 9004265531680019090ull}},
{{3123029245403212961ull, 11274892930954610946ull,
  15147569348918290184ull, 5627665957300011931ull}},
{{13127158593608792009ull, 14093616163693263682ull,
  14322775667720474826ull, 7034582446625014914ull}},
{{7185576205156214203ull, 8393648167761803795ull,
  8680097547795817725ull, 8793228058281268643ull}},
{{2185142119008939925ull, 7551873114064821324ull,
  3119217958158692126ull, 5495767536425792902ull}},
{{2731427648761174906ull, 216469355726250847ull,
  13122394484553140966ull, 6869709420532241127ull}},
{{17249342616233632344ull, 9493958731512589366ull,
  11791307087264038303ull, 8587136775665301409ull}},
{{6169153116718632311ull, 12851253234836450210ull,
  452037901898942083ull, 5366960484790813381ull}},
{{16934813432753066197ull, 11452380525118174858ull,
  5176733395801065508ull, 6708700605988516726ull}},
{{11945144754086556938ull, 14315475656397718573ull,
  15694288781606107693ull, 8385875757485645907ull}},
{{9771558480517792039ull, 11253015294462268060ull,
  7503087479290123356ull, 5241172348428528692ull}},
{{12214448100647240048ull, 14066269118077835075ull,
  9378859349112654195ull, 6551465435535660865ull}},
{{10656374107381662156ull, 12971150379169905940ull,
  16335260204818205648ull, 8189331794419576081ull}},
{{15883605853968314656ull, 8106968986981191212ull,
  3292008600370296674ull, 5118332371512235051ull}},
{{1407763243750841703ull, 910339196871713208ull,
  17950068805745034555ull, 6397915464390293813ull}},
{{1759704054688552129ull, 14972982051371805222ull,
  8602527951899129481ull, 7997394330487867267ull}},
{{14934873089462508793ull, 2440584754466296407ull,
  3070736960723261974ull, 4998371456554917042ull}},
{{14056905343400748087ull, 12274102979937646317ull,
  13061793237758853275ull, 6247964320693646302ull}},
{{3736073623968771397ull, 10730942706494669993ull,
  7103869510343790786ull, 7809955400867057878ull}},
{{13864261061048951883ull, 11318525209986556649ull,
  18274976499247032953ull, 4881222125541911173ull}},
{{3495268271029026142ull, 313098457201032100ull, 9008662568776627480ull,
  6101527656927388967ull}},
{{4369085338786282677ull, 391373071501290125ull, 6649142192543396446ull,
  7626909571159236209ull}},
{{5036521345955120625ull, 14079666224970470040ull,
  15684928916408092538ull, 4766818481974522630ull}},
{{6295651682443900782ull, 8376210744358311742ull,
  10382789108655339865ull, 5958523102468153288ull}},
{{17092936639909651785ull, 15081949448875277581ull,
  12978486385819174831ull, 7448153878085191610ull}},
{{12988928409157226318ull, 16343747433188130344ull,
  12723240009564372173ull, 4655096173803244756ull}},
{{16236160511446532897ull, 6594626236202999218ull,
  15904050011955465217ull, 5818870217254055945ull}},
{{11071828602453390313ull, 12854968813681136927ull,
  6045004459662167809ull, 7273587771567569932ull}},
{{9228099734639349987ull, 2233652961819257447ull,
  7556255574577709762ull, 9091984714459462415ull}},
{{12685091361790675598ull, 6007719119564423808ull,
  11640188761752150457ull, 5682490446537164009ull}},
{{15856364202238344498ull, 12121334917882917664ull,
  715177896908024359ull, 7103113058171455012ull}},
{{1373711179088379006ull, 10539982628926259177ull,
  893972371135030449ull, 8878891322714318765ull}},
{{12387784532998706639ull, 18116704189147381745ull,
  2864575741173087982ull, 5549307076696449228ull}},
{{1649672610966219587ull, 13422508199579451374ull,
  3580719676466359978ull, 6936633845870561535ull}},
{{11285462800562550291ull, 7554763212619538409ull,
  18310957650865113685ull, 8670792307338201918ull}},
{{135885222710512076ull, 7027570017100905458ull, 6832662513363308149ull,
  5419245192086376199ull}},
{{9393228565242915903ull, 13396148539803519726ull,
  3929142123276747282ull, 6774056490107970249ull}},
{{2518163669698869071ull, 7521813637899623850ull,
  9523113672523322007ull, 8467570612634962811ull}},
{{6185538311989181073ull, 11618662551328346762ull,
  3646103036113382302ull, 5292231632896851757ull}},
{{16955294926841252150ull, 5299956152305657644ull,
  9169314813569115782ull, 6615289541121064696ull}},
{{2747374584842013571ull, 15848317227236847864ull,
  11461643516961394727ull, 8269111926401330870ull}},
{{1717109115526258482ull, 16822727294664111771ull,
  2551841179673483800ull, 5168194954000831794ull}},
{{15981444449689986814ull, 2581665044620588097ull,
  12413173511446630559ull, 6460243692501039742ull}},
{{6141747506830319806ull, 17062139361057898834ull,
  6293094852453512390ull, 8075304615626299678ull}},
{{8450278210196337783ull, 6052151082233798867ull,
  17768242338065608956ull, 5047065384766437298ull}},
{{5951161744318034324ull, 7565188852792248584ull,
  12986930885727235387ull, 6308831730958046623ull}},
{{7438952180397542905ull, 4844800047562922826ull,
  11621977588731656330ull, 7886039663697558279ull}},
{{9261031131175852220ull, 7639686048154214670ull,
  14181265020598367062ull, 4928774789810973924ull}},
{{2352916877115039467ull, 326235523337992530ull,
  17726581275747958828ull, 6160968487263717405ull}},
{{12164518133248575142ull, 407794404172490662ull,
  8323168539402784823ull, 7701210609079646757ull}},
{{2991137814852971560ull, 7172400530248888520ull,
  7507823346340434466ull, 4813256630674779223ull}},
{{3738922268566214449ull, 18188872699665886458ull,
  4773093164498155178ull, 6016570788343474029ull}},
{{13897024872562543870ull, 13512718837727582264ull,
  10578052474050081877ull, 7520713485429342536ull}},
{{8685640545351589919ull, 10751292282793432867ull,
  6611282796281301173ull, 4700445928393339085ull}},
{{6245364663262099494ull, 18050801371919178988ull,
  12875789513779014370ull, 5875557410491673856ull}},
{{7806705829077624368ull, 13340129678044197927ull,
  16094736892223767963ull, 7344446763114592320ull}},
{{5146696267919642556ull, 12063476079127859505ull,
  1671677041570158338ull, 9180558453893240401ull}},
{{14745900213518246357ull, 12151358567882300094ull,
  12574013197049818721ull, 5737849033683275250ull}},
{{9209003230043032139ull, 1354140154570711406ull,
  6494144459457497594ull, 7172311292104094063ull}},
{{2287882000699014365ull, 10916047230068165066ull,
  3505994555894484088ull, 8965389115130117579ull}},
{{6041612268864271882ull, 6822529518792603166ull,
  18332147661929910219ull, 5603368196956323486ull}},
{{16775387372935115661ull, 3916475880063366053ull,
  13691812540557611966ull, 7004210246195404358ull}},
{{7134176160886730864ull, 14118966886933983375ull,
  7891393638842239149ull, 8755262807744255448ull}},
{{11376389128195288646ull, 11130197313547433561ull,
  4932121024276399468ull, 5472039254840159655ull}},
{{385428354961947096ull, 13912746641934291952ull,
  1553465261918111431ull, 6840049068550199569ull}},
{{481785443702433869ull, 12779247283990477036ull,
  6553517595825027193ull, 8550061335687749461ull}},
{{9524487939168796977ull, 1069500524852966291ull,
  6401791506604335948ull, 5343788334804843413ull}},
{{7293923905533608317ull, 1336875656066207864ull,
  12613925401682807839ull, 6679735418506054266ull}},
{{9117404881917010396ull, 15506152625364923542ull,
  6544034715248733990ull, 8349669273132567833ull}},
{{1086692032770743593ull, 5079659372425689310ull,
  15619236743098928504ull, 5218543295707854895ull}},
{{10581737077818205300ull, 6349574215532111637ull,
  14912359910446272726ull, 6523179119634818619ull}},
{{17838857365700144528ull, 17160339806269915354ull,
  14028763869630453003ull, 8153973899543523274ull}},
{{15760971871989978234ull, 8419369369705003144ull,
  13379663436946421031ull, 5096233687214702046ull}},
{{1254470766277921177ull, 5912525693703866027ull,
  7501207259328250481ull, 6370292109018377558ull}},
{{15403146513129565183ull, 12002343135557220437ull,
  153137037305537293ull, 7962865136272971948ull}},
{{11932809579919672192ull, 9807307468936956725ull,
  9319082685170736616ull, 4976790710170607467ull}},
{{1080953919617426527ull, 12259134336171195907ull,
  7037167338036032866ull, 6220988387713259334ull}},
{{15186250454803946871ull, 6100545883359219075ull,
  18019831209399816891ull, 7776235484641574167ull}},
{{7185563525038772843ull, 1506998167885817970ull,
  18179923533515967413ull, 4860147177900983854ull}},
{{18205326443153241861ull, 6495433728284660366ull,
  13501532380040183458ull, 6075183972376229818ull}},
{{13533286017086776518ull, 17342664197210601266ull,
  7653543438195453514ull, 7593979965470287273ull}},
{{13069989779106623228ull, 15450851141684013695ull,
  16312679694940628206ull, 4746237478418929545ull}},
{{11725801205455891131ull, 10090191890250241311ull,
  6555791563393621546ull, 5932796848023661932ull}},
{{10045565488392476010ull, 3389367825958025831ull,
  8194739454242026933ull, 7415996060029577415ull}},
{{13196007457886379362ull, 4424197900437460096ull,
  12039241186542348689ull, 4634997537518485884ull}},
{{16495009322357974203ull, 10141933393974213024ull,
  15049051483177935861ull, 5793746921898107355ull}},
{{2172017579237916137ull, 17289102760895154185ull,
  14199628335545031922ull, 7242183652372634194ull}},
{{7326707992474783075ull, 12388006414264166923ull,
  8526163382576514095ull, 9052729565465792743ull}},
{{2273349486083045470ull, 14660033036556186183ull,
  12246381141751403165ull, 5657955978416120464ull}},
{{16676744912885970550ull, 4489983240413069016ull,
  15307976427189253957ull, 7072444973020150580ull}},
{{2399187067397911571ull, 10224165068943724175ull,
  688226460277015830ull, 8840556216275188226ull}},
{{8417020944764776588ull, 1778417149662439705ull,
  5041827556100522798ull, 5525347635171992641ull}},
{{15132962199383358639ull, 11446393473932825439ull,
  10913970463553041401ull, 6906684543964990801ull}},
{{14304516730801810395ull, 472933787133868087ull,
  18254149097868689656ull, 8633355679956238501ull}},
{{15857851984392213353ull, 295583616958667554ull,
  13714686195381624987ull, 5395847299972649063ull}},
{{10598942943635490883ull, 14204537576480498155ull,
  12531671725799643329ull, 6744809124965811329ull}},
{{8636992661116975699ull, 3920613915318458982ull,
  1829531601967390450ull, 8431011406207264162ull}},
{{786434394770721908ull, 7062069715501424768ull, 5755143269657006935ull,
  5269382128879540101ull}},
{{983042993463402385ull, 4215901125949393056ull,
  11805615105498646573ull, 6586727661099425126ull}},
{{1228803741829252982ull, 9881562425864129224ull,
  5533646845018532408ull, 8233409576374281408ull}},
{{768002338643283114ull, 6175976516165080765ull, 3458529278136582755ull,
  5145880985233925880ull}},
{{5571688941731491796ull, 3108284626778963052ull,
  4323161597670728444ull, 6432351231542407350ull}},
{{6964611177164364745ull, 3885355783473703815ull,
  14627324033943186363ull, 8040439039428009187ull}},
{{11270411013368809822ull, 122504355457370932ull,
  6836234512000797525ull, 5025274399642505742ull}},
{{14088013766711012277ull, 4764816462749101569ull,
  17768665176855772714ull, 6281592999553132177ull}},
{{3774959153106601634ull, 15179392615291152770ull,
  8375773415787552180ull, 7851991249441415222ull}},
{{6971035489119013926ull, 263748347702194673ull, 623172366439832209ull,
  4907494530900884514ull}},
{{13325480379826155311ull, 4941371453055131245ull,
  10002337494904566069ull, 6134368163626105642ull}},
{{2821792419500530426ull, 10788400334746301961ull,
  3279549831775931778ull, 7667960204532632053ull}},
{{13292835308256301277ull, 11354436227643826629ull,
  4355561654073651313ull, 4792475127832895033ull}},
{{2780986080038212884ull, 357987229272619575ull,
  10056138086019452046ull, 5990593909791118791ull}},
{{17311290655329929816ull, 9670856073445550276ull,
  7958486589096927153ull, 7488242387238898489ull}},
{{1596184622726430327ull, 17573500091971938683ull,
  16503269164254049230ull, 4680151492024311555ull}},
{{15830288833690201621ull, 12743503078110147545ull,
  16017400436890173634ull, 5850189365030389444ull}},
{{5952802986830588314ull, 6706006810782908624ull,
  1575006472403165427ull, 7312736706287986806ull}},
{{7441003733538235393ull, 3770822495051247876ull,
  11192130127358732592ull, 9140920882859983507ull}},
{{13873999370316172929ull, 2356764059407029922ull,
  4689238320385513918ull, 5713075551787489692ull}},
{{8119127176040440353ull, 12169327111113563211ull,
  5861547900481892397ull, 7141344439734362115ull}},
{{5537222951623162537ull, 1376600833609790302ull,
  2715248857174977593ull, 8926680549667952644ull}},
{{17295822400046640298ull, 12389590567074588698ull,
  10920402572589136803ull, 5579175343542470402ull}},
{{12396405963203524564ull, 10875302190415847969ull,
  4427131178881645196ull, 6973969179428088003ull}},
{{1660449398722241993ull, 13594127738019809962ull,
  922227955174668591ull, 8717461474285110004ull}},
{{5649466892628789150ull, 15413858863903463082ull,
  9799764508838943677ull, 5448413421428193752ull}},
{{16285205652640762245ull, 5432265524597165140ull,
  12249705636048679597ull, 6810516776785242190ull}},
{{1909762992091401190ull, 11402017924173844330ull,
  6088760008206073688ull, 8513145970981552738ull}},
{{5805287888484513648ull, 7126261202608652706ull,
  8417161023556183959ull, 5320716231863470461ull}},
{{16479981897460417868ull, 4296140484833427978ull,
  15133137297872617853ull, 6650895289829338076ull}},
{{11376605334970746527ull, 9981861624469172877ull,
  469677548631220700ull, 8313619112286672596ull}},
{{9416221343570410531ull, 15462035552148008856ull,
  9516920504749288745ull, 5196011945179170372ull}},
{{11770276679463013164ull, 5492486384902847358ull,
  11896150630936610932ull, 6495014931473962965ull}},
{{5489473812473990647ull, 6865607981128559198ull,
  1035130233388599953ull, 8118768664342453707ull}},
{{17265979188078407867ull, 15820220034273819258ull,
  16787857460363732634ull, 5074230415214033566ull}},
{{12359101948243234025ull, 10551903005987498265ull,
  11761449788599889985ull, 6342788019017541958ull}},
{{1613819380021878819ull, 17801564775911760736ull,
  5478440198895086673ull, 7928485023771927448ull}},
{{1008637112513674262ull, 4208448957303768604ull,
  3424025124309429171ull, 4955303139857454655ull}},
{{1260796390642092828ull, 648875178202322851ull,
  18115089460668950176ull, 6194128924821818318ull}},
{{15411053543584779747ull, 811093972752903563ull,
  13420489788981411912ull, 7742661156027272898ull}},
{{7326065455526793390ull, 506933732970564727ull,
  12999492136540770349ull, 4839163222517045561ull}},
{{4545895800981103833ull, 5245353184640593813ull,
  2414307115393799224ull, 6048954028146306952ull}},
{{10294055769653767695ull, 6556691480800742266ull,
  3017883894242249030ull, 7561192535182883690ull}},
{{11045470874460992714ull, 17932990230782627628ull,
  6497863452328793547ull, 4725745334489302306ull}},
{{13806838593076240892ull, 17804551770050896631ull,
  17345701352265767742ull, 5907181668111627882ull}},
{{12646862222917913211ull, 13032317675708844981ull,
  12458754653477433870ull, 7383977085139534853ull}},
{{10210131898537389709ull, 3533512528890640209ull,
  10092564667637090121ull, 4614985678212209283ull}},
{{17374350891599125040ull, 9028576679540688165ull,
  8004019816118974747ull, 5768732097765261604ull}},
{{7882880559216742588ull, 6674034830998472303ull,
  10005024770148718434ull, 7210915122206577005ull}},
{{5241914680593540331ull, 17565915575602866187ull,
  17117966981113285946ull, 9013643902758221256ull}},
{{970353666157268755ull, 15590383253179179271ull,
  10698729363195803716ull, 5633527439223888285ull}},
{{15048000137978749656ull, 1041234992764422472ull,
  17985097722422142550ull, 7041909299029860356ull}},
{{363256098763885453ull, 10524915777810303899ull,
  4034628079318126571ull, 8802386623787325446ull}},
{{16367936126223286073ull, 4272229351917745984ull,
  16356700604855992819ull, 5501491639867078403ull}},
{{2013176084069555975ull, 728600671469794577ull,
  15834189737642603120ull, 6876864549833848004ull}},
{{7128156123514332872ull, 910750839337243221ull, 1345993098343702284ull,
  8596080687292310006ull}},
{{6760940586410151997ull, 9792591311440552821ull,
  14676303741746977639ull, 5372550429557693753ull}},
{{13062861751440077900ull, 7629053120873303122ull,
  4510321621901558337ull, 6715688036947117192ull}},
{{7105205152445321567ull, 14148002419519016807ull,
  5637902027376947921ull, 8394610046183896490ull}},
{{11358282247919407836ull, 1924972484558303648ull,
  8135374785537980355ull, 5246631278864935306ull}},
{{14197852809899259795ull, 16241273660980043272ull,
  945846445067699635ull, 6558289098581169133ull}},
{{17747316012374074743ull, 15689906057797666186ull,
  5793994074762012448ull, 8197861373226461416ull}},
{{15703758526161184619ull, 9806191286123541366ull,
  3621246296726257780ull, 5123663358266538385ull}},
{{10406326120846704965ull, 12257739107654426708ull,
  9138243889335210129ull, 6404579197833172981ull}},
{{13007907651058381206ull, 1487115829285869673ull,
  16034490880096400566ull, 8005723997291466226ull}},
{{1212413254270406398ull, 14764505448585832258ull,
  14633242818487638257ull, 5003577498307166391ull}},
{{10738888604692783806ull, 4620573755450126610ull,
  13679867504682159918ull, 6254471872883957989ull}},
{{4200238719011203949ull, 14999089231167434071ull,
  3264776325570536185ull, 7818089841104947487ull}},
{{9542678227023084324ull, 2456901741838564438ull,
  8958014231122666972ull, 4886306150690592179ull}},
{{2704975746924079597ull, 3071127177298205548ull,
  6585831770475945811ull, 6107882688363240224ull}},
{{3381219683655099496ull, 17673967026904920647ull,
  8232289713094932263ull, 7634853360454050280ull}},
{{9030791329925519041ull, 17963758419456657260ull,
  5145181070684332664ull, 4771783350283781425ull}},
{{11288489162406898802ull, 4007953950611269959ull,
  11043162356782803735ull, 5964729187854726781ull}},
{{9498925434581235598ull, 398256419836699545ull,
  18415638964405892573ull, 7455911484818408476ull}},
{{17466043442681742009ull, 2554753271611631167ull,
  2286402315898907050ull, 4659944678011505298ull}},
{{17220868284924789607ull, 12416813626369314767ull,
  12081374931728409620ull, 5824930847514381622ull}},
{{16914399337728599105ull, 15521017032961643459ull,
  5878346627805736217ull, 7281163559392977028ull}},
{{16531313153733360977ull, 5566213235919890612ull,
  7347933284757170272ull, 9101454449241221285ull}},
{{1108698684228574803ull, 3478883272449931633ull,
  6898301312186925372ull, 5688409030775763303ull}},
{{5997559373713106407ull, 4348604090562414541ull,
  4011190621806268811ull, 7110511288469704129ull}},
{{12108635235568770913ull, 824069094775630272ull,
  9625674295685223918ull, 8888139110587130161ull}},
{{7567897022230481821ull, 14350101239516932632ull,
  17545261480871734708ull, 5555086944116956350ull}},
{{9459871277788102276ull, 17937626549396165790ull,
  12708204814234892577ull, 6943858680146195438ull}},
{{2601467060380352037ull, 8586975131463043526ull,
  6661883980938839914ull, 8679823350182744298ull}},
{{15460974968019883735ull, 9978545475591790107ull,
  8775363506514162850ull, 5424889593864215186ull}},
{{14714532691597466765ull, 3249809807634961826ull,
  1745832346287927755ull, 6781111992330268983ull}},
{{9169793827642057648ull, 17897320314825865995ull,
  16017348488142073405ull, 8476389990412836228ull}},
{{3425278133062592078ull, 13491668205979860199ull,
  787470768234020070ull, 5297743744008022643ull}},
{{18116655721610403809ull, 7641213220620049440ull,
  14819396515574688800ull, 6622179680010028303ull}},
{{4199075578303453146ull, 9551516525775061801ull,
  13912559626040973096ull, 8277724600012535379ull}},
{{14153637282508127976ull, 5969697828609413625ull,
  6389506757061914233ull, 5173577875007834612ull}},
{{3856988547852996258ull, 12073808304189154936ull,
  7986883446327392791ull, 6466972343759793265ull}},
{{4821235684816245322ull, 10480574361809055766ull,
  14595290326336628893ull, 8083715429699741581ull}},
{{16848330358292317039ull, 8856201985344353805ull,
  11427899463174087010ull, 5052322143562338488ull}},
{{7225354892583232586ull, 1846880444825666449ull,
  14284874328967608763ull, 6315402679452923110ull}},
{{13643379634156428637ull, 16143658611314246773ull,
  8632720874354735145ull, 7894253349316153888ull}},
{{10832955280561461850ull, 3172257604430322377ull,
  5395450546471709466ull, 4933908343322596180ull}},
{{18152880119129215217ull, 13188694042392678779ull,
  6744313183089636832ull, 6167385429153245225ull}},
{{18079414130484131117ull, 16485867552990848474ull,
  13042077497289433944ull, 7709231786441556531ull}},
{{15911319849979969852ull, 10303667220619280296ull,
  5845455426592202263ull, 4818269866525972832ull}},
{{1442405738765410699ull, 8267898007346712467ull,
  7306819283240252829ull, 6022837333157466040ull}},
{{15638065228738927086ull, 14946558527610778487ull,
  9133524104050316036ull, 7528546666446832550ull}},
{{16691319795602911285ull, 118227042901960746ull,
  1096766546604059619ull, 4705341666529270344ull}},
{{11640777707648863298ull, 13982841858909614645ull,
  1370958183255074523ull, 5881677083161587930ull}},
{{715914079278915410ull, 12866866305209630403ull,
  10937069765923618962ull, 7352096353951984912ull}},
{{14729950654380807974ull, 6860210844657262195ull,
  13671337207404523703ull, 9190120442439981140ull}},
{{6900376149774311032ull, 11205160805551870728ull,
  17767957791482603122ull, 5743825276524988212ull}},
{{8625470187217888790ull, 4783078970085062602ull,
  3763203165643702287ull, 7179781595656235266ull}},
{{1558465697167585179ull, 1367162694178940349ull,
  13927375993909403667ull, 8974726994570294082ull}},
{{3279884069943434689ull, 16995377748357695382ull,
  13316296014620765195ull, 5609204371606433801ull}},
{{13323227124284069170ull, 16632536167019731323ull,
  2810311962993792782ull, 7011505464508042252ull}},
{{12042347886927698558ull, 11567298171919888346ull,
  3512889953742240978ull, 8764381830635052815ull}},
{{12138153447757199503ull, 11841247375877318120ull,
  9113085248729982467ull, 5477738644146908009ull}},
{{15172691809696499378ull, 10189873201419259746ull,
  16003042579339865988ull, 6847173305183635011ull}},
{{9742492725265848415ull, 12737341501774074683ull,
  15392117205747444581ull, 8558966631479543764ull}},
{{3783214944077461308ull, 10266681447822490629ull,
  396701216737377055ull, 5349354144674714853ull}},
{{9340704698524214538ull, 8221665791350725382ull,
  5107562539349109223ull, 6686692680843393566ull}},
{{2452508836300492365ull, 5665396220761018824ull,
  15607825211041162337ull, 8358365851054241957ull}},
{{1532818022687807728ull, 15070087684044106525ull,
  12060733766114420412ull, 5223978656908901223ull}},
{{6527708546787147564ull, 390865531345581540ull,
  10464231189215637612ull, 6529973321136126529ull}},
{{8159635683483934455ull, 488581914181976925ull,
  17691975004946934919ull, 8162466651420158161ull}},
{{7405615311391152987ull, 7222892724004817434ull,
  4139955350450752468ull, 5101541657137598851ull}},
{{33647102384165425ull, 9028615905006021793ull, 563258169636052681ull,
  6376927071421998564ull}},
{{4653744896407594685ull, 15897455899684915145ull,
  704072712045065851ull, 7971158839277498205ull}},
{{14437805606323216438ull, 7630066928089378013ull,
  2745888454241860109ull, 4981974274548436378ull}},
{{4212198952621856836ull, 14149269678539110421ull,
  12655732604657100944ull, 6227467843185545472ull}},
{{9876934709204708949ull, 17686587098173888026ull,
  15819665755821376180ull, 7784334803981931840ull}},
{{10784770211680330997ull, 1830744899503904208ull,
  9887291097388360113ull, 4865209252488707400ull}},
{{13480962764600413746ull, 6900117142807268164ull,
  12359113871735450141ull, 6081511565610884250ull}},
{{16851203455750517183ull, 13236832446936473109ull,
  6225520302814536868ull, 7601889457013605313ull}},
{{12837845169057767191ull, 17496392316190071501ull,
  15420165235327555302ull, 4751180910633503320ull}},
{{2212248406040045277ull, 12647118358382813569ull,
  828462470449892512ull, 5938976138291879151ull}},
{{7376996525977444500ull, 15808897947978516961ull,
  14870636143344529352ull, 7423720172864848938ull}},
{{16139837874804372573ull, 9880561217486573100ull,
  13905833608017718749ull, 4639825108040530586ull}},
{{1728053269795914100ull, 16962387540285604280ull,
  8158919973167372628ull, 5799781385050663233ull}},
{{2160066587244892625ull, 2756240351647453734ull,
  14810335984886603690ull, 7249726731313329041ull}},
{{11923455270910891589ull, 12668672476414092975ull,
  4677861925826090900ull, 9062158414141661302ull}},
{{14369688571960389099ull, 17141292334613583917ull,
  16758721758923470524ull, 5663849008838538313ull}},
{{4127052659668322662ull, 2979871344557428281ull,
  7113344143372174444ull, 7079811261048172892ull}},
{{9770501843012791231ull, 3724839180696785351ull,
  8891680179215218055ull, 8849764076310216115ull}},
{{13024092679524076376ull, 9245553515576572700ull,
  3251457102795817332ull, 5531102547693885072ull}},
{{16280115849405095470ull, 11556941894470715875ull,
  4064321378494771665ull, 6913878184617356340ull}},
{{15738458793328981433ull, 611119312806231132ull,
  5080401723118464582ull, 8642347730771695425ull}},
{{613164708975837588ull, 14217007625786058170ull,
  14704466123017510123ull, 5401467331732309640ull}},
{{9989827923074572793ull, 13159573513805184808ull,
  18380582653771887654ull, 6751834164665387050ull}},
{{12487284903843215991ull, 7226094855401705202ull,
  13752356280360083760ull, 8439792705831733813ull}},
{{12416239083329397898ull, 4516309284626065751ull,
  10901065684438746302ull, 5274870441144833633ull}},
{{10908612835734359469ull, 14868758642637357997ull,
  18238018123975820781ull, 6593588051431042041ull}},
{{18247452063095337240ull, 4750890248014533784ull,
  8962464599687612265ull, 8241985064288802552ull}},
{{11404657539434585775ull, 14498521451077553375ull,
  5601540374804757665ull, 5151240665180501595ull}},
{{9644135905865844315ull, 4288093758564778007ull,
  2390239450078559178ull, 6439050831475626994ull}},
{{7443483863904917489ull, 14583489235060748317ull,
  12211171349452974780ull, 8048813539344533742ull}},
{{6958020424154267383ull, 18338052808767743506ull,
  3020296074980721333ull, 5030508462090333589ull}},
{{17920897567047610037ull, 9087507955677515670ull,
  8387056112153289571ull, 6288135577612916986ull}},
{{13177749921954736738ull, 6747698926169506684ull,
  1260448103336836156ull, 7860169472016146233ull}},
{{17459465738076486269ull, 13440683865710717485ull,
  12316995110653992357ull, 4912605920010091395ull}},
{{7989274117313444124ull, 2965796776856233145ull,
  10784557869890102543ull, 6140757400012614244ull}},
{{14598278665069193059ull, 17542304026352455143ull,
  13480697337362628178ull, 7675946750015767805ull}},
{{16041453193309327518ull, 15575626034897672368ull,
  10731278845065336563ull, 4797466718759854878ull}},
{{1605072417927107782ull, 14857846525194702557ull,
  4190726519476894896ull, 5996833398449818598ull}},
{{6618026540836272631ull, 125564082783826580ull,
  14461780186200894429ull, 7496041748062273247ull}},
{{13359638624877446203ull, 2384320560953585564ull,
  15956141644016640874ull, 4685026092538920779ull}},
{{16699548281096807753ull, 12203772738046757763ull,
  15333491036593413188ull, 5856282615673650974ull}},
{{16262749332943621787ull, 15254715922558447204ull,
  9943491758886990677ull, 7320353269592063718ull}},
{{1881692592469975618ull, 5233336847915895294ull,
  3205992661753962539ull, 9150441586990079648ull}},
{{15011115925575898473ull, 964992520733740606ull,
  2003745413596226587ull, 5719025991868799780ull}},
{{9540522870115097284ull, 15041298706199339470ull,
  2504681766995283233ull, 7148782489835999725ull}},
{{2702281550789095796ull, 4966565327467010626ull,
  7742538227171491946ull, 8935978112294999656ull}},
{{6300611987670572777ull, 7715789348094269545ull,
  4839086391982182466ull, 5584986320184374785ull}},
{{12487451003015603875ull, 421364648263061123ull,
  10660544008405115987ull, 6981232900230468481ull}},
{{10997627735342116940ull, 14361763865610990116ull,
  17937366028933782887ull, 8726541125288085601ull}},
{{16096889371443598895ull, 15893631443647950678ull,
  4293324740442532448ull, 5454088203305053501ull}},
{{10897739677449722811ull, 1420295230850386732ull,
  9978341943980553465ull, 6817610254131316876ull}},
{{13622174596812153514ull, 6387055056990371319ull,
  12472927429975691831ull, 8522012817664146095ull}},
{{15431388150648677802ull, 10909438438260063930ull,
  14713108671375889250ull, 5326258011040091309ull}},
{{10065863151456071445ull, 4413426010970304105ull,
  4556327783937697851ull, 6657822513800114137ull}},
{{17194014957747477210ull, 905096495285492227ull,
  10307095748349510218ull, 8322278142250142671ull}},
{{8440416339378479304ull, 5177371327980820546ull,
  13359463870359525742ull, 5201423838906339169ull}},
{{1327148387368323322ull, 15695086196830801491ull,
  2864271782667243465ull, 6501779798632923962ull}},
{{15493993539492567865ull, 5783799690756338151ull,
  12803711765188830140ull, 8127224748291154952ull}},
{{16601274989823936772ull, 12838246843577487152ull,
  8002319853243018837ull, 5079515467681971845ull}},
{{2304849663570369348ull, 2212750499189695229ull,
  14614585834981161451ull, 6349394334602464806ull}},
{{7492748097890349589ull, 16600996179269282748ull,
  9044860256871676005ull, 7936742918253081008ull}},
{{13906339598036244302ull, 12681465621256995669ull,
  5653037660544797503ull, 4960464323908175630ull}},
{{3547866442263141665ull, 11240146008143856683ull,
  16289669112535772687ull, 6200580404885219537ull}},
{{18269891108111090793ull, 9438496491752432949ull,
  6527028335387552147ull, 7750725506106524422ull}},
{{13724524951783125698ull, 3593217298131576641ull,
  17914450764899383804ull, 4844203441316577763ull}},
{{3320598134446743410ull, 4491521622664470802ull,
  17781377437696841851ull, 6055254301645722204ull}},
{{13374119704913205071ull, 1002716009903200598ull,
  3779977723411500698ull, 7569067877057152756ull}},
{{3747138797143365265ull, 5238383524616888278ull,
  11585858113986963744ull, 4730667423160720472ull}},
{{13907295533283982389ull, 6547979405771110347ull,
  14482322642483704680ull, 5913334278950900590ull}},
{{12772433398177590083ull, 8184974257213887934ull,
  8879531266249855042ull, 7391667848688625738ull}},
{{3371084855433605898ull, 9727294929186067863ull,
  10161393059833547305ull, 4619792405430391086ull}},
{{18048914124574171084ull, 16770804679909972732ull,
  3478369287937158323ull, 5774740506787988858ull}},
{{4114398582008162239ull, 16351819831460078012ull,
  13571333646776223712ull, 7218425633484986072ull}},
{{5142998227510202799ull, 1993030715615545899ull,
  16964167058470279641ull, 9023032041856232590ull}},
{{908530882980182797ull, 12774859243328185947ull,
  5990918393116536871ull, 5639395026160145369ull}},
{{14970721659007392209ull, 11356888035732844529ull,
  12100334009823058993ull, 7049243782700181711ull}},
{{4878344018477076549ull, 361051989383891950ull,
  10513731493851435838ull, 8811554728375227139ull}},
{{16884023066830336555ull, 14060715548647096180ull,
  4265239174443453446ull, 5507221705234516962ull}},
{{2658284759828369078ull, 8352522398954094418ull,
  14554921004909092616ull, 6884027131543146202ull}},
{{12546227986640237155ull, 10440652998692618022ull,
  8970279219281589962ull, 8605033914428932753ull}},
{{3229706473222760318ull, 11137094142610274168ull,
  17135639558119463486ull, 5378146196518082970ull}},
{{4037133091528450398ull, 4697995641408066902ull,
  12196177410794553550ull, 6722682745647603713ull}},
{{14269788401265338805ull, 15095866588614859435ull,
  1410163708211028225ull, 8403353432059504642ull}},
{{6612774741577142801ull, 2517387590243205291ull,
  5493038336059280545ull, 5252095895037190401ull}},
{{3654282408544040597ull, 7758420506231394518ull,
  11477983938501488585ull, 6565119868796488001ull}},
{{13791225047534826555ull, 14309711651216631051ull,
  512421867844697019ull, 8206399835995610002ull}},
{{6313672645495572645ull, 6637726772796700455ull,
  4931949685830323541ull, 5128999897497256251ull}},
{{3280404788442077902ull, 12908844484423263473ull,
  1553251088860516522ull, 6411249871871570314ull}},
{{8712192003979985281ull, 6912683568674303533ull,
  11164935897930421461ull, 8014062339839462892ull}},
{{7750963011701184753ull, 6626270239635133660ull,
  16201456973061289221ull, 5008788962399664307ull}},
{{9688703764626480941ull, 12894523817971304979ull,
  15640135197899223622ull, 6260986202999580384ull}},
{{7499193687355713272ull, 6894782735609355416ull,
  1103424923664477912ull, 7826232753749475481ull}},
{{4686996054597320795ull, 4309239209755847135ull,
  12218855623358768455ull, 4891395471093422175ull}},
{{1247059049819263090ull, 774862993767421015ull,
  10661883510771072665ull, 6114244338866777719ull}},
{{15393881867556242574ull, 5580264760636664172ull,
  8715668370036452927ull, 7642805423583472149ull}},
{{397804130367875801ull, 10405194503038996964ull,
  7753135740486477031ull, 4776753389739670093ull}},
{{497255162959844751ull, 8394807110371358301ull,
  14303105694035484193ull, 5970941737174587616ull}},
{{5233254972127193843ull, 15105194906391585780ull,
  17878882117544355241ull, 7463677171468234520ull}},
{{12494156394434271960ull, 2523217788853659256ull,
  11174301323465222026ull, 4664798232167646575ull}},
{{15617695493042839950ull, 12377394272921849878ull,
  9356190635904139628ull, 5830997790209558219ull}},
{{10298747329448774129ull, 15471742841152312348ull,
  7083552276452786631ull, 7288747237761947774ull}},
{{12873434161810967662ull, 14727992533013002531ull,
  18077812382420759097ull, 9110934047202434717ull}},
{{5740053341918160837ull, 2287466305492044726ull,
  13604475748226668388ull, 5694333779501521698ull}},
{{16398438714252476854ull, 2859332881865055907ull,
  7782222648428559677ull, 7117917224376902123ull}},
{{15886362374388208163ull, 8185852120758707788ull,
  5116092292108311692ull, 8897396530471127654ull}},
{{705604447137854294ull, 14339529612328968176ull,
  17032615737849858519ull, 5560872831544454783ull}},
{{882005558922317867ull, 13312725996983822316ull,
  16679083653884935245ull, 6951091039430568479ull}},
{{1102506948652897334ull, 2805849440947614183ull,
  16237168548928781153ull, 8688863799288210599ull}},
{{7606595870549142690ull, 13282870946660728624ull,
  17065759370721570076ull, 5430539874555131624ull}},
{{9508244838186428362ull, 16603588683325910780ull,
  2885455139692410979ull, 6788174843193914531ull}},
{{11885306047733035453ull, 16142799835730000571ull,
  17441876979897677436ull, 8485218553992393163ull}},
{{5122473270619453206ull, 865877860476474549ull, 8595330103222354446ull,
  5303261596245245727ull}},
{{11014777606701704412ull, 10305719362450368994ull,
  6132476610600555153ull, 6629076995306557159ull}},
{{4545099971522354707ull, 17493835221490349147ull,
  3053909744823306037ull, 8286346244133196449ull}},
{{534844472987777740ull, 13239490022645162169ull,
  13437908636583036033ull, 5178966402583247780ull}},
{{5280241609662110079ull, 2714304473024288999ull,
  16797385795728795042ull, 6473708003229059725ull}},
{{1988615993650249694ull, 12616252628135137057ull,
  7161674189378830090ull, 8092135004036324657ull}},
{{12772100042099875819ull, 12496843911011848564ull,
  16005261414430238566ull, 5057584377522702910ull}},
{{15965125052624844774ull, 6397682851910034897ull,
  10783204731183022400ull, 6321980471903378638ull}},
{{6121348260498892255ull, 7997103564887543622ull,
  4255633877124002192ull, 7902475589879223298ull}},
{{17660900718093971372ull, 4998189728054714763ull,
  7271457191629889274ull, 4939047243674514561ull}},
{{17464439879190076310ull, 15471109196923169262ull,
  13701007507964749496ull, 6173809054593143201ull}},
{{12607177812132819580ull, 892142422444409962ull,
  3291201329673773159ull, 7717261318241429002ull}},
{{12491172151010400142ull, 7475118041668838082ull,
  6668686849473496128ull, 4823288323900893126ull}},
{{6390593151908224369ull, 9343897552086047603ull,
  17559230598696645968ull, 6029110404876116407ull}},
{{3376555421457892557ull, 11679871940107559504ull,
  17337352229943419556ull, 7536388006095145509ull}},
{{2110347138411182848ull, 16523291999422000498ull,
  13141688152928331174ull, 4710242503809465943ull}},
{{11861305959868754368ull, 11430742962422724814ull,
  11815424172733026064ull, 5887803129761832429ull}},
{{5603260412981167152ull, 14288428703028406018ull,
  934222160634118868ull, 7359753912202290537ull}},
{{16227447553081234748ull, 17860535878785507522ull,
  5779463719220036489ull, 9199692390252863171ull}},
{{14753840739103159622ull, 4245305896599860345ull,
  1306321815298828854ull, 5749807743908039482ull}},
{{4607242868596785815ull, 14530004407604601240ull,
  10856274305978311875ull, 7187259679885049352ull}},
{{5759053585745982269ull, 13550819491078363646ull,
  13570342882472889844ull, 8984074599856311690ull}},
{{17434466546373402630ull, 17692634218778753086ull,
  13093150319972944056ull, 5615046624910194806ull}},
{{12569711146111977479ull, 3669048699763889742ull,
  7143065863111404263ull, 7018808281137743508ull}},
{{6488766895785196041ull, 18421368929987025890ull,
  8928832328889255328ull, 8773510351422179385ull}},
{{8667165328293135430ull, 11513355581241891181ull,
  17109735251624254340ull, 5483443969638862115ull}},
{{15445642678793807191ull, 14391694476552363976ull,
  16775483046102930021ull, 6854304962048577644ull}},
{{860309274782707373ull, 4154560040408291259ull, 2522609733919110911ull,
  8567881202560722056ull}},
{{16678594361235049772ull, 9514129052896263892ull,
  1576631083699444319ull, 5354925751600451285ull}},
{{2401498877834260599ull, 7280975297692941962ull,
  6582474873051693303ull, 6693657189500564106ull}},
{{12225245634147601557ull, 4489533103688789548ull,
  17451465628169392437ull, 8367071486875705132ull}},
{{16864150558197026781ull, 5111801199019187419ull,
  1683793980751094465ull, 5229419679297315708ull}},
{{16468502179318895572ull, 11001437517201372178ull,
  2104742475938868081ull, 6536774599121644635ull}},
{{11362255687293843657ull, 18363482914929103127ull,
  16465986150205748813ull, 8170968248902055793ull}},
{{14018938832199734142ull, 13783019831044383406ull,
  3373712316237511152ull, 5106855155563784871ull}},
{{8300301503394891869ull, 17228774788805479258ull,
  18052198450579052652ull, 6383568944454731088ull}},
{{1152004842388839029ull, 3089224412297297457ull,
  4118503989514264200ull, 7979461180568413861ull}},
{{12249218072561494153ull, 1930765257685810910ull,
  4879908002660109077ull, 4987163237855258663ull}},
{{6088150553847091883ull, 7025142590534651542ull,
  1488198984897748442ull, 6233954047319073329ull}},
{{16833560229163640662ull, 18004800275023090235ull,
  6471934749549573456ull, 7792442559148841661ull}},
{{8215132134013581462ull, 11253000171889431397ull,
  6350802227682177362ull, 4870276599468026038ull}},
{{14880601185944364731ull, 4842878178007013438ull,
  17161874821457497511ull, 6087845749335032547ull}},
{{9377379445575680106ull, 1441911704081378894ull,
  16840657508394483985ull, 7609807186668790684ull}},
{{1249176135057412162ull, 12430409861119331569ull,
  1302038905891776682ull, 4756129491667994178ull}},
{{6173156187249153107ull, 6314640289544388653ull,
  10850920669219496661ull, 5945161864584992722ull}},
{{12328131252488829288ull, 12504986380357873720ull,
  4340278799669595018ull, 7431452330731240903ull}},
{{7705082032805518305ull, 12427302506151058979ull,
  9630203277434578742ull, 4644657706707025564ull}},
{{5019666522579509977ull, 6310756095834047916ull,
  12037754096793223428ull, 5805822133383781955ull}},
{{6274583153224387471ull, 7888445119792559895ull,
  10435506602564141381ull, 7257277666729727444ull}},
{{3231542923103096435ull, 14472242418168087773ull,
  13044383253205176726ull, 9071597083412159305ull}},
{{4325557336153129224ull, 4433465492927666954ull,
  1235210505612153598ull, 5669748177132599566ull}},
{{14630318707046187338ull, 14765203903014359500ull,
  10767385168869967805ull, 7087185221415749457ull}},
{{18287898383807734172ull, 4621446823485785663ull,
  18070917479514847661ull, 8858981526769686821ull}},
{{18347465517520915714ull, 5194247273892309991ull,
  13600166433910473740ull, 5536863454231054263ull}},
{{18322645878473756738ull, 6492809092365387489ull,
  12388522023960704271ull, 6921079317788817829ull}},
{{9068249292810032210ull, 3504325347029346458ull,
  1650594474668716627ull, 8651349147236022287ull}},
{{10279341826433658036ull, 18331104406389199200ull,
  7949150574309029747ull, 5407093217022513929ull}},
{{12849177283042072545ull, 18302194489559111096ull,
  14548124236313675088ull, 6758866521278142411ull}},
{{16061471603802590681ull, 4430999038239337254ull,
  13573469276964705957ull, 8448583151597678014ull}},
{{5426733733949231272ull, 5075217408113279736ull,
  3871732279675553319ull, 5280364469748548759ull}},
{{6783417167436539089ull, 1732335741714211766ull, 227979331167053745ull,
  6600455587185685949ull}},
{{17702643496150449669ull, 6777105695570152611ull,
  4896660182386205085ull, 8250569483982107436ull}},
{{8758309175880337092ull, 6541534068945039334ull,
  12283784650846153986ull, 5156605927488817147ull}},
{{1724514432995645556ull, 17400289623036074976ull,
  10743044795130304578ull, 6445757409361021434ull}},
{{2155643041244556945ull, 12526989991940317912ull,
  4205433957058104915ull, 8057196761701276793ull}},
{{1347276900777848091ull, 5523525735749004743ull,
  14157611269229785332ull, 5035747976063297995ull}},
{{15519154181254473826ull, 6904407169686255928ull,
  13085328068109843761ull, 6294684970079122494ull}},
{{952198652858540666ull, 13242194980535207815ull,
  7133288048282528893ull, 7868356212598903118ull}},
{{7512653185677669772ull, 10582214872048198836ull,
  18293363085458744270ull, 4917722632874314448ull}},
{{9390816482097087215ull, 4004396553205472737ull,
  4419959783113878722ull, 6147153291092893061ull}},
{{16350206621048746923ull, 14228867728361616729ull,
  10136635747319736306ull, 7683941613866116326ull}},
{{3301350110514384971ull, 13504728348653398360ull,
  1723711323647447287ull, 4802463508666322704ull}},
{{4126687638142981214ull, 12269224417389360046ull,
  2154639154559309109ull, 6003079385832903380ull}},
{{14381731584533502325ull, 1501472466454536345ull,
  2693298943199136387ull, 7503849232291129225ull}},
{{2071053212692357097ull, 17079321356029942880ull,
  13212526885567930001ull, 4689905770181955765ull}},
{{2588816515865446372ull, 7514093639755264888ull,
  2680600551677748790ull, 5862382212727444707ull}},
{{3236020644831807964ull, 169245012839305302ull,
  17185808744879349700ull, 7327977765909305883ull}},
{{13268397842894535763ull, 211556266049131627ull,
  16870574912671799221ull, 9159972207386632354ull}},
{{5986905642595390900ull, 2438065675494401219ull,
  15155795338847262417ull, 5724982629616645221ull}},
{{2871946034816850721ull, 7659268112795389428ull,
  5109686118276914309ull, 7156228287020806527ull}},
{{3589932543521063401ull, 14185771159421624689ull,
  1775421629418754982ull, 8945285358776008159ull}},
{{13772922885769134386ull, 4254420956211127526ull,
  8027167546027803720ull, 5590803349235005099ull}},
{{7992781570356642174ull, 5318026195263909408ull,
  5422273414107366746ull, 6988504186543756374ull}},
{{9990976962945802718ull, 15870904780934662568ull,
  16001213804488984240ull, 8735630233179695467ull}},
{{6244360601841126699ull, 9919315488084164105ull,
  7694915618591921198ull, 5459768895737309667ull}},
{{12417136770728796277ull, 3175772323250429323ull,
  5006958504812513594ull, 6824711119671637084ull}},
{{10909734944983607443ull, 13193087440917812462ull,
  6258698131015641992ull, 8530888899589546355ull}},
{{2206898322187366748ull, 8245679650573632789ull,
  1605843322671082293ull, 5331805562243466472ull}},
{{7370308921161596339ull, 14918785581644428890ull,
  2007304153338852866ull, 6664756952804333090ull}},
{{18436258188306771231ull, 9425109940200760304ull,
  11732502228528341891ull, 8330946191005416362ull}},
{{11522661367691732020ull, 3584850703411781238ull,
  11944499911257601586ull, 5206841369378385226ull}},
{{5179954672759889217ull, 13704435416119502356ull,
  5707252852217226174ull, 6508551711722981533ull}},
{{6474943340949861521ull, 7907172233294602137ull,
  11745752083698920622ull, 8135689639653726916ull}},
{{15576054634162133211ull, 330296627381738431ull,
  16564467089166601197ull, 5084806024783579322ull}},
{{14858382274275278609ull, 5024556802654560943ull,
  11482211824603475688ull, 6356007530979474153ull}},
{{13961291824416710357ull, 6280696003318201179ull,
  517706725472180898ull, 7945009413724342692ull}},
{{6419964381046750021ull, 8537121020501263641ull,
  9546938740274888869ull, 4965630883577714182ull}},
{{12636641494735825431ull, 15283087294053967455ull,
  2710301388488835278ull, 6207038604472142728ull}},
{{11184115849992393884ull, 9880487080712683511ull,
  3387876735611044098ull, 7758798255590178410ull}},
{{13907601433886328034ull, 10786990443872815098ull,
  6729108978184290465ull, 4849248909743861506ull}},
{{8161129755503134234ull, 18095424073268406777ull,
  17634758259585138889ull, 6061561137179826882ull}},
{{14813098212806305697ull, 8784222036303344759ull,
  12820075787626647804ull, 7576951421474783603ull}},
{{16175715410645022917ull, 14713510809544366282ull,
  5706704358052960925ull, 4735594638421739752ull}},
{{10996272226451502838ull, 4556830456648294141ull,
  7133380447566201157ull, 5919493298027174690ull}},
{{18357026301491766451ull, 10307724089237755580ull,
  18140097596312527254ull, 7399366622533968362ull}},
{{2249769401577578224ull, 1830641537346209334ull,
  15949247016122717438ull, 4624604139083730226ull}},
{{12035583788826748588ull, 11511673958537537475ull,
  10713186733298620989ull, 5780755173854662783ull}},
{{10432793717606047831ull, 554534392889758132ull,
  8779797398195888333ull, 7225943967318328479ull}},
{{13040992147007559788ull, 5304854009539585569ull,
  6363060729317472512ull, 9032429959147910599ull}},
{{1233091064238643012ull, 3315533755962240981ull,
  10894441983464502176ull, 5645268724467444124ull}},
{{6153049848725691669ull, 4144417194952801226ull,
  13618052479330627720ull, 7056585905584305155ull}},
{{16914684347761890394ull, 5180521493691001532ull,
  12410879580735896746ull, 8820732381980381444ull}},
{{1348305680496405688ull, 7849511951984263862ull,
  16980171774814711274ull, 5512957738737738402ull}},
{{10908754137475282918ull, 588517903125554019ull,
  12001842681663613285ull, 6891197173422173003ull}},
{{9024256653416715744ull, 5347333397334330428ull,
  10390617333652128702ull, 8613996466777716254ull}},
{{14863532445240223148ull, 17177141428616120229ull,
  1882449815105192534ull, 5383747791736072659ull}},
{{4744357501268115223ull, 12248054748915374479ull,
  16188120324163654380ull, 6729684739670090823ull}},
{{1318760858157756124ull, 15310068436144218099ull,
  15623464386777180071ull, 8412105924587613529ull}},
{{16965126600844455242ull, 16486321800231218167ull,
  2847136214094655688ull, 5257566202867258456ull}},
{{16594722232628181148ull, 2161158176579471093ull,
  3558920267618319611ull, 6571957753584073070ull}},
{{6908344735503062723ull, 16536505776006502579ull,
  13672022371377675321ull, 8214947191980091337ull}},
{{2011872450475720250ull, 3417787082362982256ull,
  1627484954469965220ull, 5134341994987557086ull}},
{{2514840563094650313ull, 4272233852953727820ull,
  11257728229942232333ull, 6417927493734446357ull}},
{{3143550703868312891ull, 9951978334619547679ull, 237102232145626704ull,
  8022409367168057947ull}},
{{8882248217558777413ull, 6219986459137217299ull,
  16289089959586874354ull, 5014005854480036216ull}},
{{6491124253521083862ull, 16998355110776297432ull,
  1914618375774041326ull, 6267507318100045271ull}},
{{8113905316901354827ull, 12024571851615595982ull,
  16228331024999715370ull, 7834384147625056588ull}},
{{459504804635958863ull, 12127043425687135393ull, 919334853770046298ull,
  4896490092265660368ull}},
{{5186067024222336483ull, 5935432245254143433ull,
  1149168567212557873ull, 6120612615332075460ull}},
{{11094269798705308508ull, 12030976324995067195ull,
  1436460709015697341ull, 7650765769165094325ull}},
{{4628075614977123865ull, 9825203212335610949ull,
  3203630952348504790ull, 4781728605728183953ull}},
{{10396780537148792736ull, 3058131978564737878ull,
  8616224708863018892ull, 5977160757160229941ull}},
{{3772603634581215111ull, 3822664973205922348ull,
  15381966904506161519ull, 7471450946450287426ull}},
{{11581249308468035253ull, 9306694635894783323ull,
  14225415333743738853ull, 4669656841531429641ull}},
{{9864875617157656162ull, 16245054313295867058ull,
  3946711111897509854ull, 5837071051914287052ull}},
{{3107722484592294394ull, 11082945854765058015ull,
  4933388889871887318ull, 7296338814892858815ull}},
{{17719711161022531705ull, 4630310281601546710ull,
  1555050093912471244ull, 9120423518616073519ull}},
{{6463133457211694412ull, 12117315962855742502ull,
  7889435336336376383ull, 5700264699135045949ull}},
{{17302288858369393822ull, 10534958935142290223ull,
  14473480188847858383ull, 7125330873918807436ull}},
{{17016175054534354374ull, 8557012650500474875ull,
  18091850236059822979ull, 8906663592398509295ull}},
{{8329266399870277532ull, 3042289897349102845ull,
  18224935425178471218ull, 5566664745249068309ull}},
{{15023269018265234819ull, 13026234408541154364ull,
  8946111226190925310ull, 6958330931561335387ull}},
{{332342199121991907ull, 7059420973821667148ull, 6570953014311268734ull,
  8697913664451669234ull}},
{{9431085911306020750ull, 18247196163920705679ull,
  8718531652371930862ull, 5436196040282293271ull}},
{{7177171370705138034ull, 13585623168046106291ull,
  6286478547037525674ull, 6795245050352866589ull}},
{{4359778194954034638ull, 7758656923202857056ull,
  12469784202224294997ull, 8494056312941083236ull}},
{{2724861371846271649ull, 7155003586215479612ull,
  17016987163244960181ull, 5308785195588177022ull}},
{{3406076714807839561ull, 13555440501196737419ull,
  12047861917201424418ull, 6635981494485221278ull}},
{{18092653948791963163ull, 7720928589641145965ull,
  5836455359647004715ull, 8294976868106526598ull}},
{{13613751727208670929ull, 2519737359312022276ull,
  17482842655061541659ull, 5184360542566579123ull}},
{{17017189659010838661ull, 16984729754422191557ull,
  17241867300399539169ull, 6480450678208223904ull}},
{{7436429018481384614ull, 7395854137745575735ull,
  3105590051789872346ull, 8100563347760279881ull}},
{{11565297164191947240ull, 9234094854518372738ull,
  13470208828437139976ull, 5062852092350174925ull}},
{{5233249418385158242ull, 11542618568147965923ull,
  3002702980264261258ull, 6328565115437718657ull}},
{{1929875754554059899ull, 5204901173330181596ull,
  8365064743757714477ull, 7910706394297148321ull}},
{{10429544383451063245ull, 5558906242545057449ull,
  16757380510917041308ull, 4944191496435717700ull}},
{{17648616497741216960ull, 6948632803181321811ull,
  2499981564936750019ull, 6180239370544647126ull}},
{{17449084603749133296ull, 4074104985549264360ull,
  12348348993025713332ull, 7725299213180808907ull}},
{{10905677877343208310ull, 11769687652823066033ull,
  5411875111427376880ull, 4828312008238005567ull}},
{{18243783365106398291ull, 14712109566028832541ull,
  2153157870856833196ull, 6035390010297506959ull}},
{{8969671151100834152ull, 18390136957536040677ull,
  16526505393853205207ull, 7544237512871883698ull}},
{{7911887478651715297ull, 18411364626101107279ull,
  14940751889585641158ull, 4715148445544927311ull}},
{{5278173329887256217ull, 13790833745771608291ull,
  14064253843554663544ull, 5893935556931159139ull}},
{{1986030643931682368ull, 17238542182214510364ull,
  12968631286015941526ull, 7367419446163948924ull}},
{{2482538304914602959ull, 12324805690913362147ull,
  16210789107519926908ull, 9209274307704936155ull}},
{{17692487505067484514ull, 16926375593675627149ull,
  7825900182986260365ull, 5755796442315585097ull}},
{{8280551326052191930ull, 7322911436812370225ull,
  14394061247160213361ull, 7194745552894481371ull}},
{{14962375175992627817ull, 13765325314442850685ull,
  13380890540522878797ull, 8993431941118101714ull}},
{{11657327494209086338ull, 10909171330740475630ull,
  12974742606254187152ull, 5620894963198813571ull}},
{{5348287330906582114ull, 13636464163425594538ull,
  11606742239390346036ull, 7026118703998516964ull}},
{{15908731200488003450ull, 17045580204281993172ull,
  14508427799237932545ull, 8782648379998146205ull}},
{{719584963450226349ull, 3735958600035163877ull,
  11373610383737401793ull, 5489155237498841378ull}},
{{5511167222740170840ull, 9281634268471342750ull,
  4993640942816976433ull, 6861444046873551723ull}},
{{16112331065279989357ull, 16213728854016566341ull,
  1630365160093832637ull, 8576805058591939654ull}},
{{12376049925013687301ull, 12439423542974047915ull,
  14854036280340809110ull, 5360503161619962283ull}},
{{10858376387839721222ull, 6325907391862784086ull,
  13955859331998623484ull, 6700628952024952854ull}},
{{4349598447944875719ull, 7907384239828480108ull,
  8221452128143503547ull, 8375786190031191068ull}},
{{11941871066820323132ull, 2636272140679106115ull,
  14361779616944465525ull, 5234866368769494417ull}},
{{10315652815098016011ull, 7907026194276270548ull,
  4117166465898418194ull, 6543582960961868022ull}},
{{12894566018872520014ull, 660410705990562377ull,
  14369830119227798551ull, 8179478701202335027ull}},
{{1141574734154243153ull, 7330285718885183342ull,
  6675300815303680142ull, 5112174188251459392ull}},
{{10650340454547579749ull, 18386229185461254985ull,
  8344126019129600177ull, 6390217735314324240ull}},
{{17924611586611862590ull, 9147728426544405019ull,
  10430157523912000222ull, 7987772169142905300ull}},
{{8897039232418720167ull, 1105644248162865233ull,
  15742220489299775947ull, 4992357605714315812ull}},
{{15732985058950788113ull, 15217113365485745253ull,
  1231031537915168317ull, 6240447007142894766ull}},
{{5831173268406321429ull, 5186333651575017855ull,
  10762161459248736205ull, 7800558758928618457ull}},
{{10562012320395032749ull, 5547301541448080111ull,
  18255565958098929888ull, 4875349224330386535ull}},
{{8590829382066403032ull, 6934126926810100139ull,
  18207771429196274456ull, 6094186530412983169ull}},
{{6126850709155615886ull, 8667658658512625174ull,
  8924656231213179358ull, 7617733163016228962ull}},
{{17664339748504423641ull, 805600643143002829ull,
  10189596162935625003ull, 4761083226885143101ull}},
{{8245366630348365839ull, 14842058859210917249ull,
  17348681222096919157ull, 5951354033606428876ull}},
{{14918394306362845203ull, 4717515518731482849ull,
  3239107453911597331ull, 7439192542008036096ull}},
{{2406467413835696396ull, 642604189993482829ull, 2024442158694748332ull,
  4649495338755022560ull}},
{{7619770285722008399ull, 803255237491853536ull, 2530552698368435415ull,
  5811869173443778200ull}},
{{9524712857152510499ull, 14839127102146980632ull,
  3163190872960544268ull, 7264836466804722750ull}},
{{11905891071440638123ull, 102164803974174174ull,
  13177360628055456144ull, 9081045583505903437ull}},
{{2829495901223010923ull, 63853002483858859ull, 10541693401748354042ull,
  5675653489691189648ull}},
{{17371927931810927366ull, 9303188289959599381ull,
  13177116752185442552ull, 7094566862113987060ull}},
{{7879851859481495495ull, 11628985362449499227ull,
  16471395940231803190ull, 8868208577642483825ull}},
{{2619064402962240733ull, 2656429833103549113ull,
  3377093435003795138ull, 5542630361026552391ull}},
{{7885516522130188820ull, 12543909328234212199ull,
  18056424849036907634ull, 6928287951283190488ull}},
{{5245209634235348120ull, 6456514623437989441ull,
  4123786987586582927ull, 8660359939103988111ull}},
{{14807471067465562335ull, 10952850667289825256ull,
  9494895894882696185ull, 5412724961939992569ull}},
{{62594760622401303ull, 18302749352539669475ull,
  16480305887030758135ull, 6765906202424990711ull}},
{{13913301506060165341ull, 18266750672247198939ull,
  15988696340361059765ull, 8457382753031238389ull}},
{{6389970432073909386ull, 13722562179368193289ull,
  12298778221939356305ull, 5285864220644523993ull}},
{{12599149058519774637ull, 3318144668928077899ull,
  1538414722142031670ull, 6607330275805654992ull}},
{{11137250304722330392ull, 13371052873014873182ull,
  1923018402677539587ull, 8259162844757068740ull}},
{{2349095422024068591ull, 6051065036420601787ull,
  10425258538528238050ull, 5161976777973167962ull}},
{{16771427332812249451ull, 16787203332380528041ull,
  3808201136305521754ull, 6452470972466459953ull}},
{{7129226110733148101ull, 11760632128620884244ull,
  9371937438809290097ull, 8065588715583074941ull}},
{{13679138356062993371ull, 432866052746970796ull,
  8163303908469500263ull, 5040992947239421838ull}},
{{17098922945078741714ull, 14376140621215877207ull,
  980757848732099520ull, 6301241184049277298ull}},
{{16761967662921039239ull, 17970175776519846509ull,
  10449319347769900208ull, 7876551480061596622ull}},
{{12782072798539343476ull, 11231359860324904068ull,
  1919138573928799726ull, 4922844675038497889ull}},
{{15977590998174179345ull, 4815827788551354277ull,
  7010609235838387562ull, 6153555843798122361ull}},
{{6136930692435560469ull, 15243156772543968655ull,
  13374947563225372356ull, 7691944804747652951ull}},
{{10753110710413307150ull, 303600945985204601ull,
  15276871254656939579ull, 4807465502967283094ull}},
{{18053074406444021841ull, 14214559237763669463ull,
  9872717031466398665ull, 6009331878709103868ull}},
{{17954656989627639397ull, 3933140991922423117ull,
  12340896289332998332ull, 7511664848386379835ull}},
{{13527503627730968575ull, 11681585156806290256ull,
  5407217171619430005ull, 4694790530241487397ull}},
{{16909379534663710719ull, 766923390725699108ull,
  11370707482951675411ull, 5868488162801859246ull}},
{{2689980344620086783ull, 14793712293689287598ull,
  4990012316834818455ull, 7335610203502324058ull}},
{{12585847467629884286ull, 13880454348684221593ull,
  15460887432898298877ull, 9169512754377905072ull}},
{{948625639627595823ull, 10981126977141332448ull,
  9663054645561436798ull, 5730945471486190670ull}},
{{1185782049534494779ull, 4503036684571889752ull,
  2855446270097020190ull, 7163681839357738338ull}},
{{1482227561918118473ull, 14852167892569637998ull,
  12792679874476051045ull, 8954602299197172922ull}},
{{14761450281480987758ull, 11588447942069717700ull,
  12607110939974919807ull, 5596626436998233076ull}},
{{5068778141683081ull, 9873873909159759222ull, 15758888674968649759ull,
  6995783046247791345ull}},
{{9229708009531879659ull, 7730656368022311123ull,
  5863552788428648487ull, 8744728807809739182ull}},
{{3462724496743730835ull, 11749189257655026308ull,
  17499778548050069016ull, 5465455504881086988ull}},
{{4328405620929663544ull, 14686486572068782885ull,
  3427979111353034654ull, 6831819381101358736ull}},
{{10022193044589467334ull, 9134736178231202798ull,
  4284973889191293318ull, 8539774226376698420ull}},
{{1652184634441029180ull, 1097524092967113845ull,
  11901480717599334132ull, 5337358891485436512ull}},
{{6676916811478674379ull, 1371905116208892306ull,
  14876850896999167665ull, 6671698614356795640ull}},
{{17569518051203118781ull, 6326567413688503286ull,
  149319547539407965ull, 8339623267945994551ull}},
{{6369262763574561335ull, 6259947642769008506ull,
  7010853744853211834ull, 5212264542466246594ull}},
{{17184950491322977476ull, 17048306590316036440ull,
  17986939217921290600ull, 6515330678082808242ull}},
{{3034444040444170229ull, 2863639164185493935ull,
  13260301985546837443ull, 8144163347603510303ull}},
{{8814056552918688249ull, 17930675542111791373ull,
  15205217768607855257ull, 5090102092252193939ull}},
{{15629256709575748215ull, 8578286372357575504ull,
  14394836192332431168ull, 6362627615315242424ull}},
{{1089826813260133653ull, 10722857965446969381ull,
  17993545240415538960ull, 7953284519144053030ull}},
{{2986984767501277485ull, 6701786228404355863ull,
  6634279756832323946ull, 4970802824465033144ull}},
{{17568789014658760569ull, 17600604822360220636ull,
  8292849696040404932ull, 6213503530581291430ull}},
{{3514242194613899095ull, 3554011954240724180ull,
  1142690083195730358ull, 7766879413226614288ull}},
{{11419773408488462742ull, 16056315526682616324ull,
  714181301997331473ull, 4854299633266633930ull}},
{{14274716760610578428ull, 6235336353071106693ull,
  10116098664351440150ull, 6067874541583292412ull}},
{{4008337895481059323ull, 17017542478193659175ull,
  12645123330439300187ull, 7584843176979115515ull}},
{{9422740212316743933ull, 8330121039657343032ull,
  5597359072310868665ull, 4740526985611947197ull}},
{{11778425265395929916ull, 15024337317999066694ull,
  11608384858815973735ull, 5925658732014933996ull}},
{{5499659544890136587ull, 14168735629071445464ull,
  14510481073519967169ull, 7407073415018667495ull}},
{{3437287215556335367ull, 1937930740528571559ull,
  15986579698591061337ull, 4629420884386667184ull}},
{{18131667074727582921ull, 7034099444088102352ull,
  1536480549529275055ull, 5786776105483333981ull}},
{{4217839769699927035ull, 4180938286682740037ull,
  6532286705338981723ull, 7233470131854167476ull}},
{{9883985730552296697ull, 614486839926037142ull, 8165358381673727154ull,
  9041837664817709345ull}},
{{1565805063167797532ull, 4995740293381161118ull,
  16632564034614549231ull, 5651148540511068340ull}},
{{11180628365814522723ull, 1632989348299063493ull,
  2343960969558634923ull, 7063935675638835426ull}},
{{140727401985989691ull, 15876294740655993079ull,
  12153323248803069461ull, 8829919594548544282ull}},
{{7005483653882325413ull, 12228527222123689626ull,
  12207513048929306317ull, 5518699746592840176ull}},
{{17980226604207682574ull, 1450600972372448320ull,
  15259391311161632897ull, 6898374683241050220ull}},
{{4028539181550051602ull, 6424937233892948305ull, 627495065242489505ull,
  8622968354051312776ull}},
{{14047052034537252011ull, 15544800817251562450ull,
  392184415776555940ull, 5389355221282070485ull}},
{{8335443006316789206ull, 984256947854901447ull, 5101916538148082830ull,
  6736694026602588106ull}},
{{5807617739468598603ull, 10453693221673402617ull,
  15600767709539879345ull, 8420867533253235132ull}},
{{15158976133236343887ull, 18062773309614346395ull,
  527107781607648782ull, 5263042208283271958ull}},
{{14337034148118041955ull, 13355094600163157186ull,
  9882256763864336786ull, 6578802760354089947ull}},
{{8697920648292776636ull, 7470496213349170675ull,
  7741134936403033079ull, 8223503450442612434ull}},
{{3130357395969291446ull, 11586589160984313528ull,
  9449895353679283578ull, 5139689656526632771ull}},
{{3912946744961614307ull, 5259864414375616102ull,
  7200683173671716569ull, 6424612070658290964ull}},
{{14114555468056793691ull, 11186516536396908031ull,
  9000853967089645711ull, 8030765088322863705ull}},
{{15739126195176577913ull, 13909101862889149375ull,
  17154748775499498329ull, 5019228180201789815ull}},
{{15062221725543334487ull, 3551319273329273007ull,
  16831749950946985008ull, 6274035225252237269ull}},
{{14216091138501780205ull, 4439149091661591259ull,
  7204629383401567548ull, 7842544031565296587ull}},
{{6579213952349918676ull, 11997840219143270345ull,
  2197050355412285765ull, 4901590019728310367ull}},
{{12835703458864786249ull, 1162242218646924219ull,
  16581370999547520919ull, 6126987524660387958ull}},
{{11432943305153594908ull, 15287860828590818986ull,
  11503341712579625340ull, 7658734405825484948ull}},
{{11757275584148384721ull, 331540981014486058ull,
  16412960607217041646ull, 4786709003640928092ull}},
{{5473222443330705094ull, 9637798263122883381ull,
  2069456685311750441ull, 5983386254551160116ull}},
{{11453214072590769271ull, 16658933847330992130ull,
  2586820856639688051ull, 7479232818188950145ull}},
{{11769944813796618699ull, 8105990645368176129ull,
  13145978081468274792ull, 4674520511368093840ull}},
{{877372961963609661ull, 10132488306710220162ull,
  16432472601835343490ull, 5843150639210117300ull}},
{{10320088239309287884ull, 3442238346532999394ull,
  2093846678584627747ull, 7303938299012646626ull}},
{{3676738262281834047ull, 18137855988448412955ull,
  11840680385085560491ull, 9129922873765808282ull}},
{{18438862478422003944ull, 9030316983566564144ull,
  12012111259105863211ull, 5706201796103630176ull}},
{{4601834024317953313ull, 6676210211030817277ull,
  15015139073882329014ull, 7132752245129537720ull}},
{{10363978548824829546ull, 17568634800643297404ull,
  322179768643359651ull, 8915940306411922151ull}},
{{15700858629870294274ull, 8674553741188366925ull,
  7118891383043181638ull, 5572462691507451344ull}},
{{5791015232055704131ull, 1619820139630682849ull,
  8898614228803977048ull, 6965578364384314180ull}},
{{11850455058497018067ull, 2024775174538353561ull,
  11123267786004971310ull, 8706972955480392725ull}},
{{489005383919554436ull, 15100542539368634688ull,
  9257885375466801020ull, 5441858097175245453ull}},
{{611256729899443045ull, 428934100501241744ull, 16184042737760889180ull,
  6802322621469056816ull}},
{{764070912374303806ull, 536167625626552180ull, 1783309348491559859ull,
  8502903276836321021ull}},
{{9700916357088715687ull, 16476005830512452776ull,
  3420411352020918863ull, 5314314548022700638ull}},
{{12126145446360894609ull, 15983321269713178066ull,
  13498886226880924387ull, 6642893185028375797ull}},
{{5934309771096342453ull, 15367465568714084679ull,
  3038549728318991772ull, 8303616481285469747ull}},
{{10626472634576295889ull, 381293943591527116ull,
  18039994644695227522ull, 5189760300803418591ull}},
{{13283090793220369861ull, 9699989466344184703ull,
  17938307287441646498ull, 6487200376004273239ull}},
{{11992177473098074423ull, 2901614796075455071ull,
  17811198090874670219ull, 8109000470005341549ull}},
{{14412639948327378370ull, 17954410312043017083ull,
  13437841816010362838ull, 5068125293753338468ull}},
{{13404113916981835059ull, 13219640853198995546ull,
  16797302270012953548ull, 6335156617191673085ull}},
{{7531770359372518015ull, 16524551066498744433ull,
  7161569782234028223ull, 7918945771489591357ull}},
{{16236571520676293520ull, 17245373444202797126ull,
  6781824123109961591ull, 4949341107180994598ull}},
{{11072342363990591092ull, 16945030786826108504ull,
  17700652190742227797ull, 6186676383976243247ull}},
{{13840427954988238864ull, 7346230428250471918ull,
  17514129220000396843ull, 7733345479970304059ull}},
{{4038581453440261386ull, 2285551008442850997ull,
  8640487753286554075ull, 4833340924981440037ull}},
{{9659912835227714637ull, 16691996815835727458ull,
  15412295710035580497ull, 6041676156226800046ull}},
{{2851519007179867488ull, 7029937964512495611ull,
  10041997600689699814ull, 7552095195283500058ull}},
{{17923100443983274844ull, 18228769283102473468ull,
  10887934518858450287ull, 4720059497052187536ull}},
{{3957131481269541939ull, 18174275585450703932ull,
  13609918148573062859ull, 5900074371315234420ull}},
{{4946414351586927424ull, 18106158463385992011ull,
  17012397685716328574ull, 7375092964144043025ull}},
{{1571331921056271376ull, 13409326042377714206ull,
  7430439051863247006ull, 9218866205180053782ull}},
{{14817140505942333322ull, 3769142758058683474ull, 32338388987141475ull,
  5761791378237533614ull}},
{{9298053595573140844ull, 99742429145966439ull, 9263795023088702652ull,
  7202239222796917017ull}},
{{7010880976039038151ull, 124678036432458049ull,
  16191429797288266219ull, 9002799028496146271ull}},
{{15911015656092868605ull, 16218824837266143944ull,
  17037172650946248242ull, 5626749392810091419ull}},
{{1442025496406534140ull, 11050159009727904123ull,
  16684779795255422399ull, 7033436741012614274ull}},
{{15637589925790331387ull, 9201012743732492249ull,
  11632602707214502191ull, 8791795926265767843ull}},
{{2855964675977875261ull, 12668161992473889512ull,
  4964533682795369917ull, 5494872453916104902ull}},
{{3569955844972344076ull, 2000144435310198178ull,
  15429039140348988205ull, 6868590567395131127ull}},
{{13685816843070205903ull, 7111866562565135626ull,
  14674612907008847352ull, 8585738209243913909ull}},
{{13165321545346266593ull, 4444916601603209766ull,
  11477476076094223547ull, 5366086380777446193ull}},
{{7233279894828057434ull, 944459733576624304ull, 511787039835615722ull,
  6707607975971807742ull}},
{{9041599868535071792ull, 10403946703825556188ull,
  9863105836649295460ull, 8384509969964759677ull}},
{{14874371954689195678ull, 15725838726745748425ull,
  8470284157119503614ull, 5240318731227974798ull}},
{{4757906888079330886ull, 10433926371577409724ull,
  1364483159544603710ull, 6550398414034968498ull}},
{{5947383610099163607ull, 3819035927616986347ull,
  10928975986285530446ull, 8187998017543710622ull}},
{{1411271747098283302ull, 16221955510042780179ull,
  2218923973001068624ull, 5117498760964819139ull}},
{{15599147739155017840ull, 1830700313843923607ull,
  16608713021533499493ull, 6396873451206023923ull}},
{{14887248655516384396ull, 6900061410732292413ull,
  16149205258489486462ull, 7996091814007529904ull}},
{{11610373418911434200ull, 18147596436989846470ull,
  10093253286555929038ull, 4997557383754706190ull}},
{{5289594736784516941ull, 13461123509382532280ull,
  3393194571340135490ull, 6246946729693382738ull}},
{{6611993420980646177ull, 7603032349873389542ull,
  13464865251029945171ull, 7808683412116728422ull}},
{{17967553943395067573ull, 2446052209457174511ull,
  3803854763466327828ull, 4880427132572955264ull}},
{{17847756410816446562ull, 3057565261821468139ull,
  4754818454332909785ull, 6100533915716194080ull}},
{{17698009495093170298ull, 8433642595704223078ull,
  5943523067916137231ull, 7625667394645242600ull}},
{{6449569916005843532ull, 12188555649956221280ull,
  3714701917447585769ull, 4766042121653276625ull}},
{{8061962395007304415ull, 1400636507163112888ull,
  9255063415236870116ull, 5957552652066595781ull}},
{{10077452993759130519ull, 1750795633953891110ull,
  16180515287473475549ull, 7446940815083244726ull}},
{{1686722102672068671ull, 3400090280434875896ull,
  5501136036243534314ull, 4654338009427027954ull}},
{{2108402628340085838ull, 13473484887398370678ull,
  16099792082159193700ull, 5817922511783784942ull}},
{{11858875322279883105ull, 16841856109247963347ull,
  10901368065844216317ull, 7272403139729731178ull}},
{{10211908134422465978ull, 7217262081277790472ull,
  4403338045450494589ull, 9090503924662163973ull}},
{{6382442584014041236ull, 6816631810012312997ull,
  5057929287620253070ull, 5681564952913852483ull}},
{{12589739248444939449ull, 17744161799370167054ull,
  1710725591097928433ull, 7101956191142315604ull}},
{{6513802023701398503ull, 8345144193930545106ull,
  2138406988872410542ull, 8877445238927894505ull}},
{{8682812283240761969ull, 604029102779202787ull,
  12865719414113726349ull, 5548403274329934065ull}},
{{6241829335623564557ull, 5366722396901391388ull,
  2247091212359994224ull, 6935504092912417582ull}},
{{7802286669529455696ull, 6708402996126739235ull,
  12032236052304768588ull, 8669380116140521977ull}},
{{2570586159242215858ull, 13416123909433987830ull,
  602618505049398511ull, 5418362572587826236ull}},
{{12436604735907545631ull, 12158468868365096883ull,
  753273131311748139ull, 6772953215734782795ull}},
{{10934069901457044134ull, 10586400067028983200ull,
  14776649469421848886ull, 8466191519668478493ull}},
{{6833793688410652584ull, 2004814023465726596ull,
  11541248927602349506ull, 5291369699792799058ull}},
{{8542242110513315730ull, 11729389566186934053ull,
  5203189122648161074ull, 6614212124740998823ull}},
{{15289488656569032566ull, 5438364920878891758ull,
  1892300384882813439ull, 8267765155926248529ull}},
{{4944244391928257450ull, 10316507103190389205ull,
  12711902786620228159ull, 5167353222453905330ull}},
{{10791991508337709716ull, 8283947860560598602ull,
  6666506446420509391ull, 6459191528067381663ull}},
{{4266617348567361337ull, 5743248807273360349ull,
  3721447039598248835ull, 8073989410084227079ull}},
{{4972478852068294788ull, 1283687495332156266ull,
  9243433427389987378ull, 5046243381302641924ull}},
{{15438970601940144293ull, 10827981406019971140ull,
  11554291784237484222ull, 6307804226628302405ull}},
{{851969178715628750ull, 4311604720670188118ull, 607806675014691566ull,
  7884755283285378007ull}},
{{14367538791979431681ull, 16529811005701031285ull,
  7297408199525264084ull, 4927972052053361254ull}},
{{4124365434692125889ull, 2215519683416737491ull,
  18345132286261355914ull, 6159965065066701567ull}},
{{543770774937769457ull, 11992771641125697672ull,
  18319729339399306988ull, 7699956331333376959ull}},
{{339856734336105911ull, 16718854312558336853ull,
  18367359864765648723ull, 4812472707083360599ull}},
{{5036506936347520293ull, 16286881872270533162ull,
  18347513812529673000ull, 6015590883854200749ull}},
{{15519005707289176174ull, 1911858266628614836ull,
  9099334210379927539ull, 7519488604817750937ull}},
{{476006530200959301ull, 17335812481138741937ull,
  17216298927555924471ull, 4699680378011094335ull}},
{{5206694181178587030ull, 17058079582996039517ull,
  16908687641017517685ull, 5874600472513867919ull}},
{{11120053744900621691ull, 7487541423462885684ull,
  16524173532844509203ull, 7343250590642334899ull}},
{{13900067181125777114ull, 4747740760901219201ull,
  16043530897628248600ull, 9179063238302918624ull}},
{{1770012960562528840ull, 2967337975563262001ull,
  10027206811017655375ull, 5736914523939324140ull}},
{{6824202219130548954ull, 17544230524736241213ull,
  12534008513772069218ull, 7171143154924155175ull}},
{{13141938792340574097ull, 12706916119065525708ull,
  11055824623787698619ull, 8963928943655193969ull}},
{{17437083782067634619ull, 5635979565202259615ull,
  18439105435935781397ull, 5602455589784496230ull}},
{{17184668709157155369ull, 11656660474930212423ull,
  13825509758064950938ull, 7003069487230620288ull}},
{{16869149868019056307ull, 5347453556807989721ull,
  17281887197581188673ull, 8753836859038275360ull}},
{{3625689639870828336ull, 14871373519073463336ull,
  10801179498488242920ull, 5471148036898922100ull}},
{{4532112049838535420ull, 142472825132277554ull,
  13501474373110303651ull, 6838935046123652625ull}},
{{14888512099152945083ull, 14013149086697510654ull,
  3041784911105715851ull, 8548668807654565782ull}},
{{4693634043543202773ull, 6452375169972250207ull,
  15736173624723236119ull, 5342918004784103613ull}},
{{1255356536001615562ull, 3453782944037924855ull,
  5835158975621881437ull, 6678647505980129517ull}},
{{15404253725284183165ull, 8928914698474793972ull,
  11905634737954739700ull, 8348309382475161896ull}},
{{404286541447838670ull, 14803943723401522041ull,
  7441021711221712312ull, 5217693364046976185ull}},
{{5117044195237186241ull, 58185580542350935ull, 13912963157454528295ull,
  6522116705058720231ull}},
{{1784619225619094898ull, 13907790030960102381ull,
  12779517928390772464ull, 8152645881323400289ull}},
{{3421230025225628263ull, 8692368769350063988ull,
  1069669677603150934ull, 5095403675827125181ull}},
{{4276537531532035329ull, 1642088924832804177ull,
  5948773115431326572ull, 6369254594783906476ull}},
{{9957357932842432065ull, 2052611156041005221ull,
  7435966394289158215ull, 7961568243479883095ull}},
{{8529191717240213993ull, 8200411000166710119ull,
  11565008024071805740ull, 4975980152174926934ull}},
{{6049803628122879587ull, 10250513750208387649ull,
  5232887993234981367ull, 6219975190218658668ull}},
{{12173940553580987388ull, 8201456169333096657ull,
  6541109991543726709ull, 7774968987773323335ull}},
{{691183818347035261ull, 7431753115046879363ull,
  11005722772355911049ull, 4859355617358327084ull}},
{{14699037828215957789ull, 13901377412235987107ull,
  13757153465444888811ull, 6074194521697908855ull}},
{{13762111266842559332ull, 12765035746867595980ull,
  12584755813378723110ull, 7592743152122386069ull}},
{{17824691578631375390ull, 3366461323364859583ull,
  10171315392575395896ull, 4745464470076491293ull}},
{{17669178454861831334ull, 4208076654206074479ull,
  17325830259146632774ull, 5931830587595614116ull}},
{{17474787050149901263ull, 14483467854612368907ull,
  3210543750223739351ull, 7414788234494517646ull}},
{{8615898897129994338ull, 15969696436773812423ull,
  15841647899172000806ull, 4634242646559073528ull}},
{{6158187602985105018ull, 10738748509112489721ull,
  1355315800255449392ull, 5792803308198841911ull}},
{{12309420522158769176ull, 13423435636390612151ull,
  15529202805601475452ull, 7241004135248552388ull}},
{{10775089634271073566ull, 16779294545488265189ull,
  964759433292292699ull, 9051255169060690486ull}},
{{9040274030633114931ull, 8181216081716471791ull,
  14438032701089846649ull, 5657034480662931553ull}},
{{6688656519864005760ull, 14838206120572977643ull,
  4212482821080144599ull, 7071293100828664442ull}},
{{3749134631402619296ull, 13936071632288834150ull,
  14488975563204956557ull, 8839116376035830552ull}},
{{16178267199908800772ull, 11015887779394215295ull,
  9055609727003097848ull, 5524447735022394095ull}},
{{15611147981458613061ull, 13769859724242769119ull,
  6707826140326484406ull, 6905559668777992619ull}},
{{14902248958395878422ull, 7988952618448685591ull,
  3773096656980717604ull, 8631949585972490774ull}},
{{16231434626638505870ull, 14216467423385204302ull,
  16193243465895112214ull, 5394968491232806733ull}},
{{11065921246443356529ull, 8547212242376729570ull,
  6406496277086726556ull, 6743710614041008417ull}},
{{4609029521199419854ull, 10684015302970911963ull,
  12619806364785796099ull, 8429638267551260521ull}},
{{574800441535943457ull, 4371666555143126025ull, 969849950350040706ull,
  5268523917219537826ull}},
{{5330186570347317225ull, 14687955230783683339ull,
  10435684474792326690ull, 6585654896524422282ull}},
{{2051047194506758627ull, 9136572001624828366ull,
  3821233556635632555ull, 8232068620655527853ull}},
{{15116962551848887854ull, 3404514491801823776ull,
  4694113982110964299ull, 5145042887909704908ull}},
{{449459116101558201ull, 18090701170034443433ull,
  5867642477638705373ull, 6431303609887131135ull}},
{{5173509913554335655ull, 8778318407260890579ull,
  2722867078620993813ull, 8039129512358913919ull}},
{{927600686757765833ull, 7792292013751750564ull, 8619320951779202989ull,
  5024455945224321199ull}},
{{1159500858447207291ull, 14352051035617076109ull,
  6162465171296615832ull, 6280569931530401499ull}},
{{6061062091486397018ull, 17940063794521345136ull,
  3091395445693381886ull, 7850712414413001874ull}},
{{3788163807178998136ull, 6600853853148452806ull,
  6543808171985751583ull, 4906695259008126171ull}},
{{13958576795828523478ull, 3639381298008178103ull,
  3568074196554801575ull, 6133369073760157714ull}},
{{12836534976358266443ull, 18384284677792386341ull,
  13683464782548277776ull, 7666711342200197142ull}},
{{10328677369437610479ull, 11490177923620241463ull,
  3940479470665285706ull, 4791694588875123214ull}},
{{8299160693369625195ull, 5139350367670526021ull,
  14148971375186382941ull, 5989618236093904017ull}},
{{14985636885139419398ull, 11035873978015545430ull,
  3851156163700814964ull, 7487022795117380022ull}},
{{4754337034784749220ull, 16120793273114491702ull,
  16242030657595173064ull, 4679389246948362513ull}},
{{15166293330335712333ull, 1704247517683563011ull,
  6467480266711802619ull, 5849236558685453142ull}},
{{14346180644492252512ull, 15965367452386617476ull,
  17307722370244529081ull, 7311545698356816427ull}},
{{17932725805615315639ull, 6121651260201108133ull,
  17022966944378273448ull, 9139432122946020534ull}},
{{13513796637723266227ull, 3826032037625692583ull,
  6027668321809033001ull, 5712145076841262834ull}},
{{12280559778726694879ull, 9394226065459503633ull,
  16757957439116067059ull, 7140181346051578542ull}},
{{1515641668126204887ull, 7131096563396991638ull,
  11724074762040308016ull, 8925226682564473178ull}},
{{14782334097861041767ull, 4456935352123119773ull,
  11939232744702580414ull, 5578266676602795736ull}},
{{4642859567044138496ull, 14794541227008675525ull,
  14924040930878225517ull, 6972833345753494670ull}},
{{10415260477232561024ull, 4658118478478680694ull,
  9431679126743006089ull, 8716041682191868338ull}},
{{1897851779842962736ull, 14440539095117645194ull,
  10506485472641766709ull, 5447526051369917711ull}},
{{11595686761658479228ull, 4215615813614892780ull,
  8521420822374820483ull, 6809407564212397139ull}},
{{14494608452073099035ull, 657833748591228071ull,
  6040090009541137700ull, 8511759455265496424ull}},
{{15976659310186768753ull, 9634518129724293352ull,
  3775056255963211062ull, 5319849659540935265ull}},
{{1524080064023909325ull, 2819775625300590883ull,
  9330506338381401732ull, 6649812074426169081ull}},
{{15740158135312050368ull, 3524719531625738603ull,
  16274818941404140069ull, 8312265093032711351ull}},
{{7531755825356337528ull, 4508792716479780579ull,
  17089290866018669399ull, 5195165683145444594ull}},
{{4803008763268034006ull, 1024304877172337820ull,
  12138241545668560941ull, 6493957103931805743ull}},
{{6003760954085042508ull, 5892067114892810179ull,
  10561115913658313272ull, 8117446379914757179ull}},
{{1446507587089457616ull, 3682541946808006362ull,
  4294854436822751843ull, 5073403987446723237ull}},
{{11031506520716597827ull, 18438235488792171664ull,
  9980254064455827707ull, 6341754984308404046ull}},
{{13789383150895747284ull, 18436108342562826676ull,
  3251945543715008826ull, 7927193730385505058ull}},
{{17841736506164617861ull, 16134253732529154576ull,
  6644151983249268420ull, 4954496081490940661ull}},
{{3855426558996220710ull, 1721073091951891605ull,
  12916875997488973430ull, 6193120101863675826ull}},
{{9430969217172663791ull, 11374713401794640314ull,
  6922722960006440979ull, 7741400127329594783ull}},
{{10506041779160302774ull, 4803352866907956244ull,
  11244230877645107468ull, 4838375079580996739ull}},
{{13132552223950378467ull, 6004191083634945305ull,
  9443602578628996431ull, 6047968849476245924ull}},
{{2580632224655809372ull, 2893552836116293728ull,
  11804503223286245539ull, 7559961061845307405ull}},
{{1612895140409880857ull, 17949371587068541244ull,
  9683657523767597413ull, 4724975663653317128ull}},
{{2016118925512351072ull, 8601656428553512843ull,
  12104571904709496767ull, 5906219579566646410ull}},
{{16355206712172602551ull, 6140384517264503149ull,
  5907342844032095151ull, 7382774474458308013ull}},
{{12527847204321570547ull, 10755269350931396324ull,
  5997932286733753421ull, 4614234046536442508ull}},
{{15659809005401963183ull, 18055772707091633309ull,
  7497415358417191776ull, 5767792558170553135ull}},
{{5739703201470290267ull, 4122971810154990021ull,
  4760083179594101817ull, 7209740697713191419ull}},
{{11786315020265250738ull, 9765400781121125430ull,
  1338417956065239367ull, 9012175872141489274ull}},
{{2754760869238393807ull, 13020904515841785250ull,
  5448197240968162508ull, 5632609920088430796ull}},
{{12666823123402768067ull, 16276130644802231562ull,
  6810246551210203135ull, 7040762400110538495ull}},
{{6610156867398684276ull, 15733477287575401549ull,
  3901122170585366015ull, 8800953000138173119ull}},
{{6437191051337871624ull, 16750952332375707824ull,
  9355730384256935615ull, 5500595625086358199ull}},
{{8046488814172339530ull, 16327004397042246876ull,
  7082976961893781615ull, 6875744531357947749ull}},
{{10058111017715424413ull, 15797069477875420691ull,
  13465407220794614923ull, 8594680664197434686ull}},
{{3980476376858446306ull, 7567325414458443980ull,
  3804193494569246423ull, 5371675415123396679ull}},
{{4975595471073057883ull, 4847470749645667071ull, 143555849784170125ull,
  6714594268904245849ull}},
{{1607808320413934449ull, 10671024455484471743ull,
  4791130830657600560ull, 8393242836130307311ull}},
{{7922409227899790887ull, 6669390284677794839ull,
  9911985796802082206ull, 5245776772581442069ull}},
{{5291325516447350705ull, 17560109892702019357ull,
  17001668264429990661ull, 6557220965726802586ull}},
{{11225842913986576285ull, 8115079310595360484ull,
  12028713293682712519ull, 8196526207158503233ull}},
{{16239523858096385986ull, 11989453596763182158ull,
  600416780910613468ull, 5122828879474064521ull}},
{{11076032785765706675ull, 14986816995953977698ull,
  5362206994565654739ull, 6403536099342580651ull}},
{{4621668945352357535ull, 14121835226515084219ull,
  2091072724779680520ull, 8004420124178225814ull}},
{{582700081631529508ull, 8826147016571927637ull,
  15141978508269464037ull, 5002762577611391133ull}},
{{5340061120466799788ull, 15644369789142297450ull,
  5092415080054666334ull, 6253453222014238917ull}},
{{15898448437438275543ull, 10332090199573096004ull,
  10977204868495720822ull, 7816816527517798646ull}},
{{713158236544146407ull, 1845870356305797099ull, 2249067024382437610ull,
  4885510329698624154ull}},
{{14726505850962346720ull, 11530709982237022181ull,
  12034705817332822820ull, 6106887912123280192ull}},
{{4573074258420769688ull, 14413387477796277727ull,
  15043382271666028525ull, 7633609890154100240ull}},
{{9775700439154062911ull, 11314210182836367531ull,
  9402113919791267828ull, 4771006181346312650ull}},
{{7607939530515190735ull, 14142762728545459414ull,
  2529270362884308977ull, 5963757726682890813ull}},
{{286552376289212611ull, 3843395355399660556ull, 7773273972032774126ull,
  7454697158353613516ull}},
{{9402467272035533690ull, 16237180152406951559ull,
  14081668269375259636ull, 4659185723971008447ull}},
{{7141398071617029208ull, 1849731116799137833ull,
  12990399318291686642ull, 5823982154963760559ull}},
{{13538433607948674414ull, 11535535932853698099ull,
  11626313129437220398ull, 7279977693704700699ull}},
{{12311355991508455114ull, 5196047879212346816ull,
  9921205393369137594ull, 9099972117130875874ull}},
{{7694597494692784446ull, 7859215942935104664ull,
  10812439389283098900ull, 5687482573206797421ull}},
{{9618246868365980558ull, 9824019928668880830ull,
  18127235255031261529ull, 7109353216508496776ull}},
{{2799436548602699889ull, 16891710929263488942ull,
  4212299995079525295ull, 8886691520635620971ull}},
{{15584705898158851143ull, 17474848358430762444ull,
  326844487711009357ull, 5554182200397263107ull}},
{{1034138298989012312ull, 8008502392756289344ull,
  14243613664920925409ull, 6942727750496578883ull}},
{{1292672873736265390ull, 14622314009372749584ull,
  13192831062723768857ull, 8678409688120723604ull}},
{{807920546085165869ull, 2221417228216886634ull,
  17468891451057131344ull, 5424006055075452252ull}},
{{10233272719461233144ull, 2776771535271108292ull,
  3389370240111862564ull, 6780007568844315316ull}},
{{12791590899326541430ull, 3470964419088885365ull,
  4236712800139828205ull, 8475009461055394145ull}},
{{10300587321292782346ull, 4475195771144247305ull,
  14177160546155862388ull, 5296880913159621340ull}},
{{17487420170043365836ull, 5593994713930309131ull,
  17721450682694827985ull, 6621101141449526675ull}},
{{17247589194126819391ull, 11604179410840274318ull,
  17540127334941147077ull, 8276376426811908344ull}},
{{6168057227901874216ull, 9558455140988865401ull,
  10962579584338216923ull, 5172735266757442715ull}},
{{12321757553304730674ull, 7336382907808693847ull,
  9091538461995383250ull, 6465919083446803394ull}},
{{10790510923203525438ull, 18393850671615643117ull,
  2141051040639453254ull, 8082398854308504243ull}},
{{9049912336215897351ull, 6884470651332389044ull,
  17479057964895515948ull, 5051499283942815151ull}},
{{11312390420269871688ull, 8605588314165486305ull,
  17237136437692007031ull, 6314374104928518939ull}},
{{305429970055175898ull, 6145299374279469978ull,
  16934734528687620885ull, 7892967631160648674ull}},
{{4802579749711872841ull, 6146655118138362688ull,
  15195895098857150957ull, 4933104769475405421ull}},
{{6003224687139841051ull, 12295004916100341264ull,
  5159810818289274984ull, 6166380961844256777ull}},
{{7504030858924801313ull, 15368756145125426580ull,
  11061449541288981634ull, 7707976202305320971ull}},
{{13913391323682776629ull, 14217158609130779516ull,
  4607562954091919569ull, 4817485126440825607ull}},
{{17391739154603470786ull, 3936390206131310683ull,
  1147767674187511558ull, 6021856408051032009ull}},
{{17127987924826950579ull, 14143859794518914162ull,
  6046395611161777351ull, 7527320510063790011ull}},
{{15316678471444232016ull, 15757441399215403207ull,
  1473154247762416892ull, 4704575318789868757ull}},
{{14534162070877902116ull, 1250057675309702393ull,
  6453128828130409020ull, 5880719148487335946ull}},
{{4332644533315213932ull, 1562572094137127992ull,
  17289783072017787083ull, 7350898935609169932ull}},
{{5415805666644017415ull, 15788273172953573702ull,
  3165484766312682237ull, 9188623669511462416ull}},
{{17219936596934674597ull, 12173513742309677515ull,
  1978427978945426398ull, 5742889793444664010ull}},
{{16913234727740955342ull, 5993520141032321086ull,
  11696407010536558806ull, 7178612241805830012ull}},
{{11918171372821418369ull, 16715272213145177166ull,
  14620508763170698507ull, 8973265302257287515ull}},
{{2837171089585998577ull, 8141202124002041777ull,
  6831974967767992615ull, 5608290813910804697ull}},
{{8158149880409886125ull, 5564816636575164317ull,
  13151654728137378673ull, 7010363517388505871ull}},
{{14809373368939745560ull, 11567706814146343300ull,
  11827882391744335437ull, 8762954396735632339ull}},
{{32486318732565167ull, 9535659768055158515ull, 5086583485626515696ull,
  5476846497959770212ull}},
{{13875665953697870171ull, 11919574710068948143ull,
  6358229357033144620ull, 6846058122449712765ull}},
{{12732896423694949810ull, 14899468387586185179ull,
  12559472714718818679ull, 8557572653062140956ull}},
{{5652217255595649679ull, 16229696769882447593ull,
  17073042483554037482ull, 5348482908163838097ull}},
{{11676957587921950003ull, 11063748925498283683ull,
  7506245049160383141ull, 6685603635204797622ull}},
{{9984510966475049600ull, 18441372175300242508ull,
  159434274595703118ull, 8357004544005997028ull}},
{{15463691390901681808ull, 6914171591135263663ull,
  9323018458477090257ull, 5223127840003748142ull}},
{{14717928220199714356ull, 13254400507346467483ull,
  2430401036241587013ull, 6528909800004685178ull}},
{{13785724256822255041ull, 2732942578900920642ull,
  12261373332156759575ull, 8161137250005856472ull}},
{{13227763678941297305ull, 8625618139454157257ull,
  7663358332597974734ull, 5100710781253660295ull}},
{{2699646543394457919ull, 1558650637462920764ull,
  4967511897320080514ull, 6375888476567075369ull}},
{{3374558179243072398ull, 11171685333683426763ull,
  10821075890077488546ull, 7969860595708844211ull}},
{{18249999926522777913ull, 11593989351979529630ull,
  4457329422084736389ull, 4981162872318027632ull}},
{{13589127871298696583ull, 657428634692248326ull,
  5571661777605920487ull, 6226453590397534540ull}},
{{7763037802268594921ull, 14656843848647474120ull,
  6964577222007400608ull, 7783066987996918175ull}},
{{4851898626417871826ull, 9160527405404671325ull,
  11270389791395707236ull, 4864416867498073859ull}},
{{10676559301449727686ull, 11450659256755839156ull,
  9476301220817246141ull, 6080521084372592324ull}},
{{13345699126812159607ull, 478266015662635233ull,
  11845376526021557677ull, 7600651355465740405ull}},
{{1423532926616517899ull, 2604759269002840973ull,
  9709203337977167500ull, 4750407097166087753ull}},
{{6391102176698035277ull, 3255949086253551216ull,
  16748190190898847279ull, 5938008871457609691ull}},
{{7988877720872544096ull, 17904994413099102732ull,
  16323551720196171194ull, 7422511089322012114ull}},
{{14216420612400115868ull, 15802307526614327111ull,
  14813905843549994900ull, 4639069430826257571ull}},
{{13158839747072756931ull, 1306140334558357273ull,
  13905696286010105722ull, 5798836788532821964ull}},
{{2613491628558782452ull, 10856047455052722400ull,
  17382120357512632152ull, 7248545985666027455ull}},
{{3266864535698478065ull, 13570059318815903000ull,
  17115964428463402286ull, 9060682482082534319ull}},
{{2041790334811548791ull, 3869601055832551471ull,
  17615006795430708285ull, 5662926551301583949ull}},
{{16387295973796599701ull, 9448687338218077242ull,
  8183700439006221644ull, 7078658189126979937ull}},
{{11260747930390973818ull, 11810859172772596553ull,
  14841311567185164959ull, 8848322736408724921ull}},
{{120438428853276780ull, 14299316010623954702ull,
  2358290701849646243ull, 5530201710255453076ull}},
{{9373920072921371783ull, 13262458994852555473ull,
  2947863377312057804ull, 6912752137819316345ull}},
{{16329086109579102633ull, 16578073743565694341ull,
  8296515240067460159ull, 8640940172274145431ull}},
{{12511521827700633098ull, 17278825117369640819ull,
  12102851052683244455ull, 5400587607671340894ull}},
{{11027716266198403468ull, 16986845378284663120ull,
  5905191778999279761ull, 6750734509589176118ull}},
{{13784645332748004335ull, 7398498667573665188ull,
  16604861760603875510ull, 8438418136986470147ull}},
{{17838775369822278517ull, 12375648806152838ull, 8072195591163728242ull,
  5274011335616543842ull}},
{{13075097175423072339ull, 9238841597862466856ull,
  866872452099884494ull, 6592514169520679803ull}},
{{16343871469278840423ull, 2325179960473307762ull,
  14918648620407019330ull, 8240642711900849753ull}},
{{14826605686726663169ull, 6064923493723205255ull,
  2406626360113305225ull, 5150401694938031096ull}},
{{13921571089980941057ull, 12192840385581394473ull,
  3008282950141631531ull, 6438002118672538870ull}},
{{3566905807194012609ull, 10629364463549355188ull,
  12983725724531815222ull, 8047502648340673587ull}},
{{11452688166351033689ull, 2031666771290959088ull,
  5808985568618690562ull, 5029689155212920992ull}},
{{14315860207938792111ull, 11762955500968474668ull,
  7261231960773363202ull, 6287111444016151240ull}},
{{17894825259923490138ull, 5480322339355817527ull,
  9076539950966704003ull, 7858889305020189050ull}},
{{18101794815093263193ull, 1119358452883692002ull,
  10284523487781577906ull, 4911805815637618156ull}},
{{13403871482011803183ull, 10622570102959390811ull,
  12855654359726972382ull, 6139757269547022695ull}},
{{12143153334087366074ull, 4054840591844462706ull,
  11457881931231327574ull, 7674696586933778369ull}},
{{12201156852231991701ull, 16369333425184952903ull,
  243647179378497877ull, 4796685366833611481ull}},
{{10639760046862601722ull, 6626608726199027417ull,
  4916244992650510251ull, 5995856708542014351ull}},
{{17911386077005640056ull, 3671574889321396367ull,
  1533620222385749910ull, 7494820885677517939ull}},
{{18112145325769606891ull, 16129792361108036441ull,
  17099413703486951357ull, 4684263053548448711ull}},
{{8805123601929844902ull, 6327182396102881840ull,
  16762581110931301293ull, 5855328816935560889ull}},
{{11006404502412306127ull, 12520664013555990204ull,
  7118168333381962904ull, 7319161021169451112ull}},
{{13758005628015382659ull, 15650830016944987755ull,
  8897710416727453630ull, 9148951276461813890ull}},
{{6292910508295920210ull, 5170082742163229443ull,
  10172755028882046423ull, 5718094547788633681ull}},
{{3254452116942512358ull, 1850917409276648900ull,
  17327629804529945933ull, 7147618184735792101ull}},
{{4068065146178140448ull, 6925332780023199029ull,
  7824479200380268704ull, 8934522730919740127ull}},
{{4848383725575031732ull, 4328332987514499393ull,
  11807828527878749796ull, 5584076706824837579ull}},
{{10672165675396177569ull, 5410416234393124241ull,
  10148099641421049341ull, 6980095883531046974ull}},
{{17951893112672609865ull, 11374706311418793205ull,
  3461752514921535868ull, 8725119854413808718ull}},
{{13525776204634075118ull, 16332563481491521561ull,
  15998653377108123629ull, 5453199909008630448ull}},
{{3072162200510430185ull, 6580646296582238240ull,
  1551572647675602921ull, 6816499886260788061ull}},
{{3840202750638037731ull, 12837493889155185704ull,
  6551151828021891555ull, 8520624857825985076ull}},
{{2400126719148773582ull, 5717590671508297113ull,
  13317841929368458030ull, 5325390536141240672ull}},
{{7611844417363354882ull, 16370360376240147199ull,
  16647302411710572537ull, 6656738170176550840ull}},
{{4903119503276805698ull, 6627892415018020287ull,
  2362383940928664056ull, 8320922712720688551ull}},
{{9981978717189085417ull, 4142432759386262679ull,
  8394018990721496891ull, 5200576695450430344ull}},
{{7865787378058968868ull, 566354930805440445ull,
  10492523738401871114ull, 6500720869313037930ull}},
{{14443920241001098988ull, 9931315700361576364ull,
  3892282636147563084ull, 8125901086641297413ull}},
{{18250822187480462676ull, 15430444349580761035ull,
  4738519656805920879ull, 5078688179150810883ull}},
{{18201841715923190441ull, 14676369418548563390ull,
  1311463552580013195ull, 6348360223938513604ull}},
{{13528930108049212243ull, 13733775754758316334ull,
  1639329440725016494ull, 7935450279923142005ull}},
{{3843895299103369748ull, 3971923828296559805ull,
  3330423909666829261ull, 4959656424951963753ull}},
{{9416555142306600089ull, 9576590803798087660ull,
  8774715905510924480ull, 6199570531189954691ull}},
{{11770693927883250111ull, 11970738504747609575ull,
  6356708863461267696ull, 7749463163987443364ull}},
{{14274212732568113175ull, 7481711565467255984ull,
  13196315076518068118ull, 4843414477492152102ull}},
{{17842765915710141469ull, 128767419979294172ull,
  7272021808792809340ull, 6054268096865190128ull}},
{{3856713320928125220ull, 160959274974117716ull, 9090027260991011675ull,
  7567835121081487660ull}},
{{11633817862434854071ull, 16241500611354681236ull,
  14904639074974158104ull, 4729896950675929787ull}},
{{14542272328043567589ull, 1855131690483799929ull,
  14019112825290309727ull, 5912371188344912234ull}},
{{4342782354772295774ull, 16153972668386913624ull,
  8300518994758111350ull, 7390463985431140293ull}},
{{2714238971732684859ull, 5484546899314433111ull,
  7493667380937513546ull, 4619039990894462683ull}},
{{17227856769948019785ull, 16079055660997817196ull,
  4755398207744504028ull, 5773799988618078354ull}},
{{3088076888725473115ull, 1652075502537719880ull,
  15167619796535405844ull, 7217249985772597942ull}},
{{3860096110906841394ull, 2065094378172149850ull,
  9736152708814481497ull, 9021562482215747428ull}},
{{7024246087744163775ull, 12819899032426063416ull,
  15308467479863826743ull, 5638476551384842142ull}},
{{8780307609680204719ull, 11413187772105191366ull,
  9912212312975007621ull, 7048095689231052678ull}},
{{1752012475245480091ull, 431426659849325496ull, 3166893354363983719ull,
  8810119611538815848ull}},
{{1095007797028425057ull, 7187170690046910291ull,
  1979308346477489824ull, 5506324757211759905ull}},
{{15203817801567695033ull, 8983963362558637863ull,
  7085821451524250184ull, 6882905946514699881ull}},
{{14393086233532230887ull, 11229954203198297329ull,
  13468962832832700634ull, 8603632433143374851ull}},
{{2078149868316562449ull, 11630407395426323735ull,
  6112258761306743944ull, 5377270270714609282ull}},
{{16432745390677866773ull, 14538009244282904668ull,
  16863695488488205738ull, 6721587838393261602ull}},
{{2094187664637781850ull, 8949139518498855028ull,
  11856247323755481365ull, 8401984797991577003ull}},
{{10532239327253389464ull, 7899055208275478344ull,
  5104311568133481901ull, 5251240498744735627ull}},
{{13165299159066736830ull, 14485505028771735834ull,
  1768703441739464472ull, 6564050623430919534ull}},
{{7233251911978645230ull, 18106881285964669793ull,
  11434251339029106398ull, 8205063279288649417ull}},
{{16049997491055123029ull, 6705114785300530716ull,
  228878059252109643ull, 5128164549555405886ull}},
{{1615752790109352170ull, 3769707463198275492ull,
  9509469610919912862ull, 6410205686944257357ull}},
{{2019690987636690212ull, 13935506365852620173ull,
  16498523032077278981ull, 8012757108680321696ull}},
{{3568149876486625335ull, 11015534487871581560ull,
  10311576895048299363ull, 5007973192925201060ull}},
{{4460187345608281668ull, 9157732091412089046ull,
  12889471118810374204ull, 6259966491156501325ull}},
{{14798606218865127893ull, 11447165114265111307ull,
  2276780843230804043ull, 7824958113945626657ull}},
{{6943285877577010982ull, 4848635187202000615ull,
  12952203073087722287ull, 4890598821216016660ull}},
{{4067421328543875823ull, 1449107965575112865ull,
  16190253841359652859ull, 6113248526520020825ull}},
{{9695962679107232682ull, 15646443012251054793ull,
  6402759246417402361ull, 7641560658150026032ull}},
{{17589191720510490187ull, 2861497855015827389ull,
  4001724529010876476ull, 4775975411343766270ull}},
{{8151431595355949021ull, 3576872318769784237ull,
  14225527698118371403ull, 5969969264179707837ull}},
{{14800975512622324180ull, 18306148453744394008ull,
  3946851567365800541ull, 7462461580224634797ull}},
{{9250609695388952613ull, 13747185792803940207ull,
  4772625238817319290ull, 4664038487640396748ull}},
{{6951576100808802862ull, 7960610204150149451ull,
  5965781548521649113ull, 5830048109550495935ull}},
{{4077784107583615673ull, 14562448773615074718ull,
  2845540917224673487ull, 7287560136938119919ull}},
{{14320602171334295400ull, 13591374948591455493ull,
  17391984201813005571ull, 9109450171172649898ull}},
{{11256219366297628577ull, 6188766333655965731ull,
  15481676144560516386ull, 5693406356982906186ull}},
{{9458588189444647817ull, 16959329953924732972ull,
  10128723143845869674ull, 7116757946228632733ull}},
{{11823235236805809771ull, 11975790405551140407ull,
  17272589948234724997ull, 8895947432785790916ull}},
{{14307051050644712963ull, 9790712012683156706ull,
  1571996680791927315ull, 5559967145491119323ull}},
{{8660441776451115396ull, 7626703997426557979ull,
  15800053906272072856ull, 6949958931863899153ull}},
{{6213866202136506341ull, 9533379996783197474ull,
  5915009327557927358ull, 8687448664829873942ull}},
{{8495352394762704367ull, 1346676479562110517ull,
  17531938885005868311ull, 5429655415518671213ull}},
{{15230876511880768363ull, 15518403654734801858ull,
  8079865550975171676ull, 6787069269398339017ull}},
{{9815223602996184645ull, 951260494708950707ull,
  14711517957146352500ull, 8483836586747923771ull}},
{{3828671742658921452ull, 9817909846047870000ull,
  6888855714002776360ull, 5302397866717452357ull}},
{{4785839678323651814ull, 12272387307559837500ull,
  13222755660930858354ull, 6627997333396815446ull}},
{{5982299597904564768ull, 6117112097595021067ull,
  7305072539308797135ull, 8284996666746019308ull}},
{{1433094239476659028ull, 10740724088637970023ull,
  13789042373922774017ull, 5178122916716262067ull}},
{{15626425854627987497ull, 18037591129224850432ull,
  12624616948976079617ull, 6472653645895327584ull}},
{{1086288244575432755ull, 8711930856248899329ull,
  15780771186220099522ull, 8090817057369159480ull}},
{{12208145198928115232ull, 10056642803582949984ull,
  9862981991387562201ull, 5056760660855724675ull}},
{{15260181498660144040ull, 17182489522906075384ull,
  7717041470807064847ull, 6320950826069655844ull}},
{{628482799615628434ull, 16866425885205206327ull,
  9646301838508831059ull, 7901188532587069805ull}},
{{7310330777400849627ull, 8235673169039560002ull,
  8334781658281713364ull, 4938242832866918628ull}},
{{18361285508605837842ull, 10294591461299450002ull,
  10418477072852141705ull, 6172803541083648285ull}},
{{13728234848902521494ull, 17479925345051700407ull,
  17634782359492565035ull, 7716004426354560356ull}},
{{15497675808205157790ull, 8619110331443618802ull,
  1798366937828077339ull, 4822502766471600223ull}},
{{10148722723401671430ull, 6162201895877135599ull,
  16083016727567260386ull, 6028128458089500278ull}},
{{8074217385824701383ull, 16926124406701195307ull,
  10880398872604299674ull, 7535160572611875348ull}},
{{2740542856926744413ull, 15190513772615634971ull,
  16023621332232463104ull, 4709475357882422092ull}},
{{17260736626440594228ull, 541398142059992097ull,
  1582782591581027265ull, 5886844197353027616ull}},
{{7740862727768579072ull, 5288433696002378026ull,
  1978478239476284081ull, 7358555246691284520ull}},
{{452706372855948032ull, 11222228138430360437ull,
  2473097799345355101ull, 9198194058364105650ull}},
{{2588784492248661472ull, 9319735595732669225ull,
  6157372143018234842ull, 5748871286477566031ull}},
{{7847666633738214744ull, 2426297457811060723ull,
  3085029160345405649ull, 7186089108096957539ull}},
{{5197897273745380526ull, 7644557840691213808ull,
  17691344505713920773ull, 8982611385121196923ull}},
{{3248685796090862829ull, 7083691659645702582ull,
  8751247306857506531ull, 5614132115700748077ull}},
{{13284229281968354344ull, 4242928556129740323ull,
  15550745151999271068ull, 7017665144625935096ull}},
{{11993600584033055026ull, 5303660695162175404ull,
  991687366289537219ull, 8772081430782418871ull}},
{{16719372401875435200ull, 1008944925262665675ull,
  7537333631572042618ull, 5482550894239011794ull}},
{{16287529483916906095ull, 10484553193433107902ull,
  198295002610277464ull, 6853188617798764743ull}},
{{11136039818041356811ull, 13105691491791384878ull,
  14082926808545010542ull, 8566485772248455928ull}},
{{2348338867848460103ull, 3579371163942227645ull,
  8801829255340631589ull, 5354053607655284955ull}},
{{7547109603237963033ull, 9085899973355172460ull,
  6390600550748401582ull, 6692567009569106194ull}},
{{9433887004047453791ull, 2134002929839189767ull,
  17211622725290277786ull, 8365708761961382742ull}},
{{12813708405170740475ull, 5945437849576881508ull,
  6145578184879035712ull, 5228567976225864214ull}},
{{16017135506463425594ull, 7431797311971101885ull,
  16905344767953570448ull, 6535709970282330267ull}},
{{6186361327797118281ull, 9289746639963877357ull,
  16519994941514575156ull, 8169637462852912834ull}},
{{6172318839086892878ull, 15029463686832199156ull,
  14936682856873997376ull, 5106023414283070521ull}},
{{7715398548858616097ull, 340085534830697329ull, 4835795515810333009ull,
  6382529267853838152ull}},
{{14255934204500658025ull, 5036792936965759565ull,
  6044744394762916261ull, 7978161584817297690ull}},
{{11215801887026605218ull, 5453838594817293680ull,
  8389651265154210567ull, 4986350990510811056ull}},
{{14019752358783256522ull, 2205612225094229196ull,
  10487064081442763209ull, 6232938738138513820ull}},
{{17524690448479070652ull, 7368701299795174399ull,
  13108830101803454011ull, 7791173422673142275ull}},
{{17870460557940501014ull, 2299595303158290047ull,
  5887175804413464805ull, 4869483389170713922ull}},
{{17726389678998238363ull, 7486180147375250463ull,
  16582341792371606814ull, 6086854236463392402ull}},
{{17546301080320410050ull, 134353147364287271ull,
  11504555203609732710ull, 7608567795579240503ull}},
{{17883967202841338137ull, 13919028772384843256ull,
  14107876029897164799ull, 4755354872237025314ull}},
{{3908214929842121056ull, 12787099947053666167ull,
  8411473000516680191ull, 5944193590296281643ull}},
{{273582643875263416ull, 11372188915389694805ull,
  5902655232218462335ull, 7430241987870352054ull}},
{{2476832161635733587ull, 14025147099759641109ull,
  17524217575418702671ull, 4643901242418970033ull}},
{{7707726220472054887ull, 12919747856272163482ull,
  8070213913991214627ull, 5804876553023712542ull}},
{{411285738735292801ull, 11537998801912816449ull, 864395355634242476ull,
  7256095691279640678ull}},
{{5125793191846503905ull, 14422498502391020561ull,
  10303866231397578903ull, 9070119614099550847ull}},
{{14732835790972534701ull, 15931590591635469706ull,
  13357445422264568670ull, 5668824758812219279ull}},
{{9192672701860892568ull, 10691116202689561325ull,
  12085120759403322934ull, 7086030948515274099ull}},
{{16102526895753503614ull, 4140523216507175848ull,
  10494714930826765764ull, 8857538685644092624ull}},
{{10064079309845939759ull, 11811199047171760713ull,
  6559196831766728602ull, 5535961678527557890ull}},
{{17191785155734812603ull, 5540626772109925083ull,
  17422368076563186561ull, 6919952098159447362ull}},
{{16878045426241127849ull, 11537469483564794258ull,
  12554588058849207393ull, 8649940122699309203ull}},
{{15160464409828092810ull, 293389399586914555ull,
  5540774527567060669ull, 5406212576687068252ull}},
{{14338894493857728108ull, 4978422767911031098ull,
  6925968159458825836ull, 6757765720858835315ull}},
{{8700246080467384327ull, 6223028459888788873ull,
  4045774180896144391ull, 8447207151073544144ull}},
{{16966868846360584965ull, 10806921815071574901ull,
  2528608863060090244ull, 5279504469420965090ull}},
{{7373528002668567494ull, 13508652268839468627ull,
  12384133115679888613ull, 6599380586776206362ull}},
{{4605223984908321463ull, 3050757280767172072ull,
  6256794357745084959ull, 8249225733470257953ull}},
{{2878264990567700915ull, 8824252328120564401ull,
  15439711519659147859ull, 5155766083418911220ull}},
{{8209517256637014047ull, 6418629391723317597ull, 852895325864383208ull,
  6444707604273639026ull}},
{{14873582589223655463ull, 8023286739654146996ull,
  10289491194185254818ull, 8055884505342048782ull}},
{{72617081410008856ull, 9626240230711229777ull, 1819245977938396357ull,
  5034927815838780489ull}},
{{4702457370189898974ull, 16644486306816425125ull,
  6885743490850383350ull, 6293659769798475611ull}},
{{10489757731164761622ull, 11582235846665755598ull,
  3995493345135591284ull, 7867074712248094514ull}},
{{1944412563550588110ull, 16462269441020873057ull,
  7108869359137132456ull, 4916921695155059071ull}},
{{7042201722865623041ull, 2131092727566539705ull,
  4274400680494027667ull, 6146152118943823839ull}},
{{13414438172009416705ull, 16498923964740338343ull,
  731314832190146679ull, 7682690148679779799ull}},
{{15301552885146967297ull, 17229356505603793320ull,
  7374600797759923530ull, 4801681342924862374ull}},
{{680197032724157505ull, 12313323595149965843ull,
  18441623034054680221ull, 6002101678656077967ull}},
{{14685304346187360593ull, 1556596438655293591ull,
  18440342774140962373ull, 7502627098320097459ull}},
{{16095844244008182227ull, 3278715783373252446ull,
  9219371224624407531ull, 4689141936450060912ull}},
{{10896433268155451976ull, 17933452784498729270ull,
  11524214030780509413ull, 5861427420562576140ull}},
{{4397169548339539161ull, 8581757925341247876ull,
  14405267538475636767ull, 7326784275703220175ull}},
{{5496461935424423952ull, 6115511388249171941ull,
  13394898404667158055ull, 9158480344629025219ull}},
{{5741131718853958922ull, 10739723645296814319ull,
  6065968493703279832ull, 5724050215393140762ull}},
{{2564728630140060748ull, 13424654556621017899ull,
  16805832653983875598ull, 7155062769241425952ull}},
{{17040968842957239647ull, 7557446158921496565ull,
  2560546743770292882ull, 8943828461551782441ull}},
{{12956448536061968732ull, 9335089867753323257ull,
  13129556760924902811ull, 5589892788469864025ull}},
{{2360502614795297203ull, 7057176316264266168ull,
  2576887895873964802ull, 6987365985587330032ull}},
{{2950628268494121503ull, 18044842432185108518ull,
  3221109869842456002ull, 8734207481984162540ull}},
{{15679200723090989652ull, 15889712538543080727ull,
  11236565705506310809ull, 5458879676240101587ull}},
{{14987314885436349160ull, 6027082617896687197ull,
  9434021113455500608ull, 6823599595300126984ull}},
{{4899085551513272738ull, 7533853272370858997ull,
  11792526391819375760ull, 8529499494125158730ull}},
{{5367771478909489414ull, 4708658295231786873ull,
  11982015013314497754ull, 5330937183828224206ull}},
{{11321400367064249671ull, 15109194905894509399ull,
  5754146729788346384ull, 6663671479785280258ull}},
{{9540064440402924185ull, 439749558658585133ull,
  16416055449090208789ull, 8329589349731600322ull}},
{{8268383284465521568ull, 2580686483375309660ull,
  14871720674108768397ull, 5205993343582250201ull}},
{{10335479105581901959ull, 7837544122646524979ull,
  4754592787353796784ull, 6507491679477812752ull}},
{{8307662863549989545ull, 9796930153308156224ull,
  5943240984192245980ull, 8134364599347265940ull}},
{{5192289289718743466ull, 15346453382672373448ull,
  12937897651974929545ull, 5083977874592041212ull}},
{{6490361612148429332ull, 5348008673058303098ull,
  16172372064968661932ull, 6354972343240051515ull}},
{{17336324052040312473ull, 6685010841322878872ull,
  15603779062783439511ull, 7943715429050064394ull}},
{{10835202532525195296ull, 11095660803467881151ull,
  14364047932667037598ull, 4964822143156290246ull}},
{{8932317147229106216ull, 4646203967480075631ull,
  8731687878979021190ull, 6206027678945362808ull}},
{{6553710415608994866ull, 15031126996204870347ull,
  10914609848723776487ull, 7757534598681703510ull}},
{{1790226000541927839ull, 16311983400269125823ull,
  2209945137024972400ull, 4848459124176064694ull}},
{{16072840555959573511ull, 1943235176626855662ull,
  11985803458135991309ull, 6060573905220080867ull}},
{{10867678658094691080ull, 7040729989210957482ull,
  10370568304242601232ull, 7575717381525101084ull}},
{{11403985179736569829ull, 4400456243256848426ull,
  15704977227006401578ull, 4734823363453188177ull}},
{{5031609437815936479ull, 14723942340925836341ull,
  5796163478475838260ull, 5918529204316485222ull}},
{{10901197815697308502ull, 18404927926157295426ull,
  16468576384949573633ull, 7398161505395606527ull}},
{{11424934653238205718ull, 4585550926207227785ull,
  17210389268234565377ull, 4623850940872254079ull}},
{{446110261265593435ull, 10343624676186422636ull,
  16901300566865818817ull, 5779813676090317599ull}},
{{557637826581991794ull, 17541216863660416199ull,
  16514939690154885617ull, 7224767095112896999ull}},
{{14532105338509653455ull, 8091463024293356536ull,
  16031988594266219118ull, 9030958868891121249ull}},
{{9082565836568533409ull, 445478371755959931ull, 3102463843775305093ull,
  5644349293056950781ull}},
{{6741521277283278858ull, 5168533983122337818ull,
  8489765823146519270ull, 7055436616321188476ull}},
{{17650273633458874380ull, 15684039515757698080ull,
  10612207278933149087ull, 8819295770401485595ull}},
{{11031421020911796488ull, 16720053724989643156ull,
  4326786540119524227ull, 5512059856500928497ull}},
{{13789276276139745609ull, 16288381137809666041ull,
  10020169193576793188ull, 6890074820626160621ull}},
{{3401537289892518300ull, 1913732348552530936ull,
  17136897510398379390ull, 8612593525782700776ull}},
{{2125960806182823937ull, 15031140773127495547ull,
  10710560943998987118ull, 5382870953614187985ull}},
{{16492509063010693634ull, 9565553929554593625ull,
  17999887198426121802ull, 6728588692017734981ull}},
{{6780578273481203330ull, 2733570375088466224ull,
  8664800942750488541ull, 8410735865022168727ull}},
{{4237861420925752081ull, 4014324493643985342ull,
  12333029616860137194ull, 5256709915638855454ull}},
{{14520698813011965910ull, 14241277653909757485ull,
  6192914984220395684ull, 6570887394548569318ull}},
{{4315815460982793675ull, 17801597067387196857ull,
  16964515767130270413ull, 8213609243185711647ull}},
{{14226599709182715807ull, 13431841176330691987ull,
  17520351382097500864ull, 5133505776991069779ull}},
{{13171563618051006855ull, 16789801470413364984ull,
  17288753209194488176ull, 6416882221238837224ull}},
{{16464454522563758568ull, 2540507764307154614ull,
  3164197437783558605ull, 8021102776548546531ull}},
{{5678598058174961201ull, 3893660361905665586ull,
  18118524463110581792ull, 5013189235342841581ull}},
{{16321619609573477309ull, 4867075452382081982ull,
  8813097523606063528ull, 6266486544178551977ull}},
{{11178652475112070829ull, 6083844315477602478ull,
  15628057922934967314ull, 7833108180223189971ull}},
{{2374971778517656364ull, 8414088715600889453ull,
  7461693192620660619ull, 4895692612639493732ull}},
{{7580400741574458359ull, 5905924876073723912ull,
  9327116490775825774ull, 6119615765799367165ull}},
{{9475500926968072949ull, 16605778131946930698ull,
  16270581631897170121ull, 7649519707249208956ull}},
{{10533874097782433497ull, 3461082304825749830ull,
  945741483080955518ull, 4780949817030755598ull}},
{{3943970585373266063ull, 13549724917886963096ull,
  10405548890705970205ull, 5976187271288444497ull}},
{{4929963231716582579ull, 3102098092076540158ull,
  17618622131809850661ull, 7470234089110555621ull}},
{{16916285075105027824ull, 4244654316761531550ull,
  13317481841594850615ull, 4668896305694097263ull}},
{{11921984307026508972ull, 694131877524526534ull,
  12035166283566175365ull, 5836120382117621579ull}},
{{5679108346928360407ull, 5479350865333046072ull,
  10432271836030331302ull, 7295150477647026974ull}},
{{7098885433660450508ull, 16072560618521083398ull,
  3816967758183138319ull, 9118938097058783718ull}},
{{18271861451319945280ull, 16962879414216758979ull,
  16220662904146625161ull, 5699336310661739823ull}},
{{18228140795722543696ull, 7368541212488785012ull,
  15664142611755893548ull, 7124170388327174779ull}},
{{4338431920943628004ull, 9210676515610981266ull,
  14968492246267479031ull, 8905212985408968474ull}},
{{7323205969017155406ull, 12674201849897945147ull,
  13966993672344562298ull, 5565758115880605296ull}},
{{4542321442844056354ull, 6619380275517655626ull,
  17458742090430702873ull, 6957197644850756620ull}},
{{14901273840409846250ull, 12885911362824457436ull,
  3376683539328826975ull, 8696497056063445776ull}},
{{89924113401378099ull, 14971223629406367754ull, 2110427212080516859ull,
  5435310660039653610ull}},
{{9335777178606498431ull, 14102343518330571788ull,
  11861406051955421882ull, 6794138325049567012ull}},
{{11669721473258123039ull, 8404557361058438927ull,
  14826757564944277353ull, 8492672906311958765ull}},
{{14211104948427408755ull, 16782063396729994089ull,
  11572566487303867297ull, 5307920566444974228ull}},
{{3928823130252097232ull, 7142521190630328900ull,
  14465708109129834122ull, 6634900708056217785ull}},
{{4911028912815121540ull, 18151523525142686933ull,
  4247077081130128940ull, 8293625885070272232ull}},
{{5375236079723144915ull, 2121330166359403525ull,
  2654423175706330588ull, 5183516178168920145ull}},
{{11330731118081319047ull, 2651662707949254406ull,
  7929714988060301139ull, 6479395222711150181ull}},
{{4940041860746873001ull, 17149636440218731720ull,
  14523829753502764327ull, 8099244028388937726ull}},
{{3087526162966795626ull, 17636051802777789181ull,
  4465707577511839800ull, 5062027517743086079ull}},
{{8471093722135882436ull, 3598320679762684860ull, 970448453462411847ull,
  6327534397178857599ull}},
{{10588867152669853045ull, 18332958904985519787ull,
  15048118622110178520ull, 7909417996473571998ull}},
{{4312198961204964201ull, 11458099315615949867ull,
  4793388120391473671ull, 4943386247795982499ull}},
{{778562683078817348ull, 9710938126092549430ull, 1380049132061954185ull,
  6179232809744978124ull}},
{{10196575390703297492ull, 16750358676043074691ull,
  1725061415077442731ull, 7724041012181222655ull}},
{{4067016609975866981ull, 8163131163313227730ull,
  7995692412064483563ull, 4827525632613264159ull}},
{{14307142799324609534ull, 5592227935714146758ull,
  5382929496653216550ull, 6034407040766580199ull}},
{{8660556462300986109ull, 16213656956497459256ull,
  2116975852389132783ull, 7543008800958225249ull}},
{{5412847788938116319ull, 17051064625451993891ull,
  12852324953811677749ull, 4714380500598890780ull}},
{{2154373717745257494ull, 7478772726532828652ull,
  16065406192264597187ull, 5892975625748613475ull}},
{{2692967147181571867ull, 4736779889738647911ull,
  15470071721903358580ull, 7366219532185766844ull}},
{{17201266989259128546ull, 5920974862173309888ull,
  890845578669646609ull, 9207774415232208556ull}},
{{10750791868286955342ull, 15229824334926788440ull,
  9780150523523304938ull, 5754859009520130347ull}},
{{13438489835358694177ull, 9813908381803709742ull,
  7613502135976743269ull, 7193573761900162934ull}},
{{7574740257343591913ull, 16879071495682025082ull,
  293505633116153278ull, 8991967202375203668ull}},
{{9345898679267132850ull, 5937733666373877772ull,
  9406813057552371607ull, 5619979501484502292ull}},
{{11682373349083916062ull, 2810481064539959311ull,
  11758516321940464509ull, 7024974376855627865ull}},
{{9991280667927507173ull, 8124787349102337043ull, 863087347143416924ull,
  8781217971069534832ull}},
{{3938707408240998032ull, 14301364130043736460ull,
  539429591964635577ull, 5488261231918459270ull}},
{{4923384260301247539ull, 4041647107272506863ull,
  9897659026810570280ull, 6860326539898074087ull}},
{{1542544306949171520ull, 5052058884090633579ull,
  7760387765085824946ull, 8575408174872592609ull}},
{{17104991256339089864ull, 7769222820984033890ull,
  16379457399247110351ull, 5359630109295370380ull}},
{{12157867033569086522ull, 5099842507802654459ull,
  2027577675349336323ull, 6699537636619212976ull}},
{{10585647773533970249ull, 1763117116325930170ull,
  2534472094186670404ull, 8374422045774016220ull}},
{{11227715876886119310ull, 10325320234558482164ull,
  10807417095721444810ull, 5234013778608760137ull}},
{{14034644846107649137ull, 3683278256343326897ull,
  18120957388079193917ull, 6542517223260950171ull}},
{{3708248002352397709ull, 9215783838856546526ull,
  18039510716671604492ull, 8178146529076187714ull}},
{{16152713056752412280ull, 14983236936140117386ull,
  15886380216347140711ull, 5111341580672617321ull}},
{{10967519284085739542ull, 14117360151747758829ull,
  6022917215151762177ull, 6389176975840771652ull}},
{{18321085123534562332ull, 3811642134402534824ull,
  7528646518939702722ull, 7986471219800964565ull}},
{{11450678202209101457ull, 6993962352428972169ull,
  7011247083551008153ull, 4991544512375602853ull}},
{{478289697479213110ull, 13354138958963603116ull,
  13375744872866148095ull, 6239430640469503566ull}},
{{597862121849016387ull, 12080987680277115991ull,
  7496309054227909311ull, 7799288300586879458ull}},
{{7291192853796717098ull, 14468146327814279350ull,
  9296879177319831223ull, 4874555187866799661ull}},
{{18337363104100672180ull, 13473496891340461283ull,
  16232784990077176933ull, 6093193984833499576ull}},
{{18310017861698452321ull, 3006813058893412892ull,
  1844237163886919551ull, 7616492481041874471ull}},
{{2220389126706756893ull, 8796787189449464914ull,
  8070177255070406575ull, 4760307800651171544ull}},
{{11998858445238221924ull, 6384297968384443238ull,
  10087721568838008219ull, 5950384750813964430ull}},
{{5775201019693001597ull, 3368686442053166144ull,
  3386279924192734466ull, 7437980938517455538ull}},
{{3609500637308125998ull, 6717115044710616744ull,
  6728110971047846945ull, 4648738086573409711ull}},
{{4511875796635157498ull, 13008079824315658834ull,
  3798452695382420777ull, 5810922608216762139ull}},
{{14863216782648722680ull, 2425041725112409830ull,
  136379850800638068ull, 7263653260270952674ull}},
{{9355648941456127542ull, 3031302156390512288ull,
  9393846850355573393ull, 9079566575338690842ull}},
{{5847280588410079714ull, 13423778893812539940ull,
  10482840299899621274ull, 5674729109586681776ull}},
{{7309100735512599642ull, 7556351580410899117ull,
  13103550374874526593ull, 7093411386983352220ull}},
{{13748061937818137457ull, 14057125493941011800ull,
  16379437968593158241ull, 8866764233729190275ull}},
{{8592538711136335911ull, 1868174406072050519ull,
  7931305721157029949ull, 5541727646080743922ull}},
{{6128987370493031984ull, 6946904026017451053ull, 690760114591511628ull,
  6927159557600929903ull}},
{{12272920231543677884ull, 8683630032521813816ull,
  14698508198521553247ull, 8658949447001162378ull}},
{{7670575144714798678ull, 12344797797967215491ull,
  13798253642503358683ull, 5411843404375726486ull}},
{{4976532912466110443ull, 10819311229031631460ull,
  8024445016274422546ull, 6764804255469658108ull}},
{{6220666140582638054ull, 4300766999434763517ull,
  10030556270343028183ull, 8456005319337072635ull}},
{{6193759347077842736ull, 9605508402287809054ull,
  3963254659750698662ull, 5285003324585670397ull}},
{{16965571220702079228ull, 2783513466004985509ull,
  9565754343115761232ull, 6606254155732087996ull}},
{{7371905970595435322ull, 3479391832506231887ull,
  11957192928894701540ull, 8257817694665109995ull}},
{{11524970259263228933ull, 11397991932171170737ull,
  5167402571345494510ull, 5161136059165693747ull}},
{{571154768796872454ull, 5024117878359187614ull, 1847567195754480234ull,
  6451420073957117184ull}},
{{9937315497850866375ull, 15503519384803760325ull,
  2309458994693100292ull, 8064275092446396480ull}},
{{8516665195370485437ull, 466327578647574395ull, 1443411871683187683ull,
  5040171932778997800ull}},
{{6034145475785718892ull, 14417967528591631706ull,
  1804264839603984603ull, 6300214915973747250ull}},
{{16766053881586924422ull, 13410773392312151728ull,
  11478703086359756562ull, 7875268644967184062ull}},
{{10478783675991827764ull, 12993419388622482734ull,
  2562503410547459947ull, 4922042903104490039ull}},
{{3875107558135008897ull, 11630088217350715514ull,
  17038187318466488646ull, 6152553628880612548ull}},
{{14067256484523536929ull, 5314238234833618584ull,
  2850990074373559192ull, 7690692036100765686ull}},
{{8792035302827210581ull, 3321398896771011615ull,
  15616926851765638207ull, 4806682522562978553ull}},
{{6378358110106625322ull, 17986806676245928231ull,
  5686100509424884046ull, 6008353153203723192ull}},
{{3361261619205893748ull, 13260136308452634481ull,
  7107625636781105058ull, 7510441441504653990ull}},
{{13630003558072153353ull, 12899271211210284454ull,
  18277324078270354373ull, 4694025900940408743ull}},
{{7814132410735415883ull, 2289030958730691856ull,
  18234969079410555063ull, 5867532376175510929ull}},
{{9767665513419269854ull, 16696346753695528532ull,
  8958653293981030116ull, 7334415470219388662ull}},
{{12209581891774087317ull, 2423689368409859049ull,
  1974944580621511838ull, 9168019337774235828ull}},
{{713459654717722717ull, 15349863910538325618ull,
  10457712399743220706ull, 5730012086108897392ull}},
{{10115196605251929205ull, 9963957851318131214ull,
  13072140499679025883ull, 7162515107636121740ull}},
{{3420623719710135698ull, 7843261295720276114ull,
  16340175624598782354ull, 8953143884545152175ull}},
{{6749575843246222715ull, 9513724328252560475ull,
  17130138793015320827ull, 5595714927840720109ull}},
{{3825283785630390490ull, 7280469391888312690ull,
  7577615435986987322ull, 6994643659800900137ull}},
{{14004976768892763920ull, 18323958776715166670ull,
  14083705313411122056ull, 8743304574751125171ull}},
{{4141424462130589546ull, 11452474235446979169ull,
  6496472811668257333ull, 5464565359219453232ull}},
{{9788466596090624837ull, 480534739026560249ull, 8120591014585321667ull,
  6830706699024316540ull}},
{{16847269263540668950ull, 14435726479065364023ull,
  10150738768231652083ull, 8538383373780395675ull}},
{{17447072317353999950ull, 6716486040202158562ull,
  4038368720931088600ull, 5336489608612747297ull}},
{{12585468359837724129ull, 8395607550252698203ull,
  9659646919591248654ull, 6670612010765934121ull}},
{{11120149431369767257ull, 1271137400961096946ull,
  16686244667916448722ull, 8338265013457417651ull}},
{{11561779413033492440ull, 5406146894028073495ull,
  8123059908234086499ull, 5211415633410886032ull}},
{{9840538247864477646ull, 2145997599107703965ull,
  10153824885292608124ull, 6514269541763607540ull}},
{{16912358828257984961ull, 2682496998884629956ull,
  12692281106615760155ull, 8142836927204509425ull}},
{{1346852230806464793ull, 17817461688798751387ull,
  1015146663993768240ull, 5089273079502818391ull}},
{{15518623343790244703ull, 3825083037288887617ull,
  15103991385274374013ull, 6361591349378522988ull}},
{{5563221124455642167ull, 9393039815038497426ull, 433245157883415900ull,
  7951989186723153736ull}},
{{8088699221212164258ull, 15094021921253836699ull,
  270778223677134937ull, 4969993241701971085ull}},
{{5499188008087817419ull, 5032469346285132162ull,
  4950158798023806576ull, 6212491552127463856ull}},
{{16097357046964547581ull, 6290586682856415202ull,
  6187698497529758220ull, 7765614440159329820ull}},
{{14672534172780230143ull, 13154988713640035309ull,
  13090683597810874695ull, 4853509025099581137ull}},
{{4505609660693123966ull, 11832049873622656233ull,
  2528296441981429657ull, 6066886281374476422ull}},
{{10243698094293792862ull, 955004286746156579ull,
  12383742589331562880ull, 7583607851718095527ull}},
{{4096468299719926587ull, 596877679216347862ull,
  14657368145973308656ull, 4739754907323809704ull}},
{{14343957411504684041ull, 746097099020434827ull,
  18321710182466635820ull, 5924693634154762130ull}},
{{13318260745953467147ull, 932621373775543534ull,
  13678765691228518967ull, 7405867042693452663ull}},
{{3712226947793529063ull, 7500417386250796565ull,
  15466757584658906210ull, 4628666901683407914ull}},
{{9251969703169299233ull, 152149695958719898ull,
  10110074943968856955ull, 5785833627104259893ull}},
{{2341590092106848233ull, 14025245175230563585ull,
  17249279698388459097ull, 7232292033880324866ull}},
{{7538673633560948195ull, 3696498413756040769ull,
  12338227586130798064ull, 9040365042350406083ull}},
{{16240886067044062382ull, 2310311508597525480ull,
  5405549232118054838ull, 5650228151469003802ull}},
{{1854363510095526362ull, 12111261422601682659ull,
  15980308577002344355ull, 7062785189336254752ull}},
{{16153012442901571664ull, 10527390759824715419ull,
  1528641647543378828ull, 8828481486670318441ull}},
{{7789789767599788338ull, 15802991261745222945ull,
  12484616075783081527ull, 5517800929168949025ull}},
{{14348923227927123327ull, 15142053058754140777ull,
  1770712039446688197ull, 6897251161461186282ull}},
{{4101095979626740446ull, 5092508268160512260ull,
  11436762086163136055ull, 8621563951826482852ull}},
{{11786557024121488587ull, 10100346695241402018ull,
  16371348340706735842ull, 5388477469891551782ull}},
{{5509824243297084926ull, 3402061332196976715ull,
  11240813389028643995ull, 6735596837364439728ull}},
{{2275594285693968253ull, 18087634720528384606ull,
  14051016736285804993ull, 8419496046705549660ull}},
{{15257304483840893870ull, 4387242672689158522ull,
  18005257497033403929ull, 5262185029190968537ull}},
{{9848258567946341530ull, 10095739359288836057ull,
  8671513816009591199ull, 6577731286488710672ull}},
{{16922009228360314816ull, 8007988180683657167ull,
  10839392270011988999ull, 8222164108110888340ull}},
{{17493784795366278616ull, 11922521640568367585ull,
  15997992205612268932ull, 5138852567569305212ull}},
{{8032172938925684558ull, 14903152050710459482ull,
  1550746183305784549ull, 6423565709461631516ull}},
{{816844136802329889ull, 4793882008105910641ull, 1938432729132230687ull,
  8029457136827039395ull}},
{{12039742631569925941ull, 9913705282707276006ull,
  17352421520203501843ull, 5018410710516899621ull}},
{{5826306252607631618ull, 7780445584956707104ull,
  7855468844972213592ull, 6273013388146124527ull}},
{{7282882815759539523ull, 9725556981195883880ull,
  5207650037787879086ull, 7841266735182655659ull}},
{{4551801759849712202ull, 1466787094820039521ull, 948938264403730477ull,
  4900791709489159787ull}},
{{10301438218239528156ull, 6445169886952437305ull,
  15021230885786826808ull, 6125989636861449733ull}},
{{17488483791226798099ull, 8056462358690546631ull,
  4941480551951369798ull, 7657487046076812167ull}},
{{17847831397157830668ull, 423602955754203740ull,
  10005954372610687980ull, 4785929403798007604ull}},
{{3863045172737736719ull, 529503694692754676ull,
  12507442965763359975ull, 5982411754747509505ull}},
{{4828806465922170899ull, 14496937673648107057ull,
  1799245651922036256ull, 7478014693434386882ull}},
{{14547219087269826572ull, 9060586046030066910ull,
  5736214550878660564ull, 4673759183396491801ull}},
{{8960651822232507407ull, 11325732557537583638ull,
  11781954207025713609ull, 5842198979245614751ull}},
{{1977442740935858450ull, 322107641639815836ull,
  10115756740354754108ull, 7302748724057018439ull}},
{{2471803426169823063ull, 402634552049769795ull, 8033009907016054731ull,
  9128435905071273049ull}},
{{17685778205851997078ull, 16392547659526963785ull,
  16549846237953503966ull, 5705272440669545655ull}},
{{8272164702032832636ull, 11267312537553928924ull,
  16075621779014492054ull, 7131590550836932069ull}},
{{10340205877541040795ull, 4860768635087635347ull,
  6259469168485951356ull, 8914488188546165087ull}},
{{4156785664249456545ull, 12261352433784547900ull,
  10829697257944801453ull, 5571555117841353179ull}},
{{5195982080311820681ull, 1491632486948521163ull,
  8925435554003613913ull, 6964443897301691474ull}},
{{1883291581962387947ull, 6476226627113039358ull,
  1933422405649741583ull, 8705554871627114343ull}},
{{15012115294008656179ull, 10965170669586731454ull,
  8125918031172170345ull, 5440971794766946464ull}},
{{9541772080656044416ull, 18318149355410802222ull,
  10157397538965212931ull, 6801214743458683080ull}},
{{2703843063965279712ull, 18286000675836114874ull,
  12696746923706516164ull, 8501518429323353850ull}},
{{6301587933405687724ull, 2205378385542795988ull,
  12547152845743960507ull, 5313449018327096156ull}},
{{7876984916757109655ull, 16591781037210658697ull,
  15683941057179950633ull, 6641811272908870195ull}},
{{14457917164373774972ull, 6904668241231159659ull,
  14993240303047550388ull, 8302264091136087744ull}},
{{6730355218519915406ull, 13538789687624250595ull,
  9370775189404718992ull, 5188915056960054840ull}},
{{3801258004722506353ull, 16923487109530313244ull,
  11713468986755898740ull, 6486143821200068550ull}},
{{4751572505903132941ull, 2707614813203339939ull,
  5418464196590097618ull, 8107679776500085688ull}},
{{663889806975764137ull, 6303945276679475366ull, 3386540122868811011ull,
  5067299860312553555ull}},
{{10053234295574480979ull, 3268245577421956303ull,
  18068233208868177476ull, 6334124825390691943ull}},
{{7954856851040713319ull, 4085306971777445379ull,
  17973605492657833941ull, 7917656031738364929ull}},
{{2665942522686751873ull, 4859159866574597314ull,
  4315974405270064357ull, 4948535019836478081ull}},
{{12555800190213215649ull, 10685635851645634546ull,
  10006654025014968350ull, 6185668774795597601ull}},
{{6471378200911743753ull, 4133672777702267375ull,
  17120003549696098342ull, 7732085968494497001ull}},
{{10962140403210921702ull, 16418603541346080821ull,
  3782473190918979607ull, 4832553730309060626ull}},
{{18314361522441040031ull, 15911568408255213122ull,
  13951463525503500317ull, 6040692162886325782ull}},
{{13669579866196524231ull, 6054402455036852691ull,
  8215957370024599589ull, 7550865203607907228ull}},
{{6237644407159133692ull, 6089844543611726884ull,
  14358345393120150551ull, 4719290752254942017ull}},
{{7797055508948917115ull, 3000619661087270701ull,
  4112873686118024477ull, 5899113440318677522ull}},
{{14358005404613534298ull, 8362460594786476280ull,
  14364464144502306404ull, 7373891800398346902ull}},
{{17947506755766917872ull, 10453075743483095350ull,
  8732208143773107197ull, 9217364750497933628ull}},
{{6605505703926935766ull, 8839015348890628546ull,
  14681002126712967806ull, 5760852969061208517ull}},
{{17480254166763445516ull, 1825397149258509874ull,
  4516194603109046046ull, 7201066211326510647ull}},
{{12626945671599531087ull, 11505118473427913151ull,
  1033557235458919653ull, 9001332764158138309ull}},
{{14809370072390788785ull, 9496542055106139671ull,
  2951816281375518735ull, 5625832977598836443ull}},
{{13900026572061098078ull, 7258991550455286685ull,
  17524828407001562131ull, 7032291221998545553ull}},
{{3539975159794208885ull, 4462053419641720453ull,
  8070977453469788952ull, 8790364027498181942ull}},
{{4518327484085074505ull, 2788783387276075283ull, 432674889991230191ull,
  5493977517186363714ull}},
{{1036223336678955227ull, 17321037289377257816ull,
  9764215649343813546ull, 6867471896482954642ull}},
{{1295279170848694034ull, 12427924574866796462ull,
  2981897524824991125ull, 8584339870603693303ull}},
{{14644607537062597484ull, 10073295868505441740ull,
  8781214980656701309ull, 5365212419127308314ull}},
{{18305759421328246854ull, 17203305854059190079ull,
  1753146688966100828ull, 6706515523909135393ull}},
{{18270513258232920664ull, 3057388243864435983ull,
  6803119379635013940ull, 8383144404886419241ull}},
{{18336599814036657271ull, 11134239689270048297ull,
  15781164658340353472ull, 5239465253054012025ull}},
{{9085691712263657877ull, 13917799611587560372ull,
  5891397767643278128ull, 6549331566317515032ull}},
{{11357114640329572346ull, 17397249514484450465ull,
  7364247209554097660ull, 8186664457896893790ull}},
{{180667622564900860ull, 1649908909698005733ull,
  18437712561253474750ull, 5116665286185558618ull}},
{{4837520546633513979ull, 11285758173977282974ull,
  13823768664712067629ull, 6395831607731948273ull}},
{{15270272720146668282ull, 272139662189440005ull,
  3444652775607920825ull, 7994789509664935342ull}},
{{11849763459305361628ull, 11699302334936869763ull,
  15987966040037114227ull, 4996743443540584588ull}},
{{10200518305704314131ull, 10012441900243699300ull,
  1538213476336841168ull, 6245929304425730736ull}},
{{12750647882130392664ull, 12515552375304624125ull,
  1922766845421051460ull, 7807411630532163420ull}},
{{10274997935545189367ull, 17045592271420165886ull,
  10425101315242932970ull, 4879632269082602137ull}},
{{3620375382576710901ull, 12083618302420431550ull,
  17643062662481054117ull, 6099540336353252671ull}},
{{13748841265075664434ull, 1269464822743375725ull,
  17442142309673929743ull, 7624425420441565839ull}},
{{10898868799885984223ull, 7710944541855691684ull,
  17818867971187287945ull, 4765265887775978649ull}},
{{13623585999857480279ull, 14250366695747002509ull,
  8438526908701946219ull, 5956582359719973312ull}},
{{3194424444539686637ull, 13201272351256365233ull,
  10548158635877432774ull, 7445727949649966640ull}},
{{13525730323905773908ull, 3639109201107840366ull,
  6592599147423395484ull, 4653579968531229150ull}},
{{7683790868027441577ull, 4548886501384800458ull,
  17464120971134020163ull, 5816974960664036437ull}},
{{381366548179526163ull, 1074422108303612669ull, 7995093158635361492ull,
  7271218700830045547ull}},
{{5088394203651795608ull, 1343027635379515836ull,
  5382180429866813961ull, 9089023376037556934ull}},
{{12403618414137148063ull, 12368607318180667157ull,
  17198920823948922437ull, 5680639610023473083ull}},
{{1669464962389271367ull, 1625701092443670235ull,
  16886965011508765143ull, 7100799512529341354ull}},
{{15921889258268752920ull, 15867184420836751505ull,
  11885334227531180620ull, 8875999390661676693ull}},
{{3033651758776888719ull, 693618226168193883ull, 9734176901420681840ull,
  5547499619163547933ull}},
{{17627122753753274611ull, 867022782710242353ull,
  16779407145203240204ull, 6934374523954434916ull}},
{{8198845386909429552ull, 1083778478387802942ull,
  2527514857794498639ull, 8667968154943043646ull}},
{{512592348391005566ull, 7594890576633458695ull,
  15414754841403725361ull, 5417480096839402278ull}},
{{14475798490770920669ull, 14105299239219211272ull,
  10045071514899880893ull, 6771850121049252848ull}},
{{18094748113463650837ull, 3796565993741850378ull,
  12556339393624851117ull, 8464812651311566060ull}},
{{15920903589342169677ull, 4678696755302350438ull,
  17071084157870307756ull, 5290507907069728787ull}},
{{10677757449822936288ull, 5848370944127938048ull,
  16727169178910496791ull, 6613134883837160984ull}},
{{13347196812278670360ull, 2698777661732534656ull,
  2462217399928569373ull, 8266418604796451231ull}},
{{8341998007674168975ull, 3992579047796528112ull,
  8456414902596437714ull, 5166511627997782019ull}},
{{10427497509592711219ull, 14214095846600435948ull,
  5958832609818159238ull, 6458139534997227524ull}},
{{13034371886990889024ull, 8544247771395769127ull,
  7448540762272699048ull, 8072674418746534405ull}},
{{15064011457010387496ull, 5340154857122355704ull,
  6961180985634130857ull, 5045421511716584003ull}},
{{383270247553432754ull, 11286879589830332535ull,
  4089790213615275667ull, 6306776889645730004ull}},
{{14314145864723954654ull, 9496913468860527764ull,
  5112237767019094584ull, 7883471112057162505ull}},
{{18169713202307247467ull, 5935570918037829852ull,
  14724363650455403875ull, 4927169445035726565ull}},
{{4265397429174507718ull, 2807777629119899412ull,
  4570396507787091132ull, 6158961806294658207ull}},
{{5331746786468134647ull, 3509722036399874265ull,
  1101309616306476011ull, 7698702257868322759ull}},
{{14861556787611053915ull, 18334477337245779079ull,
  7605847537832629362ull, 4811688911167701724ull}},
{{13965259966086429489ull, 13694724634702448041ull,
  9507309422290786703ull, 6014611138959627155ull}},
{{3621516902325873149ull, 12506719774950672148ull,
  7272450759436095475ull, 7518263923699533944ull}},
{{11486820100808446526ull, 5510856850130476140ull,
  4545281724647559672ull, 4698914952312208715ull}},
{{14358525126010558158ull, 6888571062663095175ull,
  1069916137382061686ull, 5873643690390260894ull}},
{{13336470389085809793ull, 17834085865183644777ull,
  10560767208582352915ull, 7342054612987826117ull}},
{{2835529931075098529ull, 17680921313052168068ull,
  17812645029155329048ull, 9177568266234782646ull}},
{{10995578243776712389ull, 11050575820657605042ull,
  6521217124794692751ull, 5735980166396739154ull}},
{{4521100767866114678ull, 9201533757394618399ull,
  17374893442848141747ull, 7169975207995923942ull}},
{{1039689941405255444ull, 6890231178315885095ull,
  12495244766705401376ull, 8962469009994904928ull}},
{{7567335241019366509ull, 4306394486447428184ull,
  7809527979190875860ull, 5601543131246815580ull}},
{{9459169051274208136ull, 5382993108059285230ull,
  9761909973988594825ull, 7001928914058519475ull}},
{{2600589277237984361ull, 11340427403501494442ull,
  7590701449058355627ull, 8752411142573149344ull}},
{{6237054316701128130ull, 4781924117974740074ull,
  4744188405661472267ull, 5470256964108218340ull}},
{{17019689932731185970ull, 1365719129041037188ull,
  5930235507076840334ull, 6837821205135272925ull}},
{{2827868342204430847ull, 10930520948156072294ull,
  12024480402273438321ull, 8547276506419091156ull}},
{{15602475769159932991ull, 18360790638666014943ull,
  16738672288275674758ull, 5342047816511931972ull}},
{{14891408693022528335ull, 13727616261477742871ull,
  2476596286635041832ull, 6677559770639914966ull}},
{{14002574847850772515ull, 17159520326847178589ull,
  12319117395148578098ull, 8346949713299893707ull}},
{{11057452289120426774ull, 15336386222706874522ull,
  5393605362754167359ull, 5216843570812433567ull}},
{{4598443324545757659ull, 14558796759956205249ull,
  2130320685015321295ull, 6521054463515541959ull}},
{{10359740174109584978ull, 13586809931517868657ull,
  16497958911551315331ull, 8151318079394427448ull}},
{{18004052654886960371ull, 6185913197984973958ull,
  10311224319719572082ull, 5094573799621517155ull}},
{{13281693781753924656ull, 16955763534335993256ull,
  8277344381222077198ull, 6368217249526896444ull}},
{{16602117227192405820ull, 11971332381065215762ull,
  10346680476527596498ull, 7960271561908620555ull}},
{{14988009285422641542ull, 12093768756593147755ull,
  4160832288616053859ull, 4975169726192887847ull}},
{{14123325588350914023ull, 10505524927314046790ull,
  589354342342679420ull, 6218962157741109809ull}},
{{8430784948583866721ull, 13131906159142558488ull,
  5348378946355737179ull, 7773702697176387261ull}},
{{5269240592864916701ull, 5901598340250405103ull,
  5648579850686029689ull, 4858564185735242038ull}},
{{1974864722653757972ull, 11988683943740394283ull,
  16284096850212312919ull, 6073205232169052547ull}},
{{16303638958599361176ull, 10374168911248104949ull,
  15743435044338003245ull, 7591506540211315684ull}},
{{12495617358338294687ull, 8789698578743759545ull,
  616274865856476220ull, 4744691587632072303ull}},
{{1784463642640704647ull, 10987123223429699432ull,
  14605401637602758987ull, 5930864484540090378ull}},
{{2230579553300880809ull, 9122218010859736386ull,
  9033380010148672926ull, 7413580605675112973ull}},
{{6005798239240438410ull, 1089700238359947337ull,
  7951705515556614531ull, 4633487878546945608ull}},
{{12118933817477935916ull, 15197183353232097883ull,
  9939631894445768163ull, 5791859848183682010ull}},
{{10536981253420031991ull, 14384793173112734450ull,
  3201167831202434396ull, 7239824810229602513ull}},
{{3947854529920264181ull, 17980991466390918063ull,
  8613145807430430899ull, 9049781012787003141ull}},
{{9384938108841246969ull, 8932276657280629837ull,
  7689059138857713264ull, 5656113132991876963ull}},
{{16342858654478946615ull, 11165345821600787296ull,
  4999637905144753676ull, 7070141416239846204ull}},
{{1981829244389131653ull, 13956682277000984121ull,
  6249547381430942095ull, 8837676770299807755ull}},
{{12767858323811677043ull, 15640455450766696931ull,
  1600124104180644857ull, 5523547981437379847ull}},
{{11348136886337208400ull, 5715511258176207452ull,
  15835213185507969784ull, 6904434976796724808ull}},
{{14185171107921510500ull, 7144389072720259315ull,
  1347272408175410614ull, 8630543720995906011ull}},
{{6559888933237250111ull, 18300301225732325784ull,
  16982946319605489297ull, 5394089825622441256ull}},
{{8199861166546562638ull, 9040318476883243518ull,
  2781938825797310006ull, 6742612282028051571ull}},
{{1026454421328427489ull, 2077026059249278590ull,
  17312481587528801220ull, 8428265352535064463ull}},
{{14476592068612430893ull, 10521513323885574926ull,
  17737830019846582618ull, 5267665845334415289ull}},
{{8872368048910762808ull, 3928519618002192850ull,
  8337229469526064561ull, 6584582306668019112ull}},
{{1867088024283677702ull, 9522335540930128967ull,
  10421536836907580701ull, 8230727883335023890ull}},
{{8084459042818380420ull, 8257302722295024556ull,
  11125146541494625842ull, 5144204927084389931ull}},
{{10105573803522975525ull, 1098256366014004887ull,
  9294747158440894399ull, 6430256158855487414ull}},
{{8020281235976331502ull, 15207878512799669821ull,
  2395061911196342190ull, 8037820198569359268ull}},
{{7318518781698901141ull, 4893238052072405734ull,
  10720285731352489677ull, 5023637624105849542ull}},
{{18371520513978402234ull, 10728233583517895071ull,
  4176985127335836288ull, 6279547030132311928ull}},
{{18352714624045614888ull, 13410291979397368839ull,
  5221231409169795360ull, 7849433787665389910ull}},
{{18387975667669591161ull, 8381432487123355524ull,
  17098327686013285812ull, 4905896117290868693ull}},
{{4538225510877437336ull, 10476790608904194406ull,
  7537851552234443553ull, 6132370146613585867ull}},
{{14896153925451572478ull, 17707674279557630911ull,
  4810628421865666537ull, 7665462683266982334ull}},
{{16227625231048314655ull, 4149767397082437463ull,
  16841700818948205298ull, 4790914177041863958ull}},
{{15672845520383005414ull, 14410581283207822637ull,
  11828753986830480814ull, 5988642721302329948ull}},
{{5755998845196593056ull, 8789854567155002489ull,
  14785942483538101018ull, 7485803401627912435ull}},
{{15126714324316340420ull, 10105345122899264459ull,
  6935371042997619184ull, 4678627126017445272ull}},
{{14296706886968037621ull, 12631681403624080574ull,
  8669213803747023980ull, 5848283907521806590ull}},
{{8647511571855271218ull, 15789601754530100718ull,
  1613145217829004167ull, 7310354884402258238ull}},
{{1586017427964313214ull, 15125316174735237994ull,
  11239803559141031017ull, 9137943605502822797ull}},
{{5602946910905083663ull, 2535793581568441890ull,
  9330720233676838338ull, 5711214753439264248ull}},
{{16227055675486130387ull, 12393114013815328170ull,
  11663400292096047922ull, 7139018441799080310ull}},
{{11060447557502887175ull, 6268020480414384405ull,
  5355878328265284095ull, 8923773052248850388ull}},
{{9218622732652998437ull, 10835041827900072109ull,
  12570795992020578367ull, 5577358157655531492ull}},
{{16134964434243635950ull, 8932116266447702232ull,
  15713494990025722959ull, 6971697697069414365ull}},
{{1721961469094993321ull, 6553459314632239887ull,
  5806810682249989987ull, 8714622121336767957ull}},
{{7993754945825452682ull, 1790069062431455977ull,
  5935099685619937694ull, 5446638825835479973ull}},
{{14603879700709203756ull, 11460958364894095779ull,
  12030560625452310021ull, 6808298532294349966ull}},
{{13643163607459116791ull, 491139900835456012ull,
  5814828744960611719ull, 8510373165367937458ull}},
{{17750349291516723803ull, 7224491465663241863ull,
  8245953984027770228ull, 5318983228354960911ull}},
{{17576250595968516849ull, 9030614332079052329ull,
  5695756461607324881ull, 6648729035443701139ull}},
{{8135255189678482349ull, 15899953933526203316ull,
  2508009558581768197ull, 8310911294304626424ull}},
{{14307906530403827277ull, 12243314217667571024ull,
  1567505974113605123ull, 5194319558940391515ull}},
{{17884883163004784096ull, 10692456753657075876ull,
  15794440522924170116ull, 6492899448675489393ull}},
{{3909359880046428503ull, 13365570942071344846ull,
  5907992598373048933ull, 8116124310844361742ull}},
{{16278407980311181527ull, 10659324848008284480ull,
  17527553429265319295ull, 5072577694277726088ull}},
{{1901265901679425292ull, 8712470041582967697ull,
  3462697712872097503ull, 6340722117847157611ull}},
{{6988268395526669519ull, 6278901533551321717ull,
  18163430196372285591ull, 7925902647308947013ull}},
{{6673510756417862402ull, 10841842486110657929ull,
  13657986881946372446ull, 4953689154568091883ull}},
{{12953574463949715906ull, 4328931070783546603ull,
  12460797584005577654ull, 6192111443210114854ull}},
{{11580282061509756978ull, 14634535875334209062ull,
  6352624943152196259ull, 7740139304012643568ull}},
{{2625990270016210208ull, 6840741912870186712ull,
  3970390589470122662ull, 4837587065007902230ull}},
{{3282487837520262760ull, 17774299427942509198ull,
  14186360273692429135ull, 6046983831259877787ull}},
{{13326481833755104257ull, 17606188266500748593ull,
  13121264323688148515ull, 7558729789074847234ull}},
{{1411522118455858305ull, 8698024657349273919ull,
  12812476220732480726ull, 4724206118171779521ull}},
{{15599460703351986593ull, 1649158784831816590ull,
  2180537220633437196ull, 5905257647714724402ull}},
{{10275953842335207433ull, 2061448481039770738ull,
  11949043562646572303ull, 7381572059643405502ull}},
{{11034157169886892550ull, 8205934328290938567ull,
  2856466208226719785ull, 4613482537277128439ull}},
{{9181010443931227783ull, 14869103928791061113ull,
  17405640815565563443ull, 5766853171596410548ull}},
{{16087949073341422633ull, 13974693892561438487ull,
  3310306945747402688ull, 7208566464495513186ull}},
{{15498250323249390387ull, 17468367365701798109ull,
  13361255719039029168ull, 9010708080619391482ull}},
{{11992249461244562944ull, 10917729603563623818ull,
  12962470842826781134ull, 5631692550387119676ull}},
{{5766939789700927872ull, 4423789967599753965ull,
  16203088553533476418ull, 7039615687983899595ull}},
{{11820360755553547744ull, 14753109496354468264ull,
  15642174673489457618ull, 8799519609979874494ull}},
{{7387725472220967340ull, 13832379453648930569ull,
  5164673152503523107ull, 5499699756237421559ull}},
{{13846342858703597079ull, 12678788298633775307ull,
  1844155422202015980ull, 6874624695296776949ull}},
{{12696242554952108445ull, 15848485373292219134ull,
  6916880296179907879ull, 8593280869120971186ull}},
{{3323465578417679874ull, 16822832385948718815ull,
  8934736203539830328ull, 5370800543200606991ull}},
{{17989390028304263555ull, 2581796408726346902ull,
  6556734235997400007ull, 6713500679000758739ull}},
{{13263365498525553635ull, 17062303566190097340ull,
  3584231776569362104ull, 8391875848750948424ull}},
{{17512975473433246830ull, 10663939728868810837ull,
  2240144860355851315ull, 5244922405469342765ull}},
{{8056161286509394826ull, 8718238642658625643ull,
  7411867093872202048ull, 6556153006836678456ull}},
{{5458515589709355628ull, 10897798303323282054ull,
  9264833867340252560ull, 8195191258545848070ull}},
{{17246630298850510980ull, 6811123939577051283ull,
  1178835148660269946ull, 5121994536591155044ull}},
{{16946601855135750820ull, 17737276961326089912ull,
  1473543935825337432ull, 6402493170738943805ull}},
{{2736508245210136909ull, 3724852127948060775ull,
  6453615938209059695ull, 8003116463423679756ull}},
{{8627846680897417424ull, 9245561607608619840ull,
  13256881998235438117ull, 5001947789639799847ull}},
{{10784808351121771780ull, 16168638027938162704ull,
  11959416479366909742ull, 6252434737049749809ull}},
{{13481010438902214725ull, 10987425498067927572ull,
  1114212543926473466ull, 7815543421312187262ull}},
{{17649003561168660012ull, 11478826954719842636ull,
  14531440895236209628ull, 4884714638320117038ull}},
{{3614510377751273398ull, 14348533693399803296ull,
  8940929082190486227ull, 6105893297900146298ull}},
{{4518137972189091748ull, 13323981098322366216ull,
  1952789315883331976ull, 7632366622375182873ull}},
{{2823836232618182343ull, 8327488186451478885ull,
  12749708368495552245ull, 4770229138984489295ull}},
{{8141481309200115832ull, 15021046251491736510ull,
  11325449442192052402ull, 5962786423730611619ull}},
{{953479599645368982ull, 9552935777509894830ull, 9545125784312677599ull,
  7453483029663264524ull}},
{{14430982805060519326ull, 12888113888584766124ull,
  15189075652050199307ull, 4658426893539540327ull}},
{{18038728506325649157ull, 11498456342303569751ull,
  14374658546635361230ull, 5823033616924425409ull}},
{{17936724614479673543ull, 5149698391024686381ull,
  4133265128012037826ull, 7278792021155531762ull}},
{{8585847712817428216ull, 15660495025635633785ull,
  14389953446869823090ull, 9098490026444414702ull}},
{{16895369866579362395ull, 14399495409449659019ull,
  4382034885866251527ull, 5686556266527759189ull}},
{{16507526314796815090ull, 13387683243384685870ull,
  10089229625760202313ull, 7108195333159698986ull}},
{{11411035856641243054ull, 2899545998948693626ull,
  3388164995345477084ull, 8885244166449623733ull}},
{{11743583428828164813ull, 11035588286197709324ull,
  4423446131304617129ull, 5553277604031014833ull}},
{{14679479286035206016ull, 18406171376174524559ull,
  10140993682558159315ull, 6941597005038768541ull}},
{{13737663089116619616ull, 18396028201790767795ull,
  17287928121625087048ull, 8676996256298460676ull}},
{{6280196421484193308ull, 11497517626119229872ull,
  1581583039160903597ull, 5423122660186537923ull}},
{{7850245526855241635ull, 536838977366873628ull,
  15812036854233293209ull, 6778903325233172403ull}},
{{9812806908569052044ull, 5282734740135979939ull,
  15153360049364228607ull, 8473629156541465504ull}},
{{3827161308641963576ull, 10219238240226069318ull,
  9470850030852642879ull, 5296018222838415940ull}},
{{14007323672657230277ull, 8162361781855198743ull,
  11838562538565803599ull, 6620022778548019925ull}},
{{12897468572394149943ull, 5591266208891610525ull,
  963145117925090787ull, 8275028473185024907ull}},
{{10366760866960037666ull, 1188698371343562626ull,
  16742866763199039406ull, 5171892795740640566ull}},
{{3735079046845271275ull, 10709245001034229091ull,
  11705211417144023449ull, 6464865994675800708ull}},
{{57162790129201189ull, 17998242269720174268ull,
  14631514271430029311ull, 8081082493344750885ull}},
{{9259098780685526552ull, 18166430446216190773ull,
  11450539428857462271ull, 5050676558340469303ull}},
{{16185559494284296093ull, 18096352039342850562ull,
  9701488267644439935ull, 6313345697925586629ull}},
{{11008577331000594309ull, 18008754030751175299ull,
  16738546352982937823ull, 7891682122406983286ull}},
{{4574517822661677491ull, 18173000296860566418ull,
  5849905452186948235ull, 4932301326504364554ull}},
{{14941519315181872672ull, 18104564352648320118ull,
  16535753852088461102ull, 6165376658130455692ull}},
{{9453527107122565031ull, 13407333403955624340ull,
  2222948241401024762ull, 7706720822663069616ull}},
{{15131826478806378953ull, 12991269395899653116ull,
  1389342650875640476ull, 4816700514164418510ull}},
{{468039024798422075ull, 16239086744874566396ull,
  10960050350449326403ull, 6020875642705523137ull}},
{{585048780998027594ull, 15687172412665820091ull,
  18311748956489045908ull, 7526094553381903921ull}},
{{16506556552619624910ull, 581110721061361748ull,
  4527314070164571837ull, 4703809095863689951ull}},
{{2186451617064979522ull, 5338074419754090090ull,
  1047456569278326892ull, 5879761369829612439ull}},
{{11956436558186000210ull, 6672593024692612612ull,
  15144378766880072327ull, 7349701712287015548ull}},
{{14945545697732500262ull, 3729055262438377861ull,
  483729384890538793ull, 9187127140358769436ull}},
{{11646809070296506616ull, 13859874585092455923ull,
  9525702902411362553ull, 5741954462724230897ull}},
{{9946825319443245366ull, 3489785176083406192ull,
  16518814646441591096ull, 7177443078405288621ull}},
{{12433531649304056707ull, 4362231470104257740ull,
  6813460252769825158ull, 8971803848006610777ull}},
{{16994329317669811250ull, 16561452724097324799ull,
  15787627704049610483ull, 5607377405004131735ull}},
{{16631225628659876159ull, 16090129886694268095ull,
  15122848611634625200ull, 7009221756255164669ull}},
{{16177346017397457294ull, 1665918284658283503ull,
  5068502709261117789ull, 8761527195318955837ull}},
{{17028370288514492665ull, 3347041937125121141ull,
  5473657202501892570ull, 5475954497074347398ull}},
{{7450404805360952119ull, 13407174458261177235ull,
  16065443539982141520ull, 6844943121342934247ull}},
{{4701319988273802245ull, 16758968072826471544ull,
  15470118406550288996ull, 8556178901678667809ull}},
{{2938324992671126403ull, 1250983008661768907ull,
  2751294976452848767ull, 5347611813549167381ull}},
{{17507964296121071716ull, 15398786816109374845ull,
  8050804738993448862ull, 6684514766936459226ull}},
{{8049897314869175933ull, 10025111483281942749ull,
  840133886887035270ull, 8355643458670574033ull}},
{{7337028831006928910ull, 1654008658623826314ull,
  12054298725372866804ull, 5222277161669108770ull}},
{{18394658075613436946ull, 2067510823279782892ull,
  5844501369861307697ull, 6527846452086385963ull}},
{{4546578520807244566ull, 7196074547527116520ull,
  2693940693899246717ull, 8159808065107982454ull}},
{{2841611575504527854ull, 6803389601418141777ull,
  15518770988969192910ull, 5099880040692489033ull}},
{{8163700487808047721ull, 17727609038627453029ull,
  5563405680929327425ull, 6374850050865611292ull}},
{{14816311628187447555ull, 8324453243002152574ull,
  6954257101161659282ull, 7968562563582014115ull}},
{{4648508749189766818ull, 9814469295303733263ull,
  2040567679012343099ull, 4980351602238758822ull}},
{{1198949918059820619ull, 7656400600702278675ull,
  11774081635620204682ull, 6225439502798448527ull}},
{{15333745452856939485ull, 347128714023072535ull,
  10105916026097867949ull, 7781799378498060659ull}},
{{16501119935676669034ull, 2522798455478114286ull,
  4010354507097473516ull, 4863624611561287912ull}},
{{11403027882741060485ull, 3153498069347642858ull,
  5012943133871841895ull, 6079530764451609890ull}},
{{5030412816571549798ull, 17776930641966717285ull,
  15489550954194578176ull, 7599413455564512362ull}},
{{5449851019570912576ull, 11110581651229198303ull,
  14292655364798999264ull, 4749633409727820226ull}},
{{2200627756036252816ull, 13888227064036497879ull,
  8642447169143973272ull, 5937041762159775283ull}},
{{16585842750327479732ull, 17360283830045622348ull,
  6191372943002578686ull, 7421302202699719104ull}},
{{1142779682099899025ull, 6238491375351126064ull,
  3869608089376611679ull, 4638313876687324440ull}},
{{1428474602624873781ull, 3186428200761519676ull,
  4837010111720764599ull, 5797892345859155550ull}},
{{1785593253281092226ull, 17818093306234063307ull,
  15269634676505731556ull, 7247365432323944437ull}},
{{16067049621883528994ull, 3825872559083027517ull,
  5251985290350000734ull, 9059206790404930547ull}},
{{12347749022890899573ull, 16226228404709055910ull,
  976647797255056506ull, 5662004244003081592ull}},
{{6211314241758848658ull, 11059413469031544080ull,
  1220809746568820633ull, 7077505305003851990ull}},
{{7764142802198560823ull, 18435952854716818004ull,
  10749384220065801599ull, 8846881631254814987ull}},
{{14075961288228876323ull, 18439999561839093108ull,
  4412522128327432047ull, 5529301019534259367ull}},
{{17594951610286095403ull, 18438313433871478481ull,
  903966641981902155ull, 6911626274417824209ull}},
{{8158631457575455542ull, 18436205773911960198ull,
  5741644320904765598ull, 8639532843022280261ull}},
{{487458642557271810ull, 6910942590267587220ull, 5894370709779172451ull,
  5399708026888925163ull}},
{{609323303196589762ull, 4026992219407096121ull, 2756277368796577660ull,
  6749635033611156454ull}},
{{5373340147423125106ull, 5033740274258870151ull,
  12668718747850497883ull, 8437043792013945567ull}},
{{10275866619780535048ull, 840244662198099892ull,
  14835478245047643033ull, 5273152370008715979ull}},
{{12844833274725668810ull, 5661991846175012769ull,
  13932661787882165887ull, 6591440462510894974ull}},
{{2220983538124922300ull, 2465803789291378058ull,
  8192455197997931551ull, 8239300578138618718ull}},
{{5999800729755464342ull, 8458656395948193142ull, 508598480321319315ull,
  5149562861336636699ull}},
{{16723122949049106235ull, 5961634476507853523ull,
  14470806155683812856ull, 6436953576670795873ull}},
{{16292217667883994889ull, 7452043095634816904ull,
  4253449639322602358ull, 8046191970838494842ull}},
{{10182636042427496806ull, 45840916344372661ull, 7270092043004014378ull,
  5028869981774059276ull}},
{{17339981071461758911ull, 9280673182285241634ull,
  9087615053755017972ull, 6286087477217574095ull}},
{{12451604302472422831ull, 11600841477856552043ull,
  6747832798766384561ull, 7857609346521967619ull}},
{{5476409679831570318ull, 332996896019263171ull, 1911552490015296399ull,
  4911005841576229762ull}},
{{2233826081362074993ull, 14251304175306242676ull,
  11612812649373896306ull, 6138757301970287202ull}},
{{2792282601702593741ull, 8590758182278027537ull,
  5292643774862594575ull, 7673446627462859003ull}},
{{13274391672132590848ull, 12286752891564849066ull,
  1002059350075427657ull, 4795904142164286877ull}},
{{7369617553310962752ull, 1523383059173897621ull,
  5864260206021672476ull, 5994880177705358596ull}},
{{13823707960066091344ull, 1904228823967372026ull,
  7330325257527090595ull, 7493600222131698245ull}},
{{13251503493468694994ull, 17331044079475465180ull,
  6887296295168125573ull, 4683500138832311403ull}},
{{16564379366835868743ull, 7828747044062167763ull,
  3997434350532769063ull, 5854375173540389254ull}},
{{16093788190117448024ull, 5174247786650321800ull,
  14220164975020737137ull, 7317968966925486567ull}},
{{1670491163937258414ull, 11079495751740290155ull,
  13163520200348533517ull, 9147461208656858209ull}},
{{17184958041956644173ull, 9230527854051375298ull,
  1309671097576751592ull, 5717163255410536381ull}},
{{12257825515591029408ull, 11538159817564219123ull,
  6248774890398327394ull, 7146454069263170476ull}},
{{10710595876061398856ull, 5199327735100498096ull,
  7810968612997909243ull, 8933067586578963095ull}},
{{6694122422538374285ull, 943736825224117358ull,
  11799384410764775133ull, 5583167241611851934ull}},
{{17591025065027743665ull, 5791357049957534601ull,
  5525858476601193108ull, 6978959052014814918ull}},
{{8153723276002515869ull, 7239196312446918252ull,
  16130695132606267193ull, 8723698815018518647ull}},
{{14319449084356348226ull, 16053712741347793667ull,
  16999213485519998851ull, 5452311759386574154ull}},
{{13287625337018047378ull, 15455454908257354180ull,
  12025644820045222756ull, 6815389699233217693ull}},
{{16609531671272559223ull, 872574561612141109ull,
  1196997969774364734ull, 8519237124041522117ull}},
{{12686800303759043467ull, 14380417156289751905ull,
  3053966740322671910ull, 5324523202525951323ull}},
{{2023442324416640621ull, 8752149408507414074ull,
  17652516480685503600ull, 6655654003157439153ull}},
{{11752674942375576584ull, 10940186760634267592ull,
  8230587545574715788ull, 8319567503946798942ull}},
{{7345421838984735365ull, 16060988762251193053ull,
  532431197556809463ull, 5199729689966749339ull}},
{{13793463317158307111ull, 15464549934386603412ull,
  14500597052228175541ull, 6499662112458436673ull}},
{{17241829146447883888ull, 5495629362701090553ull,
  4290688260003055715ull, 8124577640573045842ull}},
{{3858614188888845574ull, 1128925342474487644ull,
  7293366180929297726ull, 5077861025358153651ull}},
{{4823267736111056968ull, 10634528714947885363ull,
  4505021707734234253ull, 6347326281697692064ull}},
{{1417398651711433305ull, 17904846912112244608ull,
  5631277134667792816ull, 7934157852122115080ull}},
{{885874157319645816ull, 11190529320070152880ull,
  3519548209167370510ull, 4958848657576321925ull}},
{{1107342696649557270ull, 4764789613232915292ull,
  9011121279886601042ull, 6198560821970402406ull}},
{{1384178370811946587ull, 15179359053395919923ull,
  2040529563003475494ull, 7748201027463003008ull}},
{{17006012546253324281ull, 4875413389945062047ull,
  1275330976877172184ull, 4842625642164376880ull}},
{{16645829664389267447ull, 6094266737431327559ull,
  1594163721096465230ull, 6053282052705471100ull}},
{{16195601062059196405ull, 16841205458643935257ull,
  1992704651370581537ull, 7566602565881838875ull}},
{{3204721636145915897ull, 3608224384011377680ull,
  17386341471602471125ull, 4729126603676149296ull}},
{{4005902045182394872ull, 9121966498441610004ull,
  3286182765793537290ull, 5911408254595186621ull}},
{{5007377556477993589ull, 2179086086197236697ull,
  8719414475669309517ull, 7389260318243983276ull}},
{{14658826018867215754ull, 3667771813086966887ull,
  14673006084148094256ull, 4618287698902489547ull}},
{{13711846505156631788ull, 4584714766358708609ull,
  13729571586757729916ull, 5772859623628111934ull}},
{{3304750076163626023ull, 5730893457948385762ull,
  7938592446592386587ull, 7216074529535139918ull}},
{{13354309632059308336ull, 2551930804008094298ull,
  699868521385707426ull, 9020093161918924898ull}},
{{12958129538464455614ull, 6206642770932446840ull,
  5049103844293455045ull, 5637558226199328061ull}},
{{16197661923080569518ull, 12369989482092946454ull,
  10923065823794206710ull, 7046947782749160076ull}},
{{11023705366995936089ull, 6239114815761407260ull,
  13653832279742758388ull, 8808684728436450095ull}},
{{16113187891227235864ull, 13122818796705655345ull,
  15451174202480305848ull, 5505427955272781309ull}},
{{6306426808751881118ull, 16403523495882069182ull,
  5478909697818218598ull, 6881784944090976637ull}},
{{17106405547794627205ull, 11281032332997810669ull,
  11460323140700161152ull, 8602231180113720796ull}},
{{12997346476585335955ull, 7050645208123631668ull,
  16386073999792376528ull, 5376394487571075497ull}},
{{16246683095731669944ull, 8813306510154539585ull,
  6647534444458306948ull, 6720493109463844372ull}},
{{6473295814382423718ull, 11016633137693174482ull,
  8309418055572883685ull, 8400616386829805465ull}},
{{8657495902416402728ull, 9191238720271928003ull,
  16722601330801522063ull, 5250385241768628415ull}},
{{6210183859593115506ull, 6877362381912522100ull,
  16291565645074514675ull, 6562981552210785519ull}},
{{7762729824491394382ull, 3985016958963264721ull,
  15752771037915755440ull, 8203726940263481899ull}},
{{16380921186375591249ull, 2490635599352040450ull,
  7539638889483653198ull, 5127329337664676187ull}},
{{11252779446114713253ull, 12336666536044826371ull,
  4812862593427178593ull, 6409161672080845234ull}},
{{9454288289216003662ull, 1585775114773869252ull,
  15239450278638749050ull, 8011452090101056542ull}},
{{15132302217614778097ull, 5602795465161056186ull,
  4912970405721830252ull, 5007157556313160339ull}},
{{9692005735163696813ull, 7003494331451320233ull,
  1529526988724899911ull, 6258946945391450424ull}},
{{16726693187382008920ull, 4142681895886762387ull,
  1911908735906124889ull, 7823683681739313030ull}},
{{8148340232900061623ull, 14118391230997696252ull,
  15030001015223491767ull, 4889802301087070643ull}},
{{10185425291125077029ull, 13036303020319732411ull,
  14175815250601976805ull, 6112252876358838304ull}},
{{8120095595478958382ull, 2460320720117501802ull,
  17719769063252471007ull, 7640316095448547880ull}},
{{9686745765601736893ull, 8455229477714520482ull,
  11074855664532794379ull, 4775197559655342425ull}},
{{2885060170147395308ull, 5957350828715762699ull, 8511525383829262ull,
  5968996949569178032ull}},
{{17441383267966407847ull, 16670060572749479181ull,
  10639406729786577ull, 7461246186961472540ull}},
{{13206707551692698857ull, 3501258830327342632ull,
  9230021666060892419ull, 4663278866850920337ull}},
{{16508384439615873571ull, 18211631593191342002ull,
  16149213101003503427ull, 5829098583563650421ull}},
{{11412108512665066155ull, 18152853473061789599ull,
  6351458320972215572ull, 7286373229454563027ull}},
{{9653449622403944790ull, 4244322767617685383ull,
  3327636882787881562ull, 9107966536818203784ull}},
{{12950935041643547350ull, 7264387748188441268ull,
  2079773051742425976ull, 5692479085511377365ull}},
{{16188668802054434187ull, 9080484685235551585ull,
  7211402333105420374ull, 7115598856889221706ull}},
{{6400777947285879022ull, 2127233819689663674ull,
  18237624953236551276ull, 8894498571111527132ull}},
{{8612172235481062293ull, 10552893174160815604ull,
  2175143558918068739ull, 5559061606944704458ull}},
{{10765215294351327866ull, 8579430449273631601ull,
  11942301485502361732ull, 6948827008680880572ull}},
{{18068205136366547737ull, 10724288061592039501ull,
  14927876856877952165ull, 8686033760851100715ull}},
{{13598471219442786288ull, 9008523047708718640ull,
  7024080026335026151ull, 5428771100531937947ull}},
{{16998089024303482859ull, 6648967791208510396ull,
  4168414014491394785ull, 6785963875664922434ull}},
{{2800867206669801958ull, 12922895757438025900ull,
  14433889554969019289ull, 8482454844581153042ull}},
{{10973914041023402032ull, 1159280820757684331ull,
  13632866990283024960ull, 5301534277863220651ull}},
{{9105706532851864636ull, 1449101025947105414ull,
  12429397719426393296ull, 6626917847329025814ull}},
{{2158761129210054987ull, 1811376282433881768ull,
  6313375112428215812ull, 8283647309161282268ull}},
{{1349225705756284367ull, 10355482213375951913ull,
  13169231482122410690ull, 5177279568225801417ull}},
{{6298218150622743362ull, 3720980729865164083ull,
  2626481297370849651ull, 6471599460282251772ull}},
{{3261086669851041299ull, 39539893904067200ull, 3283101621713562064ull,
  8089499325352814715ull}},
{{2038179168656900812ull, 24712433690042000ull, 18192839578066833954ull,
  5055937078345509196ull}},
{{2547723960821126015ull, 9254262578967328308ull,
  4294305398873990826ull, 6319921347931886496ull}},
{{3184654951026407518ull, 2344456186854384577ull,
  5367881748592488533ull, 7899901684914858120ull}},
{{13519624390459974459ull, 3771128125997684312ull,
  3354926092870305333ull, 4937438553071786325ull}},
{{16899530488074968074ull, 9325596175924493294ull,
  8805343634515269570ull, 6171798191339732906ull}},
{{11901041073238934284ull, 2433623183050840810ull,
  1783307506289311155ull, 7714747739174666133ull}},
{{12049836689201721832ull, 17661915553902633170ull,
  3420410200644513423ull, 4821717336984166333ull}},
{{5838923824647376482ull, 17465708423950903559ull,
  8887198769233029683ull, 6027146671230207916ull}},
{{2686968762381832698ull, 17220449511511241545ull,
  11108998461541287104ull, 7533933339037759895ull}},
{{13208570522557115196ull, 10762780944694525965ull,
  13860653066104386296ull, 4708708336898599934ull}},
{{2675655097914230283ull, 13453476180868157457ull,
  8102444295775707062ull, 5885885421123249918ull}},
{{7956254890820175758ull, 7593473189230421013ull, 904683332864858020ull,
  7357356776404062398ull}},
{{14557004631952607602ull, 9491841486538026266ull,
  10354226202935848333ull, 9196695970505077997ull}},
{{13709813913397767655ull, 8238243938299960368ull,
  8777234386048599160ull, 5747934981565673748ull}},
{{17137267391747209569ull, 10297804922874950460ull,
  10971542982560748950ull, 7184918726957092185ull}},
{{2974840165974460345ull, 3648884116738912268ull,
  18326114746628324092ull, 8981148408696365231ull}},
{{11082647140588813524ull, 11503924609816595975ull,
  18371350744283784413ull, 5613217755435228269ull}},
{{9241622907308629001ull, 544847706988581257ull, 9129130375072566805ull,
  7016522194294035337ull}},
{{16163714652563174155ull, 5292745652163114475ull,
  16023098987268096410ull, 8770652742867544171ull}},
{{7796478648638289895ull, 7919652051029334451ull,
  7708593857828866304ull, 5481657964292215107ull}},
{{5133912292370474464ull, 9899565063786668064ull,
  5024056303858694976ull, 6852072455365268884ull}},
{{6417390365463093080ull, 12374456329733335080ull,
  6280070379823368720ull, 8565090569206586105ull}},
{{4010868978414433175ull, 7734035206083334425ull,
  15454259033458075210ull, 5353181605754116315ull}},
{{9625272241445429373ull, 444171970749392223ull,
  14706137773395206109ull, 6691477007192645394ull}},
{{7419904283379398812ull, 5166900981864128183ull,
  9159300179889231828ull, 8364346258990806743ull}},
{{11554969204753206114ull, 12452685150519855922ull,
  12642091640071851748ull, 5227716411869254214ull}},
{{5220339469086731834ull, 15565856438149819903ull,
  6579242513235038877ull, 6534645514836567768ull}},
{{1913738317931026889ull, 5622262492405111167ull,
  8224053141543798597ull, 8168306893545709710ull}},
{{8113615476347973662ull, 5819757066966888431ull, 528347195037486219ull,
  5105191808466068569ull}},
{{5530333327007579173ull, 2663010315281222635ull,
  5272120012224245678ull, 6381489760582585711ull}},
{{2301230640332086062ull, 12552134930956304102ull,
  1978463996852919193ull, 7976862200728232139ull}},
{{15273327205489717501ull, 927555304206608207ull,
  17377441062528932160ull, 4985538875455145086ull}},
{{14479972988434758972ull, 1159444130258260259ull,
  12498429291306389392ull, 6231923594318931358ull}},
{{13488280217116060811ull, 1449305162822825324ull,
  6399664577278210932ull, 7789904492898664198ull}},
{{17653547172552313815ull, 10129187763619041635ull,
  17834848416081045544ull, 4868690308061665123ull}},
{{17455247947263004365ull, 12661484704523802044ull,
  17681874501673919026ull, 6085862885077081404ull}},
{{3372315860369203840ull, 6603483843799976748ull,
  3655599053382847167ull, 7607328606346351756ull}},
{{11331069449585528208ull, 11044706430016067323ull,
  11508121445219055287ull, 4754580378966469847ull}},
{{9552150793554522356ull, 9194197019092696250ull,
  9773465788096431205ull, 5943225473708087309ull}},
{{2716816455088377137ull, 16104432292293258217ull,
  16828518253547926910ull, 7429031842135109136ull}},
{{13227225330498705471ull, 5453584164255898481ull,
  10517823908467454319ull, 4643144901334443210ull}},
{{2698973607841218126ull, 2205294186892485198ull,
  3923907848729542091ull, 5803931126668054013ull}},
{{12597089046656298466ull, 16591675788897770209ull,
  9516570829339315517ull, 7254913908335067516ull}},
{{1911303253038209370ull, 6904536680840049050ull,
  11895713536674144397ull, 9068642385418834395ull}},
{{5806250551576268760ull, 6621178434738724608ull,
  5128977951207646296ull, 5667901490886771497ull}},
{{7257813189470335950ull, 8276473043423405760ull,
  11022908457436945774ull, 7084876863608464371ull}},
{{9072266486837919938ull, 1122219267424481392ull,
  9166949553368794314ull, 8856096079510580464ull}},
{{5670166554273699961ull, 5313073060567688774ull,
  5729343470855496446ull, 5535060049694112790ull}},
{{16311080229696900759ull, 15864713362564386775ull,
  16385051375424146365ull, 6918825062117640987ull}},
{{15777164268693738045ull, 5995833647923319757ull,
  15869628200852795053ull, 8648531327647051234ull}},
{{12166570677147280230ull, 6053239039165768800ull,
  14530203643960384812ull, 5405332079779407021ull}},
{{15208213346434100288ull, 7566548798957211000ull,
  4327696499668317303ull, 6756665099724258777ull}},
{{563522609333073744ull, 4846499980269125847ull,
  10021306643012784533ull, 8445831374655323471ull}},
{{7269730658474252946ull, 5334905496881897606ull,
  13180845679524072189ull, 5278644609159577169ull}},
{{18310535359947591990ull, 11280317889529759911ull,
  2640999044122926524ull, 6598305761449471462ull}},
{{18276483181507102084ull, 14100397361912199889ull,
  12524620842008433963ull, 8247882201811839327ull}},
{{4505272960800856947ull, 6506905341981430979ull,
  14745417053896353083ull, 5154926376132399579ull}},
{{1019905182573683279ull, 3521945659049400820ull,
  13820085298943053450ull, 6443657970165499474ull}},
{{1274881478217104099ull, 13625804110666526833ull,
  8051734586824041004ull, 8054572462706874343ull}},
{{12326015969954159822ull, 17739499606021355078ull,
  11949863144406107483ull, 5034107789191796464ull}},
{{6184147925587923969ull, 17562688489099305944ull,
  14937328930507634354ull, 6292634736489745580ull}},
{{7730184906984904961ull, 12729988574519356622ull,
  224917089424991327ull, 7865793420612181976ull}},
{{219679548438177697ull, 14873771886715679745ull, 140573180890619579ull,
  4916120887882613735ull}},
{{4886285453975110025ull, 13980528839967211777ull,
  14010774531395438186ull, 6145151109853267168ull}},
{{10719542835896275435ull, 8252289013104238913ull,
  17513468164244297733ull, 7681438887316583960ull}},
{{18228929318503641907ull, 7463523642403843272ull,
  10945917602652686083ull, 4800899304572864975ull}},
{{4339417574420000768ull, 4717718534577416187ull,
  9070710984888469700ull, 6001124130716081219ull}},
{{812585949597613056ull, 5897148168221770234ull, 6726702712683199221ull,
  7501405163395101524ull}},
{{5119552236925896064ull, 5991560614352300348ull,
  13427561232281775321ull, 4688378227121938452ull}},
{{6399440296157370080ull, 12101136786367763339ull,
  16784451540352219151ull, 5860472783902423065ull}},
{{3387614351769324696ull, 10514734964532316270ull,
  7145506370158110227ull, 7325590979878028832ull}},
{{13457889976566431678ull, 8531732687238007433ull,
  8931882962697637784ull, 9156988724847536040ull}},
{{1493652207712937943ull, 5332332929523754646ull,
  5582426851686023615ull, 5723117953029710025ull}},
{{11090437296495948236ull, 2053730143477305403ull,
  11589719583034917423ull, 7153897441287137531ull}},
{{9251360602192547391ull, 16402220734628795466ull,
  9875463460366258874ull, 8942371801608921914ull}},
{{10393786394797730024ull, 14863073977570385070ull,
  10783850681156299700ull, 5588982376005576196ull}},
{{3768860956642386722ull, 132098398253429722ull,
  13479813351445374626ull, 6986227970006970245ull}},
{{13934448232657759210ull, 9388495034671562960ull,
  3014708634024554570ull, 8732784962508712807ull}},
{{8709030145411099506ull, 10479495415097114754ull,
  8801721923906428462ull, 5457990601567945504ull}},
{{1662915644909098575ull, 3875997232016617635ull,
  11002152404883035578ull, 6822488251959931880ull}},
{{15913702611418536930ull, 14068368576875547851ull,
  13752690506103794472ull, 8528110314949914850ull}},
{{7640221122922891630ull, 8792730360547217407ull,
  13207117584742259449ull, 5330068946843696781ull}},
{{4938590385226226633ull, 15602598969111409663ull,
  2673838925645660599ull, 6662586183554620977ull}},
{{1561551963105395387ull, 14891562692961874175ull,
  7953984675484463653ull, 8328232729443276221ull}},
{{7893499004581953973ull, 11613069692314865311ull,
  7277083431391483735ull, 5205145455902047638ull}},
{{5255187737300054562ull, 9904651096966193735ull,
  18319726326094130477ull, 6506431819877559547ull}},
{{1957298653197680299ull, 16992499889635130073ull,
  18287971889190275192ull, 8133039774846949434ull}},
{{12752526704317019947ull, 10620312431021956295ull,
  16041668449171309899ull, 5083149859279343396ull}},
{{11328972361968887030ull, 8663704520350057465ull,
  1605341487754585758ull, 6353937324099179246ull}},
{{326157397178945075ull, 1606258613582796024ull,
  11230048896548008006ull, 7942421655123974057ull}},
{{203848373236840672ull, 14838969688771411227ull, 101251532701423147ull,
  4964013534452483786ull}},
{{14089868521828214552ull, 13937026092536876129ull,
  9349936452731554742ull, 6205016918065604732ull}},
{{3777277597003104478ull, 8197910578816319354ull,
  11687420565914443428ull, 7756271147582005915ull}},
{{6972484516554328203ull, 14347066148614975404ull,
  4998794844482833190ull, 4847669467238753697ull}},
{{8715605645692910253ull, 8710460648913943447ull,
  10860179574030929392ull, 6059586834048442121ull}},
{{6282821038688749912ull, 10888075811142429309ull,
  18186910485966049644ull, 7574483542560552651ull}},
{{6232606158394162647ull, 16028419418818794126ull,
  9060976044515087075ull, 4734052214100345407ull}},
{{17014129734847479117ull, 15423838255096104753ull,
  6714534037216470940ull, 5917565267625431759ull}},
{{7432604113277185184ull, 833053745160579326ull, 3781481528093200772ull,
  7396956584531789699ull}},
{{33691552370852836ull, 9744030627580137887ull, 57582945844556530ull,
  4623097865332368562ull}},
{{13877172495745729757ull, 2956666247620396550ull,
  9295350719160471471ull, 5778872331665460702ull}},
{{8123093582827386389ull, 17530890864807659400ull,
  2395816362095813530ull, 7223590414581825878ull}},
{{10153866978534232986ull, 12690241544154798442ull,
  12218142489474542721ull, 9029488018227282347ull}},
{{10957852880011283520ull, 1013871937455667170ull,
  5330496046707895249ull, 5643430011392051467ull}},
{{4473944063159328592ull, 5879025940246971867ull,
  2051434039957481157ull, 7054287514240064334ull}},
{{980744060521772836ull, 11960468443736102738ull,
  11787664586801627254ull, 8817859392800080417ull}},
{{5224651056253495927ull, 2863606758907676307ull, 449761339109935178ull,
  5511162120500050261ull}},
{{1919127801889482004ull, 12802880485489371192ull,
  5173887692314806876ull, 6888952650625062826ull}},
{{2398909752361852505ull, 16003600606861713990ull,
  15690731652248284403ull, 8611190813281328532ull}},
{{15334376650508321528ull, 7696407370074877291ull,
  583335245800401944ull, 5381994258300830333ull}},
{{14556284794708014006ull, 9620509212593596614ull,
  5340855075677890334ull, 6727492822876037916ull}},
{{8971983956530241699ull, 2802264478887219960ull,
  6676068844597362918ull, 8409366028595047395ull}},
{{5607489972831401062ull, 15586473354586676187ull,
  1866700018659657871ull, 5255853767871904622ull}},
{{2397676447611863424ull, 14871405674805957330ull,
  11556747060179348147ull, 6569817209839880777ull}},
{{12220467596369605087ull, 13977571075080058758ull,
  610875769942021472ull, 8212271512299850972ull}},
{{3026106229303615276ull, 8735981921925036724ull,
  9605169393068539228ull, 5132669695187406857ull}},
{{3782632786629519095ull, 10919977402406295905ull,
  16618147759763061939ull, 6415837118984258571ull}},
{{9339977001714286772ull, 9038285734580481977ull,
  16160998681276439520ull, 8019796398730323214ull}},
{{17366700672139898993ull, 5648928584112801235ull,
  5488938157370386796ull, 5012372749206452009ull}},
{{17096689821747485837ull, 7061160730141001544ull,
  11472858715140371399ull, 6265465936508065011ull}},
{{2924118203474805680ull, 4214764894248864027ull,
  9729387375498076345ull, 7831832420635081264ull}},
{{17968474941667611214ull, 14163443104974009776ull,
  6080867109686297715ull, 4894895262896925790ull}},
{{4013849603374962402ull, 13092617862790124317ull,
  16824455923962647952ull, 6118619078621157237ull}},
{{9628998022646090906ull, 16365772328487655396ull,
  7195511849671146228ull, 7648273848276446547ull}},
{{15241495801008582624ull, 1005235668450008814ull,
  2191351896830772441ull, 4780171155172779092ull}},
{{9828497714405952472ull, 5868230603989898922ull,
  2739189871038465551ull, 5975213943965973865ull}},
{{3062250106152664782ull, 2723602236559985749ull,
  8035673357225469843ull, 7469017429957467331ull}},
{{4219749325559109441ull, 17843152462345848757ull,
  2716452839052224699ull, 4668135893723417082ull}},
{{9886372675376274705ull, 17692254559504923042ull,
  12618938085670056682ull, 5835169867154271352ull}},
{{3134593807365567573ull, 12891946162526377995ull,
  15773672607087570853ull, 7293962333942839190ull}},
{{17753300314489123179ull, 2279874647875808781ull,
  10493718722004687759ull, 9117452917428548988ull}},
{{13401655705769395939ull, 8342450682563462344ull,
  15781946238107705657ull, 5698408073392843117ull}},
{{16752069632211744923ull, 15039749371631715834ull,
  5892374742352468359ull, 7123010091741053897ull}},
{{11716715003409905346ull, 14188000696112256889ull,
  11977154446367973353ull, 8903762614676317371ull}},
{{405417849490108986ull, 1949971407429078700ull, 5179878519766289394ull,
  5564851634172698357ull}},
{{506772311862636232ull, 11660836296141124183ull,
  11086534168135249646ull, 6956064542715872946ull}},
{{14468523445110459002ull, 5352673333321629420ull,
  4634795673314286250ull, 8695080678394841183ull}},
{{18266199190048812684ull, 7957106851753406291ull,
  9814276323462510762ull, 5434425423996775739ull}},
{{18221062969133627951ull, 723011527836982056ull,
  7656159385900750549ull, 6793031779995969674ull}},
{{4329584637707483323ull, 5515450428223615475ull, 346827195521162378ull,
  8491289724994962093ull}},
{{400147389353483125ull, 8058842536067147576ull, 2522610006414420438ull,
  5307056078121851308ull}},
{{500184236691853906ull, 850181133229158662ull, 3153262508018025548ull,
  6633820097652314135ull}},
{{9848602332719593190ull, 1062726416536448327ull,
  17776636190304695647ull, 8292275122065392668ull}},
{{13072905485590827600ull, 7581733037976362060ull,
  1887025582085658971ull, 5182671951290870418ull}},
{{16341131856988534500ull, 4865480279043064671ull,
  11582154014461849522ull, 6478339939113588022ull}},
{{15814728802808280221ull, 15305222385658606647ull,
  5254320481222536094ull, 8097924923891985028ull}},
{{16801734529396256994ull, 4954077972609241250ull,
  12507322337618860867ull, 5061203077432490642ull}},
{{11778796124890545435ull, 1580911447334163659ull,
  6410780885168800276ull, 6326503846790613303ull}},
{{10111809137685793889ull, 1976139309167704574ull,
  3401790088033612441ull, 7908129808488266629ull}},
{{1708194692626233277ull, 12764302114298285119ull,
  4431961814234701727ull, 4942581130305166643ull}},
{{15970301421064955308ull, 11343691624445468494ull,
  928266249365989255ull, 6178226412881458304ull}},
{{10739504739476418327ull, 9567928512129447714ull,
  1160332811707486569ull, 7722783016101822880ull}},
{{11323876480600149359ull, 17509170366149374581ull,
  725208007317179105ull, 4826739385063639300ull}},
{{319787545468022986ull, 8051404902404554515ull, 906510009146473882ull,
  6033424231329549125ull}},
{{14234792487117192445ull, 840884091150917335ull,
  5744823529860480257ull, 7541780289161936406ull}},
{{15814274332089327134ull, 12054767603037793094ull,
  17425572761444963872ull, 4713612680726210253ull}},
{{10544470878256883109ull, 15068459503797241368ull,
  7946907896524041128ull, 5892015850907762817ull}},
{{13180588597821103887ull, 388830306037000094ull,
  14545320889082439315ull, 7365019813634703521ull}},
{{7252363710421604050ull, 14321095937828413830ull,
  4346593056070885431ull, 9206274767043379402ull}},
{{18367785374295666244ull, 15868213988783840499ull,
  7328306678471691298ull, 5753921729402112126ull}},
{{18348045699442194900ull, 10611895449125024816ull,
  18383755384944389931ull, 7192402161752640157ull}},
{{4488313050593192009ull, 8653183292978893117ull,
  9144636175898323702ull, 8990502702190800197ull}},
{{5111038665834438958ull, 796553539684420294ull, 8021240619150146266ull,
  5619064188869250123ull}},
{{15612170369147824505ull, 10219063961460301175ull,
  5414864755510294928ull, 7023830236086562654ull}},
{{14903526943007392728ull, 12773829951825376469ull,
  15991952981242644468ull, 8779787795108203317ull}},
{{11620547348593314407ull, 17207015756745636101ull,
  12300813622490346744ull, 5487367371942627073ull}},
{{690626130459479296ull, 3062025622222493511ull, 1540958972830769719ull,
  6859209214928283842ull}},
{{14698340718356512832ull, 17662590083060280600ull,
  11149570752893237956ull, 8574011518660354802ull}},
{{9186462948972820520ull, 1815746765057899567ull,
  11580167738985661627ull, 5358757199162721751ull}},
{{6871392667788637746ull, 16104741511604538171ull,
  9863523655304689129ull, 6698446498953402189ull}},
{{3977554816308409279ull, 6295868834223509002ull,
  16941090587558249316ull, 8373058123691752736ull}},
{{7097657778620143704ull, 13158290058244468934ull,
  10588181617223905822ull, 5233161327307345460ull}},
{{18095444260129955437ull, 7224490535950810359ull,
  13235227021529882278ull, 6541451659134181825ull}},
{{18007619306735056393ull, 18253985206793288757ull,
  2708975721630189135ull, 8176814573917727282ull}},
{{13560605075923104198ull, 18326269781886887329ull,
  6304795844446256113ull, 5110509108698579551ull}},
{{3115698289621716535ull, 9072779172076445450ull,
  3269308787130432238ull, 6388136385873224439ull}},
{{13117994898881921476ull, 2117601928240781004ull,
  17921694039195204010ull, 7985170482341530548ull}},
{{17422118848655976731ull, 5935187223577876031ull,
  1977686737642226698ull, 4990731551463456593ull}},
{{17165962542392583010ull, 16642356066327120847ull,
  7083794440480171276ull, 6238414439329320741ull}},
{{16845767159563340858ull, 2356201009199349443ull,
  13466429069027602000ull, 7798018049161650926ull}},
{{8222761465513394084ull, 1472625630749593402ull,
  3804832149714863346ull, 4873761280726031829ull}},
{{1055079795036966797ull, 11064154075291767561ull,
  9367726205570967086ull, 6092201600907539786ull}},
{{5930535762223596400ull, 4606820557259933643ull,
  2486285720108933050ull, 7615252001134424733ull}},
{{1400741842176053798ull, 7490948866714846431ull,
  3859771584281777108ull, 4759532500709015458ull}},
{{15585985358002230960ull, 9363686083393558038ull,
  14048086517206997193ull, 5949415625886269322ull}},
{{10259109660648012892ull, 16316293622669335452ull,
  8336736109653970683ull, 7436769532357836653ull}},
{{15635315574759783866ull, 7891840504954640705ull,
  7516303077747425629ull, 4647980957723647908ull}},
{{5709086413167566120ull, 14476486649620688786ull,
  9395378847184282036ull, 5809976197154559885ull}},
{{16359730053314233458ull, 18095608312025860982ull,
  16355909577407740449ull, 7262470246443199856ull}},
{{11226290529788016014ull, 8784452334750162516ull,
  1998142898050123946ull, 9078087808053999821ull}},
{{16239803617972285817ull, 10101968727646239476ull,
  3554682320495021418ull, 5673804880033749888ull}},
{{1853010448755805655ull, 3404088872703023538ull,
  4443352900618776773ull, 7092256100042187360ull}},
{{11539635097799532877ull, 8866797109306167326ull,
  5554191125773470966ull, 8865320125052734200ull}},
{{2600585917697320144ull, 930062174888966675ull, 3471369453608419354ull,
  5540825078157958875ull}},
{{17085790452403813892ull, 10385949755465984151ull,
  18174269872292687904ull, 6926031347697448593ull}},
{{16745552047077379461ull, 12982437194332480189ull,
  8882779285083696168ull, 8657539184621810742ull}},
{{12771813038637056115ull, 8114023246457800118ull,
  940051034749922201ull, 5410961990388631714ull}},
{{6741394261441544336ull, 14754215076499638052ull,
  10398435830292178559ull, 6763702487985789642ull}},
{{8426742826801930420ull, 13831082827197159661ull,
  3774672751010447391ull, 8454628109982237053ull}},
{{7572557275964900465ull, 15561955794639306644ull,
  4665013478595223571ull, 5284142568738898158ull}},
{{9465696594956125581ull, 14840758724871745401ull,
  15054638885098805272ull, 6605178210923622697ull}},
{{16443806762122544880ull, 104204332380130135ull,
  4983240551091342879ull, 8256472763654528372ull}},
{{17194908253967672406ull, 6982656735378663190ull,
  12337897381286865107ull, 5160295477284080232ull}},
{{12270263280604814699ull, 4116634900795941084ull,
  15422371726608581384ull, 6450369346605100290ull}},
{{15337829100756018374ull, 5145793625994926355ull,
  10054592621405950922ull, 8062961683256375363ull}},
{{7280300178758817532ull, 7827807034674216876ull,
  3978277379165025374ull, 5039351052035234602ull}},
{{9100375223448521915ull, 561386756487995287ull,
  14196218760811057526ull, 6299188815044043252ull}},
{{6763783010883264489ull, 9925105482464769917ull,
  17745273451013821907ull, 7873986018805054065ull}},
{{6533207391015734258ull, 3897347917326787246ull,
  4173266879242556836ull, 4921241261753158791ull}},
{{17389881275624443630ull, 4871684896658484057ull,
  604897580625808141ull, 6151551577191448489ull}},
{{7902293539248390826ull, 10701292139250492976ull,
  5367807994209648080ull, 7689439471489310611ull}},
{{4938933462030244266ull, 6688307587031558110ull,
  1049036987167336098ull, 4805899669680819132ull}},
{{15397038864392581141ull, 17583756520644223445ull,
  1311296233959170122ull, 6007374587101023915ull}},
{{5411240525208562714ull, 12756323613950503499ull,
  15474178347731126365ull, 7509218233876279893ull}},
{{1076182319041657744ull, 10278545267932758639ull,
  11977204476545647930ull, 4693261396172674933ull}},
{{15180285954084235892ull, 3624809548061172490ull,
  1136447540399896201ull, 5866576745215843667ull}},
{{9751985405750519057ull, 9142697953503853517ull,
  15255617480782033963ull, 7333220931519804583ull}},
{{16801667775615536725ull, 6816686423452428992ull,
  14457835832550154550ull, 9166526164399755729ull}},
{{10501042359759710454ull, 18095487069939931832ull,
  2118618367702764737ull, 5729078852749847331ull}},
{{13126302949699638067ull, 8784300782142751078ull,
  16483331014910619634ull, 7161348565937309163ull}},
{{7184506650269771775ull, 1757003940823663040ull,
  15992477750210886639ull, 8951685707421636454ull}},
{{4490316656418607360ull, 8015656490655871256ull,
  5383612575454416245ull, 5594803567138522784ull}},
{{5612895820523259200ull, 14631256631747226974ull,
  6729515719318020306ull, 6993504458923153480ull}},
{{16239491812508849808ull, 9065698752829257909ull,
  8411894649147525383ull, 8741880573653941850ull}},
{{12455525392031725082ull, 12583590748159368049ull,
  9869120174144591268ull, 5463675358533713656ull}},
{{1734348684757492640ull, 15729488435199210062ull,
  12336400217680739085ull, 6829594198167142070ull}},
{{11391307892801641608ull, 5826802488716848865ull,
  6197128235246148049ull, 8536992747708927588ull}},
{{202038405359944149ull, 15170966601516500301ull,
  13096577183883618338ull, 5335620467318079742ull}},
{{4864234025127318090ull, 9740336215040849568ull,
  7147349442999747115ull, 6669525584147599678ull}},
{{6080292531409147613ull, 7563734250373674056ull,
  18157558840604459702ull, 8336906980184499597ull}},
{{3800182832130717258ull, 115647888056158381ull,
  13654317284591481266ull, 5210566862615312248ull}},
{{9361914558590784477ull, 9367931896924973784ull,
  17067896605739351582ull, 6513208578269140310ull}},
{{11702393198238480596ull, 2486542834301441422ull,
  12111498720319413670ull, 8141510722836425388ull}},
{{2702309730471662469ull, 15389147326720564601ull,
  16793058737054409351ull, 5088444201772765867ull}},
{{7989573181516965990ull, 14624748139973317847ull,
  16379637402890623785ull, 6360555252215957334ull}},
{{5375280458468819583ull, 4445877119684483597ull,
  11251174716758503924ull, 7950694065269946668ull}},
{{5665393295756706191ull, 12002045236657578056ull,
  16255356234828840760ull, 4969183790793716667ull}},
{{7081741619695882739ull, 15002556545821972570ull,
  15707509275108663046ull, 6211479738492145834ull}},
{{18075549061474629232ull, 9529823645422689904ull,
  10411014557031053000ull, 7764349673115182293ull}},
{{11297218163421643270ull, 5956139778389181190ull,
  8812727107358102077ull, 4852718545696988933ull}},
{{4898150667422278280ull, 12056860741413864392ull,
  15627594902625015500ull, 6065898182121236166ull}},
{{6122688334277847849ull, 15071075926767330490ull,
  10311121591426493567ull, 7582372727651545208ull}},
{{8438366227351042810ull, 16336951481870663412ull,
  6444450994641558479ull, 4738982954782215755ull}},
{{10547957784188803512ull, 15809503333910941361ull,
  3443877724874560195ull, 5923728693477769694ull}},
{{17796633248663392294ull, 15150193148961288797ull,
  13528219192947976052ull, 7404660866847212117ull}},
{{13428738789628314136ull, 245498681246029690ull,
  10760980004806178985ull, 4627913041779507573ull}},
{{7562551450180616862ull, 4918559369984925017ull,
  18062911024435111635ull, 5784891302224384466ull}},
{{14064875331153158981ull, 1536513194053768367ull,
  13355266743689113736ull, 7231114127780480583ull}},
{{12969408145514060823ull, 1920641492567210459ull,
  12082397411184004266ull, 9038892659725600729ull}},
{{5800037081732594062ull, 5812086951281894441ull, 633969354348920810ull,
  5649307912328500456ull}},
{{11861732370593130482ull, 16488480725957143859ull,
  792461692936151012ull, 7061634890410625570ull}},
{{10215479444814025198ull, 2163856833736878208ull,
  10213949153024964574ull, 8827043613013281962ull}},
{{6384674653008765749ull, 15187468576367712592ull,
  10995404239067990762ull, 5516902258133301226ull}},
{{7980843316260957186ull, 9760963683604864932ull,
  4520883261980212645ull, 6896127822666626533ull}},
{{9976054145326196483ull, 16812890622933469069ull,
  10262790095902653710ull, 8620159778333283166ull}},
{{8540876850042566754ull, 5896370620906030264ull,
  1802557791511770665ull, 5387599861458301979ull}},
{{10676096062553208442ull, 11982149294559925734ull,
  16088255294671877043ull, 6734499826822877473ull}},
{{4121748041336734745ull, 10366000599772519264ull,
  6275261063057682592ull, 8418124783528596842ull}},
{{2576092525835459216ull, 6478750374857824540ull,
  8533724182838439524ull, 5261327989705373026ull}},
{{3220115657294324019ull, 8098437968572280675ull,
  1443783191693273597ull, 6576659987131716283ull}},
{{17860202626900068736ull, 14734733479142738747ull,
  15639787044898755708ull, 8220824983914645353ull}},
{{8856783632598849008ull, 18432580461318987525ull,
  2857337875420640461ull, 5138015614946653346ull}},
{{15682665559175949164ull, 9205667521366570694ull,
  12795044381130576385ull, 6422519518683316682ull}},
{{10379959912115160647ull, 16118770420135601272ull,
  6770433439558444673ull, 8028149398354145853ull}},
{{6487474945071975405ull, 3156702484943668939ull,
  6537363908937721873ull, 5017593373971341158ull}},
{{3497657662912581352ull, 8557564124606974078ull,
  17395076923026928149ull, 6271991717464176447ull}},
{{13595444115495502497ull, 15308641174186105501ull,
  17132160135356272282ull, 7839989646830220559ull}},
{{10802995581398383013ull, 14179586752293703842ull,
  17625129112238752032ull, 4899993529268887849ull}},
{{4280372439893202958ull, 17724483440367129803ull,
  8196353335016276328ull, 6124991911586109812ull}},
{{738779531439115794ull, 3708860226749360638ull,
  10245441668770345411ull, 7656239889482637265ull}},
{{14296795262431611083ull, 12194632504656446ull,
  17932616089049935642ull, 4785149930926648290ull}},
{{8647622041184738046ull, 9238615327485596366ull,
  13192398074457643744ull, 5981437413658310363ull}},
{{1586155514626146749ull, 11548269159356995458ull,
  11878811574644666776ull, 7476796767072887954ull}},
{{5603033215068729622ull, 7217668224598122161ull,
  12035943252580304639ull, 4672997979420554971ull}},
{{11615477537263299932ull, 4410399262320264797ull,
  10433243047297992895ull, 5841247474275693714ull}},
{{684288866296961203ull, 901313059472943093ull, 3818181772267715311ull,
  7301559342844617143ull}},
{{5467047101298589407ull, 14961699379623342578ull,
  161041196907256234ull, 9126949178555771429ull}},
{{8028590456739006284ull, 13962748130691977015ull,
  2406493757280729098ull, 5704343236597357143ull}},
{{5424052052496369951ull, 8230063126510195461ull,
  16843175251883075085ull, 7130429045746696428ull}},
{{11391751084047850342ull, 14899264926565132230ull,
  2607224991144292240ull, 8913036307183370536ull}},
{{2508158409102518560ull, 9312040579103207644ull,
  1629515619465182650ull, 5570647691989606585ull}},
{{3135198011378148200ull, 2416678687024233747ull,
  6648580542758866217ull, 6963309614987008231ull}},
{{17754055569504848962ull, 7632534377207680087ull,
  3699039660021194867ull, 8704137018733760289ull}},
{{18013813758581612457ull, 2464490976541106102ull,
  13841114833581716552ull, 5440085636708600180ull}},
{{13293895161372239763ull, 3080613720676382628ull,
  17301393541977145690ull, 6800107045885750225ull}},
{{16617368951715299704ull, 13074139187700254093ull,
  7791683872189268400ull, 8500133807357187782ull}},
{{12691698604035756267ull, 8171336992312658808ull,
  258116401690904846ull, 5312583629598242364ull}},
{{15864623255044695334ull, 990799203536047702ull, 322645502113631058ull,
  6640729536997802955ull}},
{{10607407031951093359ull, 10461871041274835436ull,
  14238364932924202534ull, 8300911921247253693ull}},
{{15853001431824209158ull, 1926983382369384243ull,
  11204821092291320536ull, 5188069950779533558ull}},
{{15204565771352873543ull, 2408729227961730304ull,
  4782654328509374862ull, 6485087438474416948ull}},
{{558963140481540313ull, 12234283571806938689ull,
  5978317910636718577ull, 8106359298093021185ull}},
{{11878567008869432456ull, 728898204738254824ull,
  15265663740216418871ull, 5066474561308138240ull}},
{{14848208761086790569ull, 14746180811204982242ull,
  635335601560971972ull, 6333093201635172801ull}},
{{9336888914503712404ull, 18432726014006227803ull,
  5405855520378602869ull, 7916366502043966001ull}},
{{3529712562351126301ull, 13826296767967586329ull,
  14907874746305096553ull, 4947729063777478750ull}},
{{9023826721366295780ull, 3447812904677319199ull,
  9411471396026594884ull, 6184661329721848438ull}},
{{6668097383280481820ull, 4309766130846648999ull,
  2540967208178467797ull, 7730826662152310548ull}},
{{11085089892191382994ull, 4999446840992849576ull,
  10811476541966318181ull, 4831766663845194092ull}},
{{13856362365239228742ull, 10860994569668449874ull,
  13514345677457897726ull, 6039708329806492615ull}},
{{8097080919694260120ull, 4352871175230786535ull,
  12281246078394984254ull, 7549635412258115769ull}},
{{11978204602449994431ull, 16555602539801405296ull,
  758249771355783302ull, 4718522132661322356ull}},
{{14972755753062493039ull, 11471131137896980812ull,
  947812214194729128ull, 5898152665826652945ull}},
{{269200617618564682ull, 14338913922371226016ull,
  5796451286170799314ull, 7372690832283316181ull}},
{{336500772023205852ull, 8700270366109256712ull,
  11857250126140887047ull, 9215863540354145226ull}},
{{210312982514503658ull, 12355198006459367301ull,
  12022467347265442308ull, 5759914712721340766ull}},
{{4874577246570517476ull, 15443997508074209126ull,
  5804712147227027077ull, 7199893390901675958ull}},
{{15316593595067922653ull, 5469938829810597695ull,
  16479262220888559655ull, 8999866738627094947ull}},
{{16490400024558533514ull, 10336240796272705415ull,
  7993695878841655832ull, 5624916711641934342ull}},
{{16001314012270778989ull, 12920300995340881769ull,
  768747811697293982ull, 7031145889552417928ull}},
{{6166584460056310024ull, 6927004207321326404ull, 960934764621617478ull,
  8788932361940522410ull}},
{{13077487324389969573ull, 18164435684857992714ull,
  5212270246315898827ull, 5493082726212826506ull}},
{{7123487118632686158ull, 18093858587645102989ull,
  15738709844749649342ull, 6866353407766033132ull}},
{{13516044916718245602ull, 13393951197701602928ull,
  1226643232227510062ull, 8582941759707541416ull}},
{{8447528072948903501ull, 3759533480136113926ull, 766652020142193789ull,
  5364338599817213385ull}},
{{1336038054331353569ull, 9311102868597530312ull,
  5570001043605130140ull, 6705423249771516731ull}},
{{1670047567914191961ull, 11638878585746912890ull,
  2350815286079024771ull, 8381779062214395914ull}},
{{5655465748373757880ull, 4968456106878126604ull,
  6080945572226778386ull, 5238611913883997446ull}},
{{7069332185467197349ull, 15433942170452434063ull,
  16824554002138248790ull, 6548264892354996807ull}},
{{4224979213406608783ull, 10069055676210766771ull,
  16419006484245423084ull, 8185331115443746009ull}},
{{334768999165436537ull, 15516531834486505040ull,
  3344350025012307571ull, 5115831947152341256ull}},
{{418461248956795672ull, 14783978774680743396ull,
  4180437531265384464ull, 6394789933940426570ull}},
{{523076561195994589ull, 33229394641377629ull, 14448918950936506389ull,
  7993487417425533212ull}},
{{2632765859961190570ull, 2326611380864554970ull,
  18253946381190092301ull, 4995929635890958257ull}},
{{12514329361806264021ull, 7519950244508081616ull,
  8982374921205451664ull, 6244912044863697822ull}},
{{15642911702257830026ull, 9399937805635102020ull,
  2004596614652038772ull, 7806140056079622278ull}},
{{553447777056367958ull, 15098333165376714571ull,
  15087930939439687944ull, 4878837535049763923ull}},
{{14526867776602623660ull, 426172383011341597ull,
  14248227655872222027ull, 6098546918812204904ull}},
{{4323526665471115863ull, 14367773534046340709ull,
  17810284569840277533ull, 7623183648515256130ull}},
{{5008047175133141366ull, 11285701467992656895ull,
  15743113874577561362ull, 4764489780322035081ull}},
{{1648372950489038804ull, 4883754798136045311ull,
  5843834287939787991ull, 5955612225402543852ull}},
{{15895524243393462217ull, 1493007479242668734ull,
  7304792859924734989ull, 7444515281753179815ull}},
{{5323016633693525982ull, 3238972683740361911ull,
  11483024565094041224ull, 4652822051095737384ull}},
{{2042084773689519573ull, 4048715854675452389ull,
  14353780706367551530ull, 5816027563869671730ull}},
{{7164291985539287370ull, 14284266855199091294ull,
  8718853846104663604ull, 7270034454837089663ull}},
{{18178737018778885021ull, 17855333568998864117ull,
  6286881289203441601ull, 9087543068546362079ull}},
{{13667553645950497090ull, 4242054452983208217ull,
  10846829833393232857ull, 5679714417841476299ull}},
{{3249384002155957650ull, 9914254084656398176ull,
  8946851273314153167ull, 7099643022301845374ull}},
{{4061730002694947063ull, 7781131587393109816ull,
  1960192054787915651ull, 8874553777877306718ull}},
{{2538581251684341914ull, 2557364232906999683ull,
  15060178089524610994ull, 5546596111173316698ull}},
{{17008284619887591105ull, 12420077327988525411ull,
  9601850575050987934ull, 6933245138966645873ull}},
{{16648669756432100977ull, 6301724623130880956ull,
  16613999237241122822ull, 8666556423708307341ull}},
{{1182046560915287303ull, 17773635944738964310ull,
  12689592532489395715ull, 5416597764817692088ull}},
{{10700930237998884936ull, 17605358912496317483ull,
  15861990665611744644ull, 6770747206022115110ull}},
{{8764476779071218266ull, 3559954566910845238ull,
  10604116295159904998ull, 8463434007527643888ull}},
{{866111968492123513ull, 16060029659601441986ull,
  6627572684474940623ull, 5289646254704777430ull}},
{{10306011997469930199ull, 15463351056074414578ull,
  17507837892448451587ull, 6612057818380971787ull}},
{{3659142959982636940ull, 14717502801665630319ull,
  17273111347133176580ull, 8265072272976214734ull}},
{{9204493377630229944ull, 18421811287895794757ull,
  6184008573530847458ull, 5165670170610134209ull}},
{{16117302740465175334ull, 13803892073014967638ull,
  12341696735340947227ull, 6457087713262667761ull}},
{{10923256388726693359ull, 12643179072841321644ull,
  1592062863894020322ull, 8071359641578334702ull}},
{{16050407279808959158ull, 12513672938953213931ull,
  14830097345215926413ull, 5044599775986459188ull}},
{{15451323081333811043ull, 1807033118409353702ull, 90877607810356401ull,
  6305749719983073986ull}},
{{10090781814812487996ull, 6870477416439080032ull,
  9336969046617721309ull, 7882187149978842482ull}},
{{6306738634257804997ull, 6599891394488118972ull,
  10447291672563463722ull, 4926366968736776551ull}},
{{7883423292822256247ull, 17473236279964924523ull,
  8447428572276941748ull, 6157958710920970689ull}},
{{5242593097600432404ull, 3394801276246604038ull,
  15170971733773565090ull, 7697448388651213361ull}},
{{17111678741282433965ull, 6733436816081515427ull,
  2564328305967396325ull, 4810905242907008351ull}},
{{16777912408175654552ull, 13028482038529282188ull,
  17040468437741409118ull, 6013631553633760438ull}},
{{2525646436510016574ull, 7062230511306826928ull,
  12077213510321985590ull, 7517039442042200548ull}},
{{1578529022818760359ull, 18248952124848930542ull,
  16771630480806016801ull, 4698149651276375342ull}},
{{11196533315378226256ull, 8976132100778999465ull,
  11741166064152745194ull, 5872687064095469178ull}},
{{160608588940619108ull, 1996793089118973524ull, 5453085543336155685ull,
  7340858830119336473ull}},
{{200760736175773885ull, 7107677379826104809ull,
  11428042947597582510ull, 9176073537649170591ull}},
{{11654690506178328438ull, 18277356417673479217ull,
  14060055869889570924ull, 5735045961030731619ull}},
{{733305077440746836ull, 4399951448382297406ull,
  12963383818934575752ull, 7168807451288414524ull}},
{{10140003383655709353ull, 5499939310477871757ull,
  16204229773668219690ull, 8961009314110518155ull}},
{{8643345123998512298ull, 8049148087476057752ull,
  7821800599328943354ull, 5600630821319073847ull}},
{{10804181404998140372ull, 838063072490296382ull,
  5165564730733791289ull, 7000788526648842309ull}},
{{4281854719392899657ull, 5659264859040258382ull,
  11068641931844627015ull, 8750985658311052886ull}},
{{16511217254902725998ull, 10454569564541243344ull,
  2306215188975503980ull, 5469366036444408054ull}},
{{2192277494918855881ull, 13068211955676554181ull,
  12106141023074155783ull, 6836707545555510067ull}},
{{7352032887075957755ull, 11723578926168304822ull,
  10520990260415306825ull, 8545884431944387584ull}},
{{18430078609704637309ull, 409707801214108657ull,
  6575618912759566766ull, 5341177769965242240ull}},
{{9202540206848632924ull, 9735506788372411630ull,
  8219523640949458457ull, 6676472212456552800ull}},
{{2279803221706015347ull, 16781069503892902442ull,
  10274404551186823071ull, 8345590265570691000ull}},
{{6036563031993647496ull, 17405697467574145882ull,
  6421502844491764419ull, 5215993915981681875ull}},
{{16769075826846835178ull, 17145435816040294448ull,
  3415192537187317620ull, 6519992394977102344ull}},
{{2514600709848992357ull, 2985050696340816445ull,
  4268990671484147026ull, 8149990493721377930ull}},
{{3877468452869314175ull, 6477342703640398182ull,
  7279805188104979795ull, 5093744058575861206ull}},
{{14070207602941418527ull, 3484992361123109823ull,
  18323128521986000552ull, 6367180073219826507ull}},
{{12976073485249385254ull, 4356240451403887279ull,
  18292224634055112786ull, 7958975091524783134ull}},
{{15027574955921947640ull, 7334336300554817453ull,
  6820954377857057587ull, 4974359432202989459ull}},
{{4949410639620270838ull, 4556234357266133913ull,
  3914506953893934080ull, 6217949290253736824ull}},
{{10798449317952726451ull, 5695292946582667391ull,
  4893133692367417600ull, 7772436612817171030ull}},
{{13666559851361535888ull, 3559558091614167119ull,
  16893266613011799712ull, 4857772883010731893ull}},
{{12471513795774531956ull, 4449447614517708899ull,
  7281525210982585928ull, 6072216103763414867ull}},
{{10977706226290777041ull, 5561809518147136124ull,
  4490220495300844506ull, 7590270129704268584ull}},
{{16084438428286511459ull, 8087816967269347981ull,
  2806387809563027816ull, 4743918831065167865ull}},
{{6270489980075975611ull, 10109771209086684977ull,
  8119670780381172674ull, 5929898538831459831ull}},
{{12449798493522357418ull, 3413841974503580413ull,
  5537902457049077939ull, 7412373173539324789ull}},
{{10086967067665167339ull, 18274552298560595422ull,
  5767032044869367663ull, 4632733233462077993ull}},
{{3385336797726683365ull, 18231504354773356374ull,
  11820476074514097483ull, 5790916541827597491ull}},
{{13455043034013130014ull, 18177694425039307563ull,
  10163909074715233950ull, 7238645677284496864ull}},
{{12207117774089024614ull, 13498745994444358646ull,
  12704886343394042438ull, 9048307096605621080ull}},
{{3017762590378252480ull, 3825030228100336250ull,
  7940553964621276524ull, 5655191935378513175ull}},
{{12995575274827591408ull, 4781287785125420312ull,
  5314006437349207751ull, 7068989919223141469ull}},
{{16244469093534489259ull, 1364923712979387486ull,
  11254194065113897593ull, 8836237399028926836ull}},
{{5541107165031667883ull, 12382292366680586939ull,
  16257243327550961803ull, 5522648374393079272ull}},
{{2314697937862196950ull, 10866179439923345770ull,
  1874810085729150638ull, 6903310467991349091ull}},
{{12116744459182521995ull, 4359352263049406404ull,
  16178570662443602010ull, 8629138084989186363ull}},
{{16796337323843852055ull, 7336281182833266906ull,
  7805763654813557304ull, 5393211303118241477ull}},
{{11772049617950039261ull, 9170351478541583633ull,
  14368890586944334534ull, 6741514128897801846ull}},
{{880003967155385364ull, 2239567311322203734ull, 8737741196825642360ull,
  8426892661122252308ull}},
{{14385060534754279565ull, 1399729569576377333ull,
  14684460284870802283ull, 5266807913201407692ull}},
{{4146267613160685744ull, 15584720017252635379ull,
  18355575356088502853ull, 6583509891501759615ull}},
{{571148498023469276ull, 5645841966283630512ull,
  18332783176683240663ull, 8229387364377199519ull}},
{{356967811264668297ull, 10446180256568350926ull,
  18375518513068107270ull, 5143367102735749699ull}},
{{9669581800935611180ull, 3834353283855662849ull,
  18357712122907746184ull, 6429208878419687124ull}},
{{16698663269596901878ull, 4792941604819578561ull,
  4500396079925131114ull, 8036511098024608906ull}},
{{3519135515856981818ull, 7607274521439624505ull,
  7424433568380594850ull, 5022819436265380566ull}},
{{9010605413248615177ull, 285721114944754823ull, 57169923620967755ull,
  6278524295331725708ull}},
{{6651570748133381067ull, 14192209448963107241ull, 71462404526209693ull,
  7848155369164657135ull}},
{{15686446763651832927ull, 11175973914815635977ull,
  6962193030469962914ull, 4905097105727910709ull}},
{{5773000399282627446ull, 4746595356664769164ull,
  13314427306514841547ull, 6131371382159888386ull}},
{{7216250499103284308ull, 1321558177403573551ull,
  7419662096288776126ull, 7664214227699860483ull}},
{{11427685589580634549ull, 14661031916159397181ull,
  2331445800966791126ull, 4790133892312412802ull}},
{{449548931693629474ull, 9102917858344470669ull,
  12137679288063264716ull, 5987667365390516002ull}},
{{5173622183044424746ull, 11378647322930588336ull,
  5948727073224305087ull, 7484584206738145003ull}},
{{3233513864402765466ull, 14029183604472699566ull,
  1412111411551496727ull, 4677865129211340627ull}},
{{13265264367358232641ull, 12924793487163486553ull,
  15600197319721534621ull, 5847331411514175783ull}},
{{2746522403915627089ull, 2320933803672194480ull,
  14888560631224530373ull, 7309164264392719729ull}},
{{3433153004894533861ull, 7512853273017631004ull,
  4775642733748499254ull, 9136455330490899662ull}},
{{11369092664913859471ull, 83847277208631473ull,
  16819834763874975746ull, 5710284581556812288ull}},
{{376307775860160627ull, 9328181133365565150ull, 2578049381134168066ull,
  7137855726946015361ull}},
{{9693756756679976592ull, 2436854379852180629ull,
  7834247744845097987ull, 8922319658682519201ull}},
{{8364440982138679322ull, 17663935051903470557ull,
  16425619886596656001ull, 5576449786676574500ull}},
{{15067237246100737056ull, 8244860759597174484ull,
  2085280784536268386ull, 6970562233345718126ull}},
{{387302483916369704ull, 1082703912641692298ull,
  11829973017525111291ull, 8713202791682147657ull}},
{{4853750070875118969ull, 16817591009896915350ull,
  476204108312112700ull, 5445751744801342286ull}},
{{15290559625448674520ull, 2575244688661592571ull,
  9818627172244916684ull, 6807189681001677857ull}},
{{14501513513383455246ull, 3219055860826990714ull,
  16884969983733533759ull, 8508987101252097321ull}},
{{13675131964292047433ull, 8929438940657951052ull,
  3635577212192376743ull, 5318116938282560826ull}},
{{17093914955365059291ull, 6550112657395050911ull,
  13767843552095246737ull, 6647646172853201032ull}},
{{16755707675778936209ull, 12799326840171201543ull,
  17209804440119058421ull, 8309557716066501290ull}},
{{17389846325002916987ull, 10305422284320694916ull,
  15367813793501799417ull, 5193473572541563306ull}},
{{3290563832544094618ull, 17493463873828256550ull,
  9986395205022473463ull, 6491841965676954133ull}},
{{13336576827534894080ull, 17255143823857932783ull,
  17094680024705479733ull, 8114802457096192666ull}},
{{15252889544850390656ull, 13090307899124901941ull,
  15295861033868312737ull, 5071751535685120416ull}},
{{5231053875780824608ull, 2527826818623963715ull, 673082218625839306ull,
  6339689419606400521ull}},
{{1927131326298642856ull, 12383155560134730452ull,
  5453038791709687036ull, 7924611774508000651ull}},
{{10427829115791427593ull, 16962844261938982340ull,
  1102306235604860445ull, 4952882359067500407ull}},
{{13034786394739284491ull, 7368497272141564213ull,
  15212940849788239269ull, 6191102948834375508ull}},
{{2458424938141941902ull, 13822307608604343171ull,
  569431988525747470ull, 7738878686042969386ull}},
{{17677416650834571353ull, 4027256236950326577ull,
  4967581011255980073ull, 4836799178776855866ull}},
{{8261712758261050479ull, 9645756314615296126ull,
  15432848300924750899ull, 6045998973471069832ull}},
{{1103768910971537291ull, 7445509374841732254ull, 844316302446387008ull,
  7557498716838837291ull}},
{{14524913624639374519ull, 4653443359276082658ull,
  16668598753524849544ull, 4723436698024273306ull}},
{{8932769993944442340ull, 5816804199095103323ull,
  11612376405051286122ull, 5904295872530341633ull}},
{{6554276474003165021ull, 16494377285723654962ull,
  680412451031943940ull, 7380369840662927042ull}},
{{8708108814679366043ull, 1085613766722508543ull,
  5036943800322352867ull, 4612731150414329401ull}},
{{6273449999921819649ull, 15192075263685299391ull,
  10907865768830328987ull, 5765913938017911751ull}},
{{3230126481474886657ull, 14378408061179236335ull,
  9023146192610523330ull, 7207392422522389689ull}},
{{17872716157125772033ull, 8749638039619269610ull,
  15890618759190542067ull, 9009240528152987111ull}},
{{15782133616630995425ull, 3162680765548349554ull,
  16849165752135170648ull, 5630775330095616944ull}},
{{10504294983933968473ull, 3953350956935436943ull,
  2614713116459411694ull, 7038469162619521181ull}},
{{8518682711490072687ull, 14165060733024071987ull,
  7880077414001652521ull, 8798086453274401476ull}},
{{3018333685467601478ull, 1935633930498963136ull,
  14148420420605808634ull, 5498804033296500922ull}},
{{3772917106834501847ull, 11642914449978479728ull,
  8462153488902484984ull, 6873505041620626153ull}},
{{4716146383543127309ull, 14553643062473099660ull,
  15189377879555494134ull, 8591881302025782691ull}},
{{12170963526569230376ull, 4484340895618299383ull,
  7187518165508489882ull, 5369925813766114182ull}},
{{10602018389784150066ull, 14828798156377650037ull,
  18207769743740388160ull, 6712407267207642727ull}},
{{17864209005657575486ull, 89253621762510930ull,
  18148026161248097297ull, 8390509084009553409ull}},
{{15776816646963372583ull, 11584998559670039091ull,
  4424987323138978954ull, 5244068177505970881ull}},
{{15109334790276827825ull, 5257876162732773056ull,
  10142920172351111597ull, 6555085221882463601ull}},
{{439924414136483165ull, 11184031221843354225ull,
  17290336233866277400ull, 8193856527353079501ull}},
{{11804167804903771738ull, 6990019513652096390ull,
  13112303155380117327ull, 5121160329595674688ull}},
{{5531837719274938865ull, 4125838373637732584ull,
  16390378944225146659ull, 6401450411994593360ull}},
{{6914797149093673581ull, 545611948619777826ull, 2041229606571881708ull,
  8001813014993241701ull}},
{{8933434236610933892ull, 9564379504742136949ull,
  3581611513321120019ull, 5001133134370776063ull}},
{{15778478814191055269ull, 7343788362500283282ull,
  18312072446933563736ull, 6251416417963470078ull}},
{{10499726480884043278ull, 9179735453125354103ull,
  13666718521812178862ull, 7814270522454337598ull}},
{{13479858078193608905ull, 1125648639775958410ull,
  3930013057705223885ull, 4883919076533960999ull}},
{{7626450560887235323ull, 6018746818147335917ull, 300830303704141952ull,
  6104898845667451249ull}},
{{14144749219536432058ull, 7523433522684169896ull,
  4987723898057565344ull, 7631123557084314061ull}},
{{8840468262210270036ull, 4702145951677606185ull,
  5423170445499672292ull, 4769452223177696288ull}},
{{15662271346190225449ull, 5877682439597007731ull,
  6778963056874590365ull, 5961815278972120360ull}},
{{14966153164310393908ull, 11958789067923647568ull,
  8473703821093237956ull, 7452269098715150450ull}},
{{9353845727693996192ull, 16697615204307055538ull,
  9907750906610661626ull, 4657668186696969031ull}},
{{2468935122762719432ull, 11648646968529043615ull,
  7773002614835939129ull, 5822085233371211289ull}},
{{16921226958735563002ull, 725750655379140806ull,
  14327939286972311816ull, 7277606541714014111ull}},
{{11928161661564677945ull, 907188319223926008ull,
  13298238090288001866ull, 9097008177142517639ull}},
{{7455101038477923716ull, 5178678717942341659ull,
  15228927834071083022ull, 5685630110714073524ull}},
{{4707190279670016741ull, 15696720434282702882ull,
  589415718879302161ull, 7107037638392591906ull}},
{{15107359886442296734ull, 5785842487571214890ull,
  9960141685453903510ull, 8883797047990739882ull}},
{{14053785947453823363ull, 17451209610014173018ull,
  10836774571836077597ull, 5552373154994212426ull}},
{{8343860397462503395ull, 7978953957235552561ull,
  4322596177940321189ull, 6940466443742765533ull}},
{{15041511515255517148ull, 14585378464971828605ull,
  10014931240852789390ull, 8675583054678456916ull}},
{{11706787706248392170ull, 4504175522180004974ull,
  15482704062387769177ull, 5422239409174035572ull}},
{{5410112595955714404ull, 10241905421152394122ull,
  906636004275159855ull, 6777799261467544466ull}},
{{15986012781799418813ull, 8190695758013104748ull,
  10356667042198725627ull, 8472249076834430582ull}},
{{767885951769860950ull, 2813341839544496516ull, 1861230882946815613ull,
  5295155673021519114ull}},
{{959857439712326188ull, 8128363317858008549ull,
  11549910640538295324ull, 6618944591276898892ull}},
{{5811507818067795638ull, 10160454147322510686ull,
  14437388300672869155ull, 8273680739096123615ull}},
{{17467250441574535986ull, 4044440832862875226ull,
  15940896715561625078ull, 5171050461935077259ull}},
{{12610691015113394175ull, 14278923077933369841ull,
  15314434876024643443ull, 6463813077418846574ull}},
{{1928305713609579006ull, 13236967828989324398ull,
  9919671558176028496ull, 8079766346773558218ull}},
{{15040249126288150591ull, 8273104893118327748ull,
  10811480742287405714ull, 5049853966733473886ull}},
{{353567334150636623ull, 1118009079543133878ull, 4290978891004481335ull,
  6312317458416842358ull}},
{{9665331204543071586ull, 15232569404711081059ull,
  14587095650610377476ull, 7890396823021052947ull}},
{{3734988993625725790ull, 296983841089649854ull, 6811091772417791971ull,
  4931498014388158092ull}},
{{13892108278886933045ull, 14206287856644226029ull,
  8513864715522239963ull, 6164372517985197615ull}},
{{3530077293326502594ull, 13146173802377894633ull,
  6030644875975412050ull, 7705465647481497019ull}},
{{13735513354397533881ull, 12828044644913572049ull,
  1463310038270938579ull, 4815916029675935637ull}},
{{3334333637714753640ull, 11423369787714577158ull,
  6440823566266061128ull, 6019895037094919546ull}},
{{13391289083998217857ull, 14279212234643221447ull,
  17274401494687352218ull, 7524868796368649432ull}},
{{15287084705139968017ull, 13536193665079401308ull,
  10796500934179595136ull, 4703042997730405895ull}},
{{662111807715408405ull, 16920242081349251636ull,
  8883940149297106016ull, 5878803747163007369ull}},
{{827639759644260506ull, 2703558527977012929ull,
  15716611205048770425ull, 7348504683953759211ull}},
{{5646235717982713537ull, 7991134178398654065ull,
  15034077987883575127ull, 9185630854942199014ull}},
{{15058112369807665721ull, 11911987889140240646ull,
  4784612723999846550ull, 5741019284338874384ull}},
{{9599268425404806343ull, 5666612824570525000ull,
  5980765904999808188ull, 7176274105423592980ull}},
{{11999085531756007928ull, 7083266030713156250ull,
  7475957381249760235ull, 8970342631779491225ull}},
{{12111114475774892859ull, 2121198259982028704ull,
  16201688409349569907ull, 5606464144862182015ull}},
{{15138893094718616074ull, 16486555880259699592ull,
  15640424493259574479ull, 7008080181077727519ull}},
{{476872294688718476ull, 15996508831897236587ull,
  14938844598147080195ull, 8760100226347159399ull}},
{{16438946248676306712ull, 7691975010722078914ull,
  16254306901483006978ull, 5475062641466974624ull}},
{{11325310773990607582ull, 391596726547822835ull,
  1871139553144207107ull, 6843828301833718281ull}},
{{9544952449060871573ull, 14324553963466942256ull,
  6950610459857646787ull, 8554785377292147851ull}},
{{5965595280663044733ull, 6647003217953144958ull,
  2038288528197335290ull, 5346740860807592407ull}},
{{16680366137683581725ull, 17532126059296207005ull,
  16382918715528832824ull, 6683426076009490508ull}},
{{7015399616822313444ull, 3468413500410707141ull,
  2031904320701489415ull, 8354282595011863136ull}},
{{6690467769727639854ull, 9085287465397773819ull,
  1269940200438430884ull, 5221426621882414460ull}},
{{3751398693732161914ull, 11356609331747217274ull,
  1587425250548038605ull, 6526783277353018075ull}},
{{13912620404019978200ull, 360703609401857880ull,
  15819339618467211969ull, 8158479096691272593ull}},
{{8695387752512486375ull, 11754654801944630935ull,
  2969558233900925624ull, 5099049435432045371ull}},
{{6257548672213220065ull, 14693318502430788669ull,
  17547005847658320742ull, 6373811794290056713ull}},
{{12433621858693912985ull, 9143276091183710028ull,
  8098699254290737216ull, 7967264742862570892ull}},
{{16994385698538471424ull, 5714547556989818767ull,
  14285059070786486568ull, 4979540464289106807ull}},
{{16631296104745701376ull, 7143184446237273459ull,
  13244637820055720306ull, 6224425580361383509ull}},
{{16177434112504738816ull, 18152352594651367632ull,
  2720739219787486670ull, 7780531975451729387ull}},
{{10110896320315461760ull, 6733534353229716866ull,
  17841363076863036833ull, 4862832484657330866ull}},
{{3415248363539551392ull, 13028603959964533987ull,
  13078331809224020233ull, 6078540605821663583ull}},
{{18104118509706602952ull, 2450696894673503771ull,
  11736228743102637388ull, 7598175757277079479ull}},
{{9009231059352932893ull, 10755057596025715665ull,
  14252671992080230223ull, 4748859848298174674ull}},
{{15873224842618554020ull, 8832135976604756677ull,
  8592467953245511971ull, 5936074810372718343ull}},
{{6006472997991028813ull, 6428483952328557943ull,
  6128898923129502060ull, 7420093512965897929ull}},
{{10671574651385474864ull, 13241174507060124522ull,
  15359776873024408547ull, 4637558445603686205ull}},
{{4116096277377067772ull, 11939782115397767749ull,
  5364663035998346972ull, 5796948057004607757ull}},
{{9756806365148722619ull, 14924727644247209686ull,
  11317514813425321619ull, 7246185071255759696ull}},
{{2972635919581127466ull, 14044223536881624204ull,
  14146893516781652024ull, 9057731339069699620ull}},
{{11081269486592980474ull, 8777639710551015127ull,
  18065180484843308323ull, 5661082086918562262ull}},
{{9239900839813837689ull, 6360363619761381005ull,
  13358103569199359596ull, 7076352608648202828ull}},
{{16161562068194685015ull, 7950454524701726256ull,
  16697629461499199495ull, 8845440760810253535ull}},
{{10100976292621678135ull, 11886563105579660766ull,
  17353547441078081540ull, 5528400475506408459ull}},
{{3402848328922321860ull, 14858203881974575958ull,
  17080248282920214021ull, 6910500594383010574ull}},
{{13476932448007678133ull, 4737696797186056235ull,
  12126938316795491719ull, 8638125742978763218ull}},
{{6117239770791104881ull, 9878589525882367003ull,
  12191022466424570228ull, 5398828589361727011ull}},
{{3034863695061493197ull, 12348236907352958754ull,
  10627092064603324881ull, 6748535736702158764ull}},
{{13016951655681642305ull, 1600238078909034730ull,
  13283865080754156102ull, 8435669670877698455ull}},
{{12747280803228414345ull, 14835206854600310418ull,
  15219944703112429419ull, 5272293544298561534ull}},
{{6710728967180742123ull, 13932322549823000119ull,
  9801558842035760966ull, 6590366930373201918ull}},
{{3776725190548539749ull, 8192031150423974341ull,
  3028576515689925400ull, 8237958662966502398ull}},
{{4666296253306531295ull, 5120019469014983963ull,
  15727918377588367087ull, 5148724164354063998ull}},
{{1221184298205776215ull, 1788338317841342050ull,
  10436525935130683051ull, 6435905205442579998ull}},
{{10749852409611996077ull, 16070480952583841274ull,
  3822285382058578005ull, 8044881506803224998ull}},
{{11330343774434885452ull, 12349893604578594748ull,
  16223986419068774965ull, 5028050941752015623ull}},
{{14162929718043606815ull, 1602308950441079723ull,
  15668297005408580803ull, 6285063677190019529ull}},
{{13091976129127120615ull, 15837944243333513366ull,
  5750313201478562291ull, 7856329596487524412ull}},
{{3570799062277062480ull, 7592872142869751902ull,
  12817317787778877240ull, 4910205997804702757ull}},
{{13686870864701103908ull, 9491090178587189877ull,
  2186589179441432838ull, 6137757497255878447ull}},
{{3273530525594216173ull, 2640490686379211539ull,
  16568294529583954760ull, 7672196871569848058ull}},
{{18186857642992242773ull, 1650306678987007211ull,
  14966870099417359629ull, 4795123044731155036ull}},
{{18121886035312915562ull, 6674569367161146918ull,
  261843550562147920ull, 5993903805913943796ull}},
{{13428985507286368644ull, 8343211708951433648ull,
  327304438202684900ull, 7492379757392429745ull}},
{{8393115942053980403ull, 14437879354949421838ull,
  11733780319945147822ull, 4682737348370268590ull}},
{{1268022890712699695ull, 8823977156832001490ull,
  5443853363076658970ull, 5853421685462835738ull}},
{{10808400650245650427ull, 1806599409185226054ull,
  16028188740700599521ull, 7316777106828544672ull}},
{{4287128775952287225ull, 6869935279908920472ull,
  1588491852166197785ull, 9145971383535680841ull}},
{{2679455484970179516ull, 15822924596011545055ull,
  12522022453672343375ull, 5716232114709800525ull}},
{{17184377411494888107ull, 15166969726587043414ull,
  1817470011808265507ull, 7145290143387250657ull}},
{{12257099727513834326ull, 14347026139806416364ull,
  6883523533187719788ull, 8931612679234063321ull}},
{{16884059366550922262ull, 18190263374233786035ull,
  15831417254310794627ull, 5582257924521289575ull}},
{{16493388189761264923ull, 18126143199364844640ull,
  15177585549461105380ull, 6977822405651611969ull}},
{{2169991163492029538ull, 4210934925496504185ull,
  5136923881544218014ull, 8722278007064514962ull}},
{{12885459523250988221ull, 16466892383717478827ull,
  7822263444392524162ull, 5451423754415321851ull}},
{{11495138385636347372ull, 11360243442792072726ull,
  5166143287063267299ull, 6814279693019152314ull}},
{{5145550945190658407ull, 9588618285062703004ull,
  15681051145683859932ull, 8517849616273940392ull}},
{{12439341377598937313ull, 15216258465018965185ull,
  9800656966052412457ull, 5323656010171212745ull}},
{{1714118666716507929ull, 5185265025991542770ull,
  16862507225992903476ull, 6654570012714015931ull}},
{{11366020370250410719ull, 6481581282489428462ull,
  16466448014063741441ull, 8318212515892519914ull}},
{{2492076712979118795ull, 15580203347624362549ull,
  14903216027217226304ull, 5198882822432824946ull}},
{{7726781909651286398ull, 1028510110820901570ull,
  9405647997166757073ull, 6498603528041031183ull}},
{{435105350209332190ull, 5897323656953514867ull, 7145373978031058437ull,
  8123254410051288979ull}},
{{16412841908376690283ull, 5991670294809640743ull,
  2160015727055717571ull, 5077034006282055612ull}},
{{15904366367043474949ull, 2877901850084663025ull,
  2700019658819646964ull, 6346292507852569515ull}},
{{6045399903522179974ull, 3597377312605828782ull,
  17210082628806722417ull, 7932865634815711893ull}},
{{17613432994983526196ull, 13777575866447112748ull,
  13062144652217895462ull, 4958041021759819933ull}},
{{3570047170019856129ull, 7998597796204115128ull,
  2492622759990205616ull, 6197551277199774917ull}},
{{4462558962524820161ull, 9998247245255143910ull,
  7727464468415144924ull, 7746939096499718646ull}},
{{16624157406860176313ull, 15472276565139240751ull,
  217979274332077673ull, 4841836935312324154ull}},
{{16168510740147832487ull, 5505287651141887227ull,
  9495846129769872900ull, 6052296169140405192ull}},
{{15598952406757402705ull, 6881609563927359034ull,
  11869807662212341125ull, 7565370211425506490ull}},
{{14361031272650764595ull, 6606848986668293348ull,
  12030315807310101107ull, 4728356382140941556ull}},
{{17951289090813455743ull, 3646875214907978781ull,
  15037894759137626384ull, 5910445477676176945ull}},
{{8604053308234655967ull, 4558594018634973477ull,
  4962310393639869268ull, 7388056847095221182ull}},
{{7683376326860353932ull, 12072493298501634231ull,
  16936502051307082004ull, 4617535529434513238ull}},
{{4992534390148054510ull, 15090616623127042789ull,
  11947255527279076697ull, 5771919411793141548ull}},
{{10852354006112456042ull, 5028212723626639774ull,
  14934069409098845872ull, 7214899264741426935ull}},
{{4342070470785794244ull, 6285265904533299718ull,
  14055900742946169436ull, 9018624080926783669ull}},
{{16548852099523285115ull, 13151663227188088131ull,
  11090780973555049849ull, 5636640050579239793ull}},
{{16074379105976718489ull, 2604520978702946452ull, 28418161661648600ull,
  7045800063224049742ull}},
{{1646229808761346495ull, 3255651223378683066ull,
  9258894738931836558ull, 8807250079030062177ull}},
{{5640579648903229464ull, 15869840069893840628ull,
  17316024257900867608ull, 5504531299393788860ull}},
{{7050724561129036830ull, 1390556013657749169ull,
  3198286248666532895ull, 6880664124242236076ull}},
{{13425091719838683941ull, 15573253072354350173ull,
  3997857810833166118ull, 8600830155302795095ull}},
{{10696525334112871415ull, 5121597151794080954ull,
  9416190159411810680ull, 5375518847064246934ull}},
{{4147284630786313461ull, 6401996439742601193ull,
  2546865662409987542ull, 6719398558830308668ull}},
{{9795791806910279730ull, 17225867586533027299ull,
  3183582078012484427ull, 8399248198537885835ull}},
{{3816526870105230879ull, 8460324232369448110ull,
  18130639863253660431ull, 5249530124086178646ull}},
{{13994030624486314407ull, 5963719272034422233ull,
  13439927792212299731ull, 6561912655107723308ull}},
{{3657480225325729297ull, 2842963071615639888ull,
  16799909740265374664ull, 8202390818884654135ull}},
{{2285925140828580811ull, 1776851919759774930ull,
  17417472615306941021ull, 5126494261802908834ull}},
{{12080778462890501821ull, 6832750918127106566ull,
  12548468732278900468ull, 6408117827253636043ull}},
{{5877601041758351469ull, 8540938647658883208ull,
  11073899896921237681ull, 8010147284067045054ull}},
{{3673500651098969668ull, 16867301700855271765ull,
  2309501417148385646ull, 5006342052541903159ull}},
{{9203561832301099989ull, 11860755089214313898ull,
  16721934826717645770ull, 6257927565677378948ull}},
{{2281080253521599178ull, 5602571824663116565ull,
  2455674459687505597ull, 7822409457096723686ull}},
{{3731518167664693438ull, 5807450399628141805ull,
  15369854592586854710ull, 4889005910685452303ull}},
{{9276083728008254702ull, 16482685036389953064ull,
  14600632222306180483ull, 6111257388356815379ull}},
{{11595104660010318377ull, 15991670277060053426ull,
  13639104259455337700ull, 7639071735446019224ull}},
{{11858626430933836890ull, 771421886307757583ull,
  8524440162159586063ull, 4774419834653762015ull}},
{{10211597020239908208ull, 14799335413166860691ull,
  6043864184272094674ull, 5968024793317202519ull}},
{{8152810256872497356ull, 9275797229603800056ull,
  2943144211912730439ull, 7460030991646503149ull}},
{{5095506410545310848ull, 12714902296143456891ull,
  4145308141659150476ull, 4662519369779064468ull}},
{{1757696994754250656ull, 15893627870179321114ull,
  5181635177073938095ull, 5828149212223830585ull}},
{{11420493280297589128ull, 15255348819296763488ull,
  11088729989769810523ull, 7285186515279788231ull}},
{{14275616600371986409ull, 14457500005693566456ull,
  9249226468784875250ull, 9106483144099735289ull}},
{{8922260375232491506ull, 13647623521985866939ull,
  17309981589059016791ull, 5691551965062334555ull}},
{{6541139450613226478ull, 12447843384054945770ull,
  17025790967896383085ull, 7114439956327918194ull}},
{{17399796350121308906ull, 1724746174786518500ull,
  12058866673015703049ull, 8893049945409897743ull}},
{{1651500681971042258ull, 12607181405310043823ull,
  14454320698275896261ull, 5558156215881186089ull}},
{{15899433907745966535ull, 1923918701355391066ull,
  4232842817562706615ull, 6947695269851482612ull}},
{{10650920347827682360ull, 16239956431976402545ull,
  5291053521953383268ull, 8684619087314353265ull}},
{{18186040263460771235ull, 926600733130475782ull,
  14836123497289334303ull, 5427886929571470790ull}},
{{13509178292471188236ull, 14993308971695258440ull,
  9321782334756892070ull, 6784858661964338488ull}},
{{16886472865588985295ull, 9518264177764297242ull,
  11652227918446115088ull, 8481073327455423110ull}},
{{15165731559420503714ull, 5948915111102685776ull,
  2670956430601434026ull, 5300670829659639444ull}},
{{510420375566078026ull, 16659515925733133029ull,
  3338695538251792532ull, 6625838537074549305ull}},
{{5249711487884985436ull, 2377650833456864670ull,
  8785055441242128570ull, 8282298171343186631ull}},
{{17116127735210279610ull, 6097717789337928322ull,
  12408188678417412212ull, 5176436357089491644ull}},
{{12171787632158073704ull, 7622147236672410403ull,
  15510235848021765265ull, 6470545446361864555ull}},
{{10603048521770204226ull, 14139370064267900908ull,
  14776108791599818677ull, 8088181807952330694ull}},
{{15850277362961153449ull, 11142949299381132019ull,
  4623381976322498769ull, 5055113629970206684ull}},
{{15201160685274053908ull, 93628568944251312ull, 5779227470403123462ull,
  6318892037462758355ull}},
{{554706782883015769ull, 9340407748035089949ull, 2612348319576516423ull,
  7898615046828447944ull}},
{{2652534748515578808ull, 12755283870163013074ull,
  1632717699735322764ull, 4936634404267779965ull}},
{{12539040472499249317ull, 15944104837703766342ull,
  6652583143096541359ull, 6170793005334724956ull}},
{{6450428553769285838ull, 15318445028702320024ull,
  8315728928870676699ull, 7713491256668406195ull}},
{{4031517846105803649ull, 7268185133725256063ull,
  2891487571330478985ull, 4820932035417753872ull}},
{{427711289204866657ull, 13696917435583957983ull,
  3614359464163098731ull, 6026165044272192340ull}},
{{14369697166788247034ull, 12509460776052559574ull,
  4517949330203873414ull, 7532706305340240425ull}},
{{4369374710815266492ull, 3206726966605461830ull,
  14352933377445890644ull, 4707941440837650265ull}},
{{14685090425373858923ull, 4008408708256827287ull,
  4106108666525199593ull, 5884926801047062832ull}},
{{13744677013289935750ull, 9622196903748422013ull,
  5132635833156499491ull, 7356158501308828540ull}},
{{3345788211330255975ull, 7416060111258139613ull,
  6415794791445624364ull, 9195198126636035675ull}},
{{4396960641295103937ull, 13858409606391113066ull,
  1704028735439821275ull, 5746998829147522297ull}},
{{14719572838473655729ull, 12711325989561503428ull,
  6741721937727164498ull, 7183748536434402871ull}},
{{18399466048092069661ull, 6665785450097103477ull,
  3815466403731567719ull, 8979685670543003589ull}},
{{13805509289271237490ull, 11083644933951771529ull,
  4690509511545923776ull, 5612303544089377243ull}},
{{3421828556306883151ull, 13854556167439714412ull,
  1251450871005016816ull, 7015379430111721554ull}},
{{4277285695383603938ull, 17318195209299643015ull,
  10787685625611046828ull, 8769224287639651942ull}},
{{9590832587255834317ull, 1600499968957501076ull,
  2130617497579516364ull, 5480765179774782464ull}},
{{11988540734069792897ull, 2000624961196876345ull,
  2663271871974395455ull, 6850956474718478080ull}},
{{1150617862305077409ull, 16335839256778259144ull,
  3329089839967994318ull, 8563695593398097600ull}},
{{719136163940673381ull, 5598213517059024061ull, 2080681149979996449ull,
  5352309745873811000ull}},
{{5510606223353229630ull, 11609452914751167980ull,
  2600851437474995561ull, 6690387182342263750ull}},
{{6888257779191537037ull, 676758088156796263ull,
  12474436333698520260ull, 8362983977927829687ull}},
{{11222690139635792504ull, 9646345841952773472ull,
  14714051736202657018ull, 5226864986204893554ull}},
{{14028362674544740630ull, 2834560265586191032ull,
  9169192633398545465ull, 6533581232756116943ull}},
{{17535453343180925788ull, 8154886350410126694ull,
  6849804773320793927ull, 8166976540945146179ull}},
{{6347972321060690714ull, 12014332996647411040ull,
  1975284974111802252ull, 5104360338090716362ull}},
{{7934965401325863392ull, 15017916245809263800ull,
  11692478254494528623ull, 6380450422613395452ull}},
{{9918706751657329240ull, 14160709288834191846ull,
  14615597818118160779ull, 7975563028266744315ull}},
{{1587505701358442871ull, 6544600296307675952ull,
  6828905627110156535ull, 4984726892666715197ull}},
{{1984382126698053589ull, 3569064351957207036ull,
  13147818052315083573ull, 6230908615833393996ull}},
{{2480477658372566986ull, 9073016458373896699ull,
  16434772565393854466ull, 7788635769791742495ull}},
{{17691199600978712030ull, 10282321304911073340ull,
  17189261881012240897ull, 4867897356119839059ull}},
{{3667255427513838422ull, 17464587649566229580ull,
  16874891332837913217ull, 6084871695149798824ull}},
{{4584069284392298027ull, 7995676506675623263ull,
  2646870092337839906ull, 7606089618937248531ull}},
{{9782572330386268123ull, 9608983835099652443ull,
  17795194872207007605ull, 4753806011835780331ull}},
{{7616529394555447250ull, 16622915812301953458ull,
  17632307571831371602ull, 5942257514794725414ull}},
{{297289706339533254ull, 11555272728522666015ull,
  12817012427934438695ull, 7427821893493406768ull}},
{{7103335094103290140ull, 14139574482967748115ull,
  8010632767459024184ull, 4642388683433379230ull}},
{{4267482849201724771ull, 17674468103709685144ull,
  789918922469004422ull, 5802985854291724038ull}},
{{5334353561502155963ull, 12869713092782330622ull,
  10210770689941031336ull, 7253732317864655047ull}},
{{15891313988732470762ull, 16087141365977913277ull,
  8151777343998901266ull, 9067165397330818809ull}},
{{12237914252171488178ull, 14666149372163583702ull,
  16624075886067783051ull, 5666978373331761755ull}},
{{6074020778359584415ull, 13721000696777091724ull,
  16168408839157340910ull, 7083722966664702194ull}},
{{7592525972949480518ull, 7927878834116588847ull,
  10987139012091900330ull, 8854653708330877743ull}},
{{11662857760734507180ull, 9566610289750255933ull,
  13784490910198519562ull, 5534158567706798589ull}},
{{743514145635970263ull, 2734890825333044109ull, 3395555582465985741ull,
  6917698209633498237ull}},
{{5541078700472350733ull, 8030299550093693040ull,
  8856130496509870080ull, 8647122762041872796ull}},
{{3463174187795219208ull, 5018937218808558150ull,
  14758453597173444608ull, 5404451726276170497ull}},
{{13552339771598799818ull, 6273671523510697687ull,
  4613008941184642048ull, 6755564657845213122ull}},
{{12328738696071111869ull, 7842089404388372109ull,
  14989633213335578368ull, 8444455822306516402ull}},
{{10011304694258138870ull, 4901305877742732568ull,
  13980206776762124384ull, 5277784888941572751ull}},
{{12514130867822673587ull, 6126632347178415710ull,
  12863572452525267576ull, 6597231111176965939ull}},
{{6419291547923566176ull, 7658290433973019638ull,
  11467779547229196566ull, 8246538888971207424ull}},
{{17847115272734392572ull, 174745502805749369ull,
  7167362217018247854ull, 5154086805607004640ull}},
{{8473836035635827003ull, 9441803915361962520ull,
  8959202771272809817ull, 6442608507008755800ull}},
{{10592295044544783754ull, 16413940912629841054ull,
  11199003464091012271ull, 8053260633760944750ull}},
{{2008498384413101942ull, 17176242098034732515ull,
  2387691146629494765ull, 5033287896100590469ull}},
{{16345681035798541140ull, 7635244567261251931ull,
  7596299951714256361ull, 6291609870125738086ull}},
{{15820415276320788521ull, 14155741727503952818ull,
  272002902788044643ull, 7864512337657172608ull}},
{{14499445566127880730ull, 6541495570476276559ull,
  170001814242527902ull, 4915320211035732880ull}},
{{13512620939232463008ull, 17400241499950121507ull,
  212502267803159877ull, 6144150263794666100ull}},
{{12279090155613190856ull, 7915243819655488172ull,
  265627834753949847ull, 7680187829743332625ull}},
{{16897803384113020093ull, 11864556414925761963ull,
  11695232442789688414ull, 4800117393589582890ull}},
{{16510568211713887212ull, 5607323481802426646ull,
  5395668516632334710ull, 6000146741986978613ull}},
{{11414838227787583207ull, 16232526389107809116ull,
  11356271664217806291ull, 7500183427483723266ull}},
{{16357645929222015313ull, 7839485983978686745ull,
  11709355808563516836ull, 4687614642177327041ull}},
{{6611999356245355429ull, 9799357479973358432ull, 801636705422232333ull,
  5859518302721658802ull}},
{{8264999195306694286ull, 16860882868394085944ull,
  10225417918632566224ull, 7324397878402073502ull}},
{{10331248994133367857ull, 2629359511783055814ull,
  3558400361435931973ull, 9155497348002591878ull}},
{{1845344602905967007ull, 3949192704078103836ull,
  16059058281179621195ull, 5722185842501619923ull}},
{{2306680753632458758ull, 324804861670241891ull,
  15462136833047138590ull, 7152732303127024904ull}},
{{16718408997322737160ull, 9629378113942578171ull,
  880926967599371621ull, 8940915378908781131ull}},
{{8143162614113016773ull, 8324204330427805309ull,
  16691480419245464927ull, 5588072111817988206ull}},
{{14790639286068658870ull, 5793569394607368732ull,
  11640978487202055351ull, 6985090139772485258ull}},
{{41555033876271972ull, 2630275724831823012ull, 5327851072147793381ull,
  8731362674715606573ull}},
{{9249343933027445790ull, 3949765337233583334ull,
  5635749929306064815ull, 5457101671697254108ull}},
{{2338307879429531430ull, 325520653114591264ull, 7044687411632581019ull,
  6821377089621567635ull}},
{{2922884849286914287ull, 14241958871675402792ull,
  4194173246113338369ull, 8526721362026959544ull}},
{{1826803030804321430ull, 1983695267156044889ull,
  2621358278820836481ull, 5329200851266849715ull}},
{{6895189806932789691ull, 7091305102372444015ull,
  17111755903808209313ull, 6661501064083562143ull}},
{{4007301240238599210ull, 13475817396392942923ull,
  16778008861332873737ull, 8326876330104452679ull}},
{{198720265935430554ull, 1504856845104507471ull,
  17403784565974127942ull, 5204297706315282924ull}},
{{14083458387701451905ull, 11104443093235410146ull,
  3307986633758108311ull, 6505372132894103656ull}},
{{8380950947772039073ull, 9268867848116874779ull,
  4134983292197635389ull, 8131715166117629570ull}},
{{2932251333143830469ull, 8098885414286740689ull,
  7196050576050910022ull, 5082321978823518481ull}},
{{8277000184857175990ull, 900234731003650053ull,
  13606749238491025432ull, 6352902473529398101ull}},
{{14957936249498857891ull, 1125293413754562566ull,
  3173378492831618078ull, 7941128091911747627ull}},
{{4737024137509398278ull, 14538366438878765316ull,
  18124262622515618962ull, 4963205057444842266ull}},
{{5921280171886747847ull, 8949586011743680837ull,
  13431956241289747895ull, 6204006321806052833ull}},
{{12013286233285822713ull, 6575296496252213142ull,
  2954887246330021157ull, 7755007902257566042ull}},
{{2896617877376251292ull, 6415403319371327166ull,
  6458490547383651127ull, 4846879938910978776ull}},
{{12844144383575089923ull, 3407568130786771053ull,
  8073113184229563909ull, 6058599923638723470ull}},
{{2220122424186698691ull, 8871146181910851721ull, 868019443432179078ull,
  7573249904548404338ull}},
{{12916791561185156442ull, 932780345266894421ull,
  5154198170572499828ull, 4733281190342752711ull}},
{{2310931396199281841ull, 1165975431583618027ull,
  1831061694788236881ull, 5916601487928440889ull}},
{{16723722300531266013ull, 6069155307906910437ull,
  6900513136912684005ull, 7395751859910551111ull}},
{{12758169447045735210ull, 6099065076655512975ull,
  11230349738211509359ull, 4622344912444094444ull}},
{{11336025790379781109ull, 3012145327392003315ull,
  14037937172764386699ull, 5777931140555118055ull}},
{{9558346219547338482ull, 17600239714522167856ull,
  12935735447528095469ull, 7222413925693897569ull}},
{{11947932774434173102ull, 8165241587870546108ull,
  2334611254127955625ull, 9028017407117371962ull}},
{{16690830020876133997ull, 16632491038487561077ull,
  6070818052257360169ull, 5642510879448357476ull}},
{{7028479470813003784ull, 6955555742827287635ull,
  7588522565321700212ull, 7053138599310446845ull}},
{{4173913320088866826ull, 8694444678534109544ull,
  14097339225079513169ull, 8816423249138058556ull}},
{{2608695825055541766ull, 16963242970152288225ull,
  18034209052529471538ull, 5510264530711286597ull}},
{{7872555799746815112ull, 11980681675835584473ull,
  8707703260379675711ull, 6887830663389108247ull}},
{{14452380768110906794ull, 10364166076367092687ull,
  6272943057047206735ull, 8609788329236385309ull}},
{{15950267007710398602ull, 13395132825370514785ull,
  6226432419868198161ull, 5381117705772740818ull}},
{{6102775704355834541ull, 2908857976430979770ull,
  17006412561690023510ull, 6726397132215926022ull}},
{{16851841667299568984ull, 12859444507393500520ull,
  12034643665257753579ull, 8407996415269907528ull}},
{{10532401042062230615ull, 5731309807907243873ull,
  7521652290786095987ull, 5254997759543692205ull}},
{{17777187321005176173ull, 2552451241456666937ull,
  14013751381910007888ull, 6568747199429615256ull}},
{{8386426095974306504ull, 3190564051820833672ull,
  17517189227387509860ull, 8210933999287019070ull}},
{{5241516309983941565ull, 11217474569242796853ull,
  6336557248689805758ull, 5131833749554386919ull}},
{{11163581405907314860ull, 4798471174698720258ull,
  3309010542434869294ull, 6414792186942983649ull}},
{{4731104720529367767ull, 15221461005228176131ull,
  8747949196470974521ull, 8018490233678729561ull}},
{{651097441117160903ull, 2595884100626528226ull,
  16996683293862828836ull, 5011556396049205975ull}},
{{10037243838251226936ull, 3244855125783160282ull,
  16634168098901148141ull, 6264445495061507469ull}},
{{3323182760959257862ull, 8667754925656338257ull,
  6957652068344271464ull, 7830556868826884337ull}},
{{13606204271668005924ull, 5417346828535211410ull,
  15877747588783639425ull, 4894098043016802710ull}},
{{7784383302730231597ull, 11383369554096402167ull,
  10623812449124773473ull, 6117622553771003388ull}},
{{5118793109985401592ull, 394153887338338997ull,
  13279765561405966842ull, 7647028192213754235ull}},
{{5505088702954569947ull, 4858032198013849777ull,
  5994010466665035324ull, 4779392620133596397ull}},
{{11493046897120600338ull, 6072540247517312221ull,
  12104199101758682059ull, 5974240775166995496ull}},
{{531250566118586710ull, 2978989290969252373ull,
  15130248877198352574ull, 7467800968958744370ull}},
{{2637874613037810646ull, 15696926362137946445ull,
  14068091566676358262ull, 4667375605599215231ull}},
{{7909029284724651211ull, 10397785915817657248ull,
  12973428439918059924ull, 5834219506999019039ull}},
{{9886286605905814014ull, 12997232394772071560ull,
  11605099531470187001ull, 7292774383748773799ull}},
{{12357858257382267517ull, 2411482438182925738ull,
  9894688395910345848ull, 9115967979685967249ull}},
{{12335347429291305103ull, 1507176523864328586ull,
  17713395293512435915ull, 5697479987303729530ull}},
{{6195812249759355570ull, 15719028710112574445ull,
  12918372080035769085ull, 7121849984129661913ull}},
{{12356451330626582366ull, 5813727832358554344ull,
  2312907044762547645ull, 8902312480162077392ull}},
{{7722782081641613979ull, 5939422904437790417ull,
  1445566902976592278ull, 5563945300101298370ull}},
{{14265163620479405378ull, 16647650667402013829ull,
  11030330665575516155ull, 6954931625126622962ull}},
{{3996396470317093010ull, 16197877315825129383ull,
  4564541295114619386ull, 8693664531408278703ull}},
{{9415276821589264988ull, 14735359340818093768ull,
  9770367337087718972ull, 5433540332130174189ull}},
{{11769096026986581234ull, 18419199176022617210ull,
  16824645189787036619ull, 6791925415162717736ull}},
{{5487997996878450735ull, 18412312951600883609ull,
  2584062413524244158ull, 8489906768953397171ull}},
{{14959213794117501469ull, 6896009576323164351ull,
  17755940072948510263ull, 5306191730595873231ull}},
{{14087331224219488933ull, 4008325951976567535ull,
  17583239072758249925ull, 6632739663244841539ull}},
{{12997478011846973262ull, 9622093458398097323ull,
  17367362822520424502ull, 8290924579056051924ull}},
{{5817580748190664337ull, 1402122393071422923ull,
  1631229727220489506ull, 5181827861910032453ull}},
{{2660289916810942517ull, 10976025028194054462ull,
  6650723177452999786ull, 6477284827387540566ull}},
{{12548734432868453954ull, 4496659248387792269ull,
  17536776008671025541ull, 8096606034234425707ull}},
{{10148802029756477673ull, 5116255039456064120ull,
  8654641996205697011ull, 5060378771396516067ull}},
{{12686002537195597092ull, 1783632780892692246ull,
  6206616476829733360ull, 6325473464245645084ull}},
{{6634131134639720556ull, 2229540976115865308ull,
  7758270596037166700ull, 7906841830307056355ull}},
{{13369703996004601156ull, 10616835146927191625ull,
  2543076113309535235ull, 4941776143941910222ull}},
{{2877071939723587733ull, 8659357915231601628ull,
  12402217178491694852ull, 6177220179927387777ull}},
{{3596339924654484666ull, 10824197394039502035ull,
  1667713417832454853ull, 7721525224909234722ull}},
{{18388613517404910580ull, 9070966380488382723ull,
  5654006904572672187ull, 4825953265568271701ull}},
{{18374080878328750321ull, 6727021957183090500ull,
  11679194649143228138ull, 6032441581960339626ull}},
{{4520857024201386286ull, 17632149483333638934ull,
  5375621274574259364ull, 7540551977450424533ull}},
{{16660593695408030141ull, 1796721390228748525ull,
  5665606305822606055ull, 4712844985906515333ull}},
{{6990684063977873964ull, 16080959793068099369ull,
  11693693900705645472ull, 5891056232383144166ull}},
{{13350041098399730358ull, 1654455667625572595ull,
  5393745339027281033ull, 7363820290478930208ull}},
{{12075865354572275044ull, 6679755602959353648ull,
  6742181673784101291ull, 9204775363098662760ull}},
{{7547415846607671903ull, 1869004242635902078ull,
  4213863546115063307ull, 5752984601936664225ull}},
{{210897771404814070ull, 16171313358577041310ull,
  9879015451071217037ull, 7191230752420830281ull}},
{{9486994251110793396ull, 6379083642939137925ull,
  16960455332266409201ull, 8989038440526037851ull}},
{{8235214416157939824ull, 15516142322905430963ull,
  8294441573452811798ull, 5618149025328773657ull}},
{{5682332001770036876ull, 10171805866777012896ull,
  14979737985243402652ull, 7022686281660967071ull}},
{{7102915002212546095ull, 12714757333471266120ull,
  14112986463126865411ull, 8778357852076208839ull}},
{{4439321876382841310ull, 5640880324205847373ull,
  15738145567095372738ull, 5486473657547630524ull}},
{{10160838363905939541ull, 16274472442112085024ull,
  1225937885159664306ull, 6858092071934538156ull}},
{{12701047954882424426ull, 11119718515785330472ull,
  1532422356449580383ull, 8572615089918172695ull}},
{{7938154971801515267ull, 13867353100006913401ull,
  7875293000422069595ull, 5357884431198857934ull}},
{{14534379733179281987ull, 12722505356581253847ull,
  620744213672811186ull, 6697355538998572418ull}},
{{13556288648046714580ull, 6679759658871791501ull,
  9999302303945789791ull, 8371694423748215522ull}},
{{10778523414242890565ull, 11092378814435951544ull,
  10861249958393506523ull, 5232309014842634701ull}},
{{13473154267803613206ull, 9253787499617551526ull,
  18188248466419271058ull, 6540386268553293376ull}},
{{7618070797899740699ull, 2343862337667163600ull,
  4288566509314537207ull, 8175482835691616721ull}},
{{4761294248687337937ull, 8382442988683059106ull,
  14209569114390055514ull, 5109676772307260450ull}},
{{15174989847713948229ull, 1254681698999048074ull,
  8538589356132793585ull, 6387095965384075563ull}},
{{9745365272787659478ull, 6180038142176197997ull,
  6061550676738604077ull, 7983869956730094454ull}},
{{8396696304705981126ull, 6168366848073817700ull,
  17623527228243791260ull, 4989918722956309033ull}},
{{10495870380882476408ull, 7710458560092272125ull,
  8194350980022575363ull, 6237398403695386292ull}},
{{17731523994530483413ull, 5026387181687952252ull,
  10242938725028219204ull, 7796748004619232865ull}},
{{1858830459726776325ull, 12364864025409745966ull,
  17931051749211106762ull, 4872967502887020540ull}},
{{11546910111513246215ull, 6232707994907406649ull,
  3967070612804331837ull, 6091209378608775676ull}},
{{598579584109394056ull, 12402571012061646216ull,
  4958838266005414796ull, 7614011723260969595ull}},
{{374112240068371285ull, 16974978919393304693ull, 793430907039690295ull,
  4758757327038105997ull}},
{{5079326318512852011ull, 16607037630814242962ull,
  5603474652227000773ull, 5948446658797632496ull}},
{{15572529934995840821ull, 6923738983235639990ull,
  7004343315283750967ull, 7435558323497040620ull}},
{{5121145190945012609ull, 11244865892163356850ull,
  13601086608907120162ull, 4647223952185650387ull}},
{{15624803525536041570ull, 4832710328349420254ull,
  12389672242706512299ull, 5809029940232062984ull}},
{{10307632370065276154ull, 1429201892009387414ull,
  15487090303383140374ull, 7261287425290078730ull}},
{{3661168425726819384ull, 11009874401866510076ull,
  10135490842374149659ull, 9076609281612598413ull}},
{{11511602302934037923ull, 4575328491952874845ull,
  8640524785697537489ull, 5672880801007874008ull}},
{{554444823385383692ull, 10330846633368481461ull,
  10800655982121921861ull, 7091101001259842510ull}},
{{5304742047659117519ull, 17525244310137989730ull,
  4277447940797626518ull, 8863876251574803138ull}},
{{7927149798214336353ull, 6341591675408855677ull,
  7285090981425904478ull, 5539922657234251961ull}},
{{14520623266195308346ull, 17150361631115845404ull,
  13718049745209768501ull, 6924903321542814951ull}},
{{18150779082744135432ull, 7602893983612643043ull,
  12535876163084822723ull, 8656129151928518689ull}},
{{9038393917501390693ull, 2445965730544207950ull, 917393574286932346ull,
  5410080719955324181ull}},
{{2074620360021962558ull, 12280829200035035746ull,
  5758427986286053336ull, 6762600899944155226ull}},
{{11816647486882229006ull, 15351036500043794682ull,
  16421407019712342478ull, 8453251124930194032ull}},
{{11997090697728781033ull, 4982711794099983772ull,
  10263379387320214049ull, 5283281953081371270ull}},
{{14996363372160976291ull, 10840075761052367619ull,
  3605852197295491753ull, 6604102441351714088ull}},
{{14133768196773832460ull, 18161780719742847428ull,
  4507315246619364691ull, 8255128051689642610ull}},
{{18056977159838421095ull, 9045269940625585690ull,
  7428758047564490836ull, 5159455032306026631ull}},
{{13347849412943250561ull, 11306587425781982113ull,
  4674261541028225641ull, 6449318790382533289ull}},
{{2849753710896899489ull, 298176226945313930ull,
  10454512944712669956ull, 8061648487978166611ull}},
{{6392782087737950085ull, 9409732178695597014ull,
  4228227581231724770ull, 5038530304986354132ull}},
{{17214349646527213414ull, 2538793186514720459ull,
  5285284476539655963ull, 6298162881232942665ull}},
{{16906251039731628864ull, 17008549538425564286ull,
  11218291614101957857ull, 7872703601541178331ull}},
{{5954720881404880136ull, 3712814433874895823ull,
  4705589249600029709ull, 4920439750963236457ull}},
{{2831715083328712266ull, 9252704060771007683ull,
  10493672580427425040ull, 6150549688704045571ull}},
{{17374701909443054044ull, 11565880075963759603ull,
  8505404707106893396ull, 7688187110880056964ull}},
{{8553345684188214826ull, 16452047084332125560ull,
  14539249978796584180ull, 4805116944300035602ull}},
{{10691682105235268532ull, 2118314781705605334ull,
  8950690436640954418ull, 6006396180375044503ull}},
{{4141230594689309857ull, 11871265513986782476ull,
  6576677027373805118ull, 7507995225468805629ull}},
{{11811641158535594469ull, 2807854927814351143ull,
  6416266151322322151ull, 4692497015918003518ull}},
{{10152865429742105182ull, 17344876715050102641ull,
  17243704726007678496ull, 5865621269897504397ull}},
{{17302767805605019381ull, 3234351820103076685ull,
  7719572852227434409ull, 7332026587371880497ull}},
{{7793401701724110514ull, 8654625793556233761ull,
  14261152083711680915ull, 9165033234214850621ull}},
{{16400091109646038832ull, 3103298111758952148ull,
  11219063061533494524ull, 5728145771384281638ull}},
{{2053369813347996923ull, 3879122639698690186ull,
  4800456790062092347ull, 7160182214230352048ull}},
{{11790084303539771962ull, 237217281195974828ull,
  6000570987577615434ull, 8950227767787940060ull}},
{{16592174726567133285ull, 4759946819174872171ull,
  12973728904090785454ull, 5593892354867462537ull}},
{{16128532389781528702ull, 15173305560823366022ull,
  2382103074831318105ull, 6992365443584328172ull}},
{{10937293450372135069ull, 5131573895747043816ull,
  2977628843539147632ull, 8740456804480410215ull}},
{{6835808406482584418ull, 3207233684841902385ull,
  8778547054853049126ull, 5462785502800256384ull}},
{{13156446526530618427ull, 13232414142907153789ull,
  10973183818566311407ull, 6828481878500320480ull}},
{{2610500102881109321ull, 11928831660206554333ull,
  13716479773207889259ull, 8535602348125400600ull}},
{{3937405573514387278ull, 5149676778415402506ull,
  8572799858254930787ull, 5334751467578375375ull}},
{{14145129003747759905ull, 1825409954591865228ull,
  6104313804391275580ull, 6668439334472969219ull}},
{{17681411254684699881ull, 2281762443239831535ull,
  3018706237061706571ull, 8335549168091211524ull}},
{{17968411061819019282ull, 17567002591520752373ull,
  11110063435018342414ull, 5209718230057007202ull}},
{{8625455771991610390ull, 12735381202546164659ull,
  4664207256918152210ull, 6512147787571259003ull}},
{{6170133696562125084ull, 6695854466327930016ull,
  1218573052720302359ull, 8140184734464073754ull}},
{{3856333560351328178ull, 11102438069096038116ull,
  5373294176377576878ull, 5087615459040046096ull}},
{{4820416950439160222ull, 4654675549515271837ull,
  6716617720471971098ull, 6359519323800057620ull}},
{{10637207206476338181ull, 15041716473748865604ull,
  8395772150589963872ull, 7949399154750072025ull}},
{{15871626540902487172ull, 9401072796093041002ull,
  16776572640187197180ull, 4968374471718795015ull}},
{{10616161139273333156ull, 11751340995116301253ull,
  16359029781806608571ull, 6210468089648493769ull}},
{{17881887442519054349ull, 10077490225467988662ull,
  6613729171976097002ull, 7763085112060617212ull}},
{{6564493633147021064ull, 10910117409344880818ull,
  13356952769339836434ull, 4851928195037885757ull}},
{{17428989078288552138ull, 4414274724826325214ull,
  2861132906392631831ull, 6064910243797357197ull}},
{{12562864311005914365ull, 906157387605518614ull,
  8188102151418177693ull, 7581137804746696496ull}},
{{3240104175951308574ull, 2872191376467143086ull,
  5117563844636361058ull, 4738211127966685310ull}},
{{13273502256793911526ull, 12813611257438704665ull,
  15620326842650227130ull, 5922763909958356637ull}},
{{2756819765710225695ull, 6793642034943605024ull,
  5690350498030620201ull, 7403454887447945797ull}},
{{1723012353568891060ull, 15775241317908222900ull,
  5862312070482831577ull, 4627159304654966123ull}},
{{2153765441961113824ull, 5883993592103114913ull,
  2716204069676151568ull, 5783949130818707654ull}},
{{7303892820878780184ull, 7354991990128893641ull,
  12618627123949965268ull, 7229936413523384567ull}},
{{13741552044525863134ull, 9193739987661117051ull,
  11161597886510068681ull, 9037420516904230709ull}},
{{6282627018614970507ull, 17275302538356667917ull,
  9281841688282486877ull, 5648387823065144193ull}},
{{12464969791696101038ull, 7759070117663671184ull,
  16213988128780496501ull, 7060484778831430241ull}},
{{15581212239620126297ull, 14310523665506976884ull,
  6432427105693456914ull, 8825605973539287802ull}},
{{514885612907803128ull, 13555763309369248457ull,
  8631952959485798475ull, 5516003733462054876ull}},
{{5255293034562141814ull, 12333018118284172667ull,
  10789941199357248094ull, 6895004666827568595ull}},
{{1957430274775289363ull, 6192900611000440026ull,
  8875740480769172214ull, 8618755833534460744ull}},
{{5835079940161943756ull, 17705620937157438728ull,
  5547337800480732633ull, 5386722395959037965ull}},
{{7293849925202429695ull, 8296968116164634698ull,
  11545858269028303696ull, 6733402994948797456ull}},
{{18340684443357812927ull, 10371210145205793372ull,
  14432322836285379620ull, 8416753743685996820ull}},
{{2239555740243857271ull, 15705378377608396666ull,
  18243573809533138070ull, 5260471089803748012ull}},
{{12022816712159597397ull, 10408350935155720024ull,
  4357723188206870972ull, 6575588862254685016ull}},
{{15028520890199496746ull, 13010438668944650030ull,
  5447153985258588715ull, 8219486077818356270ull}},
{{4781139537947297562ull, 5825681158876712317ull,
  17239529296068781659ull, 5137178798636472668ull}},
{{10588110440861509857ull, 2670415430168502492ull,
  3102667546376425458ull, 6421473498295590836ull}},
{{13235138051076887321ull, 12561391324565403923ull,
  3878334432970531822ull, 8026841872869488545ull}},
{{5966118272709360624ull, 3239183559425989548ull,
  13953174066675052149ull, 5016776170543430340ull}},
{{7457647840886700780ull, 8660665467709874839ull,
  17441467583343815186ull, 6270970213179287925ull}},
{{4710373782680988071ull, 1602459797782567741ull,
  7966776423897605271ull, 7838712766474109907ull}},
{{5249826623389311496ull, 7919066401255186694ull,
  2673392255722309342ull, 4899195479046318692ull}},
{{15785655316091415178ull, 675460964714207559ull,
  3341740319652886678ull, 6123994348807898365ull}},
{{15120383126686881069ull, 10067698242747535257ull,
  8788861417993496251ull, 7654992936009872956ull}},
{{2532710426538218812ull, 3986468392503515584ull,
  14716410423100710965ull, 4784370585006170597ull}},
{{3165888033172773515ull, 9594771509056782384ull,
  4560454973593724994ull, 5980463231257713247ull}},
{{3957360041465966894ull, 2770092349466202172ull,
  1088882698564768339ull, 7475579039072141559ull}},
{{11696722062771005117ull, 17872208782912234021ull,
  7598080714244062067ull, 4672236899420088474ull}},
{{785844523181592684ull, 17728574960212904623ull, 274228855950301776ull,
  5840296124275110593ull}},
{{14817363709259154567ull, 3713974626556579162ull,
  4954472088365265125ull, 7300370155343888241ull}},
{{9298332599719167400ull, 9254154301623111857ull,
  10804776128883969310ull, 9125462694179860301ull}},
{{17340672920892949385ull, 1172160420087057006ull,
  9058828089766174771ull, 5703414183862412688ull}},
{{12452469114261410923ull, 15300258580390984970ull,
  11323535112207718463ull, 7129267729828015860ull}},
{{6342214355971987846ull, 14513637207061343309ull,
  14154418890259648079ull, 8911584662285019825ull}},
{{6269726981696186356ull, 15988552282054421424ull,
  1928982778771198193ull, 5569740413928137391ull}},
{{7837158727120232945ull, 6150632297285863068ull,
  16246286528746161454ull, 6962175517410171738ull}},
{{9796448408900291181ull, 16911662408462104643ull,
  11084486124077926009ull, 8702719396762714673ull}},
{{3816937246348988036ull, 3652259977647733546ull, 10274799907621900ull,
  5439199622976696671ull}},
{{13994543594791010853ull, 4565324972059666932ull,
  13847901555166691087ull, 6798999528720870838ull}},
{{17493179493488763566ull, 1094970196647195761ull,
  8086504907103588051ull, 8498749410901088548ull}},
{{4015708155789395373ull, 16825257437400355015ull,
  14277437603794518339ull, 5311718381813180342ull}},
{{407949176309356312ull, 16419885778323055865ull,
  8623424967888372116ull, 6639647977266475428ull}},
{{5121622488814083294ull, 2078113149194268215ull,
  10779281209860465146ull, 8299559971583094285ull}},
{{10118543083149883915ull, 5910506736673805538ull,
  9042893765376484668ull, 5187224982239433928ull}},
{{3424806817082579086ull, 7388133420842256923ull,
  11303617206720605835ull, 6484031227799292410ull}},
{{18116066576635387569ull, 4623480757625433249ull,
  4906149471545981486ull, 8105039034749115513ull}},
{{4405012582756035375ull, 16724733528798059493ull,
  14595558465784708188ull, 5065649396718197195ull}},
{{10117951746872432123ull, 2459172837288022750ull,
  13632762063803497332ull, 6332061745897746494ull}},
{{3424067646735764345ull, 3073966046610028438ull,
  7817580542899595857ull, 7915077182372183118ull}},
{{15975100334492016428ull, 13450443825199737533ull,
  274301820884859506ull, 4946923238982614449ull}},
{{6133817362832856823ull, 7589682744644896109ull,
  4954563294533462287ull, 6183654048728268061ull}},
{{12278957721968458932ull, 4875417412378732232ull,
  10804890136594215763ull, 7729567560910335076ull}},
{{7674348576230286833ull, 741292873523013693ull,
  15976428372226160660ull, 4830979725568959422ull}},
{{14204621738715246445ull, 926616091903767116ull,
  10747163428427925017ull, 6038724656961199278ull}},
{{17755777173394058056ull, 5769956133307096799ull,
  4210582248680130463ull, 7548405821201499098ull}},
{{18014889761012368141ull, 10523751610958017355ull,
  7243299923852469443ull, 4717753638250936936ull}},
{{17906926182838072272ull, 8543003495270133790ull,
  9054124904815586804ull, 5897192047813671170ull}},
{{13160285691692814532ull, 10678754369087667238ull,
  2094284094164707697ull, 7371490059767088963ull}},
{{7226985077761242357ull, 17960128979786971952ull,
  16452913172988048333ull, 9214362574708861203ull}},
{{4516865673600776473ull, 13530923621580551422ull,
  7977227723903836256ull, 5758976609193038252ull}},
{{14869454128855746400ull, 16913654526975689277ull,
  9971534654879795320ull, 7198720761491297815ull}},
{{4751759605787519288ull, 2695324085010059981ull,
  7852732300172356247ull, 8998400951864122269ull}},
{{5275692762830893507ull, 8602106580772369344ull,
  7213800696821416606ull, 5624000594915076418ull}},
{{6594615953538616883ull, 1529261189110685872ull,
  18240622907881546566ull, 7030000743643845522ull}},
{{8243269941923271104ull, 11134948523243133148ull,
  13577406597997157399ull, 8787500929554806903ull}},
{{14375415750556820248ull, 13876871854668040073ull,
  15403408151389305230ull, 5492188080971754314ull}},
{{4134211632913861598ull, 8122717781480274284ull,
  10030888152381855730ull, 6865235101214692893ull}},
{{5167764541142326998ull, 930025189995567047ull,
  17150296208904707567ull, 8581543876518366116ull}},
{{10147381865855036230ull, 7498794771388311260ull,
  1495563093710666421ull, 5363464922823978823ull}},
{{12684227332318795287ull, 13985179482662776979ull,
  15704511922420496738ull, 6704331153529973528ull}},
{{11243598146971106205ull, 8258102316473695416ull,
  1183895829316069307ull, 8380413941912466911ull}},
{{7027248841856941378ull, 2855470938582365683ull,
  7657463920963625173ull, 5237758713695291819ull}},
{{4172375033893788819ull, 8181024691655345008ull,
  4960143882777143562ull, 6547198392119114774ull}},
{{5215468792367236023ull, 1002908827714405452ull,
  15423551890326205261ull, 8183997990148893467ull}},
{{12483040032084298323ull, 2932661026535197359ull,
  7333876922240184336ull, 5114998743843058417ull}},
{{10992114021677984999ull, 3665826283168996699ull,
  13779032171227618324ull, 6393748429803823021ull}},
{{9128456508670093345ull, 4582282853961245874ull,
  3388732158752359193ull, 7992185537254778777ull}},
{{10316971336346196245ull, 14393141829794248431ull,
  13647172645288694255ull, 4995115960784236735ull}},
{{8284528152005357402ull, 13379741268815422635ull,
  12447279788183479915ull, 6243894950980295919ull}},
{{5743974171579308848ull, 12112990567591890390ull,
  10947413716801961990ull, 7804868688725369899ull}},
{{17425041912519231742ull, 2958933086317543589ull,
  4536290563787532292ull, 4878042930453356187ull}},
{{7946244335366875966ull, 3698666357896929487ull,
  1058677186307027461ull, 6097553663066695234ull}},
{{5321119400781207053ull, 9235018965798549763ull,
  10546718519738560134ull, 7621942078833369042ull}},
{{1019856616274560456ull, 1160200835196705698ull,
  11203385093263987988ull, 4763713799270855651ull}},
{{10498192807197976378ull, 1450251043995882122ull,
  9392545348152597081ull, 5954642249088569564ull}},
{{3899368972142694665ull, 6424499823422240557ull,
  11740681685190746351ull, 7443302811360711955ull}},
{{4742948616802878118ull, 10932841417279982204ull,
  5032083044030522517ull, 4652064257100444972ull}},
{{5928685771003597647ull, 18277737790027365659ull,
  6290103805038153146ull, 5815080321375556215ull}},
{{2799171195327109154ull, 13623800200679431266ull,
  3250943737870303529ull, 7268850401719445269ull}},
{{12722336031013662251ull, 3194692195567125370ull,
  8675365690765267316ull, 9086063002149306586ull}},
{{12563146037810926811ull, 11220054659084229164ull,
  10033789575155679976ull, 5678789376343316616ull}},
{{15703932547263658514ull, 14025068323855286455ull,
  12542236968944599970ull, 7098486720429145770ull}},
{{15018229665652185238ull, 8307963367964332261ull,
  6454424174325974155ull, 8873108400536432213ull}},
{{11692236550246309726ull, 2886634095764013711ull,
  6339858118167427799ull, 5545692750335270133ull}},
{{10003609669380499253ull, 17443350674987180851ull,
  12536508666136672652ull, 6932115937919087666ull}},
{{7892826068298236162ull, 3357444270024424448ull,
  6447263795816065008ull, 8665144922398859583ull}},
{{4933016292686397602ull, 2098402668765265280ull,
  10947068900026122486ull, 5415715576499287239ull}},
{{6166270365857997002ull, 11846375372811357408ull,
  9072150106605265203ull, 6769644470624109049ull}},
{{7707837957322496252ull, 10196283197586808856ull,
  15951873651683969408ull, 8462055588280136311ull}},
{{4817398723326560158ull, 6372676998491755535ull,
  16887450059943562736ull, 5288784742675085194ull}},
{{1410062385730812293ull, 7965846248114694419ull,
  11885940538074677612ull, 6610980928343856493ull}},
{{15597636037445679079ull, 9957307810143368023ull,
  1022367617311183303ull, 8263726160429820617ull}},
{{16666051551044631280ull, 13140846408980686870ull,
  12168194806887959324ull, 5164828850268637885ull}},
{{11609192401951013292ull, 16426058011225858588ull,
  1375185453327785443ull, 6456036062835797357ull}},
{{14511490502438766615ull, 15920886495604935331ull,
  6330667835087119708ull, 8070045078544746696ull}},
{{6763838554810535183ull, 727182022898308774ull, 3956667396929449818ull,
  5043778174090466685ull}},
{{17678170230367944786ull, 10132349565477661775ull,
  9557520264589200176ull, 6304722717613083356ull}},
{{17486026769532543079ull, 12665436956847077219ull,
  11946900330736500220ull, 7880903397016354195ull}},
{{8622923721744145472ull, 17139270134884199070ull,
  5160969697496618685ull, 4925564623135221372ull}},
{{1555282615325406032ull, 7589029613323085126ull,
  6451212121870773357ull, 6156955778919026715ull}},
{{11167475306011533348ull, 14097973035081244311ull,
  3452329133911078792ull, 7696194723648783394ull}},
{{13897201093898290199ull, 8811233146925777694ull,
  6769391727121812149ull, 4810121702280489621ull}},
{{8148129330518086940ull, 15625727452084610022ull,
  13073425677329653090ull, 6012652127850612026ull}},
{{961789626292832867ull, 10308787278250986720ull,
  7118410059807290555ull, 7515815159813265033ull}},
{{601118516433020542ull, 4137149039693172748ull,
  15978221333448026357ull, 4697384474883290645ull}},
{{751398145541275678ull, 9783122318043853839ull, 6137718611527869234ull,
  5871730593604113307ull}},
{{14774305737208758309ull, 3005530860700041490ull,
  3060462245982448639ull, 7339663242005141634ull}},
{{9244510134656172078ull, 17591971631157215575ull,
  13048949844332836606ull, 9174579052506427042ull}},
{{12695347861801189405ull, 6383296251045871830ull,
  12767279671135410783ull, 5734111907816516901ull}},
{{6645812790396710948ull, 3367434295379951884ull,
  2124041533637099767ull, 7167639884770646127ull}},
{{8307265987995888685ull, 18044350924507103567ull,
  16490109972328538420ull, 8959549855963307658ull}},
{{12109570270138512284ull, 2054347290962163921ull,
  14918004751132724417ull, 5599718659977067286ull}},
{{1301904782390976643ull, 7179620132130092806ull,
  9424133902061129713ull, 6999648324971334108ull}},
{{10850753014843496612ull, 13586211183590003911ull,
  11780167377576412141ull, 8749560406214167635ull}},
{{13699249661918267239ull, 10797224998957446396ull,
  5056761601771563636ull, 5468475253883854772ull}},
{{17124062077397834048ull, 13496531248696807995ull,
  6320952002214454545ull, 6835594067354818465ull}},
{{16793391578319904656ull, 3035606005588846282ull,
  12512876021195456086ull, 8544492584193523081ull}},
{{15107555754877328314ull, 15732311808775192638ull,
  903018485606078197ull, 5340307865120951926ull}},
{{9661072656741884585ull, 5830331705686827086ull,
  10352145143862373555ull, 6675384831401189907ull}},
{{2852968784072579923ull, 2676228613681145954ull,
  8328495411400579040ull, 8344231039251487384ull}},
{{6394791508472750356ull, 1672642883550716221ull,
  5205309632125361900ull, 5215144399532179615ull}},
{{12605175404018325849ull, 2090803604438395276ull,
  1894951021729314471ull, 6518930499415224519ull}},
{{15756469255022907311ull, 16448562560830157807ull,
  16203746832443806800ull, 8148663124269030648ull}},
{{16765322312030398926ull, 10280351600518848629ull,
  10127341770277379250ull, 5092914452668144155ull}},
{{7121594834755834945ull, 3627067463793784979ull,
  8047491194419336159ull, 6366143065835180194ull}},
{{4290307525017405777ull, 18368892385024394936ull,
  835991956169394390ull, 7957678832293975243ull}},
{{2681442203135878611ull, 6868871722212858931ull,
  16663396037101729158ull, 4973549270183734526ull}},
{{17186860809202011975ull, 17809461689620849471ull,
  11605873009522385639ull, 6216936587729668158ull}},
{{16871889993075127065ull, 17650141093598673935ull,
  5283969225048206241ull, 7771170734662085198ull}},
{{17462460273313036272ull, 4113809155858089353ull,
  17137538820937292613ull, 4856981709163803248ull}},
{{7993017286359131628ull, 9753947463249999596ull,
  2975179452462064150ull, 6071227136454754061ull}},
{{9991271607948914534ull, 2969062292207723687ull,
  8330660334004968092ull, 7589033920568442576ull}},
{{13162073782609153440ull, 11079035969484603112ull,
  5206662708753105057ull, 4743146200355276610ull}},
{{16452592228261441800ull, 13736906573590178ull,
  15731700422796157130ull, 5928932750444095762ull}},
{{11342368248472026442ull, 9240543170071763531ull,
  10441253491640420604ull, 7411165938055119703ull}},
{{4783137146081322574ull, 14998711518149628015ull,
  13443312459916344733ull, 4631978711284449814ull}},
{{1367235414174265314ull, 4913331342404871307ull,
  7580768538040655109ull, 5789973389105562268ull}},
{{15544102322999995354ull, 10753350196433477037ull,
  9475960672550818886ull, 7237466736381952835ull}},
{{5595069848467830481ull, 4218315708687070489ull,
  7233264822261135704ull, 9046833420477441044ull}},
{{15026133701360863811ull, 2636447317929419055ull,
  13744162550767985623ull, 5654270887798400652ull}},
{{14170981108273691859ull, 17130617202693937531ull,
  17180203188459982028ull, 7067838609748000815ull}},
{{13102040366914726920ull, 2966527429657870298ull,
  16863567967147589632ull, 8834798262185001019ull}},
{{12800461247749092229ull, 1854079643536168936ull,
  8233886970253549568ull, 5521748913865625637ull}},
{{16000576559686365286ull, 2317599554420211170ull,
  14904044731244324864ull, 6902186142332032046ull}},
{{10777348662753180800ull, 2896999443025263963ull,
  9406683877200630272ull, 8627732677915040058ull}},
{{4429999905007044048ull, 1810624651890789977ull,
  10490863441677781824ull, 5392332923696900036ull}},
{{10149185899686192964ull, 2263280814863487471ull,
  13113579302097227280ull, 6740416154621125045ull}},
{{8074796356180353301ull, 2829101018579359339ull,
  2556916072339370388ull, 8425520193276406307ull}},
{{2740904713399026861ull, 10991560173466875395ull,
  17738973609707964156ull, 5265950120797753941ull}},
{{17261188947030947288ull, 13739450216833594243ull,
  8338658956852791483ull, 6582437650997192427ull}},
{{16964800165361296206ull, 12562626752614604900ull,
  5811637677638601450ull, 8228047063746490534ull}},
{{1379628066496034321ull, 12463327738811515967ull,
  17467331603806289618ull, 5142529414841556583ull}},
{{15559593138402206613ull, 6355787636659619150ull,
  17222478486330474119ull, 6428161768551945729ull}},
{{10226119386147982458ull, 3333048527397136034ull,
  7693040052630928937ull, 8035202210689932162ull}},
{{11003010634769876941ull, 13612370375691679781ull,
  9419836051321718489ull, 5022001381681207601ull}},
{{18365449311889734080ull, 3180404914332436014ull,
  16386481082579536016ull, 6277501727101509501ull}},
{{13733439603007391792ull, 3975506142915545018ull,
  6648043297942256308ull, 7846877158876886877ull}},
{{13195085770307007774ull, 11708063376176991444ull,
  6460870070427604144ull, 4904298224298054298ull}},
{{16493857212883759717ull, 14635079220221239305ull,
  17299459624889280988ull, 6130372780372567872ull}},
{{6782263460822535934ull, 18293849025276549132ull,
  3177580457402049619ull, 7662965975465709841ull}},
{{13462286699868860767ull, 9127812631584149255ull,
  13515202831944750772ull, 4789353734666068650ull}},
{{12216172356408688055ull, 11409765789480186569ull,
  7670631503076162657ull, 5986692168332585813ull}},
{{1435157390228696356ull, 427149181568069500ull,
  14199975397272591226ull, 7483365210415732266ull}},
{{10120345405747711031ull, 4878654256907431341ull,
  13486670641722757420ull, 4677103256509832666ull}},
{{17262117775612026693ull, 6098317821134289176ull,
  7634966265298670967ull, 5846379070637290833ull}},
{{3130903145805481750ull, 3011211257990473567ull,
  14155393850050726613ull, 7307973838296613541ull}},
{{17748686987539015899ull, 8375700090915479862ull,
  3859184257281244554ull, 9134967297870766927ull}},
{{6481243348784497033ull, 9846498575249562818ull,
  9329519188441859702ull, 5709354561169229329ull}},
{{17324926222835397099ull, 3084751182207177714ull,
  16273585003979712532ull, 7136693201461536661ull}},
{{12432785741689470566ull, 3855938977758972143ull,
  6506923199692476953ull, 8920866501826920827ull}},
{{14688020116197000960ull, 13939176907167827349ull,
  1760983990594104143ull, 5575541563641825517ull}},
{{4524967089964087488ull, 12812285115532396283ull,
  6812916006670018083ull, 6969426954552281896ull}},
{{1044522844027721455ull, 11403670375988107450ull,
  8516145008337522604ull, 8711783693190352370ull}},
{{5264512795944713814ull, 16350666021847342964ull,
  9934276648638339531ull, 5444864808243970231ull}},
{{6580640994930892267ull, 15826646508881790801ull,
  7806159792370536510ull, 6806081010304962789ull}},
{{12837487262091003238ull, 10559936099247462693ull,
  14369385758890558542ull, 8507601262881203486ull}},
{{10329272548020570976ull, 1988274043602276279ull,
  4369180080879211185ull, 5317250789300752179ull}},
{{8299904666598325816ull, 7097028572930233253ull, 849789082671626077ull,
  6646563486625940224ull}},
{{14986566851675295173ull, 13482971734590179470ull,
  1062236353339532596ull, 8308204358282425280ull}},
{{4754918263869671580ull, 17650229370973637977ull,
  663897720837207872ull, 5192627723926515800ull}},
{{10555333848264477378ull, 3616042640007495855ull,
  829872151046509841ull, 6490784654908144750ull}},
{{8582481291903208819ull, 9131739318436757723ull,
  10260712225662913109ull, 8113480818635180937ull}},
{{3058207798225811560ull, 8013180083236667529ull,
  17942160187107790453ull, 5070925511646988085ull}},
{{8434445766209652354ull, 14628161122473222315ull,
  8592642178602574354ull, 6338656889558735107ull}},
{{5931371189334677538ull, 9061829366236752086ull,
  6129116704825830039ull, 7923321111948418884ull}},
{{17542165048616337174ull, 12581172381539051909ull,
  13054069977370919582ull, 4952075694967761802ull}},
{{8092648255488257755ull, 6503093440069039079ull,
  7094215434858873670ull, 6190094618709702253ull}},
{{5504124300932934289ull, 17352238836941074657ull,
  13479455312000979991ull, 7737618273387127816ull}},
{{14969292734151553691ull, 17762678300729253516ull,
  8424659570000612494ull, 4836011420866954885ull}},
{{264871843979890498ull, 12979975839056791088ull,
  15142510480928153522ull, 6045014276083693606ull}},
{{331089804974863122ull, 7001597761966213052ull, 9704766064305416095ull,
  7556267845104617008ull}},
{{9430303164964065259ull, 11293527628869965013ull,
  6065478790190885059ull, 4722667403190385630ull}},
{{16399564974632469478ull, 9505223517660068362ull,
  16805220524593382132ull, 5903334253987982037ull}},
{{11276084181435811040ull, 11881529397075085453ull,
  7171467600459563953ull, 7379167817484977547ull}},
{{9353395622611075852ull, 508426845530846552ull, 2176324241073533519ull,
  4611979885928110967ull}},
{{11691744528263844815ull, 14470591612195721902ull,
  16555463356624080610ull, 5764974857410138708ull}},
{{5391308623475030210ull, 8864867478389876570ull,
  2247585122070549147ull, 7206218571762673386ull}},
{{15962507816198563571ull, 6469398329559957808ull,
  12032853439442962242ull, 9007773214703341732ull}},
{{9976567385124102232ull, 8655059974402361534ull,
  16743905436506627209ull, 5629858259189588582ull}},
{{3247337194550351982ull, 15430510986430339822ull,
  11706509758778508203ull, 7037322823986985728ull}},
{{13282543530042715785ull, 14676452714610536873ull,
  14633137198473135254ull, 8796653529983732160ull}},
{{1384060678635615510ull, 4561096928204197642ull,
  9145710749045709534ull, 5497908456239832600ull}},
{{10953447885149295195ull, 14924743197110022860ull,
  11432138436307136917ull, 6872385570299790750ull}},
{{13691809856436618994ull, 4820870941105364863ull,
  5066801008529145339ull, 8590481962874738438ull}},
{{15474910187913968727ull, 707201328977159087ull,
  17001808685612879549ull, 5369051226796711523ull}},
{{14731951716465073005ull, 5495687679648836763ull,
  16640574838588711532ull, 6711314033495889404ull}},
{{13803253627153953352ull, 6869609599561045954ull,
  2353974474526337799ull, 8389142541869861756ull}},
{{13238719535398608749ull, 11211035027366735577ull,
  10694606083433736932ull, 5243214088668663597ull}},
{{2713341363966097225ull, 14013793784208419472ull,
  17979943622719559069ull, 6554017610835829496ull}},
{{3391676704957621531ull, 3682184174978360628ull,
  4028185454689897221ull, 8192522013544786871ull}},
{{11343169977453289265ull, 4607208118575169344ull,
  9435144936822267619ull, 5120326258465491794ull}},
{{14178962471816611581ull, 1147324129791573776ull,
  2570559134173058716ull, 6400407823081864743ull}},
{{17723703089770764476ull, 1434155162239467220ull,
  17048256972998487107ull, 8000509778852330928ull}},
{{1853942394251951990ull, 17037248040895524677ull,
  10655160608124054441ull, 5000318611782706830ull}},
{{6929114011242327891ull, 7461501995837242134ull,
  4095578723300292244ull, 6250398264728383538ull}},
{{17884764550907685672ull, 9326877494796552667ull,
  14342845440980141113ull, 7812997830910479422ull}},
{{8872134835103609593ull, 17358513480316315177ull,
  4352592382185200291ull, 4883123644319049639ull}},
{{15701854562306899895ull, 17086455831968006067ull,
  829054459304112460ull, 6103904555398812049ull}},
{{15015632184456236965ull, 2911325716250455968ull,
  5648004092557528480ull, 7629880694248515061ull}},
{{9384770115285148103ull, 1819578572656534980ull,
  5835845567062149252ull, 4768675433905321913ull}},
{{11730962644106435129ull, 2274473215820668725ull,
  11906492977255074469ull, 5960844292381652391ull}},
{{828645249850880199ull, 7454777538203223811ull,
  10271430203141455182ull, 7451055365477065489ull}},
{{16658804345652657788ull, 47549942949626977ull,
  17948858923031879249ull, 4656909603423165930ull}},
{{6988447376783658523ull, 4671123447114421626ull,
  13212701616935073253ull, 5821137004278957413ull}},
{{17958931257834348962ull, 10450590327320414936ull,
  2680818965886677854ull, 7276421255348696767ull}},
{{4001919998583384587ull, 3839865872295742863ull,
  17186081762640511030ull, 9095526569185870958ull}},
{{9418729026755697223ull, 16234974225467003001ull,
  6129615083222931489ull, 5684704105741169349ull}},
{{16385097301872009432ull, 6458659726551590039ull,
  12273704872456052266ull, 7105880132176461686ull}},
{{15869685608912623886ull, 17296696695044263357ull,
  6118759053715289524ull, 8882350165220577108ull}},
{{12224396514784083881ull, 1587063397547888790ull,
  13047596445426831761ull, 5551468853262860692ull}},
{{6057123606625329043ull, 6595515265362248892ull,
  16309495556783539701ull, 6939336066578575865ull}},
{{7571404508281661304ull, 12856080100130199019ull,
  6551811390697260914ull, 8674170083223219832ull}},
{{2426284808462344363ull, 12646736081008762291ull,
  4094882119185788071ull, 5421356302014512395ull}},
{{16867914065860094166ull, 11196734082833564959ull,
  506916630554847185ull, 6776695377518140494ull}},
{{16473206563897729803ull, 160859548259792487ull,
  9857017825048334790ull, 8470869221897675617ull}},
{{17213283130077162983ull, 13935595272944534016ull,
  17689851186723679003ull, 5294293263686047260ull}},
{{3069859838886902113ull, 12807808072753279617ull,
  3665569909695047138ull, 6617866579607559076ull}},
{{8449010817036015545ull, 6786388054086823713ull,
  4581962387118808923ull, 8272333224509448845ull}},
{{16809846806715979476ull, 1935649524590570868ull,
  5169569501162949529ull, 5170208265318405528ull}},
{{2565564434685422729ull, 7031247924165601490ull,
  6461961876453686911ull, 6462760331648006910ull}},
{{12430327580211554219ull, 4177373886779613958ull,
  17300824382421884447ull, 8078450414560008637ull}},
{{3157268719204833483ull, 9528387706878340580ull,
  13118858248227371731ull, 5049031509100005398ull}},
{{3946585899006041853ull, 7298798615170537821ull,
  7175200773429438856ull, 6311289386375006748ull}},
{{9544918392184940221ull, 9123498268963172276ull,
  8969000966786798570ull, 7889111732968758435ull}},
{{15188946031970363446ull, 10313872436529370576ull,
  3299782595028055154ull, 4930694833105474022ull}},
{{539438466253402691ull, 3668968508806937413ull,
  13348100280639844751ull, 6163368541381842527ull}},
{{5285984101244141268ull, 18421268691290835478ull,
  12073439332372418034ull, 7704210676727303159ull}},
{{17138798118559752005ull, 16124978950484160077ull,
  14463428610373843127ull, 4815131672954564474ull}},
{{7588439592917526294ull, 15544537669677812193ull,
  8855913726112528101ull, 6018914591193205593ull}},
{{14097235509574295771ull, 5595614031815101529ull,
  15681578176068048031ull, 7523643238991506991ull}},
{{1893243165842853001ull, 10414787797525520312ull,
  16718515387683611875ull, 4702277024369691869ull}},
{{2366553957303566251ull, 8406798728479512486ull,
  7063086179322351132ull, 5877846280462114837ull}},
{{12181564483484233622ull, 10508498410599390607ull,
  13440543742580326819ull, 7347307850577643546ull}},
{{10615269585927904124ull, 8523936994821850355ull,
  7577307641370632716ull, 9184134813222054433ull}},
{{4328700481991246125ull, 14550832658618432280ull,
  16265032321925115207ull, 5740084258263784020ull}},
{{5410875602489057657ull, 13576854804845652446ull,
  1884546328696842393ull, 7175105322829730026ull}},
{{15986966539966097879ull, 3136010450774901845ull,
  11579054947725828800ull, 8968881653537162532ull}},
{{12297697096692505126ull, 1960006531734313653ull,
  16460281379183418808ull, 5605551033460726582ull}},
{{1537063315583467696ull, 2450008164667892067ull,
  11351979687124497702ull, 7006938791825908228ull}},
{{15756387199761498332ull, 12285882242689640891ull,
  14189974608905622127ull, 8758673489782385285ull}},
{{7541898990637242505ull, 14596205429322107413ull,
  11174577139779707781ull, 5474170931113990803ull}},
{{14039059756723941036ull, 4410198731370470554ull,
  9356535406297246823ull, 6842713663892488504ull}},
{{8325452659050150487ull, 901062395785700289ull,
  11695669257871558529ull, 8553392079865610630ull}},
{{16732622957974813814ull, 12092379043434532440ull,
  2698107267742336176ull, 5345870049916006644ull}},
{{2469034623758965652ull, 15115473804293165551ull,
  3372634084677920220ull, 6682337562395008305ull}},
{{16921351334980870776ull, 447598181656905322ull,
  8827478624274788180ull, 8352921952993760381ull}},
{{15187530602790432139ull, 9503120900390341634ull,
  7823017149385436564ull, 5220576220621100238ull}},
{{9761041216633264366ull, 11878901125487927043ull,
  555399399877019897ull, 6525720275776375298ull}},
{{7589615502364192554ull, 1013568351577745092ull,
  9917621286701050680ull, 8157150344720469122ull}},
{{13966881725832396154ull, 633480219736090682ull,
  10810199322615544579ull, 5098218965450293201ull}},
{{8235230120435719385ull, 14626908329952277065ull,
  18124435171696818627ull, 6372773706812866501ull}},
{{14905723668972037135ull, 13671949394012958427ull,
  8820485909338859572ull, 7965967133516083127ull}},
{{7010234283893829257ull, 17768340408112874825ull,
  12430332720977869088ull, 4978729458447551954ull}},
{{13374478873294674476ull, 3763681436431541915ull,
  6314543864367560553ull, 6223411823059439943ull}},
{{12106412573190955190ull, 9316287813966815298ull,
  3281493812032062787ull, 7779264778824299929ull}},
{{12178193876671734898ull, 3516836874515565609ull,
  13580148678588509002ull, 4862040486765187455ull}},
{{1387684290557504911ull, 13619418129999232820ull,
  12363499829808248348ull, 6077550608456484319ull}},
{{1734605363196881138ull, 17024272662499041025ull,
  10842688768832922531ull, 7596938260570605399ull}},
{{12613343398066520472ull, 8334327404848206688ull,
  13694209508161658438ull, 4748086412856628374ull}},
{{15766679247583150589ull, 1194537219205482552ull,
  7894389848347297240ull, 5935108016070785468ull}},
{{1261604985769386620ull, 1493171524006853191ull,
  9867987310434121550ull, 7418885020088481835ull}},
{{7706032143746948494ull, 14768290257786446956ull,
  3861649059807632016ull, 4636803137555301147ull}},
{{9632540179683685617ull, 13618748523507079ull, 215375306332152117ull,
  5796003921944126434ull}},
{{7428989206177219118ull, 4628709454081771753ull,
  9492591169769965954ull, 7245004902430158042ull}},
{{13897922526148911801ull, 15009258854456990499ull,
  2642366925357681634ull, 9056256128037697553ull}},
{{6380358569629375924ull, 13992472802463006966ull,
  13180694374417020781ull, 5660160080023560970ull}},
{{17198820248891495712ull, 3655532947796594995ull,
  7252495931166500169ull, 7075200100029451213ull}},
{{16886839292686981736ull, 9181102203173131648ull,
  13677305932385513115ull, 8844000125036814016ull}},
{{10554274557929363585ull, 3432345867769513328ull,
  8548316207740945697ull, 5527500078148008760ull}},
{{13192843197411704482ull, 8902118353139279564ull,
  10685395259676182121ull, 6909375097685010950ull}},
{{16491053996764630602ull, 15739333959851487359ull,
  4133372037740451843ull, 8636718872106263688ull}},
{{17224437775618975982ull, 7531240715693485647ull,
  2583357523587782402ull, 5397949295066414805ull}},
{{16918861201096332074ull, 190678857762081251ull,
  7840882922912115907ull, 6747436618833018506ull}},
{{16536890482943027188ull, 14073406627484765276ull,
  577731616785369075ull, 8434295773541273133ull}},
{{1112184514984616185ull, 6490036132964284346ull,
  2666925269704549624ull, 5271434858463295708ull}},
{{10613602680585546039ull, 8112545166205355432ull,
  3333656587130687030ull, 6589293573079119635ull}},
{{13267003350731932549ull, 917309420901918482ull,
  18002128789195522500ull, 8236616966348899543ull}},
{{12903563112634845747ull, 9796690424918474859ull,
  18168859520888283418ull, 5147885603968062214ull}},
{{11517767872366169280ull, 3022490994293317766ull,
  13487702364255578465ull, 6434857004960077768ull}},
{{5173837803602935792ull, 8389799761294035112ull,
  16859627955319473081ull, 8043571256200097210ull}},
{{3233648627251834870ull, 16772839896877241705ull,
  15148953490502058579ull, 5027232035125060756ull}},
{{8653746802492181491ull, 16354363852669164227ull,
  489447789418021608ull, 6284040043906325946ull}},
{{6205497484687838960ull, 1996210742126903668ull,
  9835181773627302819ull, 7855050054882907432ull}},
{{13101807964784675158ull, 17388532778325172456ull,
  6146988608517064261ull, 4909406284301817145ull}},
{{16377259955980843948ull, 7900607917624301858ull,
  12295421779073718231ull, 6136757855377271431ull}},
{{11248202908121279126ull, 5264073878602989419ull,
  10757591205414759885ull, 7670947319221589289ull}},
{{4724283808362105502ull, 5595889183340562339ull,
  18252709549452694688ull, 4794342074513493305ull}},
{{1293668742025243974ull, 6994861479175702924ull,
  8980828881533704648ull, 5992927593141866632ull}},
{{1617085927531554967ull, 8743576848969628655ull,
  11226036101917130810ull, 7491159491427333290ull}},
{{7928207732348303710ull, 10076421549033405813ull,
  11627958582125594660ull, 4681974682142083306ull}},
{{14521945683862767542ull, 12595526936291757266ull,
  5311576190802217517ull, 5852468352677604133ull}},
{{8929060067973683619ull, 1909350615082532871ull,
  11251156256930159801ull, 7315585440847005166ull}},
{{6549639066539716620ull, 6998374287280553993ull,
  4840573284307923943ull, 9144481801058756458ull}},
{{15622739462655792648ull, 11291512957191428101ull,
  7637044321119840368ull, 5715301125661722786ull}},
{{5693366273037577097ull, 14114391196489285127ull,
  322933364545024652ull, 7144126407077153483ull}},
{{2505021822869583468ull, 17642988995611606409ull,
  14238724760963444527ull, 8930158008846441853ull}},
{{13094853685361959428ull, 17944397149898335861ull,
  11205045984815846781ull, 5581348755529026158ull}},
{{2533509051420285572ull, 8595438382090756115ull,
  4782935444165032669ull, 6976685944411282698ull}},
{{17001944369557520677ull, 15355983996040833047ull,
  15202041342061066644ull, 8720857430514103372ull}},
{{17543744258614532279ull, 374117960670744846ull, 277903801933390845ull,
  5450535894071314608ull}},
{{12706308286413389541ull, 5079333469265818962ull,
  347379752416738556ull, 6813169867589143260ull}},
{{6659513321161961118ull, 6349166836582273703ull, 434224690520923195ull,
  8516462334486429075ull}},
{{11079724853367307555ull, 1662386263650227112ull,
  16412291496071434661ull, 5322788959054018171ull}},
{{13849656066709134444ull, 6689668847990171794ull,
  15903678351661905422ull, 6653486198817522714ull}},
{{8088698046531642247ull, 17585458096842490551ull,
  10656225902722605969ull, 8316857748521903393ull}},
{{11972965306723358260ull, 4073382282885474738ull,
  18189356235270098491ull, 5198036092826189620ull}},
{{5742834596549422017ull, 480041835179455519ull, 4289951220378071498ull,
  6497545116032737026ull}},
{{2566857227259389617ull, 9823424330829095207ull,
  14585811062327365180ull, 8121931395040921282ull}},
{{8521814794678200367ull, 15363012243622960312ull,
  13727817932381991141ull, 5076207121900575801ull}},
{{10652268493347750459ull, 5368707249246536678ull,
  3324714360195325215ull, 6345258902375719752ull}},
{{4091963579829912265ull, 2099198043130782944ull,
  4155892950244156519ull, 7931573627969649690ull}},
{{2557477237393695166ull, 8229527804597821196ull,
  7209119112329985728ull, 4957233517481031056ull}},
{{3196846546742118957ull, 10286909755747276495ull,
  9011398890412482160ull, 6196541896851288820ull}},
{{17831116238709812409ull, 12858637194684095618ull,
  11264248613015602700ull, 7745677371064111025ull}},
{{15756133667621020660ull, 17260020283532335569ull,
  122626355493669831ull, 4841048356915069391ull}},
{{5860109029244112112ull, 16963339335988031558ull,
  13988340999649251001ull, 6051310446143836738ull}},
{{16548508323409915948ull, 7369116114702875735ull,
  8262054212706787944ull, 7564138057679795923ull}},
{{17260346729772279324ull, 4605697571689297334ull,
  2857940873728048513ull, 4727586286049872452ull}},
{{12352061375360573347ull, 10368807983039009572ull,
  3572426092160060641ull, 5909482857562340565ull}},
{{15440076719200716683ull, 17572695997226149869ull,
  9077218633627463705ull, 7386853571952925706ull}},
{{11955890958714141879ull, 4065405970625261812ull,
  10284947664444552720ull, 4616783482470578566ull}},
{{14944863698392677349ull, 5081757463281577265ull,
  3632812543700915092ull, 5770979353088223208ull}},
{{4846021567708682974ull, 6352196829101971582ull,
  4541015679626143865ull, 7213724191360279010ull}},
{{15280898996490629525ull, 12551932054804852381ull,
  14899641636387455639ull, 9017155239200348762ull}},
{{11856404882020337406ull, 14762486561894114594ull,
  13923962041169547678ull, 5635722024500217976ull}},
{{5597134065670645949ull, 9229736165512867435ull,
  17404952551461934598ull, 7044652530625272470ull}},
{{2384731563660919532ull, 2313798170036308486ull,
  12532818652472642440ull, 8805815663281590588ull}},
{{15325515282570238420ull, 1446123856272692803ull,
  17056383694650177333ull, 5503634789550994117ull}},
{{14545208084785410120ull, 6419340838768253908ull,
  7485421563030557954ull, 6879543486938742647ull}},
{{18181510105981762650ull, 17247548085315093193ull,
  4745090935360809538ull, 8599429358673428309ull}},
{{4445914788597519801ull, 15391403571749321150ull,
  5271524843814199913ull, 5374643349170892693ull}},
{{14780765522601675559ull, 5404196409404487725ull,
  11201092073195137796ull, 6718304186463615866ull}},
{{4640898847969930736ull, 6755245511755609657ull,
  4777993054639146437ull, 8397880233079519833ull}},
{{14429776826049676470ull, 6527871454060949987ull,
  14515460705217936283ull, 5248675145674699895ull}},
{{13425535014134707684ull, 3548153299148799580ull,
  13532639863095032450ull, 6560843932093374869ull}},
{{16781918767668384605ull, 13658563660790775283ull,
  3080741773586626850ull, 8201054915116718587ull}},
{{8182856220579046426ull, 13148288306421622456ull,
  18066364672987499445ull, 5125659321947949116ull}},
{{10228570275723808033ull, 2600302327744864358ull,
  4136211767524822691ull, 6407074152434936396ull}},
{{3562340807799984233ull, 17085435964963244160ull,
  5170264709406028363ull, 8008842690543670495ull}},
{{2226463004874990146ull, 8372554468888333648ull,
  10148944471019849583ull, 5005526681589794059ull}},
{{2783078756093737682ull, 5854007067683029156ull,
  8074494570347424075ull, 6256908351987242574ull}},
{{3478848445117172102ull, 2705822816176398541ull, 869746176079504286ull,
  7821135439984053218ull}},
{{4480123287411926516ull, 15526197315392412800ull,
  5155277378477078082ull, 4888209649990033261ull}},
{{5600154109264908145ull, 10184374607385740192ull,
  11055782741523735507ull, 6110262062487541576ull}},
{{7000192636581135181ull, 8118782240804787336ull,
  13819728426904669384ull, 7637827578109426970ull}},
{{4375120397863209488ull, 5074238900502992085ull,
  13249016285242806269ull, 4773642236318391856ull}},
{{10080586515756399764ull, 10954484644056128010ull,
  16561270356553507836ull, 5967052795397989820ull}},
{{3377361107840723897ull, 13693105805070160013ull,
  2254843871982333179ull, 7458815994247487276ull}},
{{4416693701614146388ull, 6252348118955156056ull,
  10632649456843734045ull, 4661759996404679547ull}},
{{5520867127017682985ull, 12427121167121332974ull,
  8679125802627279652ull, 5827199995505849434ull}},
{{16124455945626879539ull, 15533901458901666217ull,
  1625535216429323757ull, 7283999994382311793ull}},
{{6320511876751435711ull, 5582318768344919060ull,
  6643605038964042601ull, 9104999992977889741ull}},
{{13173691959824423128ull, 15018164276284044172ull,
  6458096158566220577ull, 5690624995611181088ull}},
{{16467114949780528910ull, 4937647290072891503ull,
  8072620198207775722ull, 7113281244513976360ull}},
{{15972207668798273233ull, 15395431149445890187ull,
  10090775247759719652ull, 8891601555642470450ull}},
{{7676786783785226819ull, 398772431548905559ull,
  10918420548277212687ull, 5557250972276544031ull}},
{{4984297461304145619ull, 14333523594718295661ull,
  9036339666919127954ull, 6946563715345680039ull}},
{{10842057845057569928ull, 8693532456543093768ull,
  6683738565221522039ull, 8683204644182100049ull}},
{{6776286153160981205ull, 12350986812980515461ull,
  15706551649331921034ull, 5427002902613812530ull}},
{{13082043709878614410ull, 6215361479370868518ull,
  10409817524810125485ull, 6783753628267265663ull}},
{{7129182600493492205ull, 12380887867640973552ull,
  8400585887585268952ull, 8479692035334082079ull}},
{{4455739125308432628ull, 7738054917275608470ull,
  12167895207381874951ull, 5299807522083801299ull}},
{{14793045943490316593ull, 5060882628167122683ull,
  10598182990799955785ull, 6624759402604751624ull}},
{{13879621410935507837ull, 10937789303636291258ull,
  13247728738499944731ull, 8280949253255939530ull}},
{{13286449400262080303ull, 4530275305558988084ull,
  12891516479989853361ull, 5175593283284962206ull}},
{{16608061750327600378ull, 10274530150376123009ull,
  6891023563132540893ull, 6469491604106202758ull}},
{{6925019132627336760ull, 17454848706397541666ull,
  17837151490770451924ull, 8086864505132753447ull}},
{{8939822976319473379ull, 1685908404643687733ull,
  18065748709372614309ull, 5054290315707970904ull}},
{{15786464738826729628ull, 6719071524231997570ull,
  4135441813006216270ull, 6317862894634963631ull}},
{{10509708886678636227ull, 17622211442144772771ull,
  557616247830382433ull, 7897328618293704539ull}},
{{4262725044960453690ull, 4096353123699401126ull,
  16489411219389846685ull, 4935830386433565336ull}},
{{14551778343055342921ull, 9732127423051639311ull,
  2165019950527756740ull, 6169787983041956671ull}},
{{13578036910391790747ull, 12165159278814549139ull,
  16541332993441859637ull, 7712234978802445838ull}},
{{6180430059781175265ull, 9909067558472787164ull,
  5726647102473774369ull, 4820146861751528649ull}},
{{7725537574726469081ull, 16998020466518371859ull,
  11769994896519605865ull, 6025183577189410811ull}},
{{5045235949980698447ull, 7412467527865801112ull,
  10100807602222119428ull, 7531479471486763514ull}},
{{3153272468737936530ull, 13856164241770901503ull,
  10924690769816212546ull, 4707174669679227196ull}},
{{17776648641204584374ull, 8096833265358851070ull,
  13655863462270265683ull, 5883968337099033995ull}},
{{12997438764650954659ull, 5509355563271175934ull,
  12458143309410444200ull, 7354960421373792494ull}},
{{7023426418958917516ull, 6886694454088969918ull,
  6349307099908279442ull, 9193700526717240618ull}},
{{18224699567131487160ull, 8915870052232994102ull,
  8580002955870062555ull, 5746062829198275386ull}},
{{13557502422059583141ull, 6533151546863854724ull,
  1501631657982802386ull, 7182578536497844233ull}},
{{16946878027574478926ull, 17389811470434594213ull,
  6488725590905890886ull, 8978223170622305291ull}},
{{12897641776447743281ull, 6256946150594233479ull,
  1749610485102487852ull, 5611389481638940807ull}},
{{11510366202132291197ull, 7821182688242791849ull,
  16022071161660273527ull, 7014236852048676008ull}},
{{552899697383200285ull, 5164792341876101908ull, 1580844878365790293ull,
  8767796065060845011ull}},
{{9568934347719275986ull, 5533838222886257644ull,
  17128929113474476597ull, 5479872540663028131ull}},
{{11961167934649094982ull, 11528983797035209959ull,
  16799475373415707842ull, 6849840675828785164ull}},
{{10339773899883980824ull, 5187857709439236641ull,
  2552600143060083187ull, 8562300844785981456ull}},
{{17991573733495957775ull, 936568059185828948ull,
  1595375089412551992ull, 5351438027991238410ull}},
{{4042723093160395603ull, 1170710073982286186ull,
  11217590898620465798ull, 6689297534989048012ull}},
{{14276775903305270311ull, 10686759629332633540ull,
  14021988623275582247ull, 8361621918736310015ull}},
{{18146356976420569753ull, 13596753795973977818ull,
  15681271917188320760ull, 5226013699210193759ull}},
{{13459574183670936383ull, 16995942244967472273ull,
  14989903878058013046ull, 6532517124012742199ull}},
{{2989409674306506767ull, 12021555769354564534ull,
  14125693829145128404ull, 8165646405015927749ull}},
{{15703439101723730441ull, 16736844392701378641ull,
  11134401652429399204ull, 5103529003134954843ull}},
{{5794240821872499339ull, 2474311417167171686ull,
  9306316047109361102ull, 6379411253918693554ull}},
{{16466173064195399982ull, 12316261308313740415ull,
  2409523022031925569ull, 7974264067398366943ull}},
{{17208887192763206845ull, 780134290055005903ull,
  8423480916411035337ull, 4983915042123979339ull}},
{{16899422972526620652ull, 5586853880996145283ull,
  5917665127086406267ull, 6229893802654974174ull}},
{{16512592697230887911ull, 2371881332817793700ull,
  16620453445712783642ull, 7787367253318717717ull}},
{{1096998398914529137ull, 6094111851438508967ull,
  12693626412784183728ull, 4867104533324198573ull}},
{{15206306053925325133ull, 7617639814298136208ull,
  2031974960698065948ull, 6083880666655248217ull}},
{{561138493697104800ull, 9522049767872670261ull, 7151654719299970339ull,
  7604850833319060271ull}},
{{2656554567774384452ull, 3645438095706724961ull,
  11387313227203563318ull, 4753031770824412669ull}},
{{7932379228145368469ull, 13780169656488182009ull,
  399083478722290435ull, 5941289713530515837ull}},
{{14527160053609098490ull, 12613526052182839607ull,
  5110540366830250948ull, 7426612141913144796ull}},
{{15997004061146768412ull, 17106825819469050562ull,
  12417459766123682650ull, 4641632588695715497ull}},
{{10772883039578684707ull, 12160160237481537395ull,
  1686766652372439601ull, 5802040735869644372ull}},
{{8854417781045967980ull, 1365142241569758032ull,
  2108458315465549502ull, 7252550919837055465ull}},
{{11068022226307459975ull, 10929799838816973348ull,
  7247258912759324781ull, 9065688649796319331ull}},
{{16140885928296938293ull, 9136967908474302294ull,
  2223693811260884036ull, 5666055406122699582ull}},
{{10952735373516397058ull, 11421209885592877868ull,
  12002989300930880853ull, 7082569257653374477ull}},
{{13690919216895496322ull, 441454301708933623ull,
  1168678570881437355ull, 8853211572066718097ull}},
{{15474353538200767057ull, 16416810003063941178ull,
  12259639152869368106ull, 5533257232541698810ull}},
{{10119569885896183014ull, 11297640466975150665ull,
  6101176904231934325ull, 6916571540677123513ull}},
{{17261148375797616671ull, 286992528436774619ull,
  12238157148717305811ull, 8645714425846404391ull}},
{{8482374725659816467ull, 16320271394768841801ull,
  14566377245589397987ull, 5403571516154002744ull}},
{{15214654425502158488ull, 15788653225033664347ull,
  18207971556986747484ull, 6754464395192503430ull}},
{{14406632013450310206ull, 1289072457582528818ull,
  13536592409378658548ull, 8443080493990629288ull}},
{{13615831026833831783ull, 10029042322843856319ull,
  8460370255861661592ull, 5276925308744143305ull}},
{{12408102765114901825ull, 12536302903554820399ull,
  15187148838254464894ull, 6596156635930179131ull}},
{{10898442437966239377ull, 6447006592588749691ull,
  14372250029390693214ull, 8245195794912723914ull}},
{{4505683514515205659ull, 17864437175650132269ull,
  13594342286796571162ull, 5153247371820452446ull}},
{{10243790411571394977ull, 13107174432707889528ull,
  7769555821640938145ull, 6441559214775565558ull}},
{{12804738014464243721ull, 2548909985602698198ull,
  488572740196396874ull, 8051949018469456948ull}},
{{3391275240612764422ull, 6204754759429074278ull,
  9528729999477523854ull, 5032468136543410592ull}},
{{13462466087620731335ull, 16979315486141118655ull,
  11910912499346904817ull, 6290585170679263240ull}},
{{12216396591098526265ull, 7389086302394234607ull,
  14888640624183631022ull, 7863231463349079050ull}},
{{14552776897077660772ull, 6492920569008725ull, 13917086408542157293ull,
  4914519664593174406ull}},
{{4355913066064912253ull, 4619802169138648811ull,
  8172985973822920808ull, 6143149580741468008ull}},
{{833205314153752412ull, 5774752711423311014ull,
  10216232467278651010ull, 7678936975926835010ull}},
{{14355811376628258970ull, 8220906463066957287ull,
  10996831310476544785ull, 4799335609954271881ull}},
{{13333078202357935808ull, 14887819097261084513ull,
  18357725156523068885ull, 5999169512442839851ull}},
{{2831289697665256048ull, 4774715816294191930ull,
  18335470427226448203ull, 7498961890553549814ull}},
{{6381242079468172934ull, 678354375970176004ull, 6847982998589142223ull,
  4686851181595968634ull}},
{{7976552599335216167ull, 14683001025244883717ull,
  17783350785091203586ull, 5858563976994960792ull}},
{{14582376767596408113ull, 9130379244701328838ull,
  3782444407654452867ull, 7323204971243700991ull}},
{{9004598922640734333ull, 6801288037449273144ull, 116369491140678180ull,
  9154006214054626239ull}},
{{5627874326650458958ull, 13474177060260571523ull,
  6990259959604005718ull, 5721253883784141399ull}},
{{2423156889885685794ull, 7619349288470938596ull,
  4126138931077619244ull, 7151567354730176749ull}},
{{3028946112357107242ull, 9524186610588673245ull,
  9769359682274411959ull, 8939459193412720936ull}},
{{4198934329436885979ull, 12870145659259002634ull,
  6105849801421507474ull, 5587161995882950585ull}},
{{14472039948650883281ull, 6864310037218977484ull,
  12243998270204272247ull, 6983952494853688231ull}},
{{18090049935813604101ull, 3968701528096333951ull,
  10693311819327952405ull, 8729940618567110289ull}},
{{18223810237524584419ull, 4786281464273902671ull,
  18212534933148440013ull, 5456212886604443930ull}},
{{18168076778478342620ull, 10594537848769766243ull,
  13542296629580774208ull, 6820266108255554913ull}},
{{18098409954670540371ull, 13243172310962207804ull,
  3092812731693804048ull, 8525332635319443642ull}},
{{2088134184814311924ull, 8276982694351379878ull,
  6544693975736015434ull, 5328332897074652276ull}},
{{11833539767872665713ull, 1122856331084449039ull,
  8180867469670019293ull, 6660416121343315345ull}},
{{10180238691413444237ull, 6015256432282949203ull,
  14837770355514912020ull, 8325520151679144181ull}},
{{4056806172919708696ull, 12982907307031619060ull,
  11579449481410513964ull, 5203450094799465113ull}},
{{5071007716149635870ull, 16228634133789523825ull,
  639253796480978743ull, 6504312618499331392ull}},
{{10950445663614432742ull, 15674106648809516877ull,
  799067245601223429ull, 8130390773124164240ull}},
{{9149871548972714416ull, 12102159664719642000ull,
  499417028500764643ull, 5081494233202602650ull}},
{{11437339436215893020ull, 10516013562472164596ull,
  9847643322480731612ull, 6351867791503253312ull}},
{{14296674295269866275ull, 13145016953090205745ull,
  12309554153100914515ull, 7939834739379066640ull}},
{{2017892406902584566ull, 5909792586467684639ull,
  7693471345688071572ull, 4962396712111916650ull}},
{{16357423563910394419ull, 7387240733084605798ull,
  393467145255313657ull, 6202995890139895813ull}},
{{11223407418033217216ull, 13845736934783145152ull,
  5103519949996529975ull, 7753744862674869766ull}},
{{7014629636270760760ull, 15571114611880547576ull,
  17024758024029994946ull, 4846090539171793603ull}},
{{8768287045338450950ull, 10240521227995908662ull,
  16669261511610105779ull, 6057613173964742004ull}},
{{1736986769818287879ull, 8188965516567497924ull,
  2389832815803080608ull, 7572016467455927506ull}},
{{10308988767991205733ull, 5118103447854686202ull,
  6105331528304313284ull, 4732510292159954691ull}},
{{3662863923134231358ull, 6397629309818357753ull,
  3019978391953003701ull, 5915637865199943364ull}},
{{9190265922345177101ull, 12608722655700335095ull,
  3774972989941254626ull, 7394547331499929205ull}},
{{12661445229106817544ull, 12492137678240097338ull,
  4665201127926978093ull, 4621592082187455753ull}},
{{6603434499528746122ull, 1780114042517957961ull,
  10443187428336110521ull, 5776990102734319691ull}},
{{12865979142838320557ull, 6836828571574835355ull,
  8442298266992750247ull, 7221237628417899614ull}},
{{11470787910120512792ull, 3934349696041156290ull,
  1329500796886162001ull, 9026547035522374518ull}},
{{11780928462252708399ull, 13988183606094192441ull,
  14665996053336014962ull, 5641591897201484073ull}},
{{891102522533721787ull, 8261857470762964744ull, 4497437011387854991ull,
  7051989871501855092ull}},
{{1113878153167152233ull, 5715635820026318026ull,
  5621796264234818739ull, 8814987339377318865ull}},
{{5307859864156858050ull, 1266429378302754814ull,
  15042837711215231472ull, 5509367087110824290ull}},
{{15858196867050848370ull, 1583036722878443517ull,
  9580175102164263532ull, 6886708858888530363ull}},
{{5987688028531396751ull, 1978795903598054397ull,
  7363532859277941511ull, 8608386073610662954ull}},
{{6048148027045816922ull, 8154276467389865854ull,
  9213894055476101348ull, 5380241296006664346ull}},
{{16783557070662046960ull, 10192845584237332317ull,
  2293995532490350877ull, 6725301620008330433ull}},
{{7144388283045394988ull, 17352742998724053301ull,
  7479180434040326500ull, 8406627025010413041ull}},
{{6771085686117065819ull, 1622092337347757505ull,
  16203702817343673823ull, 5254141890631508150ull}},
{{13075543126073720178ull, 15862673476966860593ull,
  11031256484824816470ull, 6567677363289385188ull}},
{{2509370852309986511ull, 10604969809353799934ull,
  13789070606031020588ull, 8209596704111731485ull}},
{{15403414837975905281ull, 15851478167700900766ull,
  10924012137983081819ull, 5130997940069832178ull}},
{{10030896510615105793ull, 15202661691198738054ull,
  4431643135624076466ull, 6413747425087290223ull}},
{{3315248601414106434ull, 9779955077143646760ull, 927867901102707679ull,
  8017184281359112779ull}},
{{2072030375883816521ull, 13030000950855861081ull,
  16720818502685049963ull, 5010740175849445486ull}},
{{7201723988282158555ull, 11675815170142438447ull,
  11677651091501536646ull, 6263425219811806858ull}},
{{4390468966925310290ull, 5371396925823272251ull,
  5373691827522145000ull, 7829281524764758573ull}},
{{438200095114624980ull, 3357123078639545157ull, 5664400401415034577ull,
  4893300952977974108ull}},
{{5159436137320669128ull, 8808089866726819350ull,
  7080500501768793221ull, 6116626191222467635ull}},
{{15672667208505612218ull, 15621798351835912091ull,
  4238939608783603622ull, 7645782739028084544ull}},
{{7489573996102313685ull, 5151937951470057153ull,
  2649337255489752264ull, 4778614211892552840ull}},
{{13973653513555280010ull, 6439922439337571441ull,
  3311671569362190330ull, 5973267764865691050ull}},
{{3632008836661936300ull, 17273275086026740110ull,
  13362961498557513720ull, 7466584706082113812ull}},
{{16105063578195873900ull, 10795796928766712568ull,
  17575222973453221883ull, 4666615441301321132ull}},
{{1684585399035290758ull, 8883060142531002807ull,
  3522284643106975738ull, 5833269301626651416ull}},
{{15940789804076277160ull, 1880453141308977700ull,
  4402855803883719673ull, 7291586627033314270ull}},
{{1479243181385794834ull, 6962252445063610030ull,
  14726941791709425399ull, 9114483283791642837ull}},
{{14759585043648285483ull, 11268936805805838124ull,
  11510181629032084826ull, 5696552052369776773ull}},
{{2737230850805238ull, 4862798970402521848ull, 552668981007942321ull,
  7120690065462220967ull}},
{{3421538563506547ull, 10690184731430540214ull, 14525894281542091613ull,
  8900862581827776208ull}},
{{13837196516884355304ull, 8987208466357781585ull,
  9078683925963807258ull, 5563039113642360130ull}},
{{3461437590823280418ull, 2010638546092451174ull,
  2124982870599983265ull, 6953798892052950163ull}},
{{13550169025383876331ull, 7124984201042951871ull,
  16491286643532142793ull, 8692248615066187703ull}},
{{15386384668506004563ull, 15982330171720314679ull,
  17224583179848671101ull, 5432655384416367314ull}},
{{14621294817205117799ull, 6142854659368229637ull,
  12307356937956063069ull, 6790819230520459143ull}},
{{4441560466224233537ull, 12290254342637674951ull,
  10772510154017690932ull, 8488524038150573929ull}},
{{9693504319031227817ull, 16904781001003322652ull,
  18262033892329526592ull, 5305327523844108705ull}},
{{12116880398789034771ull, 2684232177544601699ull,
  8992484310129744529ull, 6631659404805135882ull}},
{{10534414480058905560ull, 7966976240358140028ull,
  2017233350807404853ull, 8289574256006419853ull}},
{{15807381086891591783ull, 7285203159437531469ull,
  3566613853468321985ull, 5180983910004012408ull}},
{{5924168303332326017ull, 13718189967724302241ull,
  4458267316835402481ull, 6476229887505015510ull}},
{{12016896397592795425ull, 3312679404373214089ull,
  14796206182899028910ull, 8095287359381269387ull}},
{{593031220854415285ull, 15905482683015422518ull,
  6941785855098199116ull, 5059554599613293367ull}},
{{9964661062922794914ull, 1435109280059726531ull,
  4065546300445360992ull, 6324443249516616709ull}},
{{7844140310226105738ull, 1793886600074658164ull,
  9693618893984089144ull, 7905554061895770886ull}},
{{14125959730746091894ull, 1121179125046661352ull,
  1446825790312667811ull, 4940971288684856804ull}},
{{17657449663432614868ull, 15236531961590490402ull,
  1808532237890834763ull, 6176214110856071005ull}},
{{12848440042435992777ull, 14433978933560725099ull,
  6872351315790931358ull, 7720267638570088756ull}},
{{5724432017308801534ull, 4409550815048065283ull,
  13518591609224107907ull, 4825167274106305472ull}},
{{2543854003208614013ull, 900252500382693700ull,
  16898239511530134884ull, 6031459092632881840ull}},
{{3179817504010767516ull, 1125315625478367125ull,
  2676055315703116989ull, 7539323865791102301ull}},
{{4293228949220423650ull, 3009165275137673405ull,
  3978377581528142070ull, 4712077416119438938ull}},
{{9978222204952917466ull, 12984828630776867564ull,
  14196344013764953395ull, 5890096770149298672ull}},
{{12472777756191146832ull, 11619349770043696551ull,
  17745430017206191744ull, 7362620962686623340ull}},
{{10979286176811545636ull, 14524187212554620689ull,
  3735043447798188064ull, 9203276203358279176ull}},
{{18391268906575685783ull, 9077617007846637930ull,
  2334402154873867540ull, 5752047627098924485ull}},
{{13765714096364831420ull, 11347021259808297413ull,
  7529688712019722329ull, 7190059533873655606ull}},
{{3372084565173875563ull, 348718519478208055ull, 188738853169877104ull,
  8987574417342069508ull}},
{{9025081880874754083ull, 217949074673880034ull, 9341333820085948998ull,
  5617234010838793442ull}},
{{2057980314238666796ull, 9495808380197125851ull,
  2453295238252660439ull, 7021542513548491803ull}},
{{16407533448080497207ull, 7258074456819019409ull,
  16901677103097989261ull, 8776928141935614753ull}},
{{3337179377409228899ull, 6842139544725581083ull,
  3646019161795161432ull, 5485580088709759221ull}},
{{18006532277043699835ull, 8552674430906976353ull,
  9169209970671339694ull, 6856975110887199026ull}},
{{8673107291022461082ull, 1467471001778944634ull,
  2238140426484398810ull, 8571218888608998783ull}},
{{10032378075316426080ull, 5528855394539228300ull,
  8316366794193831112ull, 5357011805380624239ull}},
{{12540472594145532600ull, 6911069243174035375ull,
  5783772474314900986ull, 6696264756725780299ull}},
{{11063904724254527846ull, 17862208590822320027ull,
  2618029574466238328ull, 8370330945907225374ull}},
{{4609097443445385952ull, 11163880369263950017ull,
  15471326539323562667ull, 5231456841192015858ull}},
{{10373057822734120344ull, 9343164443152549617ull,
  10115786137299677526ull, 6539321051490019823ull}},
{{17578008296845038334ull, 2455583517085911213ull,
  8033046653197209004ull, 8174151314362524779ull}},
{{13292098194741842911ull, 10758111735033470316ull,
  2714811149034561675ull, 5108844571476577987ull}},
{{16615122743427303638ull, 8835953650364449991ull,
  17228571991575365806ull, 6386055714345722483ull}},
{{16157217410856741644ull, 1821570026100786681ull,
  16924028971041819354ull, 7982569642932153104ull}},
{{3180731854144381672ull, 5750167284740379580ull,
  10577518106901137096ull, 4989106026832595690ull}},
{{3975914817680477089ull, 7187709105925474475ull,
  3998525596771645562ull, 6236382533540744613ull}},
{{358207503673208457ull, 18208008419261618902ull,
  9609843014391944856ull, 7795478166925930766ull}},
{{14058937745077918998ull, 11380005262038511813ull,
  1394465865567577631ull, 4872173854328706729ull}},
{{3738614126065235036ull, 9613320559120751863ull,
  6354768350386859943ull, 6090217317910883411ull}},
{{61581639154155890ull, 7404964680473551925ull, 3331774419556187025ull,
  7612771647388604264ull}},
{{2344331533685041384ull, 16157317971364439713ull,
  2082359012222616890ull, 4757982279617877665ull}},
{{7542100435533689633ull, 10973275427350773833ull,
  7214634783705659017ull, 5947477849522347081ull}},
{{14039311562844499946ull, 18328280302615855195ull,
  13629979498059461675ull, 7434347311902933851ull}},
{{6468726717564118514ull, 9149332179921215545ull,
  6212894177073469595ull, 4646467069939333657ull}},
{{12697594415382536047ull, 6824979206474131527ull,
  12377803739769224898ull, 5808083837424167071ull}},
{{11260307000800782154ull, 17754596044947440217ull,
  10860568656284143218ull, 7260104796780208839ull}},
{{240325695718813981ull, 12969873019329524464ull,
  8964024801927791119ull, 9075130995975261049ull}},
{{150203559824258738ull, 15023699664722034646ull,
  17131730547273339209ull, 5671956872484538155ull}},
{{9411126486635099230ull, 4944566525620379595ull,
  16802977165664286108ull, 7089946090605672694ull}},
{{7152222089866486134ull, 6180708157025474494ull,
  11780349420225581827ull, 8862432613257090868ull}},
{{18305196861448717546ull, 1557099588927227606ull,
  16586090424495764450ull, 5539020383285681792ull}},
{{13658124039956121124ull, 11169746523013810316ull,
  2285868956910153946ull, 6923775479107102241ull}},
{{17072655049945151405ull, 4738811116912487087ull,
  7469022214565080337ull, 8654719348883877801ull}},
{{17587938433856801484ull, 14490971994138774189ull,
  16197353930171644970ull, 5409199593052423625ull}},
{{8149864987038838143ull, 8890342955818691929ull,
  6411634357432392501ull, 6761499491315529532ull}},
{{14799017252225935583ull, 15724614713200752815ull,
  8014542946790490626ull, 8451874364144411915ull}},
{{16166914810282291596ull, 14439570214177858413ull,
  2703246332530362689ull, 5282421477590257447ull}},
{{6373585457570700782ull, 4214404712440159305ull,
  17214115970945117074ull, 6603026846987821808ull}},
{{12578667840390763882ull, 14491377927404974939ull,
  3070900889971844726ull, 8253783558734777261ull}},
{{5555824391030533474ull, 4445425186200721433ull,
  4225156065446096906ull, 5158614724209235788ull}},
{{11556466507215554747ull, 14780153519605677599ull,
  5281445081807621132ull, 6448268405261544735ull}},
{{9833897115592055529ull, 28447825797545383ull, 1990120333832138512ull,
  8060335506576930919ull}},
{{13063714724886116562ull, 17779891123465864ull, 8161354236286168426ull,
  5037709691610581824ull}},
{{16329643406107645702ull, 9245596900759108138ull,
  10201692795357710532ull, 6297137114513227280ull}},
{{11188682220779781320ull, 11556996125948885173ull,
  12752115994197138165ull, 7871421393141534100ull}},
{{9298769397201057277ull, 9528965587931747185ull,
  17193444533227987161ull, 4919638370713458812ull}},
{{16235147764928709500ull, 16522893003342071885ull,
  3045061592825432335ull, 6149547963391823516ull}},
{{6458876650878723163ull, 16041930235750201953ull,
  3806326991031790419ull, 7686934954239779395ull}},
{{15566012952867671737ull, 7720363388130182268ull, 73111360181175060ull,
  4804334346399862122ull}},
{{1010772117375038055ull, 9650454235162727836ull,
  9314761237081244633ull, 6005417932999827652ull}},
{{1263465146718797569ull, 16674753812380797699ull,
  11643451546351555791ull, 7506772416249784565ull}},
{{16930566781195106145ull, 17339250160379080417ull,
  9583000225683416321ull, 4691732760156115353ull}},
{{7328150421211718969ull, 7839004645191686810ull,
  16590436300531658306ull, 5864665950195144191ull}},
{{18383560063369424519ull, 575383769634832704ull,
  16126359357237184979ull, 7330832437743930239ull}},
{{4532706005502229033ull, 14554287767325704593ull,
  15546263178119093319ull, 9163540547179912799ull}},
{{14362156299507362906ull, 16013958882219647226ull,
  16633943513965515180ull, 5727212841987445499ull}},
{{8729323337529427824ull, 1570704529065007417ull,
  16180743374029506072ull, 7159016052484306874ull}},
{{15523340190339172684ull, 1963380661331259271ull,
  11002557180682106782ull, 8948770065605383593ull}},
{{16619616646603064784ull, 15062170968614200756ull,
  18405813283994786498ull, 5592981291003364745ull}},
{{2327776734544279363ull, 9604341673912975138ull,
  9172208549711319411ull, 6991226613754205932ull}},
{{12133092955035125012ull, 7393741073963831018ull,
  11465260687139149264ull, 8739033267192757415ull}},
{{12194869115324341037ull, 4621088171227394386ull,
  14083316957103050146ull, 5461895791995473384ull}},
{{6020214357300650488ull, 14999732250889018791ull,
  17604146196378812682ull, 6827369739994341730ull}},
{{2913581928198425206ull, 9526293276756497681ull,
  12781810708618740045ull, 8534212174992927163ull}},
{{13350203751192485514ull, 8259776307186505002ull,
  5682788683673018576ull, 5333882609370579477ull}},
{{7464382652135831084ull, 10324720383983131253ull,
  11715171873018661124ull, 6667353261713224346ull}},
{{13942164333597176759ull, 12905900479978914066ull,
  5420592804418550597ull, 8334191577141530433ull}},
{{13325538726925623378ull, 10372030809200515243ull,
  14917085548830063883ull, 5208869735713456520ull}},
{{12045237390229641319ull, 8353352493073256150ull,
  199612862328028238ull, 6511087169641820651ull}},
{{5833174700932275841ull, 1218318579486794380ull,
  14084574133192199010ull, 8138858962052275813ull}},
{{12869106224937448209ull, 5373135130606634391ull,
  11108701842458818333ull, 5086786851282672383ull}},
{{11474696762744422357ull, 11328104931685680893ull,
  9274191284646135012ull, 6358483564103340479ull}},
{{508312898148364234ull, 14160131164607101117ull,
  6981053087380280861ull, 7948104455129175599ull}},
{{2623538570556421598ull, 11155924987093132150ull,
  11280687207253757394ull, 4967565284455734749ull}},
{{12502795250050302806ull, 4721534197011639379ull,
  265800953785033031ull, 6209456605569668437ull}},
{{11016808044135490603ull, 1290231727837161320ull,
  4943937210658679193ull, 7761820756962085546ull}},
{{6885505027584681627ull, 12335609875966695585ull,
  7701646775089062399ull, 4851137973101303466ull}},
{{13218567302908239938ull, 10807826326530981577ull,
  403686432006552191ull, 6063922466376629333ull}},
{{2688151073353136210ull, 8898096889736339068ull,
  5116294058435578143ull, 7579903082970786666ull}},
{{10903466457700485939ull, 12478839583726293773ull,
  7809369804949624243ull, 4737439426856741666ull}},
{{18241019090552995328ull, 10986863461230479312ull,
  538340219332254496ull, 5921799283570927083ull}},
{{4354529789481692544ull, 13733579326538099141ull,
  14507983329447481832ull, 7402249104463658853ull}},
{{5027424127639751792ull, 8583487079086311963ull,
  11373332590118370097ull, 4626405690289786783ull}},
{{1672594141122301836ull, 15341044867285277858ull,
  9604979719220574717ull, 5783007112862233479ull}},
{{11314114713257653103ull, 5341248028824433610ull,
  7394538630598330493ull, 7228758891077791849ull}},
{{4919271354717290571ull, 11288246054457929917ull,
  13854859306675301020ull, 9035948613847239811ull}},
{{5380387605912000559ull, 16278525820890982006ull,
  6353444057458369185ull, 5647467883654524882ull}},
{{15948856544244776506ull, 6513099220831563795ull,
  17165177108677737290ull, 7059334854568156102ull}},
{{15324384661878582729ull, 17364746062894230552ull,
  12233099348992395804ull, 8824168568210195128ull}},
{{9577740413674114206ull, 1629594252454118287ull,
  7645687093120247378ull, 5515105355131371955ull}},
{{7360489498665254853ull, 11260364852422423667ull,
  4945422847972921318ull, 6893881693914214944ull}},
{{4588925854904180662ull, 4852084028673253776ull,
  6181778559966151648ull, 8617352117392768680ull}},
{{2868078659315112914ull, 3032552517920783610ull,
  3863611599978844780ull, 5385845073370480425ull}},
{{12808470360998666950ull, 3790690647400979512ull,
  9441200518400943879ull, 6732306341713100531ull}},
{{16010587951248333688ull, 126677290823836486ull,
  7189814629573791945ull, 8415382927141375664ull}},
{{5394931451102820651ull, 11608388352833367564ull,
  4493634143483619965ull, 5259614329463359790ull}},
{{6743664313878525814ull, 675427385759545743ull,
  14840414716209300765ull, 6574517911829199737ull}},
{{3817894373920769363ull, 5455970250626820083ull,
  4715460339979462244ull, 8218147389786499672ull}},
{{80340974486786900ull, 12633353443496538360ull, 2947162712487163902ull,
  5136342118616562295ull}},
{{100426218108483625ull, 6568319767515897142ull,
  17519011445891118590ull, 6420427648270702868ull}},
{{9348904809490380339ull, 17433771746249647235ull,
  3452020233654346621ull, 8025534560338378586ull}},
{{3537222496717793760ull, 13201950350619723474ull,
  6769198664461354542ull, 5015959100211486616ull}},
{{13644900157752018008ull, 7279065901419878534ull,
  8461498330576693178ull, 6269948875264358270ull}},
{{7832753160335246702ull, 18322204413629623976ull,
  1353500876366090664ull, 7837436094080447838ull}},
{{4895470725209529189ull, 11451377758518514985ull,
  14680996103010970377ull, 4898397558800279898ull}},
{{10731024424939299390ull, 479164142865980019ull,
  9127873091908937164ull, 6122996948500349873ull}},
{{8802094512746736333ull, 598955178582475024ull,
  16021527383313559359ull, 7653746185625437341ull}},
{{5501309070466710209ull, 7291876014255128746ull,
  12319297623784668551ull, 4783591366015898338ull}},
{{16100008374938163569ull, 4503158999391523028ull,
  6175749992876059881ull, 5979489207519872923ull}},
{{1678266394963152845ull, 10240634767666791690ull,
  3108001472667686947ull, 7474361509399841154ull}},
{{5660602515279358432ull, 4094553720578050854ull,
  6554186938844692246ull, 4671475943374900721ull}},
{{16299125180953973848ull, 14341564187577339375ull,
  12804419691983253211ull, 5839344929218625901ull}},
{{15762220457765079406ull, 13315269216044286315ull,
  2170466559696902802ull, 7299181161523282377ull}},
{{15091089553778961353ull, 7420714483200582086ull,
  7324769218048516407ull, 9123976451904102971ull}},
{{4820244952684462942ull, 11555475579641445660ull,
  2272137752066628802ull, 5702485282440064357ull}},
{{6025306190855578677ull, 5220972437697031267ull,
  7451858208510673907ull, 7128106603050080446ull}},
{{2919946720142085442ull, 1914529528693901180ull, 91450723783566576ull,
  8910133253812600558ull}},
{{11048338736943579210ull, 1196580955433688237ull,
  13892214757646892822ull, 5568833283632875348ull}},
{{18422109439606861916ull, 10719098231146886104ull,
  17365268447058616027ull, 6961041604541094185ull}},
{{4580892725799025779ull, 8787186770506219727ull,
  7871527503541106322ull, 8701302005676367732ull}},
{{9780586981265472968ull, 10103677749993775233ull,
  14143076726567967259ull, 5438313753547729832ull}},
{{16837419745009229114ull, 8017911169064831137ull,
  17678845908209959074ull, 6797892191934662290ull}},
{{7211716625979372680ull, 799016924476263114ull,
  12875185348407673035ull, 8497365239918327863ull}},
{{9119008909664495829ull, 16640286642293522110ull,
  14964519870395877502ull, 5310853274948954914ull}},
{{2175389100225843979ull, 11576986266012126830ull,
  9482277801140071070ull, 6638566593686193643ull}},
{{11942608412137080781ull, 5247860795660382729ull,
  7241161232997700934ull, 8298208242107742054ull}},
{{546601229944593632ull, 17114971052569902918ull,
  18360783825905726795ull, 5186380151317338783ull}},
{{9906623574285517848ull, 16782027797284990743ull,
  18339293763954770590ull, 6482975189146673479ull}},
{{7771593449429509406ull, 11754162709751462621ull,
  18312431186516075334ull, 8103718986433341849ull}},
{{7163088915107137331ull, 2734665675167276234ull,
  4527740463931465228ull, 5064824366520838656ull}},
{{18177233180738697472ull, 3418332093959095292ull,
  5659675579914331535ull, 6331030458151048320ull}},
{{4274797402213820224ull, 18107973172731032828ull,
  7074594474892914418ull, 7913788072688810400ull}},
{{11895120413238413448ull, 15929169251384283421ull,
  4421621546808071511ull, 4946117545430506500ull}},
{{1033842461265853098ull, 15299775545802966373ull,
  5527026933510089389ull, 6182646931788133125ull}},
{{5903989095009704276ull, 5289661376971544254ull,
  11520469685314999641ull, 7728308664735166406ull}},
{{17525051239663228885ull, 14835253406675684918ull,
  2588607534894486871ull, 4830192915459479004ull}},
{{12682942012724260298ull, 13932380739917218244ull,
  3235759418618108589ull, 6037741144324348755ull}},
{{15853677515905325372ull, 3580417869614359093ull,
  17879757328554799449ull, 7547176430405435943ull}},
{{12214391456654522310ull, 13766976214577444193ull,
  18092377357987831511ull, 4716985269003397464ull}},
{{1432931265535989175ull, 12597034249794417338ull,
  4168727623775237773ull, 5896231586254246831ull}},
{{11014536118774762277ull, 1911234756960857960ull,
  599223511291659313ull, 7370289482817808539ull}},
{{13768170148468452846ull, 7000729464628460354ull,
  14584087444396737853ull, 9212861853522260673ull}},
{{13216792361220170933ull, 6681298924606481673ull,
  2197525625106879302ull, 5758038658451412921ull}},
{{2685932396243049954ull, 17574995692612877900ull,
  7358593049810987031ull, 7197548323064266151ull}},
{{3357415495303812442ull, 17357058597338709471ull,
  4586555293836345885ull, 8996935403830332689ull}},
{{9015913712205964633ull, 13154004632550387371ull,
  14395812104716185938ull, 5623084627393957930ull}},
{{6658206121830067887ull, 7219133753833208406ull,
  8771393094040456615ull, 7028855784242447413ull}},
{{17546129689142360666ull, 4412231173864122603ull,
  15575927385977958673ull, 8786069730303059266ull}},
{{8660488046500281465ull, 14286859529733546387ull,
  14346640634663612074ull, 5491293581439412041ull}},
{{6213924039697963927ull, 8635202375312157176ull,
  4098242738047351381ull, 6864116976799265052ull}},
{{7767405049622454908ull, 15405688987567584374ull,
  5122803422559189226ull, 8580146220999081315ull}},
{{242942137586646414ull, 14240241635657128138ull, 895909129885799314ull,
  5362591388124425822ull}},
{{9527049708838083825ull, 8576930007716634364ull,
  10343258449212024951ull, 6703239235155532277ull}},
{{11908812136047604781ull, 6109476491218405051ull,
  17540759079942419093ull, 8379049043944415346ull}},
{{5137164575816059036ull, 6124265816225197109ull,
  15574660443391399837ull, 5236905652465259591ull}},
{{11033141738197461699ull, 12267018288708884290ull,
  14856639535811861892ull, 6546132065581574489ull}},
{{4568055135892051316ull, 15333772860886105363ull,
  4735741364482663653ull, 8182665081976968112ull}},
{{549191450718838121ull, 11889451047267509804ull,
  2959838352801664783ull, 5114165676235605070ull}},
{{686489313398547651ull, 10250127790656999351ull,
  12923169977856856787ull, 6392707095294506337ull}},
{{14693169697030348275ull, 8200973719893861284ull,
  2318904417038907272ull, 7990883869118132922ull}},
{{18406603097498743480ull, 5125608574933663302ull,
  6061001279076704949ull, 4994302418198833076ull}},
{{13784881835018653542ull, 11018696737094467032ull,
  7576251598845881186ull, 6242878022748541345ull}},
{{17231102293773316928ull, 4549998884513307982ull,
  14082000516984739387ull, 7803597528435676681ull}},
{{6157752915180935176ull, 537906293607123537ull, 1883721295474380261ull,
  4877248455272297926ull}},
{{12308877162403556874ull, 5284068885436292325ull,
  11578023656197751134ull, 6096560569090372407ull}},
{{1551038397722282380ull, 15828458143650141215ull,
  9860843551819801013ull, 7620700711362965509ull}},
{{7886928026217508344ull, 12198629348995032211ull,
  8468870229101069585ull, 4762937944601853443ull}},
{{5246974014344497526ull, 1413228630961626552ull,
  5974401767948949078ull, 5953672430752316804ull}},
{{6558717517930621907ull, 10989907825556808998ull,
  7468002209936186347ull, 7442090538440396005ull}},
{{17934256503988802404ull, 4562849381759311671ull,
  6973344390423810419ull, 4651306586525247503ull}},
{{17806134611558615101ull, 1091875708771751685ull,
  4104994469602375120ull, 5814133233156559379ull}},
{{8422610209166105164ull, 1364844635964689607ull, 519557068575580996ull,
  7267666541445699224ull}},
{{5916576743030243551ull, 1706055794955862009ull, 649446335719476245ull,
  9084583176807124030ull}},
{{15227075510462371979ull, 3372127881061107707ull,
  14240962015106836365ull, 5677864485504452518ull}},
{{14422158369650577070ull, 8826845869753772538ull,
  8577830482028769648ull, 7097330606880565648ull}},
{{8804325925208445530ull, 11033557337192215673ull,
  10722288102535962060ull, 8871663258600707060ull}},
{{17031918749323748216ull, 16119345372599910603ull,
  15924802100939752095ull, 5544789536625441912ull}},
{{16678212418227297366ull, 15537495697322500350ull,
  1459258552465138503ull, 6930986920781802391ull}},
{{11624393485929345900ull, 14810183603225737534ull,
  15659131245863586841ull, 8663733650977252988ull}},
{{2653559910278453283ull, 2338835724375004103ull, 563584991809965968ull,
  5414833531860783118ull}},
{{17152007943130230316ull, 2923544655468755128ull,
  9927853276617233268ull, 6768541914825978897ull}},
{{2993265855203236279ull, 3654430819335943911ull,
  17021502614198929489ull, 8460677393532473621ull}},
{{8788320187143104531ull, 13813234308153434704ull,
  12944282143088024882ull, 5287923370957796013ull}},
{{10985400233928880663ull, 8043170848337017572ull,
  2345294623577867391ull, 6609904213697245017ull}},
{{13731750292411100829ull, 5442277541993884061ull,
  7543304297899722143ull, 8262380267121556271ull}},
{{10888186941970631970ull, 10318952491387259394ull,
  11632094213828408195ull, 5163987666950972669ull}},
{{4386861640608514155ull, 8287004595806686339ull, 705059712003346532ull,
  6454984583688715837ull}},
{{871891032333254789ull, 10358755744758357924ull,
  5493010658431571069ull, 8068730729610894796ull}},
{{9768303932063060051ull, 8780065349687667654ull,
  12656503698374507726ull, 5042956706006809247ull}},
{{2987007878224049256ull, 1751709650254808760ull,
  11208943604540746754ull, 6303695882508511559ull}},
{{3733759847780061570ull, 11413009099673286758ull,
  9399493487248545538ull, 7879619853135639449ull}},
{{16168657960144702193ull, 11744816705723192127ull,
  17403898475598810721ull, 4924762408209774655ull}},
{{15599136431753489838ull, 845962826871826447ull,
  17143187076071125498ull, 6155953010262218319ull}},
{{14887234521264474393ull, 10280825570444558867ull,
  16817297826661518968ull, 7694941262827772899ull}},
{{6998678566576602544ull, 6425515981527849292ull,
  8204968132449755403ull, 4809338289267358062ull}},
{{8748348208220753180ull, 3420208958482423711ull,
  1032838128707418446ull, 6011672861584197578ull}},
{{6323749241848553570ull, 13498633234957805447ull,
  10514419697739048865ull, 7514591076980246972ull}},
{{10869872303796427838ull, 1519116744207546548ull,
  15794884347941681349ull, 4696619423112654357ull}},
{{13587340379745534797ull, 6510581948686821089ull,
  5908547379644937974ull, 5870774278890817947ull}},
{{3149117419399754784ull, 17361599472713302170ull,
  2773998206128784563ull, 7338467848613522434ull}},
{{13159768811104469288ull, 17090313322464239808ull,
  12690869794515756512ull, 9173084810766903042ull}},
{{8224855506940293305ull, 10681445826540149880ull,
  12543479639999735724ull, 5733178006729314401ull}},
{{10281069383675366631ull, 13351807283175187350ull,
  1844291494717505943ull, 7166472508411643002ull}},
{{3627964692739432481ull, 12078073085541596284ull,
  11528736405251658237ull, 8958090635514553752ull}},
{{11490849969816921109ull, 9854638687677191629ull,
  7205460253282286398ull, 5598806647196596095ull}},
{{528504406988987674ull, 3094926322741713729ull, 4395139298175470094ull,
  6998508308995745119ull}},
{{5272316527163622496ull, 13092029940281917969ull,
  882238104291949713ull, 8748135386244681399ull}},
{{14824412875545733820ull, 1264989685035116874ull,
  7468927842823550427ull, 5467584616402925874ull}},
{{9307144057577391467ull, 15416295161576059805ull,
  112787766674662225ull, 6834480770503657343ull}},
{{16245616090399127238ull, 5435310896687911044ull,
  13976042763625491494ull, 8543100963129571678ull}},
{{930138019644678716ull, 17232127365712108115ull,
  4123340708838544279ull, 5339438101955982299ull}},
{{14997730579838012107ull, 16928473188712747239ull,
  542489867620792445ull, 6674297627444977874ull}},
{{14135477206370127229ull, 7325533430608770337ull,
  9901484371380766365ull, 8342872034306222342ull}},
{{1917144226340247663ull, 6884301403344175413ull,
  1576741713685591074ull, 5214295021441388964ull}},
{{7008116301352697482ull, 17828748791034995074ull,
  1970927142106988842ull, 6517868776801736205ull}},
{{17983517413545647661ull, 13062563951938968034ull,
  7075344946061123957ull, 8147335971002170256ull}},
{{15851384401893417692ull, 10469945479175548973ull,
  4422090591288202473ull, 5092084981876356410ull}},
{{5979172447084608403ull, 17699117867396824121ull,
  14750985275965028899ull, 6365106227345445512ull}},
{{12085651577283148407ull, 17512211315818642247ull,
  18438731594956286124ull, 7956382784181806890ull}},
{{14471061263443049611ull, 1721760035531875596ull,
  16135893265275066732ull, 4972739240113629306ull}},
{{18088826579303812013ull, 2152200044414844495ull,
  10946494544739057607ull, 6215924050142036633ull}},
{{17999347205702377113ull, 16525308110800719331ull,
  18294804199351209912ull, 7769905062677545791ull}},
{{8943748994350291744ull, 10328317569250449582ull,
  18351781652235588051ull, 4856190664173466119ull}},
{{1956314206083088871ull, 8298710943135674074ull,
  18328041046867097160ull, 6070238330216832649ull}},
{{11668764794458636897ull, 10373388678919592592ull,
  9074993253301707738ull, 7587797912771040812ull}},
{{7292977996536648061ull, 11095053942752133274ull,
  14895242820168343144ull, 4742373695481900507ull}},
{{18339594532525585884ull, 13868817428440166592ull,
  14007367506783041026ull, 5927967119352375634ull}},
{{4477749091947430739ull, 8112649748695432433ull,
  8285837346624025475ull, 7409958899190469543ull}},
{{14327808228535613972ull, 2764563083720951318ull,
  12096177369281097778ull, 4631224311994043464ull}},
{{8686388248814741657ull, 12679075891505964956ull,
  15120221711601372222ull, 5789030389992554330ull}},
{{10857985311018427071ull, 6625472827527680387ull,
  9676905102646939470ull, 7236287987490692913ull}},
{{8960795620345645935ull, 17505213071264376292ull,
  16707817396736062241ull, 9045359984363366141ull}},
{{14823869299570804517ull, 4023229141899153326ull,
  12748228882173732853ull, 5653349990227103838ull}},
{{9306464587608729838ull, 9640722445801329562ull,
  6711914065862390258ull, 7066687487783879798ull}},
{{2409708697656136490ull, 2827531020396886145ull,
  17613264619182763631ull, 8833359359729849747ull}},
{{13035282982103555066ull, 8684735915389135696ull,
  8702447377775533317ull, 5520849599831156092ull}},
{{16294103727629443833ull, 15467605912663807524ull,
  10878059222219416646ull, 6901061999788945115ull}},
{{1920885585827253175ull, 10111135353974983598ull,
  8985888009346882904ull, 8626327499736181394ull}},
{{15035611546424196947ull, 6319459596234364748ull,
  10227866024269189719ull, 5391454687335113371ull}},
{{347770359320694567ull, 3287638476865568032ull, 8173146511909099245ull,
  6739318359168891714ull}},
{{434712949150868209ull, 8721234114509347944ull, 993061103031598248ull,
  8424147948961114643ull}},
{{271695593219292631ull, 5450771321568342465ull,
  16761564253890606569ull, 5265092468100696651ull}},
{{4951305509951503692ull, 11425150170387815985ull,
  16340269298935870307ull, 6581365585125870814ull}},
{{10800817905866767519ull, 9669751694557382077ull,
  11201964586815062076ull, 8226706981407338518ull}},
{{9056354200380423652ull, 15266966845953139606ull,
  2389541848332025893ull, 5141691863379586574ull}},
{{2097070713620753756ull, 5248650502159260796ull,
  12210299347269808175ull, 6427114829224483217ull}},
{{2621338392025942195ull, 1949127109271688091ull,
  1427816128805096507ull, 8033893536530604022ull}},
{{17779237559512071536ull, 17359105507790662720ull,
  14727443135785349028ull, 5021183460331627513ull}},
{{3777302875680537804ull, 3252137811028776785ull,
  4574245864449522574ull, 6276479325414534392ull}},
{{9333314613028060159ull, 13288544300640746789ull,
  5717807330561903217ull, 7845599156768167990ull}},
{{8139164642356231552ull, 1387811160259384887ull,
  17408687636883353223ull, 4903499472980104993ull}},
{{5562269784517901535ull, 15569822005606394821ull,
  7925801490822027816ull, 6129374341225131242ull}},
{{11564523249074764823ull, 1015533433298441910ull,
  683879826672758963ull, 7661717926531414053ull}},
{{2616141012244340111ull, 16775609460307383858ull,
  2733267900884168303ull, 4788573704082133783ull}},
{{12493548302160200946ull, 16357825806956841918ull,
  17251642931387374091ull, 5985717130102667228ull}},
{{6393563340845475375ull, 15835596240268664494ull,
  3117809590524665998ull, 7482146412628334036ull}},
{{17831035143310585821ull, 5285561631740527404ull,
  11172003030932692057ull, 4676341507892708772ull}},
{{3842049855428680661ull, 11218638058103047160ull,
  13965003788665865071ull, 5845426884865885965ull}},
{{4802562319285850826ull, 9411611554201421046ull,
  3621196680550167627ull, 7306783606082357457ull}},
{{15226574935962089340ull, 7152828424324388403ull,
  9138181869115097438ull, 9133479507602946821ull}},
{{7210766325762611886ull, 18305575820484906464ull,
  8017206677410629850ull, 5708424692251841763ull}},
{{9013457907203264857ull, 13658597738751357272ull,
  5409822328335899409ull, 7135530865314802204ull}},
{{11266822384004081071ull, 3238189118157032878ull,
  6762277910419874262ull, 8919413581643502755ull}},
{{2430077971575162766ull, 15858926254130309261ull,
  1920580684798727461ull, 5574633488527189222ull}},
{{7649283482896341361ull, 5988599762380722864ull,
  11624097892853185135ull, 6968291860658986527ull}},
{{9561604353620426701ull, 2874063684548515676ull,
  9918436347639093515ull, 8710364825823733159ull}},
{{15199374757867542496ull, 17937190867338679961ull,
  13116551744915515302ull, 5443978016139833224ull}},
{{5164160392052264408ull, 13198116547318574144ull,
  16395689681144394128ull, 6804972520174791530ull}},
{{6455200490065330510ull, 16497645684148217680ull,
  11271240064575716852ull, 8506215650218489413ull}},
{{4034500306290831569ull, 1087656515737860242ull,
  9350368049573516985ull, 5316384781386555883ull}},
{{14266497419718315269ull, 5971256663099713206ull,
  7076274043539508327ull, 6645480976733194854ull}},
{{8609749737793118278ull, 2852384810447253604ull,
  18068714591279161217ull, 8306851220916493567ull}},
{{14604465622975474732ull, 13311955552598003262ull,
  18210475647190557616ull, 5191782013072808479ull}},
{{9032209991864567607ull, 16639944440747504078ull,
  18151408540560809116ull, 6489727516341010599ull}},
{{2066890452975933701ull, 2353186477224828482ull,
  18077574657273623492ull, 8112159395426263249ull}},
{{5903492551537346467ull, 10694113585120293609ull,
  4380955133154932826ull, 5070099622141414531ull}},
{{11991051707849070988ull, 4144269944545591203ull,
  864507898016278129ull, 6337624527676768164ull}},
{{10377128616383950831ull, 9792023449109376908ull,
  1080634872520347661ull, 7922030659595960205ull}},
{{15709077422094745077ull, 8425857664907054519ull,
  2981239804538911240ull, 4951269162247475128ull}},
{{15024660759191043442ull, 10532322081133818149ull,
  3726549755673639050ull, 6189086452809343910ull}},
{{4945767893706640591ull, 3942030564562496879ull,
  13881559231446824621ull, 7736358066011679887ull}},
{{10008633961207732226ull, 4769612112065254501ull,
  15593503547295347244ull, 4835223791257299929ull}},
{{17122478469937053186ull, 5962015140081568126ull,
  5656821378837020343ull, 6044029739071624912ull}},
{{12179726050566540674ull, 2840832906674572254ull,
  7071026723546275429ull, 7555037173839531140ull}},
{{3000642763176700018ull, 4081363575885301611ull,
  13642763739071197951ull, 4721898233649706962ull}},
{{17585861509253038734ull, 490018451429239109ull,
  7830082636984221631ull, 5902372792062133703ull}},
{{8147268831284134705ull, 14447581119568712599ull,
  5175917277802889134ull, 7377965990077667129ull}},
{{5572400020677780477ull, 8836104362606114941ull,
  11081582615680999322ull, 9222457487597083911ull}},
{{5788593022137306750ull, 10134251245056209742ull,
  13843518162441706432ull, 5764035929748177444ull}},
{{16459113314526409246ull, 12667814056320262177ull,
  17304397703052133040ull, 7205044912185221805ull}},
{{6738833587875847845ull, 15834767570400327722ull,
  7795439073533002588ull, 9006306140231527257ull}},
{{8823457010849792808ull, 673357694645429018ull,
  16401364467026596378ull, 5628941337644704535ull}},
{{1805949226707465201ull, 10065069155161562081ull,
  15890019565355857568ull, 7036176672055880669ull}},
{{6869122551811719405ull, 12581336443951952601ull,
  6027466401412658248ull, 8795220840069850837ull}},
{{15822416640950794389ull, 7863335277469970375ull,
  6073009510096605357ull, 5497013025043656773ull}},
{{15166334782761105082ull, 14440855115264850873ull,
  12202947906048144600ull, 6871266281304570966ull}},
{{5122860423169217640ull, 18051068894081063592ull,
  6030312845705404942ull, 8589082851630713708ull}},
{{3201787764480761025ull, 6670232040373276841ull,
  12992317565420653897ull, 5368176782269196067ull}},
{{8613920724028339185ull, 12949476068893983955ull,
  11628710938348429467ull, 6710220977836495084ull}},
{{6155714886608036077ull, 11575159067690092040ull,
  14535888672935536834ull, 8387776222295618855ull}},
{{3847321804130022549ull, 11846160435733695429ull,
  16002459448225792377ull, 5242360138934761784ull}},
{{9420838273589916090ull, 972642489384955574ull, 1556330236572688856ull,
  6552950173668452231ull}},
{{2552675805132619304ull, 1215803111731194468ull,
  15780470850998024782ull, 8191187717085565288ull}},
{{10818794415062662873ull, 14594935000114160254ull,
  9862794281873765488ull, 5119492323178478305ull}},
{{4300120981973552783ull, 18243668750142700318ull,
  16940178870769594764ull, 6399365403973097881ull}},
{{14598523264321716787ull, 4357841863968823781ull,
  7340165533179829744ull, 7999206754966372352ull}},
{{11429920049414766944ull, 2723651164980514863ull,
  4587603458237393590ull, 4999504221853982720ull}},
{{9675714043341070776ull, 12627935993080419387ull,
  5734504322796741987ull, 6249380277317478400ull}},
{{7482956535748950566ull, 11173233972923136330ull,
  7168130403495927484ull, 7811725346646848000ull}},
{{9288533853270482008ull, 16206643269931736014ull,
  4480081502184954677ull, 4882328341654280000ull}},
{{2387295279733326702ull, 6423246032132506306ull,
  5600101877731193347ull, 6102910427067850000ull}},
{{12207491136521434185ull, 3417371521738244978ull,
  7000127347163991684ull, 7628638033834812500ull}},
{{12241367978753284270ull, 11359229237941178919ull,
  13598451628832270610ull, 4767898771146757812ull}},
{{10690023955014217433ull, 4975664510571697841ull,
  16998064536040338263ull, 5959873463933447265ull}},
{{17974215962195159695ull, 1607894619787234397ull,
  7412522614768259117ull, 7449841829916809082ull}},
{{13539727985585668762ull, 3310777146580715450ull,
  9244512652657549852ull, 4656151143698005676ull}},
{{7701287945127310144ull, 4138471433225894313ull,
  11555640815821937315ull, 5820188929622507095ull}},
{{14238295949836525584ull, 561403273104979987ull,
  9832865001350033740ull, 7275236162028133869ull}},
{{13186183918868269076ull, 701754091381224984ull,
  16902767270114930079ull, 9094045202535167336ull}},
{{8241364949292668173ull, 7356125334754347471ull,
  10564229543821831299ull, 5683778251584479585ull}},
{{5690020168188447312ull, 4583470650015546435ull,
  17816972948204677028ull, 7104722814480599481ull}},
{{2500839191808171235ull, 5729338312519433044ull,
  8436158129973682573ull, 8880903518100749352ull}},
{{10786396531734882830ull, 5886679454538339604ull,
  5272598831233551608ull, 5550564698812968345ull}},
{{13482995664668603538ull, 7358349318172924505ull,
  11202434557469327414ull, 6938205873516210431ull}},
{{3018686525553590710ull, 18421308684570931440ull,
  9391357178409271363ull, 8672757341895263039ull}},
{{1886679078470994194ull, 9207474918643138198ull,
  12787127264146876458ull, 5420473338684539399ull}},
{{11581720884943518550ull, 2285971611449146939ull,
  11372223061756207669ull, 6775591673355674249ull}},
{{9865465087752010284ull, 7469150532738821578ull, 380220771913095874ull,
  8469489591694592812ull}},
{{10777601698272394332ull, 9279905101389151390ull,
  9461010019300460729ull, 5293430994809120507ull}},
{{4248630085985717106ull, 16211567395163827142ull,
  7214576505698188007ull, 6616788743511400634ull}},
{{14534159644336922191ull, 15652773225527396023ull,
  18241592668977510817ull, 8270985929389250792ull}},
{{16001378805351658225ull, 2865454238313540658ull,
  11400995418110944261ull, 5169366205868281745ull}},
{{10778351469834796974ull, 8193503816319313727ull,
  416186217356516614ull, 6461707757335352182ull}},
{{8861253318866108313ull, 1018507733544366351ull,
  9743604808550421576ull, 8077134696669190227ull}},
{{12455812351932399552ull, 636567333465228969ull,
  3783909996130319533ull, 5048209185418243892ull}},
{{1734707384633335728ull, 5407395185258924116ull,
  4729887495162899416ull, 6310261481772804865ull}},
{{2168384230791669659ull, 6759243981573655145ull,
  10524045387381012174ull, 7887826852216006081ull}},
{{12884455190313263297ull, 18059585543765698177ull,
  18106743413181602368ull, 4929891782635003800ull}},
{{2270510932609415409ull, 4127737855997571106ull,
  4186685192767451345ull, 6162364728293754751ull}},
{{12061510702616545070ull, 9771358338424351786ull,
  621670472531926277ull, 7702955910367193439ull}},
{{12150130207562728573ull, 8412941970728913818ull,
  7306073072973535779ull, 4814347443979495899ull}},
{{5964290722598634908ull, 5904491444983754369ull,
  4520905322789531820ull, 6017934304974369874ull}},
{{12067049421675681539ull, 7380614306229692961ull,
  14874503690341690583ull, 7522417881217962342ull}},
{{624376860906219106ull, 11530412969034639957ull,
  4684878788036168710ull, 4701511175761226464ull}},
{{5392157094560161786ull, 5189644174438524138ull,
  5856098485045210888ull, 5876888969701533080ull}},
{{15963568405054978041ull, 6487055218048155172ull,
  7320123106306513610ull, 7346111212126916350ull}},
{{1507716432609170935ull, 17332191059414969774ull,
  18373525919737917820ull, 9182639015158645437ull}},
{{14777380825662895546ull, 1609247375279580300ull,
  13789296709049892590ull, 5739149384474153398ull}},
{{24981958369067817ull, 11234931255954251184ull, 8013248849457589929ull,
  7173936730592691748ull}},
{{31227447961334771ull, 208606014660650268ull, 10016561061821987412ull,
  8967420913240864685ull}},
{{9242889191830610040ull, 9353750796017682225ull,
  8566193672852436084ull, 5604638070775540428ull}},
{{16165297508215650454ull, 11692188495022102781ull,
  10707742091065545105ull, 7005797588469425535ull}},
{{6371563829987399355ull, 780177563495464765ull, 8772991595404543478ull,
  8757246985586781919ull}},
{{6288070402955818549ull, 14322669032466829190ull,
  12400648774768921529ull, 5473279365991738699ull}},
{{17083460040549548994ull, 4068278235301372775ull,
  10889124950033764008ull, 6841599207489673374ull}},
{{16742639032259548339ull, 5085347794126715969ull,
  4388034150687429202ull, 8551999009362091718ull}},
{{3546620367521135856ull, 7790028389756585385ull,
  16577579399461806963ull, 5344999380851307323ull}},
{{9044961477828807724ull, 5125849468768343827ull,
  16110288230899870800ull, 6681249226064134154ull}},
{{6694515828858621751ull, 6407311835960429784ull,
  10914488251770062692ull, 8351561532580167693ull}},
{{4184072393036638594ull, 13227941934330044423ull,
  9127398166569983134ull, 5219725957862604808ull}},
{{618404472868410339ull, 7311555381057779721ull,
  11409247708212478918ull, 6524657447328256010ull}},
{{5384691609512900827ull, 18362816263177000459ull,
  5038187598410822839ull, 8155821809160320013ull}},
{{1059589246731869065ull, 18394289192126707143ull,
  5454710258220458226ull, 5097388630725200008ull}},
{{15159544613697000043ull, 13769489453303608120ull,
  6818387822775572783ull, 6371735788406500010ull}},
{{502686693411698438ull, 12600175798202122247ull,
  17746356815324241787ull, 7964669735508125012ull}},
{{7231708211023393380ull, 5569266864662632452ull,
  1868100972722875309ull, 4977918584692578133ull}},
{{9039635263779241725ull, 11573269599255678469ull,
  6946812234330982040ull, 6222398230865722666ull}},
{{15911230098151440060ull, 14466586999069598086ull,
  17906887329768503358ull, 7777997788582153332ull}},
{{5332832792917262134ull, 4429930855991110900ull,
  1968432544250538791ull, 4861248617863845833ull}},
{{6666040991146577667ull, 925727551561500721ull, 7072226698740561393ull,
  6076560772329807291ull}},
{{12944237257360609988ull, 5768845457879263805ull,
  4228597354998313837ull, 7595700965412259114ull}},
{{10395991295064075194ull, 5911371420388233830ull,
  7254559365301334052ull, 4747313103382661946ull}},
{{3771617081975318185ull, 7389214275485292288ull,
  18291571243481443373ull, 5934141379228327432ull}},
{{4714521352469147731ull, 13848203862784003264ull,
  4417719980642252600ull, 7417676724035409291ull}},
{{2946575845293217332ull, 8655127414240002040ull, 455231978687713923ull,
  4636047952522130807ull}},
{{3683219806616521665ull, 6207223249372614646ull,
  14404098028641806116ull, 5795059940652663508ull}},
{{13827396795125427889ull, 7759029061715768307ull,
  18005122535802257645ull, 7243824925815829385ull}},
{{12672559975479396957ull, 14310472345572098288ull,
  8671345114470658344ull, 9054781157269786732ull}},
{{7920349984674623099ull, 8944045215982561430ull,
  14642962733398937273ull, 5659238223293616707ull}},
{{677065443988503065ull, 15791742538405589692ull,
  13692017398321283687ull, 7074047779117020884ull}},
{{846331804985628831ull, 15127992154579599211ull,
  17115021747901604609ull, 8842559723896276105ull}},
{{16669858442611875684ull, 2537466068971167650ull,
  3779359564797421025ull, 5526599827435172566ull}},
{{11613951016410068796ull, 7783518604641347467ull,
  13947571492851552089ull, 6908249784293965707ull}},
{{9905752752085198091ull, 14341084274229072238ull,
  12822778347637052207ull, 8635312230367457134ull}},
{{1579409451625860903ull, 15880706699034252005ull,
  3402550448845769725ull, 5397070143979660709ull}},
{{6585947832959714033ull, 6015825318510651294ull,
  8864874079484600061ull, 6746337679974575886ull}},
{{17455806828054418349ull, 12131467666565702021ull,
  1857720562500974268ull, 8432922099968219858ull}},
{{13215722276747705420ull, 16805539328458339571ull,
  5772761369990496821ull, 5270576312480137411ull}},
{{11907966827507243871ull, 7171866105290760752ull,
  2604265694060733123ull, 6588220390600171764ull}},
{{14884958534384054839ull, 4353146613186063036ull,
  3255332117575916404ull, 8235275488250214705ull}},
{{79727047135258467ull, 11944088670096065206ull,
  13563797619553417512ull, 5147047180156384190ull}},
{{9323030845773848891ull, 14930110837620081507ull,
  7731374987586996082ull, 6433808975195480238ull}},
{{7042102538789923210ull, 9439266510170326076ull, 440846697628969295ull,
  8042261218994350298ull}},
{{13624686123598477814ull, 12817070596497535653ull,
  4887215204445493713ull, 5026413261871468936ull}},
{{3195799599215933556ull, 2186280190339755855ull,
  6109019005556867142ull, 6283016577339336170ull}},
{{17829807554302080657ull, 11956222274779470626ull,
  16859645793800859735ull, 7853770721674170212ull}},
{{15755315739866188315ull, 14390167949378250997ull,
  1313906584270761526ull, 4908606701046356383ull}},
{{5859086619550571681ull, 8764337899868037939ull,
  15477441285620615620ull, 6135758376307945478ull}},
{{2712172256010826697ull, 10955422374835047424ull,
  10123429570170993717ull, 7669697970384931848ull}},
{{1695107660006766686ull, 9152981993485598592ull,
  6327143481356871073ull, 4793561231490582405ull}},
{{2118884575008458357ull, 16052913510284386144ull,
  12520615370123476745ull, 5991951539363228006ull}},
{{2648605718760572947ull, 6231083832573318968ull,
  6427397175799570124ull, 7489939424204035008ull}},
{{1655378574225358092ull, 13117799432213100163ull,
  4017123234874731327ull, 4681212140127521880ull}},
{{15904281273063861327ull, 11785563271838987299ull,
  5021404043593414159ull, 5851515175159402350ull}},
{{15268665572902438754ull, 10120268071371346220ull,
  15500127091346543507ull, 7314393968949252937ull}},
{{639087892418496827ull, 8038649070786794872ull, 5540100808901015672ull,
  9142992461186566172ull}},
{{399429932761560517ull, 5024155669241746795ull,
  12685935042417910603ull, 5714370288241603857ull}},
{{14334345471234114358ull, 1668508568124795589ull,
  2022360747740224542ull, 7142962860302004822ull}},
{{4082873783760479235ull, 11309007747010770295ull,
  11751322971530056485ull, 8928703575377506027ull}},
{{9469325142491381378ull, 9373972851095425386ull,
  5038733847992591351ull, 5580439734610941267ull}},
{{2613284391259450915ull, 7105780045441893829ull,
  1686731291563351285ull, 6975549668263676584ull}},
{{7878291507501701547ull, 13493911075229755190ull,
  2108414114454189106ull, 8719437085329595730ull}},
{{312246173761175563ull, 13045380440445984898ull,
  5929444839961256095ull, 5449648178330997331ull}},
{{9613679754056245262ull, 11695039532130093218ull,
  2800120031524182215ull, 6812060222913746664ull}},
{{2793727655715530769ull, 10007113396735228619ull,
  3500150039405227769ull, 8515075278642183330ull}},
{{17886980849318064395ull, 17783660919027987646ull,
  6799279793055655259ull, 5321922049151364581ull}},
{{13135354024792804685ull, 17617890130357596654ull,
  13110785759746956978ull, 6652402561439205726ull}},
{{7195820494136230049ull, 12798990626092220010ull,
  7165110162828920415ull, 8315503201799007158ull}},
{{9109073827262531685ull, 14916898168948719362ull,
  18313251907050238971ull, 5197189501124379473ull}},
{{2162970247223388798ull, 14034436692758511299ull,
  9056506828530635002ull, 6496486876405474342ull}},
{{16538770864311399709ull, 8319673829093363315ull,
  2097261498808517945ull, 8120608595506842928ull}},
{{8030888780980930866ull, 16729011189251821832ull,
  1310788436755323715ull, 5075380372191776830ull}},
{{10038610976226163583ull, 16299577968137389386ull,
  10861857582798930452ull, 6344225465239721037ull}},
{{3324891683427928670ull, 1927728386462185117ull,
  18189007996926050970ull, 7930281831549651296ull}},
{{4383900311356149371ull, 5816516259966253602ull,
  11368129998078781856ull, 4956426144718532060ull}},
{{14703247426049962522ull, 7270645324957817002ull,
  14210162497598477320ull, 6195532680898165075ull}},
{{9155687245707677344ull, 9088306656197271253ull,
  13151017103570708746ull, 7744415851122706344ull}},
{{8028147537780992292ull, 10291877678550682437ull,
  8219385689731692966ull, 4840259906951691465ull}},
{{14646870440653628269ull, 3641475061333577238ull,
  14885918130592004112ull, 6050324883689614331ull}},
{{9085216013962259528ull, 4551843826666971548ull,
  13995711644812617236ull, 7562906104612017914ull}},
{{14901632045581188013ull, 12068274428521633025ull,
  13359005796435273676ull, 4726816315382511196ull}},
{{4791982001694321305ull, 15085343035652041282ull,
  16698757245544092095ull, 5908520394228138995ull}},
{{15213349538972677439ull, 14244992776137663698ull,
  16261760538502727215ull, 7385650492785173744ull}},
{{14120029480285311303ull, 15820649512727121667ull,
  10163600336564204509ull, 4616031557990733590ull}},
{{13038350831929251225ull, 5940753835626738372ull,
  3481128383850479829ull, 5770039447488416988ull}},
{{16297938539911564031ull, 12037628312960810869ull,
  4351410479813099786ull, 7212549309360521235ull}},
{{6537365119607291327ull, 5823663354346237779ull, 827577081338986829ull,
  9015686636700651544ull}},
{{1780010190540863127ull, 5945632605680092564ull, 517235675836866768ull,
  5634804147937907215ull}},
{{2225012738176078909ull, 7432040757100115705ull,
  14481602650078247172ull, 7043505184922384018ull}},
{{7392951941147486540ull, 9290050946375144631ull,
  8878631275743033157ull, 8804381481152980023ull}},
{{11538123990858260944ull, 8112124850698159346ull,
  12466673574980477579ull, 5502738425720612514ull}},
{{5199282951718050372ull, 5528470044945311279ull,
  6359969931870821166ull, 6878423032150765643ull}},
{{1887417671220175061ull, 16133959593036414907ull,
  3338276396411138553ull, 8598028790188457054ull}},
{{17320537109008467077ull, 3166195718006677460ull,
  15921480803039125308ull, 5373767993867785658ull}},
{{3203927312551032230ull, 3957744647508346826ull,
  10678478966944130827ull, 6717209992334732073ull}},
{{13228281177543566096ull, 335494790958045628ull,
  17959784727107551438ull, 8396512490418415091ull}},
{{17491047772819504618ull, 14044742299630942229ull,
  8919022445228525696ull, 5247820306511509432ull}},
{{8028751660742217060ull, 17555927874538677787ull,
  11148778056535657120ull, 6559775383139386790ull}},
{{5424253557500383421ull, 3498165769463795618ull,
  4712600533814795593ull, 8199719228924233488ull}},
{{8001844491865127543ull, 13715568651983342021ull,
  2945375333634247245ull, 5124824518077645930ull}},
{{14613991633258797332ull, 3309402759697013814ull,
  12905091203897584865ull, 6406030647597057412ull}},
{{9044117504718720857ull, 8748439468048655172ull,
  16131364004871981081ull, 8007538309496321765ull}},
{{14875945477303976344ull, 16996989713598879242ull,
  12387945512258682127ull, 5004711443435201103ull}},
{{9371559809775194622ull, 16634551123571211149ull,
  10873245871895964755ull, 6255889304294001379ull}},
{{16326135780646381181ull, 16181502886036626032ull,
  8979871321442568040ull, 7819861630367501724ull}},
{{10203834862903988238ull, 10113439303772891270ull,
  14835791612756380833ull, 4887413518979688577ull}},
{{3531421541775209490ull, 17253485148143501992ull,
  4709681460663312329ull, 6109266898724610722ull}},
{{4414276927219011862ull, 7731798379897213778ull,
  15110473862683916220ull, 7636583623405763402ull}},
{{7370609097939270318ull, 14055746024290534419ull,
  14055732182604835541ull, 4772864764628602126ull}},
{{4601575353996699993ull, 3734624475081004312ull,
  8346293191401268619ull, 5966080955785752658ull}},
{{5751969192495874991ull, 56594575423867486ull, 1209494452396809966ull,
  7457601194732190823ull}},
{{17430038800592085582ull, 13870429664922080890ull,
  7673463060389088084ull, 4661000746707619264ull}},
{{12564176463885331169ull, 17338037081152601113ull,
  9591828825486360105ull, 5826250933384524080ull}},
{{1870162524574500249ull, 7837488296158587680ull,
  11989786031857950132ull, 7282813666730655100ull}},
{{2337703155718125312ull, 9796860370198234600ull,
  14987232539822437665ull, 9103517083413318875ull}},
{{1461064472323828320ull, 17652252777442366385ull,
  7061177328175329588ull, 5689698177133324297ull}},
{{6438016608832173304ull, 3618571898093406365ull,
  13438157678646549890ull, 7112122721416655371ull}},
{{12659206779467604534ull, 13746586909471533764ull,
  12186011079880799458ull, 8890153401770819214ull}},
{{17135376274022028642ull, 13203302836847096506ull,
  3004570906498111757ull, 5556345876106762009ull}},
{{12195848305672759994ull, 2669070490776706921ull,
  8367399651550027601ull, 6945432345133452511ull}},
{{1409752326808786280ull, 7948024131898271556ull,
  5847563546010146597ull, 8681790431416815639ull}},
{{10104467241110267233ull, 7273358091650113674ull,
  10572256243897423479ull, 5426119019635509774ull}},
{{3407212014533058234ull, 4480011596135254189ull,
  3991948268017003541ull, 6782648774544387218ull}},
{{8870701036593710696ull, 10211700513596455640ull,
  14213307371876030234ull, 8478310968180484022ull}},
{{5544188147871069185ull, 10993998839425172679ull,
  4271631088995130992ull, 5298944355112802514ull}},
{{2318549166411448577ull, 13742498549281465849ull,
  14562910898098689548ull, 6623680443891003142ull}},
{{7509872476441698625ull, 17178123186601832311ull,
  8980266585768586127ull, 8279600554863753928ull}},
{{11611199325417143497ull, 17653856019267227050ull,
  5612666616105366329ull, 5174750346789846205ull}},
{{5290627119916653563ull, 8232261968801870101ull,
  11627519288559095816ull, 6468437933487307756ull}},
{{11224969918323204858ull, 10290327461002337626ull,
  14534399110698869770ull, 8085547416859134695ull}},
{{11627292217379390940ull, 11043140681553848920ull,
  16001528471827875462ull, 5053467135536959184ull}},
{{14534115271724238675ull, 4580553815087535342ull,
  1555166516075292712ull, 6316833919421198981ull}},
{{8944272052800522536ull, 5725692268859419178ull,
  6555644163521503794ull, 7896042399276498726ull}},
{{10201856051427714489ull, 8190243686464524890ull,
  17932335657483103583ull, 4935026499547811703ull}},
{{3528948027429867303ull, 5626118589653268209ull,
  17803733553426491575ull, 6168783124434764629ull}},
{{9022871052714722033ull, 2420962218639197357ull,
  8419608886500950757ull, 7710978905543455787ull}},
{{7945137417160395223ull, 3818944395863192300ull,
  2956412544849400271ull, 4819361815964659867ull}},
{{9931421771450494029ull, 161994476401602471ull,
  17530573736343914051ull, 6024202269955824833ull}},
{{7802591195885729632ull, 14037551150784166801ull,
  8078159115147728851ull, 7530252837444781042ull}},
{{16405834543497050780ull, 6467626460026410298ull,
  9660535465394718436ull, 4706408023402988151ull}},
{{11283921142516537667ull, 8084533075033012873ull,
  7463983313316010141ull, 5883010029253735189ull}},
{{269843372863508371ull, 14717352362218653996ull,
  13941665160072400580ull, 7353762536567168986ull}},
{{337304216079385464ull, 18396690452773317495ull,
  8203709413235724917ull, 9192203170708961233ull}},
{{7128344162690697771ull, 13803774542197017386ull,
  16656533429340797833ull, 5745126981693100770ull}},
{{18133802240218148022ull, 3419660122464108020ull,
  11597294749821221484ull, 7181408727116375963ull}},
{{4220508726563133411ull, 4274575153080135026ull,
  9884932418849138951ull, 8976760908895469954ull}},
{{7249503972529346286ull, 9589138498316166247ull,
  10789768780208099748ull, 5610475568059668721ull}},
{{4450193947234294954ull, 11986423122895207809ull,
  18098896993687512589ull, 7013094460074585901ull}},
{{10174428452470256596ull, 1147970848336846049ull,
  8788563186827227025ull, 8766368075093232377ull}},
{{17888232828862380133ull, 12246696826278998540ull,
  17022067037835486650ull, 5478980046933270235ull}},
{{3913546962368423550ull, 6084998995993972368ull,
  16665897778866970409ull, 6848725058666587794ull}},
{{4891933702960529437ull, 12217934763419853364ull,
  11609000186728937203ull, 8560906323333234743ull}},
{{12280830601205106706ull, 5330366217923714400ull,
  14173154144346667608ull, 5350566452083271714ull}},
{{15351038251506383383ull, 6662957772404643000ull,
  8493070643578558702ull, 6688208065104089643ull}},
{{742053740673427612ull, 17552069252360579559ull,
  6004652286045810473ull, 8360260081380112054ull}},
{{7381312615561974114ull, 4052514255084280368ull,
  17587965734060795258ull, 5225162550862570033ull}},
{{9226640769452467642ull, 14289014855710126268ull,
  8149899112293830360ull, 6531453188578212542ull}},
{{11533300961815584553ull, 17861268569637657835ull,
  964001853512512142ull, 8164316485722765678ull}},
{{4902470091921046394ull, 6551606837596148243ull,
  14437559213727483801ull, 5102697803576728548ull}},
{{1516401596473920088ull, 12801194565422573208ull,
  18046949017159354751ull, 6378372254470910685ull}},
{{1895501995592400110ull, 11389807188350828606ull,
  8723628216167029727ull, 7972965318088638357ull}},
{{15019746802527413781ull, 14036158520360349734ull,
  7758110644318087531ull, 4983103323805398973ull}},
{{9551311466304491418ull, 12933512132023049264ull,
  14309324323824997318ull, 6228879154756748716ull}},
{{11939139332880614272ull, 6943518128174035772ull,
  17886655404781246648ull, 7786098943445935895ull}},
{{16685334119905159728ull, 4339698830108772357ull,
  18096688655629361011ull, 4866311839653709934ull}},
{{7021609594599285948ull, 812937519208577543ull,
  13397488782681925456ull, 6082889799567137418ull}},
{{4165325974821719531ull, 1016171899010721929ull,
  7523488941497631012ull, 7603612249458921773ull}},
{{14132543780332044467ull, 9858479473736477013ull,
  7008023597649713334ull, 4752257655911826108ull}},
{{3830621670132891872ull, 3099727305315820459ull,
  8760029497062141668ull, 5940322069889782635ull}},
{{176591069238726936ull, 3874659131644775574ull, 6338350852900289181ull,
  7425402587362228294ull}},
{{13945427473556368047ull, 4727504966491678685ull,
  17796527338344844450ull, 4640876617101392683ull}},
{{3596726286663296347ull, 15132753244969374165ull,
  17633973154503667658ull, 5801095771376740854ull}},
{{9107593876756508337ull, 9692569519356941898ull,
  12819094406274808765ull, 7251369714220926068ull}},
{{2161120309090859613ull, 16727397917623565277ull,
  16023868007843510956ull, 9064212142776157585ull}},
{{3656543202395481210ull, 1231251661659952490ull,
  3097388477261112492ull, 5665132589235098491ull}},
{{13794051039849127321ull, 1539064577074940612ull,
  17706793651858554327ull, 7081415736543873113ull}},
{{17242563799811409151ull, 15758888776625839477ull,
  8298434009541029196ull, 8851769670679841392ull}},
{{13082445384095824672ull, 625933448536373865ull,
  5186521255963143248ull, 5532356044174900870ull}},
{{2517998674837617127ull, 782416810670467332ull,
  15706523606808704868ull, 6915445055218626087ull}},
{{3147498343547021409ull, 978021013338084165ull,
  15021468490083493181ull, 8644306319023282609ull}},
{{4273029473930582333ull, 2917106142549996555ull,
  2470888778661101382ull, 5402691449389551631ull}},
{{729600823985840012ull, 12869754715042271502ull,
  16923669028608540439ull, 6753364311736939538ull}},
{{10135373066837075823ull, 11475507375375451473ull,
  11931214248905899741ull, 8441705389671174423ull}},
{{17863823212841642149ull, 9478035118823351122ull,
  14374537933207269194ull, 5276065868544484014ull}},
{{13106406979197276879ull, 2624171861674413095ull,
  8744800379654310685ull, 6595082335680605018ull}},
{{11771322705569208194ull, 7891900845520404273ull,
  1707628437713112548ull, 8243852919600756273ull}},
{{439547663339673266ull, 14155810065305028479ull,
  12596482819639165102ull, 5152408074750472670ull}},
{{14384492634456755294ull, 8471390544776509790ull,
  6522231487694180570ull, 6440510093438090838ull}},
{{8757243756216168309ull, 1365866144115861430ull,
  17376161396472501521ull, 8050637616797613547ull}},
{{861591329207717289ull, 12382881386140883154ull,
  8554257863581619498ull, 5031648510498508467ull}},
{{10300361198364422420ull, 6255229695821328134ull,
  6081136311049636469ull, 6289560638123135584ull}},
{{3652079461100752216ull, 12430723138204048072ull,
  7601420388812045586ull, 7861950797653919480ull}},
{{2282549663187970135ull, 12380887979804917949ull,
  4750887743007528491ull, 4913719248533699675ull}},
{{7464873097412350573ull, 10864423956328759532ull,
  1326923660332022710ull, 6142149060667124594ull}},
{{9331091371765438216ull, 4357157908556173607ull,
  10882026612269804196ull, 7677686325833905742ull}},
{{12749461134994480741ull, 11946595729702384312ull,
  2189580614241239718ull, 4798553953646191089ull}},
{{15936826418743100927ull, 5709872625273204582ull,
  7348661786228937552ull, 5998192442057738861ull}},
{{10697660986574100350ull, 7137340781591505728ull,
  13797513251213559844ull, 7497740552572173576ull}},
{{6686038116608812719ull, 13684210025349466888ull,
  8623445782008474902ull, 4686087845357608485ull}},
{{8357547645761015899ull, 7881890494832057802ull,
  15390993245937981532ull, 5857609806697010606ull}},
{{1223562520346494065ull, 9852363118540072253ull,
  10015369520567701107ull, 7322012258371263258ull}},
{{6141139168860505485ull, 7703767879747702412ull,
  3295839863854850576ull, 9152515322964079073ull}},
{{13061584017392591737ull, 4814854924842314007ull,
  13589114960977751370ull, 5720322076852549420ull}},
{{11715294003313351767ull, 15241940692907668317ull,
  16986393701222189212ull, 7150402596065686775ull}},
{{809059448859525996ull, 605681792425033781ull, 16621306108100348612ull,
  8938003245082108469ull}},
{{2811505164750897700ull, 9601923157120421921ull,
  12694159326776411834ull, 5586252028176317793ull}},
{{8126067474366010029ull, 2779031909545751593ull,
  2032641103188351081ull, 6982815035220397242ull}},
{{14769270361384900440ull, 8085475905359577395ull,
  11764173415840214659ull, 8728518794025496552ull}},
{{6924950966651868823ull, 2747579431636041920ull,
  7352608384900134162ull, 5455324246265935345ull}},
{{8656188708314836029ull, 12657846326399828208ull,
  13802446499552555606ull, 6819155307832419181ull}},
{{10820235885393545036ull, 6598935871145009452ull,
  3418000069158530796ull, 8523944134790523977ull}},
{{15986019465225741455ull, 13347706956320406715ull,
  13665465089292551507ull, 5327465084244077485ull}},
{{15370838313104788915ull, 12072947676973120490ull,
  3246773306333525672ull, 6659331355305096857ull}},
{{9990175854526210336ull, 15091184596216400613ull,
  8670152651344294994ull, 8324164194131371071ull}},
{{8549702918292575412ull, 14043676391062638287ull,
  12336374434731266227ull, 5202602621332106919ull}},
{{6075442629438331361ull, 12942909470400909955ull,
  10808782024986694880ull, 6503253276665133649ull}},
{{2982617268370526297ull, 16178636838001137444ull,
  18122663549660756504ull, 8129066595831417061ull}},
{{11087507829586354744ull, 10111648023750710902ull,
  13632507727751666767ull, 5080666622394635663ull}},
{{4636012750128167622ull, 8027874011261000724ull,
  12428948641262195555ull, 6350833277993294579ull}},
{{5795015937660209527ull, 5423156495648863001ull,
  10924499783150356540ull, 7938541597491618224ull}},
{{15151100007106100715ull, 12612844846635315183ull,
  6827812364468972837ull, 4961588498432261390ull}},
{{14327188990455237989ull, 1930998003011980267ull,
  17758137492440991855ull, 6201985623040326737ull}},
{{13297300219641659582ull, 16248805559047139046ull,
  8362613810269076106ull, 7752482028800408422ull}},
{{3699126618848649335ull, 14767189492831849808ull,
  614947612990784662ull, 4845301268000255264ull}}
};

static const UINT256 multipliers2_binary80[] =
  { {{6207925045053820451ull, 7278732838564269635ull,
      11692571226397904350ull, 2627592000557903659ull}},
{{3148220287889887660ull, 18321788085060112852ull,
  10004028014569992533ull, 3284490000697379574ull}},
{{3935275359862359575ull, 9067177051042977353ull,
  3281662981357714859ull, 4105612500871724468ull}},
{{13988762145982444495ull, 3361142647688166893ull,
  11274411400203347595ull, 2566007813044827792ull}},
{{3650894627195891906ull, 18036486364892372329ull,
  14093014250254184493ull, 3207509766306034740ull}},
{{9175304302422252786ull, 8710549900833301699ull,
  17616267812817730617ull, 4009387207882543425ull}},
{{3428722179800214040ull, 16973308734089283322ull,
  4092638355369999779ull, 2505867004926589641ull}},
{{13509274761605043357ull, 16604949899184216248ull,
  9727483962639887628ull, 3132333756158237051ull}},
{{16886593452006304197ull, 2309443300270718694ull,
  7547668934872471632ull, 3915417195197796314ull}},
{{5942434889076552219ull, 1443402062669199184ull,
  9328979102722682674ull, 2447135746998622696ull}},
{{7428043611345690274ull, 11027624615191274788ull,
  11661223878403353342ull, 3058919683748278370ull}},
{{9285054514182112842ull, 4561158732134317677ull,
  5353157811149415870ull, 3823649604685347963ull}},
{{8109002080577514479ull, 16685782262866112260ull,
  1039880622754690966ull, 2389781002928342477ull}},
{{10136252600721893098ull, 11633855791727864517ull,
  5911536796870751612ull, 2987226253660428096ull}},
{{17282001769329754276ull, 14542319739659830646ull,
  7389420996088439515ull, 3734032817075535120ull}},
{{6189565087403708519ull, 6783106828073700202ull,
  4618388122555274697ull, 2333770510672209450ull}},
{{16960328396109411457ull, 13090569553519513156ull,
  14996357190048869179ull, 2917213138340261812ull}},
{{2753666421427212705ull, 11751525923472003542ull,
  298702413851534858ull, 3646516422925327266ull}},
{{12665455063638791689ull, 5466035367485228619ull,
  9596750054169194381ull, 4558145528656659082ull}},
{{5610066405560550854ull, 5722115113891961839ull,
  10609654802283134392ull, 2848840955410411926ull}},
{{2400896988523300663ull, 7152643892364952299ull,
  4038696465999142182ull, 3561051194263014908ull}},
{{16836179290936289540ull, 18164176902310966181ull,
  5048370582498927727ull, 4451313992828768635ull}},
{{12828455066048874915ull, 18270139591585435719ull,
  849388604848135877ull, 2782071245517980397ull}},
{{11423882814133705740ull, 9002616434199630937ull,
  5673421774487557751ull, 3477589056897475496ull}},
{{444795462384968462ull, 6641584524322150768ull, 7091777218109447189ull,
  4346986321121844370ull}},
{{277997163990605289ull, 6456833336915038182ull, 9044046779745792397ull,
  2716866450701152731ull}},
{{9570868491843032419ull, 12682727689571185631ull,
  6693372456254852592ull, 3396083063376440914ull}},
{{7351899596376402620ull, 15853409611963982039ull,
  17590087607173341548ull, 4245103829220551142ull}},
{{11512466275376333494ull, 685008970622712966ull,
  6382118736055950564ull, 2653189893262844464ull}},
{{5167210807365641059ull, 856261213278391208ull, 7977648420069938205ull,
  3316487366578555580ull}},
{{6459013509207051324ull, 5682012535025376914ull,
  9972060525087422756ull, 4145609208223194475ull}},
{{8648569461681794981ull, 12774629871245636379ull,
  3926694818965945270ull, 2591005755139496547ull}},
{{6199025808674855823ull, 6744915302202269666ull, 296682505280043684ull,
  3238757193924370684ull}},
{{16972154297698345586ull, 8431144127752837082ull,
  370853131600054605ull, 4048446492405463355ull}},
{{15219282454488853896ull, 7575308089059217128ull,
  16372684271745891792ull, 2530279057753414596ull}},
{{577358994401515753ull, 9469135111324021411ull, 2019111265972813124ull,
  3162848822191768246ull}},
{{14556756798284058404ull, 11836418889155026763ull,
  11747261119320792213ull, 3953561027739710307ull}},
{{6792129989713842550ull, 9703604814935585679ull,
  5036195190361801181ull, 2470975642337318942ull}},
{{3878476468714915284ull, 16741192037096870003ull,
  15518616024807027284ull, 3088719552921648677ull}},
{{236409567466256201ull, 2479745972661535888ull, 5563211975726620394ull,
  3860899441152060847ull}},
{{147755979666410126ull, 6161527251340847834ull,
  10394536512470219602ull, 2413062150720038029ull}},
{{9408067011437788465ull, 16925281101030835600ull,
  17604856659015162406ull, 3016327688400047536ull}},
{{11760083764297235581ull, 11933229339433768692ull,
  3559326750059401392ull, 3770409610500059421ull}},
{{16573424389540548046ull, 7458268337146105432ull,
  4530422228000819822ull, 2356506006562537138ull}},
{{2270036413216133442ull, 99463384577855983ull, 14886399821855800586ull,
  2945632508203171422ull}},
{{16672603571802330514ull, 9347701267577095786ull,
  9384627740464974924ull, 3682040635253964278ull}},
{{11617382427898137335ull, 11684626584471369733ull,
  2507412638726442847ull, 4602550794067455348ull}},
{{9566707026650029786ull, 14220420642935687939ull,
  10790504936058802587ull, 2876594246292159592ull}},
{{7346697764885149329ull, 13163839785242222020ull,
  13488131170073503234ull, 3595742807865199490ull}},
{{9183372206106436661ull, 7231427694698001717ull,
  7636791925737103235ull, 4494678509831499363ull}},
{{8045450638030216865ull, 2213799299972557121ull,
  2467151944371995570ull, 2809174068644687102ull}},
{{14668499315965158985ull, 11990621161820472209ull,
  12307311967319770270ull, 3511467585805858877ull}},
{{4500566089674285020ull, 5764904415420814454ull,
  1549081903867549126ull, 4389334482257323597ull}},
{{16647911861328591849ull, 17438123314920172745ull,
  3274019199130912155ull, 2743334051410827248ull}},
{{6974831771378576100ull, 17185968125222828028ull,
  4092523998913640194ull, 3429167564263534060ull}},
{{8718539714223220124ull, 12259088119673759227ull,
  5115654998642050243ull, 4286459455329417575ull}},
{{3143244312175818626ull, 5356087065582405565ull,
  10114813401792363258ull, 2679037159580885984ull}},
{{8540741408647161186ull, 15918480868832782764ull,
  12643516752240454072ull, 3348796449476107480ull}},
{{10675926760808951483ull, 1451357012331426839ull,
  15804395940300567591ull, 4185995561845134350ull}},
{{13589983253146676533ull, 7824627160348223630ull,
  5266061444260466840ull, 2616247226153208969ull}},
{{7764107029578569858ull, 9780783950435279538ull,
  11194262823752971454ull, 3270309032691511211ull}},
{{481761750118436514ull, 3002607901189323615ull, 9381142511263826414ull,
  4087886290864389014ull}},
{{7218630121465104678ull, 15711687993525490971ull,
  1251528051112503604ull, 2554928931790243134ull}},
{{4411601633403992943ull, 1192865918197312098ull,
  10787782100745405314ull, 3193661164737803917ull}},
{{14737874078609766987ull, 10714454434601415930ull,
  18096413644359144546ull, 3992076455922254896ull}},
{{13822857317558492271ull, 11308220040053272860ull,
  11310258527724465341ull, 2495047784951409310ull}},
{{17278571646948115338ull, 300216994784427363ull,
  4914451122800805869ull, 3118809731189261638ull}},
{{16986528540257756269ull, 4986957261907922108ull,
  15366435940355783144ull, 3898512163986577047ull}},
{{1393208300806321860ull, 3116848288692451318ull,
  16521551490363446321ull, 2436570102491610654ull}},
{{10964882412862678133ull, 8507746379292952051ull,
  11428567326099532093ull, 3045712628114513318ull}},
{{9094416997650959762ull, 15246368992543577968ull,
  5062337120769639308ull, 3807140785143141648ull}},
{{5684010623531849852ull, 305608583484960422ull, 3163960700481024568ull,
  2379462990714463530ull}},
{{16328385316269588122ull, 382010729356200527ull,
  13178322912456056518ull, 2974328738393079412ull}},
{{15798795626909597249ull, 9700885448550026467ull,
  16472903640570070647ull, 3717910922991349265ull}},
{{7568404257604804329ull, 12980582432984848398ull,
  3378035747715212298ull, 2323694326869593291ull}},
{{237133285151229603ull, 7002356004376284690ull,
  18057602739926179085ull, 2904617908586991613ull}},
{{9519788643293812811ull, 13364631023897743766ull,
  8736945369625560144ull, 3630772385733739517ull}},
{{2676363767262490206ull, 16705788779872179708ull,
  15532867730459338084ull, 4538465482167174396ull}},
{{10896099391393832187ull, 1217745950565336509ull,
  484670294682310495ull, 2836540926354483998ull}},
{{18231810257669678138ull, 15357240493488834348ull,
  9829209905207663926ull, 3545676157943104997ull}},
{{4343018748377546056ull, 9973178580006267128ull,
  16898198399936967812ull, 4432095197428881246ull}},
{{2714386717735966285ull, 15456608649358692763ull,
  5949687981533216978ull, 2770059498393050779ull}},
{{17228041452452121568ull, 10097388774843590145ull,
  2825423958489133319ull, 3462574372991313474ull}},
{{7699993760282988248ull, 8010049950127099778ull,
  12755151984966192457ull, 4328217966239141842ull}},
{{9424182118604255559ull, 16535496264897907121ull,
  12583656009031258189ull, 2705136228899463651ull}},
{{16391913666682707353ull, 6834312275840220189ull,
  11117883992861684833ull, 3381420286124329564ull}},
{{6654834028071220479ull, 13154576363227663141ull,
  13897354991077106041ull, 4226775357655411955ull}},
{{6465114276758206752ull, 1304081199376207607ull,
  6380003860209497324ull, 2641734598534632472ull}},
{{3469706827520370535ull, 1630101499220259509ull,
  7975004825261871655ull, 3302168248168290590ull}},
{{8948819552827851073ull, 15872684929307488098ull,
  745383994722563760ull, 4127710310210363238ull}},
{{10204698238944794825ull, 9920428080817180061ull,
  14300923051983766062ull, 2579818943881477023ull}},
{{17367558817108381435ull, 3177163064166699268ull,
  13264467796552319674ull, 3224773679851846279ull}},
{{3262704447675925178ull, 13194825867063149894ull,
  11968898727263011688ull, 4030967099814807849ull}},
{{15874248335079616948ull, 8246766166914468683ull,
  563032676898300449ull, 2519354437384254906ull}},
{{15231124400422133281ull, 14920143727070473758ull,
  9927162882977651369ull, 3149193046730318632ull}},
{{9815533463672890793ull, 4815121603555928486ull,
  12408953603722064212ull, 3936491308412898290ull}},
{{1523022396368168842ull, 12232823039077231112ull,
  12367282020753678036ull, 2460307067758061431ull}},
{{1903777995460211052ull, 15291028798846538890ull,
  10847416507514709641ull, 3075383834697576789ull}},
{{11603094531180039623ull, 5278727943276009900ull,
  18170956652820774956ull, 3844229793371970986ull}},
{{16475306118842300573ull, 12522577001402281995ull,
  15968533926440372251ull, 2402643620857481866ull}},
{{15982446630125487812ull, 11041535233325464590ull,
  10737295371195689506ull, 3003304526071852333ull}},
{{10754686250802083957ull, 4578547004802054930ull,
  18033305232421999787ull, 3754130657589815416ull}},
{{11333364925178690377ull, 555748868787590379ull,
  11270815770263749867ull, 2346331660993634635ull}},
{{9555020138045975067ull, 14529744141266651686ull,
  9476833694402299429ull, 2932914576242043294ull}},
{{2720403135702693026ull, 4327122121301150896ull,
  2622670081148098479ull, 3666143220302554118ull}},
{{3400503919628366282ull, 797216633199050716ull,
  12501709638289898907ull, 4582679025378192647ull}},
{{11348686986622504735ull, 16639161460245264361ull,
  14731097551572268672ull, 2864174390861370404ull}},
{{350800677995967206ull, 2352207751597028836ull,
  18413871939465335841ull, 3580217988576713005ull}},
{{438500847494959008ull, 7551945707923673949ull, 9182281869049506089ull,
  4475272485720891257ull}},
{{2579906038898043332ull, 16249181113520765978ull,
  17268141214224411065ull, 2797045303575557035ull}},
{{12448254585477329973ull, 6476418336618793760ull,
  16973490499353125928ull, 3496306629469446294ull}},
{{15560318231846662466ull, 8095522920773492200ull,
  11993491087336631602ull, 4370383286836807868ull}},
{{9725198894904164041ull, 9671387843910820529ull,
  16719303966440170559ull, 2731489554273004917ull}},
{{16768184637057592956ull, 7477548786461137757ull,
  7064071902768049487ull, 3414361942841256147ull}},
{{7125172741039827482ull, 4735249964649034293ull,
  4218403860032673955ull, 4267952428551570184ull}},
{{6759075972363586129ull, 653688218691952481ull, 2636502412520421222ull,
  2667470267844731365ull}},
{{13060530983881870565ull, 10040482310219716409ull,
  7907314034077914431ull, 3334337834805914206ull}},
{{2490605674570174494ull, 7938916869347257608ull, 660770505742617231ull,
  4167922293507392758ull}},
{{1556628546606359059ull, 11879352070983117861ull,
  14248039621371299481ull, 2604951433442120473ull}},
{{6557471701685336727ull, 1014132033446733614ull,
  3974991471431960640ull, 3256189291802650592ull}},
{{17420211663961446717ull, 1267665041808417017ull,
  4968739339289950800ull, 4070236614753313240ull}},
{{3970103262334822342ull, 792290651130260636ull, 3105462087056219250ull,
  2543897884220820775ull}},
{{4962629077918527928ull, 10213735350767601603ull,
  17716885664102437774ull, 3179872355276025968ull}},
{{1591600328970772006ull, 3543797151604726196ull,
  3699363006418495602ull, 3974840444095032461ull}},
{{10218122242461508312ull, 6826559238180341776ull,
  4617944888225253703ull, 2484275277559395288ull}},
{{12772652803076885390ull, 3921513029298039316ull,
  5772431110281567129ull, 3105344096949244110ull}},
{{15965816003846106737ull, 9513577305049937049ull,
  16438910924706734719ull, 3881680121186555137ull}},
{{3061105974762734855ull, 12863514843297292512ull,
  3356790300300627343ull, 2426050075741596961ull}},
{{3826382468453418568ull, 11467707535694227736ull,
  8807673893803172083ull, 3032562594676996201ull}},
{{4782978085566773210ull, 9722948401190396766ull,
  15621278385681353008ull, 3790703243346245251ull}},
{{16824419358761396969ull, 6076842750743997978ull,
  7457455981837151678ull, 2369189527091403282ull}},
{{11807152161596970403ull, 16819425475284773281ull,
  98447940441663789ull, 2961486908864254103ull}},
{{923882146714049291ull, 7189223788823802890ull,
  13958117980834243449ull, 3701858636080317628ull}},
{{5189112360123668711ull, 16022479914083346566ull,
  17947195774876177963ull, 2313661647550198517ull}},
{{15709762487009361697ull, 15416413874176795303ull,
  8598936663313058742ull, 2892077059437748147ull}},
{{15025517090334314217ull, 10047145305866218321ull,
  6136984810713935524ull, 3615096324297185184ull}},
{{4946838307635729059ull, 12558931632332772902ull,
  7671231013392419405ull, 4518870405371481480ull}},
{{16926831997554494374ull, 10155175279421677015ull,
  4794519383370262128ull, 2824294003357175925ull}},
{{16546853978515730063ull, 12693969099277096269ull,
  10604835247640215564ull, 3530367504196469906ull}},
{{6848509417862498867ull, 15867461374096370337ull,
  4032672022695493647ull, 4412959380245587383ull}},
{{15809533432232531552ull, 16834692386451313316ull,
  9437949041825765385ull, 2758099612653492114ull}},
{{1315172716581112824ull, 7208307427781977934ull,
  2574064265427430924ull, 3447624515816865143ull}},
{{10867337932581166838ull, 9010384284727472417ull,
  17052638387066452367ull, 4309530644771081428ull}},
{{18321301253931699034ull, 12549019205595752116ull,
  1434526955061756921ull, 2693456652981925893ull}},
{{4454882493705072176ull, 1851215951712526434ull,
  6404844712254584056ull, 3366820816227407366ull}},
{{14791975153986116028ull, 2314019939640658042ull,
  17229427927173005878ull, 4208526020284259207ull}},
{{13856670489668710422ull, 15281320517557574988ull,
  17685921482124210529ull, 2630328762677662004ull}},
{{17320838112085888027ull, 5266592591664805023ull,
  3660657778945711546ull, 3287910953347077506ull}},
{{17039361621679972130ull, 15806612776435782087ull,
  13799194260536915240ull, 4109888691683846882ull}},
{{17567130041191064437ull, 9879132985272363804ull,
  13236182431262959929ull, 2568680432302404301ull}},
{{3512168477779278930ull, 16960602250017842660ull,
  2710169983796536199ull, 3210850540378005377ull}},
{{4390210597224098663ull, 16589066794094915421ull,
  7999398498173058153ull, 4013563175472506721ull}},
{{5049724632478755617ull, 3450637718668240282ull,
  16528839107426631106ull, 2508476984670316700ull}},
{{15535527827453220329ull, 13536669185190076160ull,
  2214304810573737266ull, 3135596230837895876ull}},
{{972665710606973795ull, 7697464444632819393ull, 2767881013217171583ull,
  3919495288547369845ull}},
{{12137131115197828382ull, 11728444305536593976ull,
  4035768642474426191ull, 2449684555342106153ull}},
{{15171413893997285477ull, 10048869363493354566ull,
  9656396821520420643ull, 3062105694177632691ull}},
{{9740895330641831038ull, 7949400685939305304ull,
  7458810008473137900ull, 3827632117722040864ull}},
{{6088059581651144399ull, 14191747465566841623ull,
  4661756255295711187ull, 2392270073576275540ull}},
{{2998388458636542595ull, 13127998313531164125ull,
  5827195319119638984ull, 2990337591970344425ull}},
{{8359671591723066147ull, 16409997891913955156ull,
  11895680167326936634ull, 3737921989962930531ull}},
{{14448166781681692150ull, 14867934700873609876ull,
  5128957095365641444ull, 2336201243726831582ull}},
{{18060208477102115188ull, 138174302382460729ull,
  15634568406061827614ull, 2920251554658539477ull}},
{{8740202541095480273ull, 9396089914832851720ull,
  5708152452295120805ull, 3650314443323174347ull}},
{{10925253176369350341ull, 16356798411968452554ull,
  2523504546941513102ull, 4562893054153967934ull}},
{{11439969253658231867ull, 5611312989052894942ull,
  15412248397120609401ull, 2851808158846229958ull}},
{{5076589530218014026ull, 11625827254743506582ull,
  10041938459545985943ull, 3564760198557787448ull}},
{{15569108949627293340ull, 9920598050001995323ull,
  12552423074432482429ull, 4455950248197234310ull}},
{{7424850084303364386ull, 8506216790464941029ull,
  3233578403092913614ull, 2784968905123271444ull}},
{{13892748623806593386ull, 1409398951226400478ull,
  4041973003866142018ull, 3481211131404089305ull}},
{{8142563742903465924ull, 10985120725887776406ull,
  9664152273260065426ull, 4351513914255111631ull}},
{{477416320887278299ull, 11477386472107248158ull,
  12957624198428622747ull, 2719696196409444769ull}},
{{9820142437963873681ull, 9735047071706672293ull,
  2361972192753614722ull, 3399620245511805962ull}},
{{16886864065882230006ull, 2945436802778564558ull,
  12175837277796794211ull, 4249525306889757452ull}},
{{5942604022749005850ull, 17981799066232460513ull,
  16833270335477772189ull, 2655953316806098407ull}},
{{12039941046863645216ull, 8642190777508411929ull,
  16429901900919827333ull, 3319941646007623009ull}},
{{1214868253297392808ull, 15414424490312902816ull,
  6702319320867620454ull, 4149927057509528762ull}},
{{759292658310870505ull, 5022329288018176356ull, 8800635593969650688ull,
  2593704410943455476ull}},
{{949115822888588131ull, 6277911610022720445ull,
  11000794492462063360ull, 3242130513679319345ull}},
{{5798080797038123068ull, 7847389512528400556ull,
  18362679134004967104ull, 4052663142099149181ull}},
{{12847172535003602726ull, 4904618445330250347ull,
  13782517467966798392ull, 2532914463811968238ull}},
{{11447279650327115503ull, 6130773056662812934ull,
  8004774798103722182ull, 3166143079764960298ull}},
{{5085727526054118571ull, 16886838357683291976ull,
  782596460774876919ull, 3957678849706200373ull}},
{{3178579703783824107ull, 17471803001193139341ull,
  2794965797197992026ull, 2473549281066375233ull}},
{{8584910648157168037ull, 12616381714636648368ull,
  8105393264924877937ull, 3091936601332969041ull}},
{{10731138310196460047ull, 1935419088013646748ull,
  14743427599583485326ull, 3864920751666211301ull}},
{{15930333480727563337ull, 15044694985290692929ull,
  11520485258953372280ull, 2415575469791382063ull}},
{{6077858795627290460ull, 359124657903814546ull, 9788920555264327447ull,
  3019469337239227579ull}},
{{16820695531388888882ull, 14283963877661931894ull,
  7624464675653021404ull, 3774336671549034474ull}},
{{5901248688690667648ull, 18150849460393483242ull,
  9376976440710526281ull, 2358960419718146546ull}},
{{16599932897718110367ull, 8853503770209690340ull,
  2497848514033382044ull, 2948700524647683183ull}},
{{2303172048438086343ull, 11066879712762112926ull,
  16957368697823891267ull, 3685875655809603978ull}},
{{12102337097402383737ull, 9221913622525253253ull,
  11973338835425088276ull, 4607344569762004973ull}},
{{9869803695090183788ull, 14987068050933059091ull,
  9789179781354374124ull, 2879590356101253108ull}},
{{7725568600435341830ull, 287090989956772248ull,
  12236474726692967656ull, 3599487945126566385ull}},
{{9656960750544177288ull, 358863737445965310ull, 1460535353084045858ull,
  4499359931408207982ull}},
{{1423914450662722901ull, 4835975854331116223ull,
  14747892650959692373ull, 2812099957130129988ull}},
{{15614951118610567338ull, 10656655836341283182ull,
  18434865813699615466ull, 3515124946412662485ull}},
{{10295316861408433365ull, 4097447758571828170ull,
  9208524211842355621ull, 4393906183015828107ull}},
{{11046259056807658757ull, 4866747858321086558ull,
  3449484623187778311ull, 2746191364384892567ull}},
{{4584451784154797638ull, 1471748804473970294ull,
  18146913834266886601ull, 3432739205481115708ull}},
{{14953936767048272856ull, 6451372024019850771ull,
  4236898219124056635ull, 4290924006851394636ull}},
{{7040367470191476583ull, 1726264505798712780ull,
  11871433423807311205ull, 2681827504282121647ull}},
{{8800459337739345729ull, 6769516650675778879ull,
  10227605761331751102ull, 3352284380352652059ull}},
{{6388888153746794257ull, 17685267850199499407ull,
  8172821183237300973ull, 4190355475440815074ull}},
{{10910584123732828267ull, 13359135415588381081ull,
  9719699257950701012ull, 2618972172150509421ull}},
{{18249916173093423237ull, 16698919269485476351ull,
  16761310090865764169ull, 3273715215188136776ull}},
{{18200709197939391142ull, 7038591031574681727ull,
  2504893539872653596ull, 4092144018985170971ull}},
{{18292972276353201320ull, 13622491431588951887ull,
  17706459526916266161ull, 2557590011865731856ull}},
{{18254529327014113746ull, 3193056234204026147ull,
  3686330334935781086ull, 3196987514832164821ull}},
{{18206475640340254279ull, 13214692329609808492ull,
  9219598937097114261ull, 3996234393540206026ull}},
{{2155675238357883116ull, 10565025715219824260ull,
  10373935354113084317ull, 2497646495962628766ull}},
{{2694594047947353895ull, 17817968162452168229ull,
  3744047155786579588ull, 3122058119953285958ull}},
{{7979928578361580273ull, 3825716129355658670ull,
  13903430981588000294ull, 3902572649941607447ull}},
{{375769343048599767ull, 16226130636129450381ull,
  15607173391133582039ull, 2439107906213504654ull}},
{{5081397697238137612ull, 15670977276734425072ull,
  10285594702062201741ull, 3048884882766880818ull}},
{{6351747121547672015ull, 5753663540635867628ull,
  3633621340722976369ull, 3811106103458601023ull}},
{{13193213987822070818ull, 15125254758965887027ull,
  9188542365592942086ull, 2381941314661625639ull}},
{{11879831466350200618ull, 9683196411852582976ull,
  6873991938563789704ull, 2977426643327032049ull}},
{{14849789332937750772ull, 12103995514815728720ull,
  13204175941632125034ull, 3721783304158790061ull}},
{{9281118333086094233ull, 12176683215187218354ull,
  10558452972733772098ull, 2326114565099243788ull}},
{{2378025879502841983ull, 5997481982129247135ull,
  13198066215917215123ull, 2907643206374054735ull}},
{{16807590404660716191ull, 2885166459234171014ull,
  11885896751469131000ull, 3634554007967568419ull}},
{{11786115968971119430ull, 3606458074042713768ull,
  10245684920909025846ull, 4543192509959460524ull}},
{{7366322480606949644ull, 16089094351558859817ull,
  15626925112422916961ull, 2839495318724662827ull}},
{{13819589119186074959ull, 6276309884166411059ull,
  14921970372101258298ull, 3549369148405828534ull}},
{{12662800380555205795ull, 17068759392062789632ull,
  9429090928271797064ull, 4436711435507285668ull}},
{{7914250237847003622ull, 10667974620039243520ull,
  15116553867024648973ull, 2772944647192053542ull}},
{{9892812797308754527ull, 17946654293476442304ull,
  9672320296926035408ull, 3466180808990066928ull}},
{{12366015996635943159ull, 3986573793136001264ull,
  12090400371157544261ull, 4332726011237583660ull}},
{{7728759997897464474ull, 4797451629923694742ull,
  16779872268828240971ull, 2707953757023489787ull}},
{{437577960517054785ull, 1385128518977230524ull,
  16363154317607913310ull, 3384942196279362234ull}},
{{546972450646318481ull, 10954782685576313963ull,
  11230570860155115829ull, 4231177745349202793ull}},
{{16482758846149806715ull, 9152582187698890178ull,
  101577759955865537ull, 2644486090843251746ull}},
{{11380076520832482585ull, 16052413753051000627ull,
  9350344236799607729ull, 3305607613554064682ull}},
{{9613409632613215328ull, 6230459136031587072ull,
  2464558259144733854ull, 4132009516942580853ull}},
{{6008381020383259580ull, 17729095015301905632ull,
  3846191921179152610ull, 2582505948089113033ull}},
{{7510476275479074475ull, 12937996732272606232ull,
  9419425919901328667ull, 3228132435111391291ull}},
{{9388095344348843093ull, 11560809896913369886ull,
  7162596381449272930ull, 4035165543889239114ull}},
{{1255873571790639030ull, 11837192203998244083ull,
  9088308756833183485ull, 2521978464930774446ull}},
{{15404900020020462499ull, 961432199715641391ull,
  2137013909186703549ull, 3152473081163468058ull}},
{{14644439006598190219ull, 5813476268071939643ull,
  11894639423338155244ull, 3940591351454335072ull}},
{{6846931369910174935ull, 12856794704399738085ull,
  7434149639586347027ull, 2462869594658959420ull}},
{{13170350230815106573ull, 11459307362072284702ull,
  9292687049482933784ull, 3078586993323699275ull}},
{{7239565751664107408ull, 14324134202590355878ull,
  7004172793426279326ull, 3848233741654624094ull}},
{{18359786650072230842ull, 4340897858191584519ull,
  18212666051173588291ull, 2405146088534140058ull}},
{{18338047294162900649ull, 814436304312092745ull,
  13542460527112209556ull, 3006432610667675073ull}},
{{9087501062421462099ull, 1018045380390115932ull,
  3093017603608098233ull, 3758040763334593842ull}},
{{14903060200868189620ull, 12165493408812292217ull,
  6544822020682449299ull, 2348775477084121151ull}},
{{4793767195803073313ull, 10595180742587977368ull,
  3569341507425673720ull, 2935969346355151439ull}},
{{5992208994753841641ull, 13243975928234971710ull,
  18296734939564255862ull, 3669961682943939298ull}},
{{16713633280297077859ull, 7331597873438938829ull,
  13647546637600544020ull, 4587452103679924123ull}},
{{12751863809399367614ull, 13805620707754112576ull,
  6223873639286646060ull, 2867157564799952577ull}},
{{15939829761749209517ull, 17257025884692640720ull,
  12391528067535695479ull, 3583946955999940721ull}},
{{1478043128476960281ull, 16959596337438412997ull,
  1654352029137455637ull, 4479933694999925902ull}},
{{3229619964511794128ull, 12905590720112702075ull,
  14869028073493073485ull, 2799958559374953688ull}},
{{17872083010921906371ull, 2296930344858713881ull,
  139541018156790241ull, 3499948199218692111ull}},
{{8505045708370219252ull, 7482848949500780256ull,
  14009484327978151513ull, 4374935249023365138ull}},
{{5315653567731387033ull, 16205995639506457420ull,
  13367613723413732599ull, 2734334530639603211ull}},
{{6644566959664233791ull, 15645808530955683871ull,
  12097831135839777845ull, 3417918163299504014ull}},
{{3694022681152904334ull, 5722202608412441127ull,
  5898916882944946499ull, 4272397704124380018ull}},
{{9226293203361647065ull, 1270533621044081752ull,
  8298509070267979466ull, 2670248565077737511ull}},
{{11532866504202058831ull, 10811539063159877998ull,
  5761450319407586428ull, 3337810706347171889ull}},
{{5192711093397797731ull, 13514423828949847498ull,
  11813498917686870939ull, 4172263382933964861ull}},
{{7857130451801011486ull, 6140671883879960734ull,
  9689279832767988289ull, 2607664614333728038ull}},
{{598041027896488549ull, 12287525873277338822ull,
  2888227754105209553ull, 3259580767917160048ull}},
{{9970923321725386495ull, 1524349286314509815ull,
  3610284692631511942ull, 4074475959896450060ull}},
{{13149356103719448415ull, 14787776359228732346ull,
  11479799969749470771ull, 2546547474935281287ull}},
{{7213323092794534711ull, 13873034430608527529ull,
  9738063943759450560ull, 3183184343669101609ull}},
{{13628339884420556293ull, 17341293038260659411ull,
  16784265948126701104ull, 3978980429586377011ull}},
{{6211869418549153731ull, 10838308148912912132ull,
  8184323208365494238ull, 2486862768491485632ull}},
{{7764836773186442164ull, 4324513149286364357ull,
  10230404010456867798ull, 3108578460614357040ull}},
{{14317731984910440609ull, 14629013473462731254ull,
  12788005013071084747ull, 3885723075767946300ull}},
{{4336896472141637477ull, 6837290411700513082ull,
  17215875170024203775ull, 2428576922354966437ull}},
{{14644492627031822654ull, 3934926996198253448ull,
  7684785907248091007ull, 3035721152943708047ull}},
{{18305615783789778317ull, 306972726820428906ull,
  4994296365632725855ull, 3794651441179635059ull}},
{{16052695883295999352ull, 7109386981903849922ull,
  815592219306759707ull, 2371657150737271912ull}},
{{10842497817265223382ull, 4275047708952424499ull,
  1019490274133449634ull, 2964571438421589890ull}},
{{8941436253154141324ull, 14567181673045306432ull,
  10497734879521587850ull, 3705714298026987362ull}},
{{5588397658221338327ull, 13716174564080704424ull,
  11172770318128380310ull, 2316071436266867101ull}},
{{6985497072776672909ull, 7921846168246104722ull, 130904842378311676ull,
  2895089295333583877ull}},
{{17955243377825616944ull, 9902307710307630902ull,
  4775317071400277499ull, 3618861619166979846ull}},
{{13220682185427245372ull, 7766198619457150724ull,
  15192518376105122682ull, 4523577023958724807ull}},
{{17486298402746804166ull, 9465560155588107106ull,
  16412853012706783532ull, 2827235639974203004ull}},
{{12634500966578729399ull, 11831950194485133883ull,
  2069322192173927799ull, 3534044549967753756ull}},
{{11181440189796023845ull, 10178251724679029450ull,
  2586652740217409749ull, 4417555687459692195ull}},
{{11600086137049902807ull, 8667250337138087358ull,
  17757559027131738757ull, 2760972304662307621ull}},
{{5276735634457602701ull, 15445748939849997102ull,
  8361890728632509734ull, 3451215380827884527ull}},
{{15819291579926779184ull, 10083814137957720569ull,
  5840677392363249264ull, 4314019226034855659ull}},
{{2969528209813155134ull, 6302383836223575356ull,
  1344580361013336838ull, 2696262016271784787ull}},
{{3711910262266443918ull, 17101351832134245003ull,
  15515783506548834759ull, 3370327520339730983ull}},
{{28201809405666993ull, 16765003771740418350ull,
  14783043364758655545ull, 4212909400424663729ull}},
{{13852684186160705583ull, 3560598329696679612ull,
  2321873075333077860ull, 2633068375265414831ull}},
{{17315855232700881978ull, 4450747912120849515ull,
  16737399399448511037ull, 3291335469081768538ull}},
{{17033133022448714569ull, 10175120908578449798ull,
  11698377212455862988ull, 4114169336352210673ull}},
{{6034022120603058702ull, 15582822604716306932ull,
  393956730143832511ull, 2571355835220131671ull}},
{{7542527650753823377ull, 14866842237467995761ull,
  14327503967961954351ull, 3214194794025164588ull}},
{{14039845581869667125ull, 13971866778407606797ull,
  17909379959952442939ull, 4017743492531455735ull}},
{{11080746497882235905ull, 6426573727291060296ull,
  18110891502611358693ull, 2511089682832159834ull}},
{{13850933122352794882ull, 12644903177541213274ull,
  13415242341409422558ull, 3138862103540199793ull}},
{{8090294366086217794ull, 6582756935071740785ull,
  2933994871479614486ull, 3923577629425249742ull}},
{{16585649024872355881ull, 17949281139702001702ull,
  15668804849956922765ull, 2452236018390781088ull}},
{{11508689244235669044ull, 8601543369345338416ull,
  1139261988736601841ull, 3065295022988476361ull}},
{{14385861555294586304ull, 15363615230109060924ull,
  6035763504348140205ull, 3831618778735595451ull}},
{{18214535508913892248ull, 11908102528031857029ull,
  1466509181003893676ull, 2394761736709747157ull}},
{{8933111330860201598ull, 14885128160039821287ull,
  6444822494682254999ull, 2993452170887183946ull}},
{{6554703145147864094ull, 13994724181622388705ull,
  17279400155207594557ull, 3741815213608979932ull}},
{{15625904511785884819ull, 11052545622727686892ull,
  1576253060149970790ull, 2338634508505612458ull}},
{{1085636566022804407ull, 4592309991554832808ull,
  11193688362042239296ull, 2923293135632015572ull}},
{{1357045707528505509ull, 5740387489443541010ull,
  13992110452552799120ull, 3654116419540019465ull}},
{{10919679171265407694ull, 7175484361804426262ull,
  3655080010408835188ull, 4567645524425024332ull}},
{{2213113463613491905ull, 13708049762982542222ull,
  11507797043360297800ull, 2854778452765640207ull}},
{{11989763866371640689ull, 17135062203728177777ull,
  9773060285772984346ull, 3568473065957050259ull}},
{{1152146777682387150ull, 12195455717805446414ull,
  7604639338788842529ull, 4460591332446312824ull}},
{{14555149791333655681ull, 704630795987322152ull,
  4752899586743026581ull, 2787869582778945515ull}},
{{18193937239167069601ull, 5492474513411540594ull,
  1329438465001395322ull, 3484836978473681894ull}},
{{13519049512104061193ull, 16088965178619201551ull,
  10885170118106519960ull, 4356046223092102367ull}},
{{15366934972706120102ull, 10055603236637000969ull,
  13720760351457656831ull, 2722528889432563979ull}},
{{5373610660600486415ull, 7957818027368863308ull,
  12539264420894683135ull, 3403161111790704974ull}},
{{6717013325750608019ull, 5335586515783691231ull,
  6450708489263578111ull, 4253951389738381218ull}},
{{11115662356235211868ull, 10252270600005888875ull,
  8643378824217124223ull, 2658719618586488261ull}},
{{9282891926866626931ull, 8203652231579973190ull,
  15415909548698793183ull, 3323399523233110326ull}},
{{2380242871728507855ull, 5642879271047578584ull,
  10046514899018715671ull, 4154249404041387908ull}},
{{1487651794830317410ull, 10444328572045818471ull,
  15502443848741473102ull, 2596405877525867442ull}},
{{15694622798820060474ull, 3832038678202497280ull,
  10154682774072065570ull, 3245507346907334303ull}},
{{1171534424815523976ull, 14013420384607897409ull,
  8081667449162694058ull, 4056884183634167879ull}},
{{12261424061578172245ull, 13370073758807323784ull,
  11968571183367765642ull, 2535552614771354924ull}},
{{15326780076972715307ull, 7489220161654378922ull,
  14960713979209707053ull, 3169440768464193655ull}},
{{9935103059361118325ull, 13973211220495361557ull,
  14089206455584745912ull, 3961800960580242069ull}},
{{8515282421314392905ull, 8733257012809600973ull,
  11111597043954160147ull, 2476125600362651293ull}},
{{15255789045070379036ull, 6304885247584613312ull, 54438249660536472ull,
  3095157000453314117ull}},
{{622992232628422178ull, 7881106559480766641ull, 4679733830503058494ull,
  3868946250566642646ull}},
{{11918585191461233622ull, 314005581248091246ull,
  16759891699346575271ull, 2418091406604151653ull}},
{{5674859452471766219ull, 14227565031842277770ull,
  7114806568901055376ull, 3022614258255189567ull}},
{{16316946352444483582ull, 17784456289802847212ull,
  4281822192698931316ull, 3778267822818986959ull}},
{{974719433423026431ull, 1891913144272003700ull, 9593667898077913929ull,
  2361417389261866849ull}},
{{1218399291778783038ull, 6976577448767392529ull,
  16603770891024780315ull, 2951771736577333561ull}},
{{6134685133150866702ull, 4109035792531852757ull,
  6919655558498811682ull, 3689714670721666952ull}},
{{6140021217432985641ull, 7179833388759795877ull,
  4324784724061757301ull, 2306071669201041845ull}},
{{12286712540218619955ull, 13586477754377132750ull,
  10017666923504584530ull, 2882589586501302306ull}},
{{6135018638418499135ull, 7759725156116640130ull,
  3298711617525954855ull, 3603236983126627883ull}},
{{16892145334877899727ull, 5087970426718412258ull,
  17958447577189607281ull, 4504046228908284853ull}},
{{15169276852726075234ull, 14709196562767477421ull,
  13529872744957198502ull, 2815028893067678033ull}},
{{5126538010625430330ull, 9163123666604570969ull,
  3077282875914334416ull, 3518786116334597542ull}},
{{11019858531709175816ull, 11453904583255713711ull,
  13069975631747693828ull, 4398482645418246927ull}},
{{13804940609959316741ull, 16382062401389596877ull,
  15086263797483390498ull, 2749051653386404329ull}},
{{3421117707166982215ull, 11254205964882220289ull,
  5022771691572074411ull, 3436314566733005412ull}},
{{8888083152386115672ull, 9456071437675387457ull,
  6278464614465093014ull, 4295393208416256765ull}},
{{17084267016309792055ull, 1298358630119729256ull,
  6229883393254377086ull, 2684620755260160478ull}},
{{2908589696677688453ull, 10846320324504437379ull,
  17010726278422747165ull, 3355775944075200597ull}},
{{17470795176129274278ull, 18169586424057934627ull,
  7428349792746270244ull, 4194719930094000747ull}},
{{8613403975867102472ull, 2132619478181433334ull,
  2336875611252724951ull, 2621699956308750467ull}},
{{1543382932979102282ull, 16500832403008955380ull,
  16756152569348069900ull, 3277124945385938083ull}},
{{1929228666223877852ull, 2179296430051642609ull,
  16333504693257699472ull, 4096406181732422604ull}},
{{12734982962458393418ull, 1362060268782276630ull,
  985068396431286362ull, 2560253863582764128ull}},
{{6695356666218215964ull, 10925947372832621596ull,
  1231335495539107952ull, 3200317329478455160ull}},
{{8369195832772769955ull, 13657434216040776995ull,
  1539169369423884940ull, 4000396661848068950ull}},
{{2924904386269287270ull, 17759268421880261430ull,
  14797038911172091799ull, 2500247913655043093ull}},
{{12879502519691384895ull, 17587399508922938883ull,
  4661240583682951037ull, 3125309892068803867ull}},
{{11487692131186843215ull, 8149191330871509892ull,
  1214864711176300893ull, 3906637365086004834ull}},
{{16403179618846552818ull, 7399087591008387634ull,
  5370976462912575962ull, 2441648353178753021ull}},
{{11280602486703415214ull, 25487451905708735ull,
  11325406597068107857ull, 3052060441473441276ull}},
{{9489067089951881113ull, 4643545333309523823ull,
  14156758246335134821ull, 3815075551841801595ull}},
{{12848195958861007552ull, 5208058842532146341ull,
  6542130894745765311ull, 2384422219901125997ull}},
{{2225186893294095728ull, 1898387534737795023ull,
  12789349636859594543ull, 2980527774876407496ull}},
{{16616541671899783372ull, 16208042473704407490ull,
  15986687046074493178ull, 3725659718595509370ull}},
{{14997024563364752511ull, 14741712564492642585ull,
  14603365422223946140ull, 2328537324122193356ull}},
{{4911222648923776927ull, 18427140705615803232ull,
  18254206777779932675ull, 2910671655152741695ull}},
{{6139028311154721159ull, 18422239863592366136ull,
  18206072453797527940ull, 3638339568940927119ull}},
{{7673785388943401449ull, 4581055755780906054ull,
  18145904548819522022ull, 4547924461176158899ull}},
{{184429849662238002ull, 16698217902645229996ull,
  9035347333798507311ull, 2842452788235099312ull}},
{{230537312077797502ull, 16261086359879149591ull,
  11294184167248134139ull, 3553065985293874140ull}},
{{14123229695379410589ull, 15714671931421549084ull,
  14117730209060167674ull, 4441332481617342675ull}},
{{18050390596466907426ull, 14433355975565856081ull,
  6517738371448910844ull, 2775832801010839172ull}},
{{8727930190301470571ull, 18041694969457320102ull,
  8147172964311138555ull, 3469791001263548965ull}},
{{1686540701022062405ull, 17940432693394262224ull,
  14795652223816311098ull, 4337238751579436206ull}},
{{1054087938138789004ull, 15824456451798801794ull,
  4635596621457806532ull, 2710774219737147629ull}},
{{10540981959528262062ull, 1333826491038950626ull,
  10406181795249646070ull, 3388467774671434536ull}},
{{3952855412555551770ull, 10890655150653464091ull,
  13007727244062057587ull, 4235584718339293170ull}},
{{164691623633525904ull, 4500816459944721105ull,
  12741515545966173896ull, 2647240448962058231ull}},
{{4817550547969295284ull, 5626020574930901381ull,
  11315208414030329466ull, 3309050561202572789ull}},
{{10633624203389007009ull, 16255897755518402534ull,
  308952462255748120ull, 4136313201503215987ull}},
{{2034329108690741477ull, 10159936097199001584ull,
  16333996353405700239ull, 2585195750939509991ull}},
{{2542911385863426846ull, 8088234103071364076ull,
  15805809423329737395ull, 3231494688674387489ull}},
{{3178639232329283557ull, 5498606610411817191ull,
  5922203723880008032ull, 4039368360842984362ull}},
{{8904178547846884080ull, 3436629131507385744ull,
  8313063345852392924ull, 2524605225526865226ull}},
{{11130223184808605099ull, 4295786414384232180ull,
  1167957145460715347ull, 3155756531908581533ull}},
{{13912778981010756374ull, 758046999552902321ull,
  6071632450253282088ull, 3944695664885726916ull}},
{{1777957835490640878ull, 473779374720563951ull,
  13018142318263077113ull, 2465434790553579322ull}},
{{16057505349645464809ull, 5203910236828092842ull,
  7049305860974070583ull, 3081793488191974153ull}},
{{10848509650202055204ull, 1893201777607728149ull,
  13423318344644976133ull, 3852241860239967691ull}},
{{9086161540589978454ull, 3489094120218524045ull,
  6083730956189416131ull, 2407651162649979807ull}},
{{15969387944164860972ull, 18196425705555318768ull,
  2992977676809382259ull, 3009563953312474759ull}},
{{1514990856496524599ull, 18133846113516760557ull,
  17576280151293891536ull, 3761954941640593448ull}},
{{3252712294524021826ull, 11333653820947975348ull,
  10985175094558682210ull, 2351221838525370905ull}},
{{4065890368155027283ull, 4943695239330193377ull,
  18343154886625740667ull, 2939027298156713631ull}},
{{9694048978621172007ull, 1567933030735353817ull,
  18317257589854787930ull, 3673784122695892039ull}},
{{16729247241703852913ull, 11183288325273968079ull,
  18284885968891097008ull, 4592230153369865049ull}},
{{17373308553705989927ull, 6989555203296230049ull,
  4510524702915853774ull, 2870143845856165656ull}},
{{7881577636850323697ull, 17960316040975063370ull,
  5638155878644817217ull, 3587679807320207070ull}},
{{628600009208128813ull, 8615336995936665501ull,
  16271066885160797330ull, 4484599759150258837ull}},
{{2698718014968774460ull, 9996271640887803842ull,
  12475259812439192283ull, 2802874849468911773ull}},
{{12596769555565743883ull, 7883653532682366898ull,
  1759016710266826642ull, 3503593561836139717ull}},
{{6522589907602404046ull, 631194878998182815ull, 6810456906260921207ull,
  4379491952295174646ull}},
{{10994147719892584385ull, 7312025827014946115ull,
  18091593621695239466ull, 2737182470184484153ull}},
{{9130998631438342577ull, 18363404320623458452ull,
  8779433971836885620ull, 3421478087730605192ull}},
{{11413748289297928221ull, 4507511327069771449ull,
  10974292464796107026ull, 4276847609663256490ull}},
{{216063653170123282ull, 7428880597845995060ull,
  11470618808924954795ull, 2673029756039535306ull}},
{{270079566462654103ull, 4674414728880105921ull, 5114901474301417686ull,
  3341287195049419133ull}},
{{4949285476505705532ull, 15066390447954908209ull,
  11005312861304160011ull, 4176608993811773916ull}},
{{14622518468884535718ull, 7110651020758123678ull,
  16101692575169875815ull, 2610380621132358697ull}},
{{9054776049250893839ull, 4276627757520266694ull,
  6292057663680181057ull, 3262975776415448372ull}},
{{2095098024708841491ull, 9957470715327721272ull,
  7865072079600226321ull, 4078719720519310465ull}},
{{1309436265443025932ull, 17752634243148295555ull,
  16444885095818611210ull, 2549199825324569040ull}},
{{15471853387085946127ull, 12967420767080593635ull,
  2109362296063712397ull, 3186499781655711301ull}},
{{14728130715430044754ull, 2374217903568578332ull,
  7248388888507028401ull, 3983124727069639126ull}},
{{18428453733998553780ull, 13013101235798831217ull,
  18365301110599056462ull, 2489452954418524453ull}},
{{9200509112216028512ull, 7043004507893763214ull,
  9121568332966656866ull, 3111816193023155567ull}},
{{2277264353415259832ull, 18027127671721979826ull,
  6790274397780933178ull, 3889770241278944459ull}},
{{6034976239311925299ull, 15878640813253625295ull,
  1938078489399389284ull, 2431106400799340287ull}},
{{2932034280712518720ull, 1401556942857480003ull,
  16257656167031400318ull, 3038883000999175358ull}},
{{17500100906172812112ull, 10975318215426625811ull,
  11098698171934474589ull, 3798603751248969198ull}},
{{8631720057144313618ull, 9165416893855335084ull,
  2325000339031658714ull, 2374127344530605749ull}},
{{10789650071430392023ull, 2233399080464393047ull,
  7517936442216961297ull, 2967659180663257186ull}},
{{8875376570860602124ull, 7403434869007879213ull, 174048515916425813ull,
  3709573975829071483ull}},
{{7852953366001570280ull, 6932989802343618460ull,
  16249681386943623797ull, 2318483734893169676ull}},
{{9816191707501962850ull, 13277923271356910979ull,
  1865357659969978130ull, 2898104668616462096ull}},
{{7658553615950065658ull, 7374032052341362916ull,
  2331697074962472663ull, 3622630835770577620ull}},
{{9573192019937582072ull, 4605854046999315741ull,
  2914621343703090829ull, 4528288544713222025ull}},
{{8289088021674682747ull, 5184501788588266290ull,
  13350853385882901528ull, 2830180340445763765ull}},
{{1137987990238577626ull, 6480627235735332863ull,
  2853508677071463198ull, 3537725425557204707ull}},
{{15257543043080385744ull, 17324156081523941886ull,
  17401943901621492709ull, 4422156781946505883ull}},
{{4924278383497853186ull, 13133440560166157631ull,
  8570371929299738991ull, 2763847988716566177ull}},
{{1543661960944928579ull, 11805114681780309135ull,
  15324650930052061643ull, 3454809985895707721ull}},
{{15764635506463324436ull, 10144707333797998514ull,
  5320755607282913342ull, 4318512482369634652ull}},
{{14464583209966965676ull, 1728756065196361167ull,
  12548844291406596647ull, 2699070301481021657ull}},
{{13469042994031319191ull, 15996003136777615171ull,
  1850997308976082096ull, 3373837876851277072ull}},
{{12224617724111761085ull, 1548259847262467348ull,
  2313746636220102621ull, 4217297346064096340ull}},
{{16863758114424626486ull, 3273505413752736044ull,
  10669463684492339946ull, 2635810841290060212ull}},
{{2632953569321231492ull, 13315253804045695864ull,
  13336829605615424932ull, 3294763551612575265ull}},
{{3291191961651539365ull, 16644067255057119830ull,
  2835978951737117453ull, 4118454439515719082ull}},
{{15892053031314375815ull, 12708385043624393845ull,
  6384172863263086312ull, 2574034024697324426ull}},
{{6030008233860806057ull, 15885481304530492307ull,
  17203588115933633698ull, 3217542530871655532ull}},
{{2925824273898619667ull, 10633479593808339576ull,
  3057741071207490507ull, 4021928163589569416ull}},
{{1828640171186637292ull, 4340081736916518283ull,
  1911088169504681567ull, 2513705102243480885ull}},
{{16120858269265460327ull, 813416152718259949ull,
  7000546230308239863ull, 3142131377804351106ull}},
{{6316014781299661696ull, 14851828246179988649ull,
  17974054824740075636ull, 3927664222255438882ull}},
{{15476724284380758320ull, 59020617007717097ull,
  15845470283889935177ull, 2454790138909649301ull}},
{{5510847300193784188ull, 4685461789687034276ull,
  5971779799580255259ull, 3068487673637061627ull}},
{{6888559125242230235ull, 1245141218681404941ull,
  2853038731047931170ull, 3835609592046327034ull}},
{{6611192462490087849ull, 5389899280103265992ull,
  6394835225332344885ull, 2397255995028954396ull}},
{{8263990578112609812ull, 11349060118556470394ull,
  7993544031665431106ull, 2996569993786192995ull}},
{{1106616185785986456ull, 4962953111340812185ull,
  5380244021154400979ull, 3745712492232741244ull}},
{{12220850162184711295ull, 796002685374313663ull,
  12586024550076276420ull, 2341070307645463277ull}},
{{10664376684303501215ull, 995003356717892079ull,
  1897472632313181813ull, 2926337884556829097ull}},
{{8718784836951988615ull, 5855440214324753003ull,
  6983526808818865170ull, 3657922355696036371ull}},
{{6286795027762597864ull, 16542672304760717062ull,
  4117722492596193558ull, 4572402944620045464ull}},
{{17764304947633787377ull, 5727484172048060259ull,
  2573576557872620974ull, 2857751840387528415ull}},
{{17593695166114846318ull, 16382727251914851132ull,
  17052028752622939929ull, 3572189800484410518ull}},
{{3545374883934006281ull, 6643351009611400204ull,
  12091663903923899104ull, 4465237250605513148ull}},
{{11439231339313529734ull, 4152094381007125127ull,
  16780661976807212748ull, 2790773281628445717ull}},
{{9687353155714524263ull, 5190117976258906409ull,
  7140769415726852223ull, 3488466602035557147ull}},
{{16720877463070543233ull, 1875961451896245107ull,
  4314275751231177375ull, 4360583252544446434ull}},
{{8144705405205395569ull, 8090004935076235048ull,
  7308108362946873763ull, 2725364532840279021ull}},
{{10180881756506744461ull, 5500820150417905906ull,
  13746821472110980108ull, 3406705666050348776ull}},
{{3502730158778654768ull, 6876025188022382383ull,
  17183526840138725135ull, 4258382082562935970ull}},
{{9106735376877741086ull, 11215044770155070845ull,
  15351390293514091113ull, 2661488801601834981ull}},
{{15995105239524564261ull, 183747907411674844ull,
  5354179811610450180ull, 3326861002002293727ull}},
{{1547137475696153711ull, 229684884264593556ull, 2081038746085674821ull,
  4158576252502867159ull}},
{{10190332959164871877ull, 2449396061879064924ull,
  8218178243944628619ull, 2599110157814291974ull}},
{{12737916198956089846ull, 16896803132630994867ull,
  1049350768076009965ull, 3248887697267864968ull}},
{{11310709230267724404ull, 7285945860506579872ull,
  1311688460095012457ull, 4061109621584831210ull}},
{{7069193268917327753ull, 16082931208885082180ull,
  5431491305986770689ull, 2538193513490519506ull}},
{{8836491586146659691ull, 6268605955824189013ull,
  16012736169338239170ull, 3172741891863149382ull}},
{{15657300501110712517ull, 17059129481635012074ull,
  10792548174818023154ull, 3965927364828936728ull}},
{{14397498831621583227ull, 15273641944449270450ull,
  6745342609261264471ull, 2478704603018085455ull}},
{{8773501502672203226ull, 14480366412134200159ull,
  3819992243149192685ull, 3098380753772606819ull}},
{{6355190859912866129ull, 4265399959885586487ull, 163304285509102953ull,
  3872975942215758524ull}},
{{10889523315086623187ull, 14195090020996961314ull,
  9325437215297965153ull, 2420609963884849077ull}},
{{4388532107003503175ull, 3908804470964037931ull,
  16268482537549844346ull, 3025762454856061346ull}},
{{873979115326991065ull, 14109377625559823222ull,
  11112231135082529624ull, 3782203068570076683ull}},
{{14381295002361533128ull, 8818361015974889513ull,
  4639301450212887063ull, 2363876917856297927ull}},
{{4141560697669752697ull, 6411265251541223988ull,
  1187440794338720925ull, 2954846147320372409ull}},
{{5176950872087190872ull, 12625767582853917889ull,
  6095987011350789060ull, 3693557684150465511ull}},
{{14764809341122964055ull, 17114476776138474488ull,
  10727520909735325018ull, 2308473552594040944ull}},
{{9267602694153453ull, 12169723933318317303ull, 13409401137169156273ull,
  2885591940742551180ull}},
{{13846642558649855528ull, 1377096861365732916ull,
  16761751421461445342ull, 3606989925928188975ull}},
{{17308303198312319409ull, 10944743113561941953ull,
  16340503258399418773ull, 4508737407410236219ull}},
{{3900160471304117775ull, 9146307455189907673ull,
  7906971527285942781ull, 2817960879631397637ull}},
{{9486886607557535123ull, 16044570337414772495ull,
  14495400427534816380ull, 3522451099539247046ull}},
{{7246922241019530999ull, 1608968848058914003ull,
  8895878497563744668ull, 4403063874424058808ull}},
{{2223483391423512923ull, 10228977566891597060ull,
  5559924060977340417ull, 2751914921515036755ull}},
{{2779354239279391153ull, 17397907977041884229ull,
  2338219057794287617ull, 3439893651893795944ull}},
{{8085878817526626846ull, 7912326916020191574ull,
  2922773822242859522ull, 4299867064867244930ull}},
{{441988242526753875ull, 9556890340940007638ull, 6438419657329175105ull,
  2687416915542028081ull}},
{{9775857340013218151ull, 16557798944602397451ull,
  12659710590088856785ull, 3359271144427535101ull}},
{{7608135656589134785ull, 6862190625470833102ull,
  1989580182328907270ull, 4199088930534418877ull}},
{{143398766940821337ull, 18123927196201434401ull,
  3549330623169260995ull, 2624430581584011798ull}},
{{4790934477103414575ull, 18043222976824405097ull,
  13660035315816352052ull, 3280538226980014747ull}},
{{10600354114806656122ull, 4107284647320954755ull,
  12463358126343052162ull, 4100672783725018434ull}},
{{4319378312540466125ull, 7178738923002984626ull,
  12401284847391795505ull, 2562920489828136521ull}},
{{14622594927530358464ull, 13585109672181118686ull,
  1666548003957580669ull, 3203650612285170652ull}},
{{9054871622558172271ull, 3146329034944234646ull,
  2083185004946975837ull, 4004563265356463315ull}},
{{1047608745671469766ull, 4272298656053840606ull,
  17442891692587717562ull, 2502852040847789571ull}},
{{10532882968944113015ull, 14563745356922076565ull,
  17191928597307259048ull, 3128565051059736964ull}},
{{17777789729607529173ull, 18204681696152595706ull,
  3043166672924522194ull, 3910706313824671206ull}},
{{15722804599432093637ull, 15989612078522760220ull,
  15737037225859990083ull, 2444191446140419503ull}},
{{1206761675580565430ull, 15375329079726062372ull,
  15059610513897599700ull, 3055239307675524379ull}},
{{1508452094475706788ull, 772417275948026349ull,
  14212827123944611722ull, 3819049134594405474ull}},
{{3248625568261010695ull, 5094446815894904372ull,
  13494702970892770230ull, 2386905709121503421ull}},
{{4060781960326263368ull, 15591430556723406273ull,
  3033320658333799075ull, 2983632136401879277ull}},
{{9687663468835217114ull, 14877602177476869937ull,
  8403336841344636748ull, 3729540170502349096ull}},
{{17584004714090480456ull, 75129324068267902ull, 5252085525840397968ull,
  2330962606563968185ull}},
{{12756633855758324762ull, 93911655085334878ull,
  11176792925727885364ull, 2913703258204960231ull}},
{{6722420282843130145ull, 117389568856668598ull, 9359305138732468801ull,
  3642129072756200289ull}},
{{17626397390408688489ull, 4758422979498223651ull,
  16310817441842973905ull, 4552661340945250361ull}},
{{8710655359791736354ull, 14503229408254859542ull,
  3276731873510776834ull, 2845413338090781476ull}},
{{1664947162884894634ull, 8905664723463798620ull,
  4095914841888471043ull, 3556766672613476845ull}},
{{2081183953606118293ull, 6520394885902360371ull,
  9731579570787976708ull, 4445958340766846056ull}},
{{17441641035499681597ull, 13298618840543751039ull,
  6082237231742485442ull, 2778723962979278785ull}},
{{17190365275947214092ull, 7399901513824912991ull,
  12214482558105494707ull, 3473404953724098481ull}},
{{16876270576506629711ull, 4638190873853753335ull,
  1433045142349704672ull, 4341756192155123102ull}},
{{17465198137957725426ull, 2898869296158595834ull,
  14730711269250729132ull, 2713597620096951938ull}},
{{12608125635592380974ull, 3623586620198244793ull,
  9190017049708635607ull, 3391997025121189923ull}},
{{1925098989208312505ull, 18364541330529969704ull,
  6875835293708406604ull, 4239996281401487404ull}},
{{1203186868255195316ull, 2254466294726455257ull,
  13520769095422529936ull, 2649997675875929627ull}},
{{6115669603746382049ull, 2818082868408069071ull,
  12289275350850774516ull, 3312497094844912034ull}},
{{3032900986255589657ull, 3522603585510086339ull,
  6138222151708692337ull, 4140621368556140043ull}},
{{18036464180905601200ull, 13730842287012273721ull,
  1530545835604238758ull, 2587888355347587527ull}},
{{8710522170849837788ull, 7940180821910566344ull,
  15748240349787462160ull, 3234860444184484408ull}},
{{10888152713562297234ull, 9925226027388207930ull,
  1238556363524776084ull, 4043575555230605511ull}},
{{11416781464403823676ull, 15426638303972405764ull,
  7691626754844066908ull, 2527234722019128444ull}},
{{14270976830504779595ull, 836553806255955589ull,
  9614533443555083636ull, 3159043402523910555ull}},
{{4003662982848810781ull, 1045692257819944487ull,
  7406480786016466641ull, 3948804253154888194ull}},
{{9419818391921588594ull, 12182772707205935064ull,
  9240736509687679554ull, 2468002658221805121ull}},
{{11774772989901985743ull, 6005093847152643022ull,
  16162606655536987347ull, 3085003322777256401ull}},
{{5495094200522706370ull, 2894681290513415874ull,
  6368200264139070472ull, 3856254153471570502ull}},
{{8046119893754079386ull, 1809175806570884921ull,
  17815183220369082757ull, 2410158845919731563ull}},
{{14669335885619987136ull, 6873155776640994055ull,
  17657293007033965542ull, 3012698557399664454ull}},
{{13724983838597596016ull, 17814816757656018377ull,
  12848244221937681119ull, 3765873196749580568ull}},
{{1660585871482415654ull, 18051789501176093342ull,
  8030152638711050699ull, 2353670747968487855ull}},
{{11299104376207795375ull, 17953050858042728773ull,
  5426004779961425470ull, 2942088434960609819ull}},
{{288822414977580507ull, 13217941535698635159ull,
  2170819956524393934ull, 3677610543700762274ull}},
{{14196086074004139346ull, 7299054882768518140ull,
  11936896982510268226ull, 4597013179625952842ull}},
{{18095925833107362899ull, 9173595320157711741ull,
  12072246632496305545ull, 2873133237266220526ull}},
{{8784849236102039912ull, 16078680168624527581ull,
  5866936253765606123ull, 3591416546582775658ull}},
{{15592747563554937794ull, 15486664192353271572ull,
  16557042354061783462ull, 4489270683228469572ull}},
{{522095190367060313ull, 5067479101793406829ull, 1124779434433838856ull,
  2805794177017793483ull}},
{{5264305006386213296ull, 6334348877241758536ull,
  15241032348324462282ull, 3507242721272241853ull}},
{{6580381257982766619ull, 17141308133406973978ull,
  5216232380123414140ull, 4384053401590302317ull}},
{{8724424304666617041ull, 1489945546524582928ull,
  5565988246790827790ull, 2740033375993938948ull}},
{{10905530380833271302ull, 11085803970010504468ull,
  6957485308488534737ull, 3425041719992423685ull}},
{{13631912976041589127ull, 22196907230966873ull,
  13308542654038056326ull, 4281302149990529606ull}},
{{1602416582384911348ull, 13848931122301518008ull,
  3706153140346397299ull, 2675813843744081004ull}},
{{2003020727981139185ull, 12699477884449509606ull,
  4632691425432996624ull, 3344767304680101255ull}},
{{11727147946831199790ull, 15874347355561887007ull,
  1179178263363857876ull, 4180959130850126569ull}},
{{14246996494410581725ull, 698095060371403571ull,
  12266201460670880933ull, 2613099456781329105ull}},
{{13197059599585839252ull, 5484304843891642368ull,
  1497693770556437454ull, 3266374320976661382ull}},
{{16496324499482299065ull, 16078753091719328768ull,
  11095489250050322625ull, 4082967901220826727ull}},
{{10310202812176436916ull, 3131691654683498624ull,
  13852209808922533497ull, 2551854938263016704ull}},
{{12887753515220546144ull, 8526300586781761184ull,
  17315262261153166871ull, 3189818672828770880ull}},
{{16109691894025682680ull, 6046189715049813576ull,
  3197333752731906973ull, 3987273341035963601ull}},
{{10068557433766051675ull, 6084711581119827437ull,
  13527548641525911618ull, 2492045838147477250ull}},
{{17197382810634952498ull, 16829261513254560104ull,
  7686063765052613714ull, 3115057297684346563ull}},
{{3049984439584139006ull, 11813204854713424323ull,
  4995893687888379239ull, 3893821622105433204ull}},
{{18047141339235944543ull, 14300782061836972057ull,
  12345805591785012832ull, 2433638513815895752ull}},
{{8723868618762766967ull, 17875977577296215072ull,
  15432256989731266040ull, 3042048142269869690ull}},
{{10904835773453458709ull, 3898227897910717224ull,
  10066949200309306743ull, 3802560177837337113ull}},
{{6815522358408411693ull, 9353921463835280121ull,
  17821058296261786474ull, 2376600111148335695ull}},
{{13131088966437902520ull, 2469029792939324343ull,
  17664636851899845189ull, 2970750138935419619ull}},
{{11802175189619990246ull, 7697973259601543333ull,
  17469110046447418582ull, 3713437673669274524ull}},
{{9682202502726187856ull, 199547268823576679ull, 1694821742174860806ull,
  2320898546043296578ull}},
{{7491067109980346916ull, 9472806122884246657ull,
  11341899214573351815ull, 2901123182554120722ull}},
{{13975519905902821549ull, 7229321635177920417ull,
  4954001981361913961ull, 3626403978192650903ull}},
{{3634341827096363224ull, 13648338062399788426ull,
  1580816458275004547ull, 4533004972740813629ull}},
{{6883149660362614919ull, 6224368279786173814ull,
  3293853295635571794ull, 2833128107963008518ull}},
{{17827309112308044457ull, 17003832386587493075ull,
  13340688656399240550ull, 3541410134953760647ull}},
{{17672450371957667667ull, 12031418446379590536ull,
  12064174802071662784ull, 4426762668692200809ull}},
{{11045281482473542292ull, 7519636528987244085ull,
  622580223653707384ull, 2766726667932625506ull}},
{{18418287871519315769ull, 9399545661234055106ull,
  10001597316421910038ull, 3458408334915781882ull}},
{{13799487802544368903ull, 2526060039687793075ull,
  3278624608672611740ull, 4323010418644727353ull}},
{{6318836867376536612ull, 10802159561659646480ull,
  13578355426488852097ull, 2701881511652954595ull}},
{{7898546084220670765ull, 18114385470501946004ull,
  12361258264683677217ull, 3377351889566193244ull}},
{{9873182605275838457ull, 8807923782845268793ull,
  15451572830854596522ull, 4221689861957741555ull}},
{{17699954174365868796ull, 10116638382705680899ull,
  7351390010070428874ull, 2638556163723588472ull}},
{{17513256699529948090ull, 3422425941527325316ull,
  9189237512588036093ull, 3298195204654485590ull}},
{{3444826800702883497ull, 8889718445336544550ull,
  2263174853880269308ull, 4122744005818106988ull}},
{{15988074805721465898ull, 14779446065190116151ull,
  10637856320529944125ull, 2576715003636316867ull}},
{{15373407488724444468ull, 4639249526205481477ull,
  8685634382235042253ull, 3220893754545396084ull}},
{{5381701305623391873ull, 10410747926184239751ull,
  10857042977793802816ull, 4026117193181745105ull}},
{{10281092343655701777ull, 6506717453865149844ull,
  18314866907189596520ull, 2516323245738590690ull}},
{{12851365429569627221ull, 8133396817331437305ull,
  13670211597132219842ull, 3145404057173238363ull}},
{{2229148731679870314ull, 943373984809520824ull,
  12476078477987886899ull, 3931755071466547954ull}},
{{1393217957299918946ull, 16730509805001808179ull,
  12409235067169817215ull, 2457346919666592471ull}},
{{15576580501907062395ull, 16301451237824872319ull,
  10899857815534883615ull, 3071683649583240589ull}},
{{14859039608956440089ull, 15765128028853702495ull,
  18236508287845992423ull, 3839604561979050736ull}},
{{16204428783238856912ull, 16770734045674645915ull,
  11397817679903745264ull, 2399752851236906710ull}},
{{15643849960621183236ull, 2516673483383755778ull,
  5023900063024905773ull, 2999691064046133388ull}},
{{10331440413921703237ull, 7757527872657082627ull,
  6279875078781132216ull, 3749613830057666735ull}},
{{4151307249487370571ull, 4848454920410676642ull,
  10842450951879289491ull, 2343508643786041709ull}},
{{14412506098713989022ull, 1448882632085957898ull,
  18164749708276499768ull, 2929385804732552136ull}},
{{8792260586537710469ull, 1811103290107447373ull,
  4259193061636073094ull, 3661732255915690171ull}},
{{15602011751599525990ull, 11487251149489085024ull,
  712305308617703463ull, 4577165319894612714ull}},
{{9751257344749703744ull, 14097060996071759996ull,
  5056876836313452568ull, 2860728324934132946ull}},
{{12189071680937129680ull, 17621326245089699995ull,
  15544468082246591518ull, 3575910406167666182ull}},
{{10624653582744024196ull, 12803285769507349186ull,
  10207213065953463590ull, 4469888007709582728ull}},
{{11252094507642403027ull, 3390367587514705337ull,
  6379508166220914744ull, 2793680004818489205ull}},
{{230060079270840071ull, 4237959484393381672ull,
  12586071226203531334ull, 3492100006023111506ull}},
{{287575099088550089ull, 14520821392346502898ull,
  6509216995899638359ull, 4365125007528889383ull}},
{{4791420455357731710ull, 15993042397857646167ull,
  10985789650078355830ull, 2728203129705555864ull}},
{{1377589550769776733ull, 10767930960467281901ull,
  13732237062597944788ull, 3410253912131944830ull}},
{{6333672956889608820ull, 13459913700584102376ull,
  7941924291392655177ull, 4262817390164931038ull}},
{{3958545598056005513ull, 1494917035223982129ull, 352016663693021582ull,
  2664260868853081899ull}},
{{9559868015997394795ull, 11092018330884753469ull,
  14275078884898440689ull, 3330326086066352373ull}},
{{16561521038424131397ull, 29964858323778124ull, 4008790550840887150ull,
  4162907607582940467ull}},
{{1127578612160306316ull, 13853786091734525040ull,
  199651085061860516ull, 2601817254739337792ull}},
{{1409473265200382894ull, 17317232614668156300ull,
  249563856327325645ull, 3252271568424172240ull}},
{{1761841581500478618ull, 7811482713053031663ull, 311954820409157057ull,
  4065339460530215300ull}},
{{8018680016078880992ull, 16411391741726614549ull,
  9418343799610498968ull, 2540837162831384562ull}},
{{14635036038525989144ull, 2067495603448716570ull,
  2549557712658347903ull, 3176046453539230703ull}},
{{9070423011302710622ull, 16419427559593059425ull,
  17022005196105098590ull, 3970058066924038378ull}},
{{17198229428132663899ull, 5650456206318274236ull,
  15250439265993074523ull, 2481286291827523986ull}},
{{3051042711456278258ull, 2451384239470454892ull,
  9839677045636567346ull, 3101607864784404983ull}},
{{3813803389320347822ull, 12287602336192844423ull,
  7687910288618321278ull, 3877009830980506229ull}},
{{9301156145966299245ull, 3068065441693139860ull,
  7110786939600144751ull, 2423131144362816393ull}},
{{11626445182457874056ull, 17670139857398588537ull,
  13500169692927568842ull, 3028913930453520491ull}},
{{697998422790178858ull, 12864302784893459864ull,
  12263526097732073149ull, 3786142413066900614ull}},
{{436249014243861786ull, 10346032249772106367ull,
  3053017792655157814ull, 2366339008166812884ull}},
{{14380369323086990945ull, 3709168275360357150ull,
  3816272240818947268ull, 2957923760208516105ull}},
{{8752089617003962873ull, 4636460344200446438ull,
  9382026319451071989ull, 3697404700260645131ull}},
{{858369992200088892ull, 5203630724338972976ull, 3557923440443226041ull,
  2310877937662903207ull}},
{{1072962490250111115ull, 11116224423851104124ull,
  18282462355836196263ull, 2888597422078629008ull}},
{{1341203112812638893ull, 9283594511386492251ull,
  4406333871085693713ull, 3610746777598286261ull}},
{{15511561946297962328ull, 16216179157660503217ull,
  10119603357284505045ull, 4513433471997857826ull}},
{{2777197188795144599ull, 12440954982751508463ull,
  10936438116730203557ull, 2820895919998661141ull}},
{{17306554541276094461ull, 1716135673157221866ull,
  18282233664340142351ull, 3526119899998326426ull}},
{{12409821139740342268ull, 15980227646728691045ull,
  13629420043570402130ull, 4407649874997908033ull}},
{{10061981221551407870ull, 14599328297632819807ull,
  1600858499590419475ull, 2754781171873692521ull}},
{{7965790508511871933ull, 13637474353613636855ull,
  6612759142915412248ull, 3443476464842115651ull}},
{{5345552117212452012ull, 17046842942017046069ull,
  3654262910216877406ull, 4304345581052644564ull}},
{{5646813082471476460ull, 6042590820333265889ull,
  11507286355740324187ull, 2690215988157902852ull}},
{{11670202371516733479ull, 2941552506989194457ull,
  14384107944675405234ull, 3362769985197378565ull}},
{{752694909113753136ull, 12900312670591268880ull,
  4145076875562092830ull, 4203462481496723207ull}},
{{470434318196095710ull, 3451009400692155146ull, 9508202074867389875ull,
  2627164050935452004ull}},
{{9811414934599895446ull, 18148819806147357644ull,
  11885252593584237343ull, 3283955063669315005ull}},
{{12264268668249869307ull, 18074338739256809151ull,
  1021507686698132967ull, 4104943829586643757ull}},
{{14582696945297250173ull, 18213990739676587575ull,
  2944285313400027056ull, 2565589893491652348ull}},
{{13616685163194174812ull, 4320744350886182853ull,
  3680356641750033821ull, 3206987366864565435ull}},
{{3185798398710554803ull, 10012616457035116471ull,
  18435503857469705988ull, 4008734208580706793ull}},
{{8908653026835178608ull, 15481257322501723602ull,
  4604660883277484386ull, 2505458880362941746ull}},
{{1912444246689197452ull, 10128199616272378695ull,
  14979198140951631291ull, 3131823600453677182ull}},
{{16225613363643660527ull, 8048563501913085464ull,
  9500625639334763306ull, 3914779500567096478ull}},
{{10141008352277287830ull, 9642038207123066319ull,
  1326205006156839162ull, 2446737187854435299ull}},
{{8064574421919221883ull, 2829175722049057091ull,
  15492814312978212665ull, 3058421484818044123ull}},
{{5469032008971639450ull, 8148155670988709268ull,
  14754331872795377927ull, 3823026856022555154ull}},
{{12641517042462050464ull, 12010126322009025148ull,
  13833143438924499108ull, 2389391785014096971ull}},
{{15801896303077563080ull, 15012657902511281435ull,
  12679743280228235981ull, 2986739731267621214ull}},
{{15140684360419565946ull, 4930764322856938082ull,
  6626307063430519169ull, 3733424664084526518ull}},
{{14074613743689616620ull, 14610942747854056061ull,
  17976499969926238192ull, 2333390415052829073ull}},
{{3758209124329857063ull, 18263678434817570077ull,
  8635566907125634028ull, 2916738018816036342ull}},
{{9309447423839709233ull, 4382853969812410980ull,
  1571086597052266728ull, 3645922523520045428ull}},
{{11636809279799636541ull, 5478567462265513725ull,
  1963858246315333410ull, 4557403154400056785ull}},
{{9578848809088466791ull, 8035790682343333982ull,
  12756626450015553141ull, 2848376971500035490ull}},
{{2750188974505807680ull, 14656424371356555382ull,
  6722411025664665618ull, 3560471214375044363ull}},
{{12661108254987035408ull, 9097158427340918419ull,
  3791327763653444119ull, 4450589017968805454ull}},
{{5607349650153203178ull, 12603253044729155868ull,
  16204637907565566286ull, 2781618136230503408ull}},
{{7009187062691503973ull, 6530694269056669027ull,
  1809053310747406242ull, 3477022670288129261ull}},
{{4149797809936992062ull, 17386739873175612092ull,
  6873002656861645706ull, 4346278337860161576ull}},
{{11816995668065395847ull, 15478398439162145461ull,
  4295626660538528566ull, 2716423961162600985ull}},
{{936186529799581096ull, 10124626012097906019ull,
  9981219344100548612ull, 3395529951453251231ull}},
{{15005291217531640082ull, 12655782515122382523ull,
  7864838161698297861ull, 4244412439316564039ull}},
{{7072464001743581099ull, 10215707081165183029ull,
  11833052878702518019ull, 2652757774572852524ull}},
{{13452266020606864278ull, 8157947833029090882ull,
  14791316098378147524ull, 3315947218216065655ull}},
{{7591960488903804540ull, 10197434791286363603ull,
  13877459104545296501ull, 4144934022770082069ull}},
{{2439132296351183885ull, 8679239753767671204ull,
  10979254949554504265ull, 2590583764231301293ull}},
{{3048915370438979857ull, 15460735710636976909ull,
  18335754705370518235ull, 3238229705289126616ull}},
{{8422830231476112725ull, 14714233619868833232ull,
  4472949308003596178ull, 4047787131611408271ull}},
{{5264268894672570453ull, 13808082030845408674ull,
  9713122345143329467ull, 2529866957257130169ull}},
{{15803708155195488874ull, 12648416520129372938ull,
  16753088949856549738ull, 3162333696571412711ull}},
{{10531263157139585285ull, 6587148613306940365ull,
  16329675168893299269ull, 3952917120714265889ull}},
{{8887882482425934755ull, 6422810892530531680ull,
  3288517952917230187ull, 2470573200446416181ull}},
{{11109853103032418444ull, 3416827597235776696ull,
  8722333459573925638ull, 3088216500558020226ull}},
{{13887316378790523055ull, 13494406533399496678ull,
  1679544787612631239ull, 3860270625697525283ull}},
{{4067886718316689005ull, 15351533111015767280ull,
  17190616556753752188ull, 2412669141060953301ull}},
{{5084858397895861257ull, 742672315060157484ull, 7653212640660026524ull,
  3015836426326191627ull}},
{{6356072997369826571ull, 928340393825196855ull, 4954829782397645251ull,
  3769795532907739534ull}},
{{10890074650997223463ull, 16721113810636605698ull,
  16931826669280691993ull, 2356122208067337208ull}},
{{4389221276891753520ull, 7066334208013593411ull,
  2718039262891313376ull, 2945152760084171511ull}},
{{874840577687303996ull, 8832917760016991764ull,
  17232607133896305432ull, 3681440950105214388ull}},
{{1093550722109129995ull, 11041147200021239705ull,
  3094014843660830174ull, 4601801187631517986ull}},
{{12212684247386676007ull, 2289030981585886911ull,
  6545445295715406763ull, 2876125742269698741ull}},
{{10654169290805957105ull, 16696346782264522351ull,
  12793492638071646357ull, 3595157177837123426ull}},
{{8706025595080058477ull, 7035375422548489227ull,
  6768493760734782139ull, 4493946472296404283ull}},
{{3135422987711342596ull, 2091266629879111815ull,
  1924465591245544885ull, 2808716545185252677ull}},
{{17754336789921341957ull, 7225769305776277672ull,
  7017268007484319010ull, 3510895681481565846ull}},
{{3746176913692125831ull, 18255583669075122899ull,
  17994957046210174570ull, 4388619601851957307ull}},
{{35517561843884692ull, 16021425811599339716ull, 8941005144667665154ull,
  2742887251157473317ull}},
{{44396952304855865ull, 10803410227644398837ull,
  15787942449261969347ull, 3428609063946841646ull}},
{{4667182208808457735ull, 8892576766128110642ull,
  10511556024722685876ull, 4285761329933552058ull}},
{{7528674898932673989ull, 14781232515684844959ull,
  11181408533879066576ull, 2678600831208470036ull}},
{{4799157605238454582ull, 29796570896504583ull, 13976760667348833221ull,
  3348251039010587545ull}},
{{1387260988120680323ull, 4648931732048018633ull,
  3635892778903877814ull, 4185313798763234432ull}},
{{12396253163643894962ull, 16740640387812175357ull,
  2272432986814923633ull, 2615821124227021520ull}},
{{1660258399272704991ull, 7090742429483055485ull,
  2840541233518654542ull, 3269776405283776900ull}},
{{6687009017518269142ull, 18086800073708595164ull,
  3550676541898318177ull, 4087220506604721125ull}},
{{13402752672803694022ull, 4386721018426790121ull,
  4525015847900142813ull, 2554512816627950703ull}},
{{2918382785722453815ull, 10095087291460875556ull,
  1044583791447790612ull, 3193141020784938379ull}},
{{3647978482153067269ull, 12618859114326094445ull,
  15140787794591901977ull, 3991426275981172973ull}},
{{4585829560559360995ull, 969257918812727172ull,
  11768835380833632688ull, 2494641422488233108ull}},
{{5732286950699201244ull, 1211572398515908965ull,
  14711044226042040860ull, 3118301778110291385ull}},
{{11777044706801389459ull, 1514465498144886206ull,
  4553747227270387363ull, 3897877222637864232ull}},
{{2748966923323480508ull, 17087442000836411543ull,
  2846092017043992101ull, 2436173264148665145ull}},
{{17271266709436514347ull, 7524244445763350716ull,
  8169301039732378031ull, 3045216580185831431ull}},
{{3142339313086091318ull, 4793619538776800492ull,
  5599940281238084635ull, 3806520725232289289ull}},
{{11187334107533582882ull, 690169202521806355ull,
  15029177721842272657ull, 2379075453270180805ull}},
{{9372481615989590698ull, 5474397521579645848ull,
  4951414097020677109ull, 2973844316587726007ull}},
{{11715602019986988372ull, 11454682920401945214ull,
  1577581602848458482ull, 3717305395734657509ull}},
{{2710565244064479829ull, 11770862843678603663ull,
  3291831510993980503ull, 2323315872334160943ull}},
{{17223264610362763498ull, 10101892536170866674ull,
  17949847444024639341ull, 2904144840417701178ull}},
{{12305708726098678564ull, 17239051688640971247ull,
  13213937268176023368ull, 3630181050522126473ull}},
{{10770449889195960301ull, 3102070537091662443ull,
  2682363529937865499ull, 4537726313152658092ull}},
{{4425688171533781237ull, 18079695150178146691ull,
  10899849243065941744ull, 2836078945720411307ull}},
{{920424195989838642ull, 4152874864013131748ull, 9013125535405039277ull,
  3545098682150514134ull}},
{{1150530244987298302ull, 9802779598443802589ull,
  2043034882401523288ull, 4431373352688142668ull}},
{{3024924412330755391ull, 6126737249027376618ull,
  10500268838355727863ull, 2769608345430089167ull}},
{{13004527552268220046ull, 3046735542856832868ull,
  8513650029517271925ull, 3462010431787611459ull}},
{{16255659440335275058ull, 8420105446998428989ull,
  6030376518469202002ull, 4327513039734514324ull}},
{{12465630159423240863ull, 9874251922801406022ull,
  12992357360898027059ull, 2704695649834071452ull}},
{{6358665662424275271ull, 7731128885074369624ull,
  16240446701122533824ull, 3380869562292589315ull}},
{{7948332078030344089ull, 9663911106342962030ull,
  15688872357975779376ull, 4226086952865736644ull}},
{{356021530341577152ull, 6039944441464351269ull, 582173186880086302ull,
  2641304345541085403ull}},
{{5056712931354359343ull, 16773302588685214894ull,
  14562774538882271589ull, 3301630431926356753ull}},
{{15544263201047724987ull, 7131570180574354905ull,
  4368410118320675775ull, 4127038039907945942ull}},
{{2797635473013746261ull, 11374760390500053672ull,
  16565314379232586071ull, 2579398774942466213ull}},
{{3497044341267182826ull, 9606764469697679186ull,
  6871584918758568877ull, 3224248468678082767ull}},
{{13594677463438754341ull, 16620141605549486886ull,
  3977795130020823192ull, 4030310585847603459ull}},
{{3884987396221833559ull, 10387588503468429304ull,
  180278947049320543ull, 2518944116154752162ull}},
{{4856234245277291949ull, 8372799610908148726ull,
  9448720720666426487ull, 3148680145193440202ull}},
{{15293664843451390744ull, 5854313495207798003ull,
  2587528863978257301ull, 3935850181491800253ull}},
{{7252697517943425263ull, 5964788943718567704ull,
  3923048549200104765ull, 2459906363432375158ull}},
{{9065871897429281579ull, 12067672198075597534ull,
  14127182723354906764ull, 3074882954290468947ull}},
{{2108967834931826165ull, 15084590247594496918ull,
  13047292385766245551ull, 3843603692863086184ull}},
{{15153162952114555066ull, 16345397932387642429ull,
  8154557741103903469ull, 2402252308039428865ull}},
{{5106395634861030120ull, 6596689360202389325ull,
  14804883194807267241ull, 3002815385049286081ull}},
{{10994680562003675554ull, 12857547718680374560ull,
  4671045938226920339ull, 3753519231311607602ull}},
{{6871675351252297221ull, 5730124314961540148ull,
  7531089729819213116ull, 2345949519569754751ull}},
{{8589594189065371526ull, 7162655393701925185ull,
  4802176143846628491ull, 2932436899462193439ull}},
{{15348678754759102312ull, 4341633223700018577ull,
  1391034161380897710ull, 3665546124327741799ull}},
{{5350790388166714178ull, 14650413566479799030ull,
  15573850757008285849ull, 4581932655409677248ull}},
{{17179302047886360073ull, 2238979451408792537ull,
  9733656723130178656ull, 2863707909631048280ull}},
{{7639069504575786379ull, 2798724314260990672ull,
  12167070903912723320ull, 3579634887038810350ull}},
{{9548836880719732974ull, 3498405392826238340ull,
  5985466593036128342ull, 4474543608798512938ull}},
{{15191395087304608917ull, 16021561425798562674ull,
  8352602639074968117ull, 2796589755499070586ull}},
{{9765871822275985338ull, 6191893726966039631ull,
  1217381261988934339ull, 3495737194373838233ull}},
{{7595653759417593769ull, 3128181140280161635ull,
  6133412595913555828ull, 4369671492967297791ull}},
{{2441440590422302154ull, 11178485249529876830ull,
  10750911900087054248ull, 2731044683104561119ull}},
{{12275172774882653500ull, 13973106561912346037ull,
  8826953856681429906ull, 3413805853880701399ull}},
{{1508907913321153163ull, 8243011165535656739ull,
  6422006302424399479ull, 4267257317350876749ull}},
{{17083968510321578391ull, 12069411006100867317ull,
  6319596948228943626ull, 2667035823344297968ull}},
{{7519902582619809276ull, 5863391720771308339ull,
  7899496185286179533ull, 3333794779180372460ull}},
{{4788192209847373691ull, 11940925669391523328ull,
  9874370231607724416ull, 4167243473975465575ull}},
{{2992620131154608557ull, 7463078543369702080ull,
  13089010422395909616ull, 2604527171234665984ull}},
{{3740775163943260697ull, 9328848179212127600ull,
  16361263027994887020ull, 3255658964043332480ull}},
{{4675968954929075871ull, 11661060224015159500ull,
  2004834711284057159ull, 4069573705054165601ull}},
{{12145852633685448227ull, 14205691667650556543ull,
  12782236740621005484ull, 2543483565658853500ull}},
{{10570629773679422380ull, 17757114584563195679ull,
  15977795925776256855ull, 3179354457073566875ull}},
{{8601601198671890071ull, 17584707212276606695ull,
  15360558888792933165ull, 3974193071341958594ull}},
{{12293529776811013150ull, 13296285016886573136ull,
  14212035323922971132ull, 2483870669588724121ull}},
{{15366912221013766438ull, 16620356271108216420ull,
  3929986099621550203ull, 3104838336985905152ull}},
{{761896202557656431ull, 16163759320457882622ull,
  4912482624526937754ull, 3881047921232381440ull}},
{{14311243181880698982ull, 14714035593713564542ull,
  3070301640329336096ull, 2425654950770238400ull}},
{{8665681940496097919ull, 18392544492141955678ull,
  3837877050411670120ull, 3032068688462798000ull}},
{{1608730388765346591ull, 4543936541467892982ull,
  4797346313014587651ull, 3790085860578497500ull}},
{{14840514548260505331ull, 534117329203739161ull,
  12221713482488893090ull, 2368803662861560937ull}},
{{4715585130043467952ull, 9891018698359449760ull,
  1442083797828952650ull, 2961004578576951172ull}},
{{5894481412554334940ull, 3140401336094536392ull,
  1802604747286190813ull, 3701255723221188965ull}},
{{3684050882846459338ull, 4268593844272779197ull,
  3432470976267563210ull, 2313284827013243103ull}},
{{9216749621985462076ull, 14559114342195749804ull,
  18125646775616617724ull, 2891606033766553878ull}},
{{11520937027481827595ull, 18198892927744687255ull,
  13433686432665996347ull, 3614507542208192348ull}},
{{9789485265924896590ull, 18136930141253471165ull,
  16792108040832495434ull, 4518134427760240435ull}},
{{8424271300416754321ull, 15947267356710807382ull,
  8189224516306615694ull, 2823834017350150272ull}},
{{1306967088666167093ull, 10710712159033733420ull,
  10236530645383269618ull, 3529792521687687840ull}},
{{1633708860832708866ull, 4165018161937390967ull,
  12795663306729087023ull, 4412240652109609800ull}},
{{7938597065661524897ull, 9520665378851951210ull,
  7997289566705679389ull, 2757650407568506125ull}},
{{699874295222130313ull, 16512517741992326917ull,
  14608297976809487140ull, 3447063009460632656ull}},
{{5486528887455050796ull, 2193903103780857030ull,
  18260372471011858926ull, 4308828761825790820ull}},
{{17264138609941570459ull, 15206247495145199355ull,
  2189360757527636020ull, 2693017976141119263ull}},
{{16968487243999575170ull, 561065295221947578ull,
  16571759002191708738ull, 3366272470176399078ull}},
{{11987237018144693155ull, 9924703655882210281ull,
  11491326715884860114ull, 4207840587720498848ull}},
{{574494108699351366ull, 10814625803353769330ull,
  7182079197428037571ull, 2629900367325311780ull}},
{{9941489672728965015ull, 8906596235764823758ull,
  8977598996785046964ull, 3287375459156639725ull}},
{{3203490054056430461ull, 11133245294706029698ull,
  15833684764408696609ull, 4109219323945799656ull}},
{{6613867302212656942ull, 40749281550186705ull, 9896052977755435381ull,
  2568262077466124785ull}},
{{12879020146193209082ull, 4662622620365121285ull,
  16981752240621682130ull, 3210327596832655981ull}},
{{2263717127459347640ull, 15051650312311177415ull,
  7392132245494938950ull, 4012909496040819977ull}},
{{8332352232303174131ull, 4795595426767097980ull,
  16149297699502806604ull, 2508068435025512485ull}},
{{10415440290378967664ull, 5994494283458872475ull,
  6351564069096344543ull, 3135085543781890607ull}},
{{8407614344546321676ull, 2881431835896202690ull,
  3327769067943042775ull, 3918856929727363259ull}},
{{9866444983768838951ull, 8718423925076208537ull,
  18220756731960259398ull, 2449285581079602036ull}},
{{16944742248138436593ull, 1674657869490484863ull,
  4329201841240772632ull, 3061606976349502546ull}},
{{16569241791745657837ull, 2093322336863106079ull,
  14634874338405741598ull, 3827008720436878182ull}},
{{17273305147482118005ull, 15143384515821605011ull,
  4535110443076200594ull, 2391880450273048864ull}},
{{16979945415925259602ull, 9705858607922230456ull,
  5668888053845250743ull, 2989850562841311080ull}},
{{2778187696197022886ull, 7520637241475400167ull,
  7086110067306563429ull, 3737313203551638850ull}},
{{8653896337764221160ull, 7006241285135819056ull,
  9040504810493990047ull, 2335820752219774281ull}},
{{10817370422205276450ull, 4146115587992385916ull,
  15912317031544875463ull, 2919775940274717851ull}},
{{13521713027756595562ull, 570958466563094491ull,
  15278710271003706425ull, 3649719925343397314ull}},
{{12290455266268356548ull, 5325384101631256018ull,
  9875015801899857223ull, 4562149906679246643ull}},
{{12293220559845110747ull, 10245894091160616867ull,
  3866041866973716812ull, 2851343691674529152ull}},
{{10754839681379000529ull, 12807367613950771084ull,
  4832552333717146015ull, 3564179614593161440ull}},
{{13443549601723750662ull, 11397523499011075951ull,
  6040690417146432519ull, 4455224518241451800ull}},
{{15319747528718426020ull, 14040981214523004325ull,
  3775431510716520324ull, 2784515323900907375ull}},
{{5314626355615868813ull, 17551226518153755407ull,
  107603369968262501ull, 3480644154876134219ull}},
{{2031596926092448112ull, 8103975092410030547ull,
  13969562267742491839ull, 4350805193595167773ull}},
{{17410649143303637734ull, 11982513460397350947ull,
  11036819426552751351ull, 2719253245996979858ull}},
{{17151625410702159263ull, 10366455807069300780ull,
  4572652246336163381ull, 3399066557496224823ull}},
{{2992787689668147463ull, 17569755777264013880ull,
  1104129289492816322ull, 4248833196870281029ull}},
{{1870492306042592165ull, 15592783379217396579ull,
  2995923815146704153ull, 2655520748043925643ull}},
{{16173173437835403918ull, 5655921168739582011ull,
  17579962824215543904ull, 3319400935054907053ull}},
{{15604780778866866993ull, 7069901460924477514ull,
  8139895474987266168ull, 4149251168818633817ull}},
{{14364674005219179775ull, 4418688413077798446ull,
  16616649717935511115ull, 2593281980511646135ull}},
{{8732470469669198910ull, 911674497919860154ull,
  16159126128992000990ull, 3241602475639557669ull}},
{{1692216050231722830ull, 10362965159254601001ull,
  6363849605957837525ull, 4052003094549447087ull}},
{{12586850077463296529ull, 8782696233747819577ull,
  10894935031364730309ull, 2532501934093404429ull}},
{{1898504541546956949ull, 15590056310612162376ull,
  18230354807633300790ull, 3165627417616755536ull}},
{{2373130676933696186ull, 10264198351410427162ull,
  4341199435832074372ull, 3957034272020944421ull}},
{{6094892691510948020ull, 15638496006486292784ull,
  5019092656608740434ull, 2473146420013090263ull}},
{{7618615864388685025ull, 10324747971253090172ull,
  1662179802333537639ull, 3091433025016362829ull}},
{{9523269830485856282ull, 8294248945638974811ull,
  6689410771344309953ull, 3864291281270453536ull}},
{{3646200634839966224ull, 16713120637092829017ull,
  4180881732090193720ull, 2415182050794033460ull}},
{{9169436811977345684ull, 2444656722656484655ull,
  5226102165112742151ull, 3018977563492541825ull}},
{{6850109996544294201ull, 16890878958602769531ull,
  11144313724818315592ull, 3773721954365677281ull}},
{{1975475738626489924ull, 10556799349126730957ull, 47667050370365389ull,
  2358576221478548301ull}},
{{7081030691710500309ull, 17807685204835801600ull,
  4671269831390344640ull, 2948220276848185376ull}},
{{8851288364638125386ull, 3812862432335200384ull,
  5839087289237930801ull, 3685275346060231720ull}},
{{11064110455797656732ull, 9377764058846388384ull,
  7298859111547413501ull, 4606594182575289650ull}},
{{6915069034873535458ull, 8166945545992686692ull,
  9173472963144521342ull, 2879121364109556031ull}},
{{8643836293591919322ull, 985309895636082557ull, 6855155185503263774ull,
  3598901705136945039ull}},
{{15416481385417287056ull, 10455009406399879004ull,
  3957257963451691813ull, 4498627131421181299ull}},
{{411928829031028602ull, 8840223888213618330ull, 167443217943613431ull,
  2811641957138238312ull}},
{{9738283073143561561ull, 6438593841839635008ull, 209304022429516789ull,
  3514552446422797890ull}},
{{12172853841429451951ull, 12659928320726931664ull,
  9485002064891671794ull, 4393190558028497362ull}},
{{7608033650893407470ull, 12524141218881720194ull,
  10539812308984682775ull, 2745744098767810851ull}},
{{286670026761983529ull, 11043490505174762339ull,
  8563079367803465565ull, 3432180123459763564ull}},
{{14193395588734643123ull, 18416049149895840827ull,
  10703849209754331956ull, 4290225154324704455ull}},
{{6565029233745458000ull, 2286658681830124709ull,
  13607434783737539329ull, 2681390721452940284ull}},
{{12817972560609210404ull, 7470009370715043790ull,
  17009293479671924161ull, 3351738401816175355ull}},
{{6799093663906737197ull, 13949197731821192642ull,
  16649930831162517297ull, 4189673002270219194ull}},
{{8861119558369098652ull, 1800719554747163545ull,
  15017892787903961215ull, 2618545626418886996ull}},
{{15688085466388761219ull, 16085957498716118143ull,
  325621911170399902ull, 3273182033023608746ull}},
{{14998420814558563620ull, 10884074836540371871ull,
  9630399425817775686ull, 4091477541279510932ull}},
{{16291542036740184118ull, 2190860754410344515ull,
  15242371677990885612ull, 2557173463299694332ull}},
{{15752741527497842244ull, 2738575943012930644ull,
  606220523779055399ull, 3196466829124617916ull}},
{{1244182835662751189ull, 17258277984048327018ull,
  757775654723819248ull, 3995583536405772395ull}},
{{5389300290716607397ull, 10786423740030204386ull,
  16614510848698244694ull, 2497239710253607746ull}},
{{15959997400250535054ull, 4259657638182979674ull,
  11544766524018030060ull, 3121549637817009683ull}},
{{10726624713458393010ull, 5324572047728724593ull,
  9819272136595149671ull, 3901937047271262104ull}},
{{18233355491979965391ull, 10245386557471534726ull,
  6137045085371968544ull, 2438710654544538815ull}},
{{13568322328120180931ull, 12806733196839418408ull,
  3059620338287572776ull, 3048388318180673519ull}},
{{16960402910150226164ull, 16008416496049273010ull,
  17659583478141629682ull, 3810485397725841898ull}},
{{15211937837271279256ull, 14616946328458183535ull,
  15648925692265906455ull, 2381553373578651186ull}},
{{14403236278161711166ull, 13659496892145341515ull,
  10337785078477607261ull, 2976941716973313983ull}},
{{13392359329274751054ull, 3239313059899513182ull,
  8310545329669621173ull, 3721177146216642479ull}},
{{3758538562369331505ull, 4330413671650889691ull,
  12111619858684595089ull, 2325735716385401549ull}},
{{86487184534276477ull, 10024703107991000018ull, 1304466768073580149ull,
  2907169645481751937ull}},
{{9331481017522621404ull, 17142564903416137926ull,
  6242269478519363090ull, 3633962056852189921ull}},
{{2440979235048500947ull, 12204834092415396600ull,
  12414522866576591767ull, 4542452571065237401ull}},
{{1525612021905313092ull, 14545550335400704731ull,
  841547763969287998ull, 2839032856915773376ull}},
{{15742073082663805077ull, 8958565882396105105ull,
  1051934704961609998ull, 3548791071144716720ull}},
{{5842533298047592634ull, 1974835316140355574ull,
  1314918381202012498ull, 4435988838930895900ull}},
{{17486641366561909109ull, 5845958091015110137ull,
  10045196025106033619ull, 2772493024331809937ull}},
{{8023243652920222674ull, 2695761595341499768ull,
  17168181049809929928ull, 3465616280414762421ull}},
{{10029054566150278342ull, 3369701994176874710ull,
  7625168256980248698ull, 4332020350518453027ull}},
{{1656473085416536060ull, 6717749764787934598ull,
  2459887151398961484ull, 2707512719074033142ull}},
{{11293963393625445883ull, 8397187205984918247ull,
  12298230976103477663ull, 3384390898842541427ull}},
{{9505768223604419449ull, 5884797989053759905ull,
  10761102701701959175ull, 4230488623553176784ull}},
{{17470320185821231916ull, 10595527770799681796ull,
  6725689188563724484ull, 2644055389720735490ull}},
{{3391156158566988279ull, 13244409713499602246ull,
  17630483522559431413ull, 3305069237150919362ull}},
{{13462317235063511156ull, 2720454086592339095ull,
  12814732366344513459ull, 4131336546438649203ull}},
{{15331477299555776329ull, 17841184868616069598ull,
  5703364719751626959ull, 2582085341524155752ull}},
{{9940974587589944603ull, 17689795067342699094ull,
  7129205899689533699ull, 3227606676905194690ull}},
{{3202846197632654946ull, 17500557815750985964ull,
  18134879411466692932ull, 4034508346131493362ull}},
{{11225150910375185149ull, 1714476597989590419ull,
  15945985650594070987ull, 2521567716332183351ull}},
{{9419752619541593532ull, 15978153802769151736ull,
  15320796044815200829ull, 3151959645415229189ull}},
{{11774690774426991915ull, 6137634198179275958ull,
  5315937000736837325ull, 3939949556769036487ull}},
{{2747495715589482043ull, 6141864383075741426ull,
  10239989653101605184ull, 2462468472980647804ull}},
{{12657741681341628362ull, 7677330478844676782ull,
  12799987066377006480ull, 3078085591225809755ull}},
{{6598805064822259644ull, 9596663098555845978ull,
  11388297814543870196ull, 3847606989032262194ull}},
{{8735939183941300182ull, 15221286473452179544ull,
  11729372152517306776ull, 2404754368145163871ull}},
{{10919923979926625227ull, 579864018105672814ull,
  10050029172219245567ull, 3005942960181454839ull}},
{{4426532938053505726ull, 14559888077914254730ull,
  7950850446846669054ull, 3757428700226818549ull}},
{{7378269104710828983ull, 4488244030269021302ull,
  7275124538492862111ull, 2348392937641761593ull}},
{{18446208417743312037ull, 998619019408888723ull,
  13705591691543465543ull, 2935491172052201991ull}},
{{18446074503751752142ull, 15083331829543274616ull,
  12520303596001944024ull, 3669363965065252489ull}},
{{4610849055980138561ull, 407420713219541655ull, 1815321439720266319ull,
  4586704956331565612ull}},
{{9799309687628668457ull, 7172166973403295390ull,
  10357947936679942257ull, 2866690597707228507ull}},
{{3025765072681059763ull, 13576894735181507142ull,
  8335748902422539917ull, 3583363247134035634ull}},
{{13005578377706100511ull, 3136060363694720215ull,
  1196314091173399089ull, 4479204058917544543ull}},
{{15046015513707394676ull, 13489252773377669894ull,
  7665225334624456286ull, 2799502536823465339ull}},
{{9584147355279467537ull, 7638193929867311560ull,
  4969845649853182454ull, 3499378171029331674ull}},
{{11980184194099334421ull, 324370375479363642ull,
  15435679099171253876ull, 4374222713786664592ull}},
{{12099301139739471917ull, 9426103521529378084ull,
  9647299436982033672ull, 2733889196116665370ull}},
{{15124126424674339896ull, 11782629401911722605ull,
  2835752259372766282ull, 3417361495145831713ull}},
{{5070099975560761158ull, 5504914715534877449ull,
  8156376342643345757ull, 4271701868932289641ull}},
{{14698027530793945484ull, 5746414706422992357ull,
  16626950260220560858ull, 2669813668082681025ull}},
{{4537476358210268143ull, 16406390419883516255ull,
  6948629769993537360ull, 3337267085103351282ull}},
{{1060159429335447274ull, 2061243951144843703ull,
  17909159249346697509ull, 4171583856379189102ull}},
{{7580128670975736403ull, 3594120478679221266ull,
  6581538512414298039ull, 2607239910236993189ull}},
{{251788801864894695ull, 18327708653631190295ull,
  12838609158945260452ull, 3259049887796241486ull}},
{{14149794057613282081ull, 4462891743329436252ull,
  6824889411826799758ull, 4073812359745301858ull}},
{{18066993322863077109ull, 16624365394863061369ull,
  8877241900819137752ull, 2546132724840813661ull}},
{{8748683598296682674ull, 2333712669869275096ull,
  15708238394451310095ull, 3182665906051017076ull}},
{{10935854497870853342ull, 16752198892618757582ull,
  1188553919354586002ull, 3978332382563771346ull}},
{{2223223042741895435ull, 15081810326314111393ull,
  5354532218024004155ull, 2486457739102357091ull}},
{{7390714821854757198ull, 14240576889465251337ull,
  2081479254102617290ull, 3108072173877946364ull}},
{{13850079545745834401ull, 8577349074976788363ull,
  2601849067628271613ull, 3885090217347432955ull}},
{{6350456706877452549ull, 7666686181074186679ull,
  17767056731763527422ull, 2428181385842145596ull}},
{{3326384865169427782ull, 359985689487957541ull, 3762076840994857662ull,
  3035226732302681996ull}},
{{8769667099889172631ull, 9673354148714722734ull,
  4702596051243572077ull, 3794033415378352495ull}},
{{869355919003344991ull, 8351689352160395661ull, 9856651559668314404ull,
  2371270884611470309ull}},
{{5698380917181569142ull, 10439611690200494576ull,
  16932500468012780909ull, 2964088605764337886ull}},
{{7122976146476961428ull, 17661200631178006124ull,
  11942253548161200328ull, 3705110757205422358ull}},
{{13675232128402876700ull, 11038250394486253827ull,
  2852222449173362301ull, 2315694223253388974ull}},
{{12482354142076207971ull, 18409499011535205188ull,
  12788650098321478684ull, 2894617779066736217ull}},
{{15602942677595259964ull, 4565129690709454869ull,
  2150754567619684644ull, 3618272223833420272ull}},
{{5668620291711911243ull, 5706412113386818587ull,
  2688443209524605805ull, 4522840279791775340ull}},
{{1237044673106250575ull, 5872350580080455569ull,
  10903649042807654436ull, 2826775174869859587ull}},
{{6157991859810201123ull, 7340438225100569461ull,
  9017875285082180141ull, 3533468968587324484ull}},
{{12309175843190139307ull, 13787233799803099730ull,
  11272344106352725176ull, 4416836210734155605ull}},
{{12304920920421224971ull, 8617021124876937331ull,
  9351058075684147187ull, 2760522631708847253ull}},
{{10769465132099143310ull, 6159590387668783760ull,
  16300508613032571888ull, 3450653289636059066ull}},
{{13461831415123929137ull, 7699487984585979700ull,
  11152263729435939052ull, 4313316612045073833ull}},
{{17637016671307231519ull, 14035552027221013120ull,
  52635803256380051ull, 2695822882528171146ull}},
{{3599526765424487783ull, 12932754015598878497ull,
  9289166790925250872ull, 3369778603160213932ull}},
{{9111094475207997632ull, 16165942519498598121ull,
  11611458488656563590ull, 4212223253950267415ull}},
{{17223649093073468280ull, 5492028056259235921ull,
  14174690583051434100ull, 2632639533718917134ull}},
{{7694503311059671638ull, 6865035070324044902ull,
  8494991191959516817ull, 3290799417148646418ull}},
{{394757101969813740ull, 13192979856332444032ull,
  1395366953094620213ull, 4113499271435808023ull}},
{{246723188731133588ull, 10551455419421471472ull,
  7789633373325219489ull, 2570937044647380014ull}},
{{308403985913916984ull, 17801005292704227244ull, 513669679801748553ull,
  3213671305809225018ull}},
{{385504982392396230ull, 8416198560598120343ull, 9865459136606961500ull,
  4017089132261531272ull}},
{{7158469641636329500ull, 14483496137228601022ull,
  6165911960379350937ull, 2510680707663457045ull}},
{{18171459088900187683ull, 4269312116253587565ull,
  12319075968901576576ull, 3138350884579321306ull}},
{{8879265805843070892ull, 5336640145316984457ull,
  6175472924272194912ull, 3922938605724151633ull}},
{{17078756174720389067ull, 3335400090823115285ull,
  15388885623738591580ull, 2451836628577594770ull}},
{{7513387163118322622ull, 4169250113528894107ull,
  10012734992818463667ull, 3064795785721993463ull}},
{{4780047935470515374ull, 599876623483729730ull, 7904232722595691680ull,
  3830994732152491829ull}},
{{7599215978096460013ull, 374922889677331081ull, 7245988460836001252ull,
  2394371707595307393ull}},
{{14110705991047962920ull, 468653612096663851ull,
  13669171594472389469ull, 2992964634494134241ull}},
{{13026696470382565746ull, 5197503033548217718ull,
  3251406437808323124ull, 3741205793117667802ull}},
{{3529999275561715687ull, 12471811432822411882ull,
  6643815042057589856ull, 2338253620698542376ull}},
{{13635871131306920417ull, 15589764291028014852ull,
  8304768802571987320ull, 2922817025873177970ull}},
{{17044838914133650521ull, 1040461290075466949ull,
  1157588966360208343ull, 3653521282341472463ull}},
{{7470990587384899439ull, 15135634667876497399ull,
  15282044263232424140ull, 4566901602926840578ull}},
{{11586898144756644006ull, 236399630568035066ull,
  14162963682947652992ull, 2854313501829275361ull}},
{{5260250644091029199ull, 295499538210043833ull, 3868646548402402528ull,
  3567891877286594202ull}},
{{11186999323541174402ull, 369374422762554791ull,
  14059180222357778968ull, 4459864846608242752ull}},
{{13909403604854315858ull, 230859014226596744ull,
  8786987638973611855ull, 2787415529130151720ull}},
{{17386754506067894822ull, 14123631823065409642ull,
  10983734548717014818ull, 3484269411412689650ull}},
{{12510071095730092719ull, 8431167741976986245ull,
  4506296149041492715ull, 4355336764265862063ull}},
{{10124637444045001902ull, 2963636829521922451ull,
  9733964120792014803ull, 2722085477666163789ull}},
{{8044110786628864473ull, 17539604092184566776ull,
  16779141169417406407ull, 3402606847082704736ull}},
{{10055138483286080591ull, 17312819096803320566ull,
  2527182388062206393ull, 4253258558853380921ull}},
{{1672775533626412466ull, 3902982907860993498ull,
  13108704038607348756ull, 2658286599283363075ull}},
{{11314341453887791390ull, 4878728634826241872ull,
  11774194029831798041ull, 3322858249104203844ull}},
{{14142926817359739237ull, 10710096811960190244ull,
  14717742537289747551ull, 4153572811380254805ull}},
{{18062701297704612832ull, 13611339535116200758ull,
  11504432095019786171ull, 2595983007112659253ull}},
{{13355004585275990231ull, 12402488400467863044ull,
  545482063492569002ull, 3244978758890824067ull}},
{{16693755731594987789ull, 6279738463730052997ull,
  14516910634647874965ull, 4056223448613530083ull}},
{{12739440341460561320ull, 6230679549044977075ull,
  6767226137441227901ull, 2535139655383456302ull}},
{{11312614408398313746ull, 12400035454733609248ull,
  17682404708656310684ull, 3168924569229320377ull}},
{{14140768010497892183ull, 15500044318417011560ull,
  8267947830538224643ull, 3961155711536650472ull}},
{{8837980006561182614ull, 7381684689796938273ull,
  5167467394086390402ull, 2475722319710406545ull}},
{{15659161026628866172ull, 3733825391397033ull, 11071020261035375907ull,
  3094652899638008181ull}},
{{5738893228003919003ull, 13839725337021410004ull, 3717271012056171ull,
  3868316124547510227ull}},
{{12810180304357225185ull, 6343985326424687300ull,
  16143224358878392771ull, 2417697577842193891ull}},
{{16012725380446531481ull, 3318295639603471221ull,
  15567344430170603060ull, 3022121972302742364ull}},
{{6180848670276000639ull, 4147869549504339027ull,
  1012436464003702209ull, 3777652465378427956ull}},
{{1557187409708806448ull, 14121633514508681652ull,
  9856144826857089688ull, 2361032790861517472ull}},
{{1946484262136008059ull, 17652041893135852065ull,
  12320181033571362110ull, 2951290988576896840ull}},
{{7044791346097397978ull, 12841680329565039273ull,
  15400226291964202638ull, 3689113735721121050ull}},
{{13417675201049135377ull, 6828728375101523283ull,
  10026910828100477490ull, 4611392169651401313ull}},
{{6080203991442015659ull, 8879641252865839956ull,
  17796034313631268191ull, 2882120106032125820ull}},
{{7600254989302519573ull, 6487865547654912041ull,
  3798298818329533623ull, 3602650132540157276ull}},
{{14112004755055537370ull, 3498145916141252147ull,
  4747873522911917029ull, 4503312665675196595ull}},
{{6514159962696016905ull, 4492184206801976544ull, 661577942606254191ull,
  2814570416046997872ull}},
{{8142699953370021131ull, 1003544240075082776ull, 826972428257817739ull,
  3518213020058747340ull}},
{{10178374941712526413ull, 15089488355376017182ull,
  1033715535322272173ull, 4397766275073434175ull}},
{{1749798320142941104ull, 11736773231323704691ull,
  7563601237217501964ull, 2748603921920896359ull}},
{{16022305955460840092ull, 14670966539154630863ull,
  4842815528094489551ull, 3435754902401120449ull}},
{{15416196425898662211ull, 13727022155515900675ull,
  10665205428545499843ull, 4294693628001400561ull}},
{{7329279756972969930ull, 6273545837983743970ull,
  18194968438909407162ull, 2684183517500875350ull}},
{{18384971733070988221ull, 17065304334334455770ull,
  13520338511781983144ull, 3355229396876094188ull}},
{{13757842629483959468ull, 2884886344208518097ull,
  16900423139727478931ull, 4194036746095117735ull}},
{{1681122615786392812ull, 17943955029626181475ull,
  17480293489970756187ull, 2621272966309448584ull}},
{{15936461325015154726ull, 17818257768605338939ull,
  3403622788753893618ull, 3276591207886810731ull}},
{{15308890637841555504ull, 13049450173901897866ull,
  18089586541224530735ull, 4095739009858513413ull}},
{{14179742667078360094ull, 15073435386329768022ull,
  13611834597479025661ull, 2559836881161570883ull}},
{{8501306296993174309ull, 5006736177630046316ull,
  12403107228421394173ull, 3199796101451963604ull}},
{{10626632871241467887ull, 10870106240464945799ull,
  15503884035526742716ull, 3999745126814954505ull}},
{{13559174572166999285ull, 16017188437145366932ull,
  2772398494563132341ull, 2499840704259346566ull}},
{{16948968215208749107ull, 6186427491149544953ull,
  12688870155058691235ull, 3124800880324183207ull}},
{{7351152213728772671ull, 3121348345509543288ull,
  11249401675395976140ull, 3906001100405229009ull}},
{{4594470133580482920ull, 11174214752798240363ull,
  113347019481403231ull, 2441250687753268131ull}},
{{1131401648548215745ull, 9356082422570412550ull,
  13976741829633917751ull, 3051563359691585163ull}},
{{10637624097540045490ull, 7083417009785627783ull,
  12859241268615009285ull, 3814454199614481454ull}},
{{13566044088603610287ull, 6732978640329711316ull,
  3425339774456992899ull, 2384033874759050909ull}},
{{16957555110754512859ull, 3804537281984751241ull,
  8893360736498629028ull, 2980042343448813636ull}},
{{7361885833160977361ull, 4755671602480939052ull,
  11116700920623286285ull, 3725052929311017045ull}},
{{13824550682580386659ull, 5278137760764280859ull,
  9253781084603247880ull, 2328158080819385653ull}},
{{12669002334798095420ull, 6597672200955351074ull,
  16178912374181447754ull, 2910197601024232066ull}},
{{6612880881642843467ull, 17470462288048964651ull,
  11000268430872033884ull, 3637747001280290083ull}},
{{3654415083626166429ull, 3391333786351654198ull,
  9138649520162654452ull, 4547183751600362604ull}},
{{16119067482548517730ull, 11342955653324559681ull,
  14935027986956434840ull, 2841989844750226627ull}},
{{6313776297903483451ull, 14178694566655699602ull,
  14057098965268155646ull, 3552487305937783284ull}},
{{17115592409234130121ull, 8499996171464848694ull,
  17571373706585194558ull, 4440609132422229105ull}},
{{6085559237343943422ull, 700811588738142530ull, 4064579538974664743ull,
  2775380707763893191ull}},
{{16830321083534705085ull, 14711072541204841874ull,
  469038405290943024ull, 3469225884704866489ull}},
{{11814529317563605549ull, 18388840676506052343ull,
  5197984025041066684ull, 4336532355881083111ull}},
{{14301609851118335324ull, 2269653385961506906ull,
  10166269043291748534ull, 2710332722425676944ull}},
{{8653640277043143347ull, 12060438769306659441ull,
  12707836304114685667ull, 3387915903032096180ull}},
{{15428736364731317088ull, 10463862443205936397ull,
  15884795380143357084ull, 4234894878790120225ull}},
{{11948803237170767132ull, 15763286063858486056ull,
  3010468084948516321ull, 2646809299243825141ull}},
{{14936004046463458915ull, 5869049524540943858ull,
  8374771124613033306ull, 3308511624054781426ull}},
{{9446633021224547835ull, 16559683942530955631ull,
  1245091868911515824ull, 4135639530068476783ull}},
{{12821674665906424253ull, 10349802464081847269ull,
  7695711445710779246ull, 2584774706292797989ull}},
{{2192035277100866605ull, 3713881043247533279ull,
  14231325325565861962ull, 3230968382865997486ull}},
{{16575102151658246968ull, 13865723340914192406ull,
  8565784620102551644ull, 4038710478582496858ull}},
{{5747752826359016451ull, 17889449124926146062ull,
  9965301405991482681ull, 2524194049114060536ull}},
{{16408063069803546371ull, 8526753350875518865ull,
  12456626757489353352ull, 3155242561392575670ull}},
{{6675020781972269252ull, 10658441688594398582ull,
  6347411410006915882ull, 3944053201740719588ull}},
{{18006946044014831995ull, 11273212073798887017ull,
  13190504168109098234ull, 2465033251087949742ull}},
{{8673624499736376281ull, 4868143055393832964ull,
  7264758173281596985ull, 3081291563859937178ull}},
{{10842030624670470352ull, 10696864837669679109ull,
  18304319753456772039ull, 3851614454824921472ull}},
{{9082112149632737922ull, 13603069551184631299ull,
  11440199845910482524ull, 2407259034265575920ull}},
{{6740954168613534498ull, 17003836938980789124ull,
  14300249807388103155ull, 3009073792831969900ull}},
{{8426192710766918123ull, 16643110155298598501ull,
  17875312259235128944ull, 3761342241039962375ull}},
{{7572213453443017779ull, 10401943847061624063ull,
  18089599189663037446ull, 2350838900649976484ull}},
{{4853580798376384320ull, 3779057771972254271ull,
  4165254913369245192ull, 2938548625812470606ull}},
{{1455289979543092495ull, 4723822214965317839ull,
  14429940678566332298ull, 3673185782265588257ull}},
{{15654170529711029331ull, 15128149805561423106ull,
  4202367792925751660ull, 4591482227831985322ull}},
{{14395542599496781236ull, 231721591621113633ull,
  7238165889005982692ull, 2869676392394990826ull}},
{{4159370194088812833ull, 289651989526392042ull,
  18271079398112254173ull, 3587095490493738532ull}},
{{14422584779465791849ull, 4973751005335377956ull,
  4392105173930766100ull, 4483869363117173166ull}},
{{18237487524020895714ull, 12331966415189387030ull,
  16580123788988892524ull, 2802418351948233228ull}},
{{13573487368171343834ull, 15414958018986733788ull,
  2278410662526564039ull, 3503022939935291536ull}},
{{16966859210214179793ull, 14657011505306029331ull,
  2848013328158205049ull, 4378778674919114420ull}},
{{8298443997170168419ull, 2243103163175186476ull,
  11003380366953653964ull, 2736736671824446512ull}},
{{10373054996462710523ull, 2803878953968983095ull,
  13754225458692067455ull, 3420920839780558140ull}},
{{8354632727151000250ull, 17339906747743392581ull,
  17192781823365084318ull, 4276151049725697675ull}},
{{7527488463683069108ull, 6225755698912232459ull,
  8439645630389483747ull, 2672594406078561047ull}},
{{4797674561176448481ull, 3170508605212902670ull,
  5937871019559466780ull, 3340743007598201309ull}},
{{15220465238325336409ull, 3963135756516128337ull,
  12034024792876721379ull, 4175928759497751636ull}},
{{2595261746312253400ull, 171116838608886259ull,
  16744637532402726670ull, 2609955474686094772ull}},
{{17079135238172480462ull, 9437268085115883631ull,
  2484052841793856721ull, 3262444343357618466ull}},
{{16737233029288212673ull, 16408271124822242443ull,
  12328438089097096709ull, 4078055429197023082ull}},
{{8154927634091438969ull, 12561012462227595479ull,
  12316959824113073347ull, 2548784643248139426ull}},
{{5581973524186910807ull, 11089579559357106445ull,
  6172827743286565876ull, 3185980804060174283ull}},
{{11589152923661026413ull, 13861974449196383056ull,
  3104348660680819441ull, 3982476005075217854ull}},
{{7243220577288141508ull, 1746205003106657554ull,
  15775275968207675863ull, 2489047503172011158ull}},
{{18277397758464952693ull, 16017814309165485654ull,
  10495722923404819020ull, 3111309378965013948ull}},
{{13623375161226415058ull, 1575523812747305452ull,
  13119653654256023776ull, 3889136723706267435ull}},
{{17737981512621285220ull, 984702382967065907ull,
  5893940524696320908ull, 2430710452316417147ull}},
{{17560790872349218620ull, 1230877978708832384ull,
  2755739637443013231ull, 3038388065395521434ull}},
{{3504244516726971659ull, 15373655528668204193ull,
  12668046583658542346ull, 3797985081744401792ull}},
{{13719367869022827047ull, 14220220723845015524ull,
  7917529114786588966ull, 2373740676090251120ull}},
{{17149209836278533809ull, 8551903867951493597ull,
  9896911393483236208ull, 2967175845112813900ull}},
{{7601454240066003549ull, 10689879834939366997ull,
  12371139241854045260ull, 3708969806391017375ull}},
{{7056751909254946170ull, 15904546933691880181ull,
  14649491053799860143ull, 2318106128994385859ull}},
{{13432625904996070617ull, 15268997648687462322ull,
  13700177798822437275ull, 2897632661242982324ull}},
{{7567410344390312463ull, 14474561042431939999ull,
  17125222248528046594ull, 3622040826553727905ull}},
{{4847576912060502675ull, 8869829266185149191ull,
  7571469755377894531ull, 4527551033192159882ull}},
{{9947264597678896028ull, 3237800282152024292ull,
  9343854615538571986ull, 2829719395745099926ull}},
{{12434080747098620035ull, 13270622389544806173ull,
  2456446232568439174ull, 3537149244681374908ull}},
{{1707542878591111331ull, 7364905950076231909ull,
  3070557790710548968ull, 4421436555851718635ull}},
{{3373057308333138534ull, 4603066218797644943ull,
  18059999683689950769ull, 2763397847407324146ull}},
{{18051379690698586880ull, 10365518791924444082ull,
  13351627567757662653ull, 3454247309259155183ull}},
{{13340852576518457791ull, 17568584508332943007ull,
  12077848441269690412ull, 4317809136573943979ull}},
{{15255561887965117976ull, 1756993280853313571ull,
  5242812266579862556ull, 2698630710358714987ull}},
{{14457766341529009566ull, 2196241601066641964ull,
  1941829314797440291ull, 3373288387948393734ull}},
{{18072207926911261957ull, 16580360056615466167ull,
  11650658680351576171ull, 4216610484935492167ull}},
{{18212658981960620579ull, 8056882026170972402ull,
  14199190702860816963ull, 2635381553084682604ull}},
{{13542451690595999916ull, 5459416514286327599ull,
  17748988378576021204ull, 3294226941355853255ull}},
{{12316378594817611991ull, 6824270642857909499ull,
  17574549454792638601ull, 4117783676694816569ull}},
{{5391893612547313542ull, 15794384197854663197ull,
  4066564381604317269ull, 2573614797934260356ull}},
{{11351553034111529832ull, 5907922192036165284ull,
  5083205477005396587ull, 3217018497417825445ull}},
{{14189441292639412290ull, 2773216721617818701ull,
  10965692864684133638ull, 4021273121772281806ull}},
{{11174243817113326633ull, 15568318506293300400ull,
  2241872022000195619ull, 2513295701107676129ull}},
{{13967804771391658291ull, 14848712114439237596ull,
  7414026045927632428ull, 3141619626384595161ull}},
{{17459755964239572864ull, 114146069339495379ull,
  13879218575836928440ull, 3927024532980743951ull}},
{{8606504468436039088ull, 71341293337184612ull, 15592040637539162131ull,
  2454390333112964969ull}},
{{10758130585545048860ull, 13924234671953644477ull,
  5654992741641788951ull, 3067987916391206212ull}},
{{18059349250358698979ull, 12793607321514667692ull,
  7068740927052236189ull, 3834984895489007765ull}},
{{2063721244619411054ull, 10301847585160361260ull,
  6723806088621341570ull, 2396865559680629853ull}},
{{2579651555774263818ull, 3653937444595675767ull,
  13016443629204064867ull, 2996081949600787316ull}},
{{17059622499999993484ull, 18402479861026758420ull,
  16270554536505081083ull, 3745102437000984145ull}},
{{1438892025645220120ull, 9195706903928030061ull,
  3251567557674593821ull, 2340689023125615091ull}},
{{6410301050483913053ull, 16106319648337425480ull,
  17899517502375405988ull, 2925861278907018863ull}},
{{8012876313104891317ull, 1686155486712230234ull,
  17762710859541869582ull, 3657326598633773579ull}},
{{792723354526338338ull, 11331066395245063601ull,
  17591702555999949073ull, 4571658248292216974ull}},
{{12024667142647431221ull, 164387469387082894ull,
  6383128079072580267ull, 2857286405182635609ull}},
{{5807461891454513218ull, 14040542392016017330ull,
  12590596117268113237ull, 3571608006478294511ull}},
{{16482699401172917331ull, 3715619934737857950ull,
  11126559128157753643ull, 4464510008097868139ull}},
{{5690001107305685428ull, 16419449997467267ull, 4648256445884902075ull,
  2790318755061167587ull}},
{{2500815365704718881ull, 13855582367778997796ull,
  1198634538928739689ull, 3487898443826459484ull}},
{{3126019207130898601ull, 3484419904441583533ull,
  1498293173660924612ull, 4359873054783074355ull}},
{{4259605013670505578ull, 11401134477130765516ull,
  17077334298033935546ull, 2724920659239421471ull}},
{{5324506267088131972ull, 5028046059558681087ull,
  16734981854115031529ull, 3406150824049276839ull}},
{{2043946815432777061ull, 10896743592875739263ull,
  16307041299216401507ull, 4257688530061596049ull}},
{{8194995787286567519ull, 4504621736333643087ull,
  3274371784369169086ull, 2661055331288497531ull}},
{{5632058715680821495ull, 14854149207271829667ull,
  17928022785743625069ull, 3326319164110621913ull}},
{{2428387376173638965ull, 4732628453807623372ull,
  8574970426897367625ull, 4157898955138277392ull}},
{{10741114146963300161ull, 14487107829698234367ull,
  5359356516810854765ull, 2598686846961423370ull}},
{{8814706665276737297ull, 4273826731840629247ull,
  15922567682868344265ull, 3248358558701779212ull}},
{{6406697313168533717ull, 9953969433228174463ull,
  1456465529875878715ull, 4060448198377224016ull}},
{{10921714848371415430ull, 3915387886553915087ull,
  910290956172424197ull, 2537780123985765010ull}},
{{9040457542036881383ull, 9505920876619781763ull,
  10361235732070306054ull, 3172225154982206262ull}},
{{6688885909118713824ull, 2659029058919951396ull,
  3728172628233106760ull, 3965281443727757828ull}},
{{13403925730053971948ull, 1661893161824969622ull,
  11553479929500467533ull, 2478300902329848642ull}},
{{7531535125712689127ull, 6689052470708599932ull,
  5218477875020808608ull, 3097876127912310803ull}},
{{9414418907140861409ull, 8361315588385749915ull,
  1911411325348622856ull, 3872345159890388504ull}},
{{3578168807749344429ull, 5225822242741093697ull,
  1194632078342889285ull, 2420215724931492815ull}},
{{9084397028114068440ull, 11143963821853755025ull,
  15328348153210775318ull, 3025269656164366018ull}},
{{15967182303569973454ull, 4706582740462417973ull,
  9937063154658693340ull, 3781587070205457523ull}},
{{12285331948944927361ull, 12164986249643787041ull,
  3904821462447989385ull, 2363491918878410952ull}},
{{1521606880898995489ull, 1371174756772570090ull,
  4881026828059986732ull, 2954364898598013690ull}},
{{11125380637978520169ull, 1713968445965712612ull,
  15324655571929759223ull, 3692956123247517112ull}},
{{16176734935591350914ull, 7988759306369652238ull,
  9577909732456099514ull, 2308097577029698195ull}},
{{10997546632634412834ull, 762577096107289490ull,
  7360701147142736489ull, 2885121971287122744ull}},
{{4523561253938240235ull, 5564907388561499767ull,
  9200876433928420611ull, 3606402464108903430ull}},
{{1042765548995412389ull, 2344448217274486805ull,
  2277723505555749956ull, 4508003080136129288ull}},
{{2957571477335826695ull, 10688652172651330061ull,
  1423577190972343722ull, 2817501925085080805ull}},
{{8308650365097171273ull, 4137443178959386768ull,
  6391157507142817557ull, 3521877406356351006ull}},
{{10385812956371464091ull, 9783489992126621364ull,
  17212318920783297754ull, 4402346757945438757ull}},
{{15714505134586940865ull, 10726367263506526256ull,
  13063542334703255048ull, 2751466723715899223ull}},
{{1196387344524124465ull, 13407959079383157821ull,
  11717741899951680906ull, 3439333404644874029ull}},
{{6107170199082543486ull, 7536576812374171468ull, 812119319657437421ull,
  4299166755806092537ull}},
{{13040353411281365487ull, 7016203516947551119ull,
  12036789620854368148ull, 2686979222378807835ull}},
{{11688755745674318954ull, 8770254396184438899ull,
  10434301007640572281ull, 3358724027973509794ull}},
{{9999258663665510789ull, 15574504013657936528ull,
  3819504222695939543ull, 4198405034966887243ull}},
{{6249536664790944243ull, 16651594036177292186ull, 81347129971268262ull,
  2624003146854304527ull}},
{{17035292867843456112ull, 11591120508366839424ull,
  13936741967746249040ull, 3280003933567880658ull}},
{{2847372011094768524ull, 14488900635458549281ull,
  8197555422828035492ull, 4100004916959850823ull}},
{{13308822553002700087ull, 18278934934016369108ull,
  12041001166908604038ull, 2562503073099906764ull}},
{{16636028191253375109ull, 13625296630665685577ull,
  15051251458635755048ull, 3203128841374883455ull}},
{{6959977183784555174ull, 17031620788332106972ull,
  14202378304867305906ull, 4003911051718604319ull}},
{{13573357776720122792ull, 15256449011134954761ull,
  15794015468183148047ull, 2502444407324127699ull}},
{{3131639165617989778ull, 14458875245491305548ull,
  15130833316801547155ull, 3128055509155159624ull}},
{{3914548957022487222ull, 13461908038436744031ull,
  466797572292382328ull, 3910069386443949531ull}},
{{9364122125780136370ull, 8413692524022965019ull,
  16432649547178596619ull, 2443793366527468456ull}},
{{7093466638797782559ull, 5905429636601318370ull,
  2094067860263694158ull, 3054741708159335571ull}},
{{18090205335352004006ull, 16605159082606423770ull,
  16452642880611781409ull, 3818427135199169463ull}},
{{15918064353022390408ull, 3460695398987933000ull,
  17200430828023445237ull, 2386516959499480914ull}},
{{1450836367568436394ull, 8937555267162304155ull,
  12277166498174530738ull, 2983146199374351143ull}},
{{15648603514742709204ull, 1948572047098104385ull,
  10734772104290775519ull, 3728932749217938929ull}},
{{2862848169073111397ull, 8135386557077397097ull,
  18238447611250204459ull, 2330582968261211830ull}},
{{8190246229768777150ull, 5557547177919358467ull,
  13574687477207979766ull, 2913228710326514788ull}},
{{5626121768783583533ull, 16170306009253973892ull,
  16968359346509974707ull, 3641535887908143485ull}},
{{7032652210979479417ull, 15601196493140079461ull,
  7375391127855304672ull, 4551919859885179357ull}},
{{6701250641075868588ull, 9750747808212549663ull,
  6915462464123259372ull, 2844949912428237098ull}},
{{3764877282917447830ull, 12188434760265687079ull,
  17867700117008850023ull, 3556187390535296372ull}},
{{94410585219421884ull, 10623857431904720945ull, 3887881072551510913ull,
  4445234238169120466ull}},
{{11588221661830608438ull, 18169125941008920350ull,
  7041611688772082224ull, 2778271398855700291ull}},
{{5261905040433484739ull, 4264663352551598822ull,
  4190328592537714877ull, 3472839248569625364ull}},
{{15800753337396631731ull, 9942515209116886431ull,
  5237910740672143596ull, 4341049060712031705ull}},
{{16792999863513976688ull, 15437444042552829827ull,
  14802909258988559507ull, 2713155662945019815ull}},
{{16379563810965082956ull, 14685119034763649380ull,
  13891950555308311480ull, 3391444578681274769ull}},
{{2027710689996802079ull, 18356398793454561726ull,
  3529880138853225638ull, 4239305723351593462ull}},
{{15102377236530165012ull, 6861063227481713174ull,
  16041233142065429736ull, 2649566077094745913ull}},
{{9654599508807930456ull, 8576329034352141468ull,
  6216483372299623458ull, 3311957596368432392ull}},
{{12068249386009913070ull, 1497039256085401027ull,
  7770604215374529323ull, 4139946995460540490ull}},
{{5236812857042501717ull, 17076550599549233306ull,
  9468313653036468730ull, 2587466872162837806ull}},
{{15769388108157902954ull, 12122316212581765824ull,
  2612020029440810105ull, 3234333590203547258ull}},
{{1264991061487827077ull, 1317837210445043569ull,
  12488397073655788440ull, 4042916987754434072ull}},
{{12319834459498361683ull, 823648256528152230ull,
  7805248171034867775ull, 2526823117346521295ull}},
{{6176421037518176296ull, 14864618375942354000ull,
  5144874195366196814ull, 3158528896683151619ull}},
{{7720526296897720370ull, 9357400933073166692ull,
  1819406725780358114ull, 3948161120853939524ull}},
{{14048700972415851039ull, 10460061601598117086ull,
  10360501240467499629ull, 2467600700533712202ull}},
{{8337504178665037991ull, 17686763020425034262ull,
  3727254513729598728ull, 3084500875667140253ull}},
{{1198508186476521681ull, 3661709701821741212ull,
  9270754160589386315ull, 3855626094583925316ull}},
{{9972439653402601859ull, 18429469628134445921ull,
  15017593387223142254ull, 2409766309114953322ull}},
{{17077235585180640227ull, 13813464998313281593ull,
  9548619697174152010ull, 3012207886393691653ull}},
{{7511486426193636572ull, 8043459211036826184ull,
  16547460639895077917ull, 3765259857992114566ull}},
{{4694679016371022858ull, 7333005016111710317ull,
  5730476881507035794ull, 2353287411245071604ull}},
{{10480034788891166476ull, 18389628306994413704ull,
  7163096101883794742ull, 2941609264056339505ull}},
{{13100043486113958095ull, 13763663346888241322ull,
  13565556145782131332ull, 3677011580070424381ull}},
{{7151682320787671810ull, 17204579183610301653ull,
  3121887126945500453ull, 4596264475088030477ull}},
{{6775644459705988834ull, 13058704998970132485ull,
  4257022463554631735ull, 2872665296930019048ull}},
{{13081241593059873946ull, 11711695230285277702ull,
  5321278079443289669ull, 3590831621162523810ull}},
{{7128179954470066624ull, 804560982574433416ull,
  15874969636158887895ull, 4488539526453154762ull}},
{{4455112471543791640ull, 7420379641750102741ull,
  14533542041026692838ull, 2805337204033221726ull}},
{{10180576607857127454ull, 52102515332852618ull, 8943555514428590240ull,
  3506671505041527158ull}},
{{3502348722966633510ull, 65128144166065773ull, 1956072356180961992ull,
  4383339381301908948ull}},
{{4494810961067839896ull, 40705090103791108ull, 10445917259467877053ull,
  2739587113313693092ull}},
{{5618513701334799869ull, 4662567381057126789ull,
  13057396574334846316ull, 3424483891642116365ull}},
{{11634828145095887741ull, 5828209226321408486ull,
  2486687662636394183ull, 4280604864552645457ull}},
{{2660081572257541934ull, 10560159794091962160ull,
  13083394835216216124ull, 2675378040345403410ull}},
{{3325101965321927418ull, 13200199742614952700ull,
  7130871507165494347ull, 3344222550431754263ull}},
{{4156377456652409272ull, 11888563659841302971ull,
  4301903365529480030ull, 4180278188039692829ull}},
{{291892901194061843ull, 2818666268973426453ull, 4994532612669618971ull,
  2612673867524808018ull}},
{{4976552144919965208ull, 17358390891498946778ull,
  15466537802691799521ull, 3265842334406010022ull}},
{{15444062218004732318ull, 7862930559091519760ull,
  10109800216509973594ull, 4082302918007512528ull}},
{{9652538886252957699ull, 9526017617859587754ull,
  6318625135318733496ull, 2551439323754695330ull}},
{{2842301570961421315ull, 11907522022324484693ull,
  17121653456003192678ull, 3189299154693369162ull}},
{{8164562982129164548ull, 5661030491050830058ull,
  12178694783149215040ull, 3986623943366711453ull}},
{{9714537882258115747ull, 3538144056906768786ull,
  9917527248681953352ull, 2491639964604194658ull}},
{{2919800315967868875ull, 4422680071133460983ull,
  3173537023997665882ull, 3114549955755243323ull}},
{{17484808450241999806ull, 14751722125771602036ull,
  17801979335279246064ull, 3893187444694054153ull}},
{{1704633244546474071ull, 9219826328607251273ull,
  4208708056908446934ull, 2433242152933783846ull}},
{{6742477574110480492ull, 2301410873904288283ull,
  14484257107990334476ull, 3041552691167229807ull}},
{{3816410949210712711ull, 2876763592380360354ull,
  13493635366560530191ull, 3801940863959037259ull}},
{{6996942861684083349ull, 8715506272878807077ull,
  6127679094886637417ull, 2376213039974398287ull}},
{{13357864595532492090ull, 15506068859525896750ull,
  3047912850180908867ull, 2970266299967997859ull}},
{{7473958707560839304ull, 14770900055979983034ull,
  17644949118008299796ull, 3712832874959997323ull}},
{{9282910210652912469ull, 8440498132713588ull, 8722250189541493421ull,
  2320520546849998327ull}},
{{11603637763316140587ull, 4622236641093279889ull,
  6291126718499478872ull, 2900650683562497909ull}},
{{669489148863012021ull, 5777795801366599862ull,
  12475594416551736494ull, 3625813354453122386ull}},
{{10060233472933540834ull, 16445616788563025635ull,
  6371120983834894809ull, 4532266693066402983ull}},
{{3981802911369769070ull, 3360981465210809166ull,
  10899479642537891112ull, 2832666683166501864ull}},
{{14200625676066987145ull, 4201226831513511457ull,
  13624349553172363890ull, 3540833353958127330ull}},
{{3915724039801570219ull, 14474905576246665130ull,
  7807064904610679054ull, 4426041692447659163ull}},
{{7059013543303369291ull, 4435129966726777802ull,
  2573572556167980457ull, 2766276057779786977ull}},
{{18047138965983987422ull, 10155598476835860156ull,
  7828651713637363475ull, 3457845072224733721ull}},
{{4112179633770432661ull, 8082812077617437292ull,
  14397500660474092248ull, 4322306340280917151ull}},
{{11793484307961296221ull, 5051757548510898307ull,
  15915966940437389511ull, 2701441462675573219ull}},
{{10130169366524232372ull, 1703010917211234980ull,
  15283272657119348985ull, 3376801828344466524ull}},
{{12662711708155290465ull, 6740449664941431629ull,
  657346747689634615ull, 4221002285430583156ull}},
{{10220037826810750493ull, 11130310068229476624ull,
  9634213754160797442ull, 2638126428394114472ull}},
{{12775047283513438116ull, 4689515548432069972ull,
  12042767192700996803ull, 3297658035492643090ull}},
{{15968809104391797645ull, 1250208417112699561ull,
  5830086954021470196ull, 4122072544365803863ull}},
{{3062976662603791672ull, 10004752297550213034ull,
  10561333373904500728ull, 2576295340228627414ull}},
{{13052092865109515398ull, 12505940371937766292ull,
  3978294680525850102ull, 3220369175285784268ull}},
{{16315116081386894248ull, 6409053428067432057ull,
  4972868350657312628ull, 4025461469107230335ull}},
{{3279418523225727049ull, 13229030429396920844ull,
  10025571746801902248ull, 2515913418192018959ull}},
{{4099273154032158811ull, 16536288036746151055ull,
  7920278665074989906ull, 3144891772740023699ull}},
{{512405424112810610ull, 11446988009077913011ull,
  5288662312916349479ull, 3931114715925029624ull}},
{{16461154454566364295ull, 14071896533314777487ull,
  3305413945572718424ull, 2456946697453143515ull}},
{{15964757049780567465ull, 17589870666643471859ull,
  17966825487248061742ull, 3071183371816429393ull}},
{{15344260293798321427ull, 12763966296449564016ull,
  8623473803777913466ull, 3838979214770536742ull}},
{{9590162683623950892ull, 12589164953708365414ull,
  777985108933808012ull, 2399362009231585464ull}},
{{2764331317675162807ull, 15736456192135456768ull,
  972481386167260015ull, 2999202511539481830ull}},
{{3455414147093953509ull, 15058884221741933056ull,
  10438973769563850827ull, 3749003139424352287ull}},
{{2159633841933720943ull, 7105959629375014208ull,
  13441887633618488623ull, 2343126962140220179ull}},
{{2699542302417151179ull, 4270763518291379856ull,
  12190673523595722875ull, 2928908702675275224ull}},
{{3374427878021438973ull, 726768379436836916ull,
  15238341904494653594ull, 3661135878344094030ull}},
{{4218034847526798717ull, 10131832511150821953ull,
  9824555343763541184ull, 4576419847930117538ull}},
{{14165486825772718958ull, 6332395319469263720ull,
  10752033108279601144ull, 2860262404956323461ull}},
{{17706858532215898698ull, 7915494149336579650ull,
  18051727403776889334ull, 3575328006195404326ull}},
{{12910201128415097564ull, 670995649815948755ull,
  13341287217866335860ull, 4469160007744255408ull}},
{{5763032696045742026ull, 9642744317989743780ull,
  8338304511166459912ull, 2793225004840159630ull}},
{{7203790870057177532ull, 12053430397487179725ull,
  1199508602103299082ull, 3491531256050199538ull}},
{{13616424605998859819ull, 5843415960004198848ull,
  10722757789483899661ull, 4364414070062749422ull}},
{{8510265378749287387ull, 5957977984216318232ull,
  2090037600000049384ull, 2727758793789218389ull}},
{{10637831723436609233ull, 7447472480270397790ull,
  7224233018427449634ull, 3409698492236522986ull}},
{{4073917617440985734ull, 85968563483221430ull, 18253663309889087851ull,
  4262123115295653732ull}},
{{16381256566182779796ull, 16194631416672871057ull,
  2185167531825904098ull, 2663826947059783583ull}},
{{6641512652446311033ull, 11019917233986313014ull,
  16566517470064543835ull, 3329783683824729478ull}},
{{17525262852412664599ull, 9163210524055503363ull,
  11484774800725903986ull, 4162229604780911848ull}},
{{8647446273544221422ull, 10338692595962077506ull,
  7177984250453689991ull, 2601393502988069905ull}},
{{1585935805075500970ull, 8311679726525208979ull,
  13584166331494500393ull, 3251741878735087381ull}},
{{15817477811626539924ull, 15001285676583899127ull,
  3145149859085961779ull, 4064677348418859227ull}},
{{16803452659907669309ull, 7069960538651243002ull,
  18106619726424583776ull, 2540423342761787016ull}},
{{11780943788029810828ull, 8837450673314053753ull,
  4186530584321178104ull, 3175529178452233771ull}},
{{891121679755099823ull, 11046813341642567192ull, 621477211974084726ull,
  3969411473065292214ull}},
{{556951049846937389ull, 2292572320099216591ull,
  14223481312765966666ull, 2480882170665807633ull}},
{{14531246867590835448ull, 12089087436978796546ull,
  3944293585675294620ull, 3101102713332259542ull}},
{{8940686547633768502ull, 15111359296223495683ull,
  14153739018948894083ull, 3876378391665324427ull}},
{{3282086083057411362ull, 7138756550925990850ull,
  6540243877629364850ull, 2422736494790827767ull}},
{{13325979640676540011ull, 18146817725512264370ull,
  3563618828609318158ull, 3028420618488534709ull}},
{{7434102513990899205ull, 13460150120035554655ull,
  9066209554189035602ull, 3785525773110668386ull}},
{{11563843098885393859ull, 13024279843449609563ull,
  10278066989795535155ull, 2365953608194167741ull}},
{{9843117855179354420ull, 11668663785884624050ull,
  17459269755671806848ull, 2957442010242709676ull}},
{{3080525282119417217ull, 14585829732355780063ull,
  3377343120880206944ull, 3696802512803387096ull}},
{{8842857328965717617ull, 9116143582722362539ull,
  2110839450550129340ull, 2310501570502116935ull}},
{{6441885642779759117ull, 11395179478402953174ull,
  16473607368469825387ull, 2888126963127646168ull}},
{{17275729090329474704ull, 9632288329576303563ull,
  2145265136877730118ull, 3610158703909557711ull}},
{{16982975344484455476ull, 2816988375115603646ull,
  16516639476379326360ull, 4512698379886947138ull}},
{{6002673571875396769ull, 1760617734447252279ull,
  14934585691164466879ull, 2820436487429341961ull}},
{{2891655946416858057ull, 16035830223341229061ull,
  4833174058673419886ull, 3525545609286677452ull}},
{{8226255951448460475ull, 10821415742321760518ull,
  6041467573341774858ull, 4406932011608346815ull}},
{{529723951227899893ull, 11375070857378488228ull,
  10693446260979691142ull, 2754332507255216759ull}},
{{662154939034874866ull, 4995466534868334477ull, 8755121807797226024ull,
  3442915634069020949ull}},
{{5439379692220981486ull, 6244333168585418096ull,
  15555588278173920434ull, 4303644542586276186ull}},
{{3399612307638113429ull, 8514394248793274214ull,
  14333928692286088175ull, 2689777839116422616ull}},
{{13472887421402417594ull, 6031306792564204863ull,
  17917410865357610219ull, 3362222298895528270ull}},
{{12229423258325634089ull, 2927447472277868175ull,
  13173391544842236966ull, 4202777873619410338ull}},
{{14560918564094603162ull, 15664712725455831321ull,
  12845055733953786007ull, 2626736171012131461ull}},
{{4366090149836090240ull, 14969204888392401248ull,
  2221261612160068797ull, 3283420213765164327ull}},
{{5457612687295112800ull, 4876448055208337848ull,
  16611635070482249709ull, 4104275267206455408ull}},
{{3411007929559445500ull, 5353623043718905107ull,
  10382271919051406068ull, 2565172042004034630ull}},
{{18098817967231470587ull, 6692028804648631383ull,
  3754467861959481777ull, 3206465052505043288ull}},
{{18011836440611950330ull, 12976722024238177133ull,
  4693084827449352221ull, 4008081315631304110ull}},
{{13563240784596162908ull, 10416294274362554660ull,
  16768236072438008850ull, 2505050822269565068ull}},
{{16954050980745203635ull, 3796995806098417517ull,
  2513551016837959447ull, 3131313527836956336ull}},
{{7357505670649340832ull, 134558739195633993ull, 3141938771047449309ull,
  3914141909796195420ull}},
{{16127656090224307780ull, 2389942221210965197ull,
  11187083768759431626ull, 2446338693622622137ull}},
{{6324512057498221013ull, 12210799813368482305ull,
  148796655667125820ull, 3057923367028277672ull}},
{{12517326090300164170ull, 15263499766710602881ull,
  185995819583907275ull, 3822404208785347090ull}},
{{905799778796520750ull, 7233844344980432849ull, 4727933405667329951ull,
  2389002630490841931ull}},
{{5743935741923038842ull, 4430619412798153157ull,
  1298230738656774535ull, 2986253288113552414ull}},
{{11791605695831186456ull, 926588247570303542ull,
  10846160460175743977ull, 3732816610141940517ull}},
{{2758067541467103631ull, 12108332700799909474ull,
  9084693296823533937ull, 2333010381338712823ull}},
{{12670956463688655347ull, 1300357820717723130ull,
  6744180602602029518ull, 2916262976673391029ull}},
{{6615323542756043376ull, 10848819312751929721ull,
  13041911771679924801ull, 3645328720841738786ull}},
{{12880840446872442124ull, 18172710159367300055ull,
  7079017677745130193ull, 4556660901052173483ull}},
{{14968054306936358183ull, 4440414821963480678ull,
  2118543039377012419ull, 2847913063157608427ull}},
{{9486695846815671921ull, 938832509026962944ull,
  16483236854503429236ull, 3559891328947010533ull}},
{{11858369808519589901ull, 1173540636283703680ull,
  6768988012847122833ull, 4449864161183763167ull}},
{{7411481130324743689ull, 12262677943745784560ull,
  11148146535670533626ull, 2781165100739851979ull}},
{{9264351412905929611ull, 6104975392827454892ull,
  9323497151160779129ull, 3476456375924814974ull}},
{{11580439266132412013ull, 12242905259461706519ull,
  2430999402096198103ull, 4345570469906018718ull}},
{{14155303568973839364ull, 14569344814804648430ull,
  15354432681592287526ull, 2715981543691261698ull}},
{{8470757424362523397ull, 8988308981651034730ull,
  9969668815135583600ull, 3394976929614077123ull}},
{{1365074743598378438ull, 11235386227063793413ull,
  7850400000492091596ull, 4243721162017596404ull}},
{{3159014723962680476ull, 16245488428769646691ull,
  14129872037162333055ull, 2652325726260997752ull}},
{{17783826460235514307ull, 15695174517534670459ull,
  17662340046452916319ull, 3315407157826247190ull}},
{{17618097056867004980ull, 15007282128490950170ull,
  12854553021211369591ull, 4144258947282808988ull}},
{{15622996678969266017ull, 16297080357947925712ull,
  17257467675111881802ull, 2590161842051755617ull}},
{{1082001775002030905ull, 11147978410580131333ull,
  7736776538607688541ull, 3237702302564694522ull}},
{{5964188237179926535ull, 99914957943000454ull, 447598636404834869ull,
  4047127878205868153ull}},
{{17562675703519617796ull, 2368289857928069235ull,
  11808964193821491553ull, 2529454923878667595ull}},
{{17341658610972134341ull, 7572048340837474448ull,
  10149519223849476537ull, 3161818654848334494ull}},
{{3230329190005616311ull, 14076746444474230965ull,
  3463526992957069863ull, 3952273318560418118ull}},
{{4324798752967204146ull, 15715495555437476209ull,
  15999762425880332376ull, 2470170824100261323ull}},
{{10017684459636393087ull, 1197625370587293645ull,
  15388017013923027567ull, 3087713530125326654ull}},
{{17133791592972879262ull, 15332089768516280768ull,
  10011649230549008650ull, 3859641912656658318ull}},
{{10708619745608049539ull, 14194242123750063384ull,
  1645594750665742502ull, 2412276195410411449ull}},
{{13385774682010061924ull, 8519430617832803422ull,
  6668679456759566032ull, 3015345244263014311ull}},
{{7508846315657801597ull, 10649288272291004278ull,
  3724163302522069636ull, 3769181555328767889ull}},
{{81342928858738094ull, 15879177207036653482ull,
  13856817110144763282ull, 2355738472080479930ull}},
{{9325050697928198425ull, 10625599471941041044ull,
  8097649350826178295ull, 2944673090100599913ull}},
{{11656313372410248032ull, 8670313321498913401ull,
  14733747706960110773ull, 3680841362625749891ull}},
{{735333660230646327ull, 15449577670301029656ull,
  13805498615272750562ull, 4601051703282187364ull}},
{{459583537644153955ull, 14267672062365531439ull,
  17851808671400244909ull, 2875657314551367102ull}},
{{14409537477337356155ull, 3999532022674750586ull,
  13091388802395530329ull, 3594571643189208878ull}},
{{8788549809816919386ull, 9611101046770826137ull,
  7140863966139637103ull, 4493214553986511098ull}},
{{17022058677204044377ull, 12924467181872848191ull,
  9074725997264661093ull, 2808259096241569436ull}},
{{16665887328077667567ull, 2320525922058896527ull,
  11343407496580826367ull, 3510323870301961795ull}},
{{16220673141669696554ull, 16735715457855784371ull,
  9567573352298645054ull, 4387904837877452244ull}},
{{7832077704329866394ull, 5848136142732477328ull,
  15203105382041428967ull, 2742440523673407652ull}},
{{9790097130412332993ull, 2698484159988208756ull, 557137653842234593ull,
  3428050654591759566ull}},
{{12237621413015416241ull, 7984791218412648849ull,
  9919794104157569049ull, 4285063318239699457ull}},
{{730984355493553295ull, 16519709557576375291ull,
  17729086361166950415ull, 2678164573899812160ull}},
{{14748788499649105330ull, 16037950928543081209ull,
  3714613877749136403ull, 3347705717374765201ull}},
{{4600927569279217951ull, 15435752642251463608ull,
  9254953365613808408ull, 4184632146718456501ull}},
{{2875579730799511220ull, 9647345401407164755ull,
  8090188862722324207ull, 2615395091699035313ull}},
{{17429532718781552736ull, 7447495733331568039ull,
  14724422096830293163ull, 3269243864623794141ull}},
{{17175229880049553016ull, 4697683648237072145ull,
  4570469565755702742ull, 4086554830779742677ull}},
{{3816989647389888779ull, 16771110335430333803ull,
  5162386487811008165ull, 2554096769237339173ull}},
{{159551040809973070ull, 7128829864005753542ull,
  11064669128191148111ull, 3192620961546673966ull}},
{{9422810837867242145ull, 4299351311579804023ull,
  4607464373384159331ull, 3990776201933342458ull}},
{{12806785801308108197ull, 381251560523683562ull,
  7491351251792487486ull, 2494235126208339036ull}},
{{6785110214780359438ull, 9699936487509380261ull,
  9364189064740609357ull, 3117793907760423795ull}},
{{13093073786902837202ull, 16736606627814113230ull,
  7093550312498373792ull, 3897242384700529744ull}},
{{3571485098386885347ull, 10460379142383820769ull,
  4433468945311483620ull, 2435776490437831090ull}},
{{9076042391410994588ull, 13075473927979775961ull,
  14765208218494130333ull, 3044720613047288862ull}},
{{15956739007691131139ull, 2509284354692556239ull,
  9233138236262887109ull, 3805900766309111078ull}},
{{16890490907448038818ull, 3874145730896541601ull,
  1159025379236916539ull, 2378687978943194424ull}},
{{7278055579027884810ull, 230996145193289098ull, 1448781724046145674ull,
  2973359973678993030ull}},
{{18320941510639631821ull, 9512117218346387180ull,
  11034349191912457900ull, 3716699967098741287ull}},
{{2227216407294994080ull, 15168445298321267796ull,
  13813997272586368043ull, 2322937479436713304ull}},
{{2784020509118742600ull, 14348870604474196841ull,
  17267496590732960054ull, 2903671849295891630ull}},
{{8091711654825816154ull, 8712716218737970243ull,
  12360998701561424260ull, 3629589811619864538ull}},
{{5502953550104882288ull, 10890895273422462804ull,
  6227876340097004517ull, 4536987264524830673ull}},
{{12662718005670327238ull, 9112652555102733204ull,
  15421637758629097583ull, 2835617040328019170ull}},
{{15828397507087909048ull, 6779129675451028601ull,
  10053675161431596171ull, 3544521300410023963ull}},
{{5950438828577722598ull, 3862226075886397848ull,
  7955407933362107310ull, 4430651625512529954ull}},
{{3719024267861076624ull, 16248949352711162367ull,
  9583815976778704972ull, 2769157265945331221ull}},
{{37094316398957876ull, 1864442617179401343ull, 16591455989400769120ull,
  3461446582431664026ull}},
{{13881425950780861056ull, 2330553271474251678ull,
  11515947949896185592ull, 4326808228039580033ull}},
{{4064205200810650256ull, 1456595794671407299ull, 279938441044034139ull,
  2704255142524737521ull}},
{{468570482585924916ull, 15655802798621422836ull,
  4961609069732430577ull, 3380318928155921901ull}},
{{585713103232406145ull, 5734695442994614833ull,
  10813697355592926126ull, 4225398660194902376ull}},
{{11895285735588723601ull, 17419242707153797982ull,
  6758560847245578828ull, 2640874162621813985ull}},
{{5645735132631128693ull, 3327309310232695862ull,
  13059887077484361440ull, 3301092703277267481ull}},
{{16280540952643686674ull, 4159136637790869827ull,
  2489800791573288088ull, 4126365879096584352ull}},
{{7869495086188610220ull, 2599460398619293642ull,
  1556125494733305055ull, 2578978674435365220ull}},
{{613496820880986966ull, 17084383553556280765ull,
  1945156868416631318ull, 3223723343044206525ull}},
{{5378557044528621612ull, 12132107405090575148ull,
  7043132103948177052ull, 4029654178805258156ull}},
{{12584970189685164316ull, 16805939165036385275ull,
  13625329601822386465ull, 2518533861753286347ull}},
{{11119526718679067490ull, 7172365901013317882ull,
  12419975983850595178ull, 3148167327191607934ull}},
{{4676036361494058555ull, 18188829413121423161ull,
  6301597942958468164ull, 3935209158989509918ull}},
{{14451737772002256357ull, 2144646346346113667ull,
  17773556769631206315ull, 2459505724368443698ull}},
{{13452986196575432542ull, 16515865988214805796ull,
  12993573925184232085ull, 3074382155460554623ull}},
{{16816232745719290677ull, 6809774429986343533ull,
  11630281388052902203ull, 3842977694325693279ull}},
{{12815988475288250626ull, 1950266009527770756ull,
  14186454895174145733ull, 2401861058953558299ull}},
{{16019985594110313282ull, 7049518530337101349ull,
  13121382600540294262ull, 3002326323691947874ull}},
{{6189923937355727890ull, 18035270199776152495ull,
  7178356213820592019ull, 3752907904614934843ull}},
{{10786231488488411788ull, 8966200865646401357ull,
  2180629624424176060ull, 2345567440384334277ull}},
{{18094475379037902638ull, 11207751082058001696ull,
  7337473048957607979ull, 2931959300480417846ull}},
{{4171350150087826682ull, 9398002834145114217ull,
  18395213348051785782ull, 3664949125600522307ull}},
{{9825873706037171256ull, 2524131505826616963ull,
  18382330666637344324ull, 4581186407000652884ull}},
{{3835328057059538083ull, 10800954227996411410ull,
  2265584629793564394ull, 2863241504375408053ull}},
{{14017532108179198412ull, 4277820748140738454ull,
  7443666805669343397ull, 3579051880469260066ull}},
{{8298543098369222207ull, 9958961953603310972ull, 81211470231903438ull,
  4473814850586575083ull}},
{{14409961473335539687ull, 1612665202574681453ull,
  16191658233390797313ull, 2796134281616609426ull}},
{{4177393786387260897ull, 6627517521645739721ull,
  11016200754883720833ull, 3495167852020761783ull}},
{{9833428251411464025ull, 12896082920484562555ull,
  9158564925177263137ull, 4368959815025952229ull}},
{{3840049647918471064ull, 1142522797661769741ull,
  8029946087449483413ull, 2730599884391220143ull}},
{{9411748078325476734ull, 6039839515504600080ull,
  5425746590884466362ull, 3413249855489025179ull}},
{{11764685097906845917ull, 16773171431235525908ull,
  2170497220178195048ull, 4266562319361281474ull}},
{{16576300223046554506ull, 10483232144522203692ull,
  5968246781038759809ull, 2666601449600800921ull}},
{{2273631205098641517ull, 17715726199080142520ull,
  12071994494725837665ull, 3333251812001001151ull}},
{{2842039006373301896ull, 8309599693568014438ull,
  10478307099979909178ull, 4166564765001251439ull}},
{{15611332434265477397ull, 9805185826907396927ull,
  13466470965128525092ull, 2604102978125782149ull}},
{{14902479524404458842ull, 12256482283634246159ull,
  2998030651128492653ull, 3255128722657227687ull}},
{{14016413387078185649ull, 1485544799260643987ull,
  17582596369192779529ull, 4068910903321534608ull}},
{{6454415357710172079ull, 12457680545606372252ull,
  10989122730745487205ull, 2543069314575959130ull}},
{{8068019197137715098ull, 1737042626725801603ull,
  4513031376577083199ull, 3178836643219948913ull}},
{{5473337977994755969ull, 16006361338689415716ull,
  10252975239148741902ull, 3973545804024936141ull}},
{{12644208273101498289ull, 5392289818253496918ull,
  8713952533681657641ull, 2483466127515585088ull}},
{{6581888304522097053ull, 11352048291244259052ull,
  10892440667102072051ull, 3104332659394481360ull}},
{{8227360380652621316ull, 9578374345627935911ull,
  13615550833877590064ull, 3880415824243101700ull}},
{{12059629265548970179ull, 5986483966017459944ull,
  17733091308028269598ull, 2425259890151938562ull}},
{{15074536581936212723ull, 16706476994376600738ull,
  12942992098180561189ull, 3031574862689923203ull}},
{{9619798690565490096ull, 7048038187688587211ull,
  11567054104298313583ull, 3789468578362404004ull}},
{{3706531172389737358ull, 11322552894946448863ull,
  16452780852041221797ull, 2368417861476502502ull}},
{{21477947059783793ull, 318133063400897367ull, 11342604028196751439ull,
  2960522326845628128ull}},
{{13861905489106893454ull, 14232724384533285420ull,
  14178255035245939298ull, 3700652908557035160ull}},
{{17887062967546584217ull, 13507138758760691291ull,
  8861409397028712061ull, 2312908067848146975ull}},
{{17747142691005842367ull, 3048865393168700402ull,
  6465075727858502173ull, 2891135084810183719ull}},
{{12960556326902527150ull, 8422767759888263407ull,
  3469658641395739812ull, 3613918856012729649ull}},
{{11589009390200771034ull, 10528459699860329259ull,
  8948759320172062669ull, 4517398570015912061ull}},
{{4937287859661787944ull, 8886130321626399739ull,
  7898817584321233120ull, 2823374106259945038ull}},
{{1559923806149847026ull, 11107662902032999674ull,
  650149943546765592ull, 3529217632824931298ull}},
{{11173276794542084591ull, 13884578627541249592ull,
  10036059466288232798ull, 4411522041031164122ull}},
{{6983297996588802869ull, 4066175623785893091ull,
  10884223184857533403ull, 2757201275644477576ull}},
{{4117436477308615683ull, 471033511304978460ull,
  13605278981071916754ull, 3446501594555596970ull}},
{{5146795596635769603ull, 9812163925985998883ull,
  7783226689485120134ull, 4308126993194496213ull}},
{{910904238683662050ull, 1520916435313861398ull, 7170359690141894036ull,
  2692579370746560133ull}},
{{10362002335209353370ull, 1901145544142326747ull,
  13574635631104755449ull, 3365724213433200166ull}},
{{8340816900584303809ull, 6988117948605296338ull,
  7744922502026168503ull, 4207155266791500208ull}},
{{9824696581292577785ull, 11285102745519392067ull,
  4840576563766355314ull, 2629472041744687630ull}},
{{7669184708188334327ull, 4883006395044464276ull,
  15274092741562719951ull, 3286840052180859537ull}},
{{9586480885235417908ull, 1492071975378192441ull,
  5257557871671236227ull, 4108550065226074422ull}},
{{17520765599340605953ull, 17073446049107227939ull,
  17121031725076686353ull, 2567843790766296513ull}},
{{17289270980748369537ull, 7506749506101871212ull,
  7566231601063694230ull, 3209804738457870642ull}},
{{3164844652225910305ull, 160064845772563208ull, 234417464474841980ull,
  4012255923072338303ull}},
{{1978027907641193941ull, 9323412565462627813ull,
  7064039942937858093ull, 2507659951920211439ull}},
{{7084220902978880330ull, 16265951725255672670ull,
  4218363910244934712ull, 3134574939900264299ull}},
{{18078648165578376220ull, 1885695582860039221ull,
  661268869378780487ull, 3918218674875330374ull}},
{{13604998112700179090ull, 8096088766928606369ull,
  14248351098643901516ull, 2448886671797081483ull}},
{{3171189585593060150ull, 10120110958660757962ull,
  13198752854877488991ull, 3061108339746351854ull}},
{{13187359018846100996ull, 8038452679898559548ull,
  7275069031742085431ull, 3826385424682939818ull}},
{{17465471423633588931ull, 11941561952577681573ull,
  9158604163266191298ull, 2391490890426837386ull}},
{{7996781224259822451ull, 5703580403867326159ull,
  2224883167227963315ull, 2989363613033546733ull}},
{{5384290511897390160ull, 2517789486406769795ull,
  7392789977462342048ull, 3736704516291933416ull}},
{{1059338560722174898ull, 1573618429004231122ull,
  4620493735913963780ull, 2335440322682458385ull}},
{{10547545237757494430ull, 1967023036255288902ull,
  10387303188319842629ull, 2919300403353072981ull}},
{{3961059510342092230ull, 7070464813746499032ull,
  17595815003827191190ull, 3649125504191341226ull}},
{{4951324387927615287ull, 18061453054037899598ull,
  12771396717929213179ull, 4561406880239176533ull}},
{{16929635797736923267ull, 8982565149559993296ull,
  10287965957919452189ull, 2850879300149485333ull}},
{{2715300673461602467ull, 15839892455377379525ull,
  17471643465826703140ull, 3563599125186856666ull}},
{{8005811860254390988ull, 1353121495512172790ull,
  12616182295428603118ull, 4454498906483570833ull}},
{{391946394231606464ull, 14680758989977271706ull, 967584907001795092ull,
  2784061816552231771ull}},
{{9713305029644283887ull, 18350948737471589632ull,
  15044539189034407577ull, 3480077270690289713ull}},
{{12141631287055354859ull, 9103627866557323328ull,
  4970615931010845760ull, 4350096588362862142ull}},
{{7588519554409596787ull, 5689767416598327080ull,
  16941693012163942312ull, 2718810367726788838ull}},
{{9485649443011995984ull, 7112209270747908850ull,
  11953744228350152082ull, 3398512959658486048ull}},
{{2633689766910219172ull, 18113633625289661871ull,
  14942180285437690102ull, 4248141199573107560ull}},
{{8563585131959968839ull, 6709334997378650765ull,
  9338862678398556314ull, 2655088249733192225ull}},
{{15316167433377348952ull, 17610040783578089264ull,
  16285264366425583296ull, 3318860312166490281ull}},
{{698465218012134574ull, 3565806905763059965ull, 6521522402749815409ull,
  4148575390208112852ull}},
{{2742383770471278061ull, 13757844362170382238ull,
  13299323538573410438ull, 2592859618880070532ull}},
{{12651351749943873384ull, 7973933415858201989ull,
  16624154423216763048ull, 3241074523600088165ull}},
{{1979131632147678018ull, 9967416769822752487ull,
  6945134973738790098ull, 4051343154500110207ull}},
{{8154486297733380617ull, 10841321499566608208ull,
  11258238386227825667ull, 2532089471562568879ull}},
{{10193107872166725772ull, 8939965856030872356ull,
  9461111964357394180ull, 3165111839453211099ull}},
{{12741384840208407214ull, 11174957320038590445ull,
  7214703937019354821ull, 3956389799316513874ull}},
{{10269208534343948461ull, 9290191334237812980ull,
  9120875979064484667ull, 2472743624572821171ull}},
{{12836510667929935576ull, 7001053149369878321ull,
  6789408955403217930ull, 3090929530716026464ull}},
{{2210580279630255758ull, 17974688473567123710ull,
  8486761194254022412ull, 3863661913395033080ull}},
{{15216670730051073561ull, 2010808259124676510ull,
  5304225746408764008ull, 2414788695871895675ull}},
{{9797466375709066143ull, 2513510323905845638ull,
  2018596164583567106ull, 3018485869839869594ull}},
{{3023460932781556871ull, 12365259941737082856ull,
  11746617242584234690ull, 3773107337299836992ull}},
{{1889663082988473044ull, 12339973482013064689ull,
  7341635776615146681ull, 2358192085812398120ull}},
{{6973764872162979209ull, 1589908797234167149ull,
  9177044720768933352ull, 2947740107265497650ull}},
{{13328892108631111916ull, 1987385996542708936ull,
  2247933864106390882ull, 3684675134081872063ull}},
{{16661115135788889895ull, 11707604532533161978ull,
  16644975385415152314ull, 4605843917602340078ull}},
{{15024882978295444088ull, 11928938851260614140ull,
  5791423597457082292ull, 2878652448501462549ull}},
{{334359649159753494ull, 14911173564075767676ull,
  11850965515248740769ull, 3598315560626828186ull}},
{{417949561449691868ull, 4803908899812545883ull, 5590334857206150154ull,
  4497894450783535233ull}},
{{16402119540401915081ull, 7614129080810229080ull,
  15023174331822313606ull, 2811184031739709520ull}},
{{2055905351792842236ull, 294289314158010543ull, 332223841068340392ull,
  3513980039674636901ull}},
{{16404939745023216507ull, 367861642697513178ull,
  5026965819762813394ull, 4392475049593296126ull}},
{{14864773359066898221ull, 4841599545113333640ull,
  16976911692633922083ull, 2745296905995810078ull}},
{{134222625124071160ull, 1440313412964279147ull,
  11997767578937626796ull, 3431621132494762598ull}},
{{14002836336687252662ull, 1800391766205348933ull,
  5773837436817257687ull, 4289526415618453248ull}},
{{11057615719643226866ull, 8042773881519424939ull,
  3608648398010786054ull, 2680954009761533280ull}},
{{9210333631126645678ull, 830095315044505366ull, 4510810497513482568ull,
  3351192512201916600ull}},
{{2289545002053531289ull, 1037619143805631708ull,
  5638513121891853210ull, 4188990640252395750ull}},
{{10654337663138232864ull, 5260197983305907721ull,
  17359128756464571968ull, 2618119150157747343ull}},
{{17929608097350178984ull, 6575247479132384651ull,
  17087224927153327056ull, 3272648937697184179ull}},
{{17800324103260335826ull, 8219059348915480814ull,
  16747345140514270916ull, 4090811172121480224ull}},
{{6513516546110321987ull, 14360284129926951317ull,
  10467090712821419322ull, 2556756982575925140ull}},
{{12753581701065290388ull, 8726983125553913338ull,
  13083863391026774153ull, 3195946228219906425ull}},
{{6718605089476837177ull, 15520414925369779577ull,
  2519771183501303979ull, 3994932785274883032ull}},
{{15728343226991492996ull, 7394416319142418283ull,
  1574856989688314987ull, 2496832990796801895ull}},
{{15048743015311978341ull, 4631334380500634950ull,
  15803629292392557446ull, 3121041238496002368ull}},
{{9587556732285197118ull, 15012540012480569496ull,
  1307792541781145191ull, 3901301548120002961ull}},
{{5992222957678248199ull, 16300366535441437791ull,
  12346585384681685504ull, 2438313467575001850ull}},
{{2878592678670422344ull, 1928714095592245623ull,
  6209859693997331073ull, 3047891834468752313ull}},
{{17433298903620191642ull, 7022578637917694932ull,
  12374010635924051745ull, 3809864793085940391ull}},
{{1672439777907843969ull, 15918326694767029093ull,
  14651285675093614196ull, 2381165495678712744ull}},
{{6702235740812192865ull, 1451164294749234750ull,
  18314107093867017746ull, 2976456869598390930ull}},
{{17601166712870016889ull, 11037327405291319245ull,
  13669261830478996374ull, 3720571086997988663ull}},
{{13306572204757454508ull, 2286643609879686624ull,
  15460817671690454590ull, 2325356929373742914ull}},
{{16633215255946818134ull, 12081676549204384088ull,
  10102650052758292429ull, 2906696161717178643ull}},
{{2344774996223971052ull, 1267037631223316399ull,
  8016626547520477633ull, 3633370202146473304ull}},
{{16766026800562127527ull, 6195483057456533402ull,
  10020783184400597041ull, 4541712752683091630ull}},
{{15090452768778717608ull, 15401391956978803136ull,
  1651303471822985246ull, 2838570470426932269ull}},
{{416321887263845394ull, 10028367909368728113ull,
  6675815358206119462ull, 3548213088033665336ull}},
{{5132088377507194647ull, 3312087849856134333ull,
  8344769197757649328ull, 4435266360042081670ull}},
{{5513398245155690606ull, 2070054906160083958ull, 603794730171142926ull,
  2772041475026301044ull}},
{{16115119843299389066ull, 11810940669554880755ull,
  754743412713928657ull, 3465051843782876305ull}},
{{15532213785696848428ull, 928617781661437232ull,
  5555115284319798726ull, 4331314804728595381ull}},
{{9707633616060530268ull, 14415444168820561982ull,
  5777790061913568155ull, 2707071752955372113ull}},
{{2911169983220887027ull, 13407619192598314574ull,
  11833923595819348098ull, 3383839691194215141ull}},
{{12862334515880884591ull, 7536151953893117409ull,
  957346439492021411ull, 4229799613992768927ull}},
{{1121430044784471014ull, 2404251961969504429ull,
  7515870552323595238ull, 2643624758745480579ull}},
{{6013473574407976671ull, 12228686989316656344ull,
  4783152171977106143ull, 3304530948431850724ull}},
{{7516841968009970839ull, 10674172718218432526ull,
  5978940214971382679ull, 4130663685539813405ull}},
{{86340211578843870ull, 13588886976527602185ull, 6042680643570808126ull,
  2581664803462383378ull}},
{{4719611282900942742ull, 7762736683804726923ull,
  16776722841318285966ull, 3227081004327979222ull}},
{{1287828085198790523ull, 480048817901132846ull,
  11747531514793081650ull, 4033851255409974028ull}},
{{14639950608531407789ull, 4911716529615595932ull,
  16565579233600451839ull, 2521157034631233767ull}},
{{18299938260664259736ull, 1527959643592107011ull,
  16095288023573176895ull, 3151446293289042209ull}},
{{18263236807402936766ull, 15745007609772297476ull,
  6284051974184307406ull, 3939307866611302762ull}},
{{2191150967772059671ull, 5228943737680298019ull,
  8539218502292580033ull, 2462067416632064226ull}},
{{16573996764997238301ull, 11147865690527760427ull,
  1450651091010949233ull, 3077584270790080283ull}},
{{16105809937819159972ull, 99774057877536822ull,
  15648371919045850254ull, 3846980338487600353ull}},
{{5454445192709587079ull, 13897416841455624226ull,
  2862703421762574552ull, 2404362711554750221ull}},
{{16041428527741759656ull, 17371771051819530282ull,
  8190065295630606094ull, 3005453389443437776ull}},
{{10828413622822423762ull, 12491341777919637045ull,
  10237581619538257618ull, 3756816736804297220ull}},
{{9073601523477708803ull, 12418774629627161057ull,
  15621860549066186819ull, 2348010460502685762ull}},
{{15953687922774523908ull, 10911782268606563417ull,
  10303953649477957716ull, 2935013075628357203ull}},
{{6107051848185991173ull, 13639727835758204272ull,
  8268256043420059241ull, 3668766344535446504ull}},
{{7633814810232488966ull, 3214601739415591628ull,
  10335320054275074052ull, 4585957930669308130ull}},
{{13994506293250081412ull, 11232498123989520575ull,
  11071261052349309186ull, 2866223706668317581ull}},
{{12881446848135213861ull, 4817250618132124911ull, 4018260154472771ull,
  3582779633335396977ull}},
{{11490122541741629422ull, 1409877254237768235ull,
  4616708843620478868ull, 4478474541669246221ull}},
{{4875483579374824437ull, 10104545320753380955ull,
  5191286036476493244ull, 2799046588543278888ull}},
{{1482668455791142642ull, 12630681650941726194ull,
  6489107545595616555ull, 3498808235679098610ull}},
{{11076707606593704110ull, 11176666045249769838ull,
  17334756468849296502ull, 4373510294598873262ull}},
{{2311256235693677165ull, 2373730259853718245ull,
  6222536774603422410ull, 2733443934124295789ull}},
{{7500756313044484360ull, 12190534861671923614ull,
  12389856986681665916ull, 3416804917655369736ull}},
{{152573354450829642ull, 15238168577089904518ull,
  15487321233352082395ull, 4271006147069212170ull}},
{{13930416401813932239ull, 7218012351467496371ull,
  14291261789272439401ull, 2669378841918257606ull}},
{{12801334483840027394ull, 13634201457761758368ull,
  8640705199735773443ull, 3336723552397822008ull}},
{{16001668104800034243ull, 12431065803774810056ull,
  10800881499669716804ull, 4170904440497277510ull}},
{{10001042565500021402ull, 16992788164214032093ull,
  2138864918866185098ull, 2606815275310798444ull}},
{{17112989225302414656ull, 12017613168412764308ull,
  2673581148582731373ull, 3258519094138498055ull}},
{{2944492457918466704ull, 1186958405233791674ull,
  17177034491010577929ull, 4073148867673122568ull}},
{{6451993804626429594ull, 12271064049339589556ull,
  10735646556881611205ull, 2545718042295701605ull}},
{{8064992255783036993ull, 1503772006392323233ull,
  18031244214529401911ull, 3182147552869627006ull}},
{{14692926338156184145ull, 15714773063272567753ull,
  13315683231306976580ull, 3977684441087033758ull}},
{{2265549933706533235ull, 598361127690579038ull, 3710616001139472459ull,
  2486052775679396099ull}},
{{12055309453987942351ull, 14583009464895387509ull,
  26583982996952669ull, 3107565969599245124ull}},
{{1234078762202764227ull, 4393703775837070675ull, 33229978746190837ull,
  3884457461999056405ull}},
{{16912200290872585306ull, 5051907869111863123ull,
  2326611745930063225ull, 2427785913749410253ull}},
{{16528564345163343728ull, 10926570854817216808ull,
  7519950700839966935ull, 3034732392186762816ull}},
{{2213961357744628044ull, 9046527550094133107ull,
  9399938376049958669ull, 3793415490233453520ull}},
{{17524626913086250192ull, 7959922728022527143ull,
  5874961485031224168ull, 2370884681395908450ull}},
{{17294097622930424836ull, 9949903410028158929ull,
  16567073893143806018ull, 2963605851744885562ull}},
{{7782563973380867332ull, 3214007225680422854ull,
  11485470329574981715ull, 3704507314681106953ull}},
{{252416464935654179ull, 18149655580546121948ull, 260889928343281715ull,
  2315317071675691846ull}},
{{315520581169567724ull, 18075383457255264531ull,
  9549484447283877952ull, 2894146339594614807ull}},
{{14229458781744123366ull, 4147485247859529047ull,
  7325169540677459537ull, 3617682924493268509ull}},
{{13175137458752766304ull, 9796042578251799213ull,
  13768147944274212325ull, 4522103655616585636ull}},
{{10540303920934172892ull, 8428369620621068460ull,
  17828464502026158511ull, 2826314784760366022ull}},
{{13175379901167716115ull, 5923776007348947671ull,
  13062208590677922331ull, 3532893480950457528ull}},
{{11857538858032257240ull, 2793033990758796685ull,
  16327760738347402914ull, 4416116851188071910ull}},
{{9716804795483854727ull, 6357332262651635832ull,
  5593164443039738917ull, 2760073031992544944ull}},
{{12146005994354818409ull, 12558351346741932694ull,
  6991455553799673646ull, 3450091289990681180ull}},
{{5959135456088747203ull, 6474567146572640060ull,
  8739319442249592058ull, 4312614112488351475ull}},
{{12947831696910242810ull, 8658290485035287941ull,
  3156231642192301084ull, 2695383820305219672ull}},
{{2349731565855639800ull, 10822863106294109927ull,
  3945289552740376355ull, 3369229775381524590ull}},
{{16772222512601713462ull, 8916892864440249504ull,
  14154983977780246252ull, 4211537219226905737ull}},
{{10482639070376070914ull, 14796430077129931748ull,
  1929335958471572051ull, 2632210762016816086ull}},
{{13103298837970088642ull, 13883851577985026781ull,
  11635041984944240872ull, 3290263452521020107ull}},
{{2544065492180447091ull, 17354814472481283477ull,
  9932116462752913186ull, 4112829315651275134ull}},
{{3895883941826473384ull, 15458445063728190077ull,
  1595886770793182837ull, 2570518322282046959ull}},
{{9481540945710479634ull, 5487998274378073884ull,
  15829916518773642259ull, 3213147902852558698ull}},
{{11851926182138099542ull, 2248311824545204451ull,
  10564023611612277016ull, 4016434878565698373ull}},
{{5101610854622618262ull, 1405194890340752782ull,
  8908357766471367087ull, 2510271799103561483ull}},
{{15600385605133048635ull, 15591551668208104689ull,
  6523761189661820954ull, 3137839748879451854ull}},
{{5665423951134147082ull, 10266067548405355054ull,
  17378073523932052001ull, 3922299686099314817ull}},
{{17375948024741005638ull, 17945507263821816668ull,
  3943766924816450644ull, 2451437303812071761ull}},
{{3273190957216705432ull, 3985140006067719220ull,
  9541394674447951210ull, 3064296629765089701ull}},
{{4091488696520881790ull, 14204797044439424833ull,
  16538429361487326916ull, 3830370787206362126ull}},
{{14086395481394020879ull, 18101370189629416328ull,
  5724832332502191418ull, 2393981742003976329ull}},
{{17607994351742526098ull, 13403340700181994602ull,
  11767726434055127177ull, 2992477177504970411ull}},
{{12786620902823381815ull, 2919117819945329541ull,
  10097972024141521068ull, 3740596471881213014ull}},
{{10297481073478307587ull, 11047820674320606771ull,
  1699546496661062763ull, 2337872794925758134ull}},
{{8260165323420496579ull, 9198089824473370560ull,
  11347805157681104262ull, 2922340993657197667ull}},
{{10325206654275620724ull, 2274240243736937392ull,
  9573070428673992424ull, 3652926242071497084ull}},
{{12906508317844525904ull, 2842800304671171740ull,
  11966338035842490530ull, 4566157802589371355ull}},
{{17289939735507604498ull, 6388436208846870241ull,
  5173118263187862629ull, 2853848626618357097ull}},
{{7777366614102341911ull, 12597231279485975706ull,
  11078083847412216190ull, 3567310783272946371ull}},
{{498336230773151581ull, 6523167062502693825ull, 9235918790837882334ull,
  4459138479091182964ull}},
{{11840675190301689498ull, 17912037469346347352ull,
  14995821281128452266ull, 2786961549431989352ull}},
{{14800843987877111872ull, 13166674799828158382ull,
  298032527701013717ull, 3483701936789986691ull}},
{{9277682947991614032ull, 2623285444503034266ull,
  14207598714908430859ull, 4354627420987483363ull}},
{{10410237860922146674ull, 17780454467310254080ull,
  6573906187604075334ull, 2721642138117177102ull}},
{{13012797326152683343ull, 13002196047283041792ull,
  17440754771359869976ull, 3402052672646471377ull}},
{{16265996657690854179ull, 16252745059103802240ull,
  7965885408917673758ull, 4252565840808089222ull}},
{{10166247911056783862ull, 5546279643512488496ull,
  366992362146158195ull, 2657853650505055764ull}},
{{12707809888820979827ull, 2321163535963222716ull,
  458740452682697744ull, 3322317063131319705ull}},
{{15884762361026224784ull, 2901454419954028395ull,
  5185111584280760084ull, 4152896328914149631ull}},
{{7622133466427696538ull, 11036781049326043555ull,
  10158223767816556908ull, 2595560205571343519ull}},
{{4915980814607232768ull, 13795976311657554444ull,
  8086093691343308231ull, 3244450256964179399ull}},
{{6144976018259040960ull, 12633284371144555151ull,
  5495931095751747385ull, 4055562821205224249ull}},
{{10758139039052982456ull, 978273704324265113ull,
  14964171980913311876ull, 2534726763253265155ull}},
{{18059359817243615974ull, 1222842130405331391ull,
  14093528957714251941ull, 3168408454066581444ull}},
{{17962513753127132064ull, 6140238681434052143ull,
  17616911197142814926ull, 3960510567583226805ull}},
{{18144100123345539396ull, 17672707231178446301ull,
  13316412507427953280ull, 2475319104739516753ull}},
{{8845067098899760533ull, 3644139965263506261ull,
  2810457579002777889ull, 3094148880924395942ull}},
{{15668019892052088570ull, 9166860975006770730ull,
  12736444010608248169ull, 3867686101155494927ull}},
{{14404198450959943261ull, 17258503155447701466ull,
  14877806534271236961ull, 2417303813222184329ull}},
{{8781876026845153268ull, 7738070889027463121ull,
  4762200112556882490ull, 3021629766527730412ull}},
{{15589031051983829488ull, 449216574429553093ull,
  5952750140696103113ull, 3777037208159663015ull}},
{{12048987416703587382ull, 11809975405086940443ull,
  10637997865576146301ull, 2360648255099789384ull}},
{{10449548252452096324ull, 927411201076511842ull,
  13297497331970182877ull, 2950810318874736730ull}},
{{3838563278710344597ull, 5770950019773027707ull,
  7398499628107952788ull, 3688512898593420913ull}},
{{186518079960542842ull, 7213687524716284634ull,
  13859810553562328889ull, 4610641123241776141ull}},
{{4728259818402727180ull, 16037769749016147656ull,
  10968224605190149507ull, 2881650702026110088ull}},
{{5910324773003408975ull, 15435526167842796666ull,
  13710280756487686884ull, 3602063377532637610ull}},
{{16611278003109037027ull, 847663636093944216ull,
  7914478908754832798ull, 4502579221915797013ull}},
{{10382048751943148142ull, 14364847827840878847ull,
  7252392327185464450ull, 2814112013697373133ull}},
{{8365874921501547273ull, 8732687747946322751ull,
  13677176427409218467ull, 3517640017121716416ull}},
{{5845657633449546188ull, 6304173666505515535ull,
  17096470534261523084ull, 4397050021402145520ull}},
{{10571065048547048223ull, 13163480578420723017ull,
  10685294083913451927ull, 2748156263376340950ull}},
{{17825517329111198183ull, 11842664704598515867ull,
  4133245568037039101ull, 3435195329220426188ull}},
{{17670210642961609825ull, 968272825465981122ull,
  5166556960046298877ull, 4293994161525532735ull}},
{{15655567670278394045ull, 2911013525129932153ull,
  10146627127670018654ull, 2683746350953457959ull}},
{{5734401532565828844ull, 12862138943267191000ull,
  8071597891160135413ull, 3354682938691822449ull}},
{{7168001915707286055ull, 2242615623801825038ull,
  14701183382377557171ull, 4193353673364778061ull}},
{{18315059252599217496ull, 17542535829371998312ull,
  11494082623199667183ull, 2620846045852986288ull}},
{{4447079992039470254ull, 17316483768287609987ull,
  14367603278999583979ull, 3276057557316232860ull}},
{{947163971621949914ull, 17033918691932124580ull,
  17959504098749479974ull, 4095071946645291075ull}},
{{9815349519118494504ull, 6034513164030189958ull,
  8918847052504731032ull, 2559419966653306922ull}},
{{3045814862043342322ull, 7543141455037737448ull,
  1925186778776137982ull, 3199274958316633653ull}},
{{3807268577554177903ull, 205554781942396002ull, 7018169491897560382ull,
  3999093697895792066ull}},
{{6991228879398749093ull, 13963529793996161213ull,
  8998041950863363142ull, 2499433561184870041ull}},
{{13350722117675824270ull, 8231040205640425708ull,
  15859238457006591832ull, 3124291951481087551ull}},
{{16688402647094780338ull, 10288800257050532135ull,
  15212362052830851886ull, 3905364939351359439ull}},
{{17347780682075319567ull, 1818814142229194680ull,
  16425255310660364285ull, 2440853087094599649ull}},
{{3237981778884597843ull, 6885203696213881255ull,
  6696511083043291644ull, 3051066358868249562ull}},
{{17882535278887911016ull, 8606504620267351568ull,
  17594010890658890363ull, 3813832948585311952ull}},
{{11176584549304944385ull, 3073222378453400778ull,
  10996256806661806477ull, 2383645592865819970ull}},
{{4747358649776404673ull, 8453213991494138877ull,
  4521948971472482288ull, 2979556991082274963ull}},
{{10545884330647893745ull, 10566517489367673596ull,
  1040750195913214956ull, 3724446238852843704ull}},
{{15814549743509709399ull, 15827445467709571805ull,
  650468872445759347ull, 2327778899283027315ull}},
{{5933129124104973037ull, 15172620816209576853ull,
  14648144145839362896ull, 2909723624103784143ull}},
{{12028097423558604200ull, 519031946552419450ull,
  13698494163871815717ull, 3637154530129730179ull}},
{{5811749742593479442ull, 5260475951617912217ull,
  12511431686412381742ull, 4546443162662162724ull}},
{{15161558635189394411ull, 17122855525043358847ull,
  17043016840862514396ull, 2841526976663851702ull}},
{{14340262275559355110ull, 2956825332594646943ull,
  12080399014223367188ull, 3551908720829814628ull}},
{{13313641826021805983ull, 3696031665743308679ull,
  15100498767779208985ull, 4439885901037268285ull}},
{{15238555168904710596ull, 13839234837158037684ull,
  11743654739075699567ull, 2774928688148292678ull}},
{{601449887421336628ull, 12687357528020159202ull,
  5456196386989848651ull, 3468660860185365848ull}},
{{9975184396131446593ull, 11247510891597811098ull,
  6820245483737310814ull, 4335826075231707310ull}},
{{10846176266009542025ull, 2418008288821244032ull,
  18097711482617982971ull, 2709891297019817068ull}},
{{13557720332511927531ull, 16857568416308718752ull,
  4175395279562927097ull, 3387364121274771336ull}},
{{16947150415639909414ull, 7236902465103734728ull,
  5219244099453658872ull, 4234205151593464170ull}},
{{10591969009774943384ull, 4523064040689834205ull,
  7873713580585924699ull, 2646378219745915106ull}},
{{17851647280646067134ull, 1042144032434904852ull,
  618769938877630066ull, 3307972774682393883ull}},
{{3867815027098032301ull, 10526052077398406874ull,
  14608520478879201294ull, 4134965968352992353ull}},
{{7029070410363658092ull, 1967096529946616392ull,
  2212796271658418953ull, 2584353730220620221ull}},
{{8786338012954572615ull, 7070556680860658394ull,
  7377681358000411595ull, 3230442162775775276ull}},
{{1759550479338439961ull, 4226509832648435089ull,
  9222101697500514494ull, 4038052703469719095ull}},
{{12628934095654994736ull, 16476626700687435642ull,
  12681342588578903414ull, 2523782939668574434ull}},
{{6562795582713967612ull, 11372411339004518745ull,
  6628306198868853460ull, 3154728674585718043ull}},
{{12815180496819847418ull, 14215514173755648431ull,
  3673696730158678921ull, 3943410843232147554ull}},
{{14927016838153486493ull, 1967167330956198413ull,
  6907746474776562230ull, 2464631777020092221ull}},
{{4823712992409694404ull, 11682331200550023825ull,
  13246369111898090691ull, 3080789721275115276ull}},
{{10641327258939505909ull, 9991227982260141877ull,
  16557961389872613364ull, 3850987151593894095ull}},
{{8956672546050885145ull, 15467889525767364481ull,
  17266254896311465208ull, 2406866969746183809ull}},
{{15807526700990994335ull, 888117833499653985ull,
  7747760565107167799ull, 3008583712182729762ull}},
{{5924350320956579207ull, 14945205347156731194ull,
  461328669529183940ull, 3760729640228412203ull}},
{{8314404969025249908ull, 117381305118181188ull,
  16429231482951597627ull, 2350456025142757626ull}},
{{10393006211281562385ull, 13981784686679890197ull,
  11313167316834721225ull, 2938070031428447033ull}},
{{17602943782529340886ull, 3642172803067699034ull,
  306401090761237820ull, 3672587539285558792ull}},
{{12780307691306900299ull, 4552716003834623793ull,
  383001363451547275ull, 4590734424106948490ull}},
{{1070163279425730831ull, 539604493182945919ull, 4851061870584604951ull,
  2869209015066842806ull}},
{{15172762154564327251ull, 14509563671760846110ull,
  15287199375085531996ull, 3586511268833553507ull}},
{{9742580656350633255ull, 18136954589701057638ull,
  14497313200429527091ull, 4483139086041941884ull}},
{{1477426891791757881ull, 9029753609349467072ull,
  18284192787123230240ull, 2801961928776213677ull}},
{{1846783614739697351ull, 11287192011686833840ull,
  9020182928621874088ull, 3502452410970267097ull}},
{{2308479518424621688ull, 14108990014608542300ull,
  15886914679204730514ull, 4378065513712833871ull}},
{{10666171735870164363ull, 13429804777557726841ull,
  16846850702144038427ull, 2736290946070521169ull}},
{{17944400688265093358ull, 12175569953519770647ull,
  7223505322397884322ull, 3420363682588151462ull}},
{{17818814841903978794ull, 5996090405044937501ull,
  18252753689852131211ull, 4275454603235189327ull}},
{{13442602285403680698ull, 1441713493939391986ull,
  18325500083798663863ull, 2672159127021993329ull}},
{{7579880819899825065ull, 15637199922706403695ull,
  9071817049466166116ull, 3340198908777491662ull}},
{{4863165006447393427ull, 1099755829673453003ull,
  2116399274977931838ull, 4175248635971864578ull}},
{{733635119815926940ull, 14522405448828071839ull,
  5934435565288595302ull, 2609530397482415361ull}},
{{14752101955052072387ull, 8929634774180313990ull,
  12029730475038132032ull, 3261912996853019201ull}},
{{9216755406960314675ull, 11162043467725392488ull,
  1202105038515501328ull, 4077391246066274002ull}},
{{5760472129350196672ull, 6976277167328370305ull,
  5363001667499576234ull, 2548369528791421251ull}},
{{11812276180115133744ull, 17943718496015238689ull,
  2092066065947082388ull, 3185461910989276564ull}},
{{930287169861753468ull, 3982904046309496746ull, 2615082582433852986ull,
  3981827388736595705ull}},
{{5193115499590983822ull, 7101001047370823370ull,
  13163641660089627876ull, 2488642117960372315ull}},
{{15714766411343505585ull, 8876251309213529212ull,
  11842866056684646941ull, 3110802647450465394ull}},
{{1196713940469830365ull, 15707000154944299420ull,
  5580210534001032868ull, 3888503309313081743ull}},
{{9971318249648419786ull, 593503059985411329ull,
  10405160611391727399ull, 2430314568320676089ull}},
{{17075833830487912637ull, 14576936880263927873ull,
  17618136782667047152ull, 3037893210400845111ull}},
{{7509734232827727084ull, 18221171100329909842ull,
  17410984959906421036ull, 3797366513001056389ull}},
{{9305269913944717332ull, 2164859900851417843ull,
  13187708609155207100ull, 2373354070625660243ull}},
{{7019901374003508760ull, 2706074876064272304ull,
  11872949743016620971ull, 2966692588282075304ull}},
{{8774876717504385950ull, 17217651650362504092ull,
  14841187178770776213ull, 3708365735352594130ull}},
{{14707669985295017027ull, 13066875290690259009ull,
  13887428005159123037ull, 2317728584595371331ull}},
{{4549529426336607572ull, 2498536058080660050ull,
  12747598988021515893ull, 2897160730744214164ull}},
{{14910283819775535273ull, 7734856091028212966ull,
  15934498735026894866ull, 3621450913430267705ull}},
{{9414482737864643283ull, 445198076930490400ull, 6083065363501454871ull,
  4526813641787834632ull}},
{{5884051711165402052ull, 7195777825722638356ull,
  3801915852188409294ull, 2829258526117396645ull}},
{{7355064638956752565ull, 18218094319008073753ull,
  9364080833662899521ull, 3536573157646745806ull}},
{{13805516817123328610ull, 8937559843477928479ull,
  2481729005223848594ull, 4420716447058432258ull}},
{{15545977038343162237ull, 10197660920601093203ull,
  6162766646692293275ull, 2762947779411520161ull}},
{{14820785279501564893ull, 8135390132323978600ull,
  12315144326792754498ull, 3453684724264400201ull}},
{{79237525667404500ull, 945865628550197443ull, 1558872353208779411ull,
  4317105905330500252ull}},
{{16190424518037985476ull, 16732067082339731065ull,
  10197667257610262939ull, 2698191190831562657ull}},
{{6402972592265318133ull, 16303397834497275928ull,
  17358770090440216578ull, 3372738988539453321ull}},
{{8003715740331647667ull, 11155875256266819102ull,
  7863404557768107011ull, 4215923735674316652ull}},
{{390636319279891888ull, 4666579025953067987ull,
  14137999885459842690ull, 2634952334796447907ull}},
{{14323353454382028572ull, 15056595819296110791ull,
  13060813838397415458ull, 3293690418495559884ull}},
{{13292505799550147810ull, 9597372737265362681ull,
  16326017297996769323ull, 4117113023119449855ull}},
{{1390287097077760526ull, 3692514951577157724ull,
  17121289838889062683ull, 2573195639449656159ull}},
{{1737858871347200657ull, 3957671044059251ull, 16789926280183940450ull,
  3216494549312070199ull}},
{{16007381644466164533ull, 9228319125659849871ull,
  16375721831802537658ull, 4020618186640087749ull}},
{{16922142555432434689ull, 10379385471964794073ull,
  12540669154090279988ull, 2512886366650054843ull}},
{{7317620139008379650ull, 12974231839955992592ull,
  11064150424185462081ull, 3141107958312568554ull}},
{{9147025173760474562ull, 2382731744662827028ull,
  4606815993377051794ull, 3926384947890710693ull}},
{{14940262770455072409ull, 6100893358841654796ull,
  5185103005074351323ull, 2453990592431694183ull}},
{{228584389359288896ull, 3014430680124680592ull, 1869692737915551250ull,
  3067488240539617729ull}},
{{285730486699111119ull, 12991410387010626548ull,
  6948801940821826966ull, 3834360300674522161ull}},
{{9401953591041720258ull, 3507945473454253688ull,
  15872216259082111614ull, 2396475187921576350ull}},
{{11752441988802150322ull, 13608303878672592918ull,
  10616898286997863709ull, 2995593984901970438ull}},
{{5467180449147912095ull, 3175321793058577436ull,
  4047750821892553829ull, 3744492481127463048ull}},
{{12640359817572220867ull, 4290419129875304849ull,
  2529844263682846143ull, 2340307800704664405ull}},
{{1965391716683112372ull, 751337893916743158ull, 7773991348030945583ull,
  2925384750880830506ull}},
{{11680111682708666273ull, 14774230422678092659ull,
  494117148183906170ull, 3656730938601038133ull}},
{{9988453584958444937ull, 9244415991492840016ull,
  5229332453657270617ull, 4570913673251297666ull}},
{{6242783490599028086ull, 17306975040751494770ull,
  7880018801963182039ull, 2856821045782061041ull}},
{{17026851400103560915ull, 17022032782511980558ull,
  14461709520881365453ull, 3571026307227576301ull}},
{{12060192213274675336ull, 7442482922857811986ull,
  4242078845819543105ull, 4463782884034470377ull}},
{{12149306151724059989ull, 16180766872854602251ull,
  14180514324705684200ull, 2789864302521543985ull}},
{{10574946671227687082ull, 1779214517358701198ull,
  3890584850599941539ull, 3487330378151929982ull}},
{{3995311302179833045ull, 16059076201980540210ull,
  14086603100104702731ull, 4359162972689912477ull}},
{{7108755582289783557ull, 7731079617024143679ull,
  11109969946779133159ull, 2724476857931195298ull}},
{{4274258459434841542ull, 5052163502852791695ull,
  4664090396619140641ull, 3405596072413994123ull}},
{{731137055866164024ull, 10926890396993377523ull,
  1218426977346537897ull, 4256995090517492654ull}},
{{16597861724412210179ull, 18358521544189330711ull,
  14596574916123749897ull, 2660621931573432908ull}},
{{16135641137087874820ull, 9113093874954499677ull,
  18245718645154687372ull, 3325777414466791135ull}},
{{6334493366077679812ull, 11391367343693124597ull,
  18195462288015971311ull, 4157221768083488919ull}},
{{6264901363012243835ull, 14037133617449284729ull,
  18289692957651063925ull, 2598263605052180574ull}},
{{12442812722192692697ull, 3711358966529442199ull,
  13638744160209054099ull, 3247829506315225718ull}},
{{10941829884313477968ull, 27512689734414845ull, 7825058163406541816ull,
  4059786882894032148ull}},
{{9144486686909617682ull, 17195431084009278ull, 14114033388983864443ull,
  2537366801808770092ull}},
{{2207236321782246294ull, 13856552344137175310ull,
  17642541736229830553ull, 3171708502260962615ull}},
{{11982417439082583676ull, 3485632374889305425ull,
  17441491151859900288ull, 3964635627826203269ull}},
{{571481871785532942ull, 2178520234305815891ull,
  13206774979126131632ull, 2477897267391377043ull}},
{{14549410395014079889ull, 2723150292882269863ull,
  11896782705480276636ull, 3097371584239221304ull}},
{{13575076975340211957ull, 3403937866102837329ull,
  14870978381850345795ull, 3871714480299026630ull}},
{{1566894081946550617ull, 18268362230810130995ull,
  4682675470229078217ull, 2419821550186891644ull}},
{{15793675657715351983ull, 9000394733230500031ull,
  5853344337786347772ull, 3024776937733614555ull}},
{{15130408553716802075ull, 11250493416538125039ull,
  2704994403805546811ull, 3780971172167018194ull}},
{{16374034373714083153ull, 4725715376122634197ull,
  6302307520805854661ull, 2363106982604386371ull}},
{{6632484911860440229ull, 10518830238580680651ull,
  3266198382579930422ull, 2953883728255482964ull}},
{{3678920121398162383ull, 3925165761371075006ull,
  4082747978224913028ull, 3692354660319353705ull}},
{{16134383131156015201ull, 11676600637711697686ull,
  14080932532459040402ull, 2307721662699596065ull}},
{{10944606877090243193ull, 5372378760284846300ull,
  3766107610291636791ull, 2884652078374495082ull}},
{{13680758596362803992ull, 2103787431928669971ull,
  13931006549719321797ull, 3605815097968118852ull}},
{{12489262227026117086ull, 7241420308338225368ull,
  17413758187149152246ull, 4507268872460148565ull}},
{{7805788891891323179ull, 18360945747993554567ull,
  13189441876181914105ull, 2817043045287592853ull}},
{{5145550096436766069ull, 9116124129709779497ull,
  2651744289945228920ull, 3521303806609491067ull}},
{{11043623638973345490ull, 11395155162137224371ull,
  17149738417713699862ull, 4401629758261863833ull}},
{{4596421765144646980ull, 2510285957908377328ull,
  3801057483429980558ull, 2751018598913664896ull}},
{{5745527206430808724ull, 12361229484240247468ull,
  4751321854287475697ull, 3438773248642081120ull}},
{{7181909008038510905ull, 1616478800018145623ull,
  5939152317859344622ull, 4298466560802601400ull}},
{{11406222157665151172ull, 14845357305293504726ull,
  3711970198662090388ull, 2686541600501625875ull}},
{{5034405660226663157ull, 109952557907329292ull, 28276729900225082ull,
  3358177000627032344ull}},
{{6293007075283328946ull, 9360812734238937423ull, 35345912375281352ull,
  4197721250783790430ull}},
{{10850658449693162448ull, 5850507958899335889ull,
  13857149250516714557ull, 2623575781739869018ull}},
{{18175009080543840963ull, 11924820967051557765ull,
  8098064526291117388ull, 3279469727174836273ull}},
{{8883703295397637492ull, 14906026208814447207ull,
  14734266676291284639ull, 4099337158968545341ull}},
{{12469843587264605289ull, 16233795408150111360ull,
  11514759681895746851ull, 2562085724355340838ull}},
{{15587304484080756611ull, 15680558241760251296ull,
  5170077565514907756ull, 3202607155444176048ull}},
{{1037386531391394147ull, 1153953728490762505ull,
  6462596956893634696ull, 4003258944305220060ull}},
{{12177581628188091102ull, 721221080306726565ull,
  13262495134913297493ull, 2502036840190762537ull}},
{{1386918979952950166ull, 5513212368810796111ull,
  2743060863359458154ull, 3127546050238453172ull}},
{{15568706780223351419ull, 16114887497868270946ull,
  3428826079199322692ull, 3909432562798066465ull}},
{{14342127756066982541ull, 848432649312893533ull,
  13672231345568046443ull, 2443395351748791540ull}},
{{4092601639801564464ull, 14895598866923280629ull,
  17090289181960058053ull, 3054244189685989425ull}},
{{9727438068179343484ull, 4784440528371937074ull,
  7527803422167908855ull, 3817805237107486782ull}},
{{10691334811039477582ull, 9907804357873542527ull, 93191120427555130ull,
  2386128273192179239ull}},
{{8752482495371959073ull, 3161383410487152351ull,
  13951546955816607625ull, 2982660341490224048ull}},
{{6328917100787560937ull, 8563415281536328343ull,
  17439433694770759531ull, 3728325426862780060ull}},
{{10873102215633307442ull, 3046291541746511262ull,
  1676274022376948899ull, 2330203391789237538ull}},
{{4368005732686858494ull, 17642922482465302790ull,
  11318714564825961931ull, 2912754239736546922ull}},
{{14683379202713348926ull, 17441967084654240583ull,
  4925021169177676606ull, 3640942799670683653ull}},
{{13742537984964298253ull, 12579086818963024921ull,
  10767962479899483662ull, 4551178499588354566ull}},
{{1671557212961604552ull, 3250243243424502672ull,
  2118290531509789385ull, 2844486562242721604ull}},
{{2089446516202005690ull, 8674490072708016244ull,
  2647863164387236731ull, 3555608202803402005ull}},
{{2611808145252507113ull, 6231426572457632401ull,
  7921514973911433818ull, 4444510253504252506ull}},
{{13161595136851286706ull, 8506327626213408154ull,
  9562632877122034040ull, 2777818908440157816ull}},
{{7228621884209332574ull, 10632909532766760193ull,
  11953291096402542550ull, 3472273635550197270ull}},
{{13647463373689053621ull, 4067764879103674433ull,
  5718241833648402380ull, 4340342044437746588ull}},
{{1612135580914576657ull, 11765725086294572329ull,
  12797273182885027295ull, 2712713777773591617ull}},
{{6626855494570608726ull, 10095470339440827507ull,
  2161533423324120407ull, 3390892222216989522ull}},
{{3671883349785873003ull, 8007651905873646480ull,
  11925288816009926317ull, 4238615277771236902ull}},
{{2294927093616170627ull, 7310625450384723002ull,
  2841619491578816044ull, 2649134548607023064ull}},
{{12092030903874989092ull, 9138281812980903752ull,
  3552024364473520055ull, 3311418185758778830ull}},
{{15115038629843736365ull, 6811166247798741786ull,
  13663402492446675877ull, 4139272732198473537ull}},
{{14058585162079723132ull, 6562821914087907568ull,
  1622097530138090567ull, 2587045457624045961ull}},
{{17573231452599653915ull, 3591841374182496556ull,
  6639307931100001113ull, 3233806822030057451ull}},
{{3519795242040015778ull, 9101487736155508600ull,
  3687448895447613487ull, 4042258527537571814ull}},
{{2199872026275009861ull, 12605958862738274731ull,
  16139713614936922141ull, 2526411579710982383ull}},
{{16584898088125926038ull, 1922390523140679701ull,
  15562956000243764773ull, 3158014474638727979ull}},
{{6896064554875243836ull, 7014674172353237531ull,
  14842008981877318062ull, 3947518093298409974ull}},
{{2004197337583333446ull, 18219229413002937169ull,
  4664569595245935884ull, 2467198808311506234ull}},
{{7116932690406554711ull, 4327292692544119845ull,
  15054084030912195664ull, 3083998510389382792ull}},
{{13507851881435581292ull, 5409115865680149806ull,
  370860964930692964ull, 3854998137986728491ull}},
{{3830721407469850404ull, 12604069452904869437ull,
  16372689167577540766ull, 2409373836241705306ull}},
{{9400087777764700909ull, 6531714779276310988ull,
  11242489422617150150ull, 3011717295302131633ull}},
{{11750109722205876136ull, 17388015510950164543ull,
  218053722989273975ull, 3764646619127664542ull}},
{{14261347604019754441ull, 17785038721984934695ull,
  13971341632150459946ull, 2352904136954790338ull}},
{{13214998486597305147ull, 13007926365626392561ull,
  8240805003333299125ull, 2941130171193487923ull}},
{{2683690052964467722ull, 2424849901750826990ull,
  5689320235739236003ull, 3676412713991859904ull}},
{{12577984603060360460ull, 16866120432470697449ull,
  7111650294674045003ull, 4595515892489824880ull}},
{{943711349271643432ull, 8235482261080491954ull, 4444781434171278127ull,
  2872197432806140550ull}},
{{10403011223444330098ull, 5682666807923227038ull,
  14779348829568873467ull, 3590246791007675687ull}},
{{3780391992450636814ull, 2491647491476645894ull,
  13862500018533703930ull, 4487808488759594609ull}},
{{16197803050563811721ull, 6168965700600291587ull,
  1746533483942483100ull, 2804880305474746631ull}},
{{15635567794777376747ull, 7711207125750364484ull,
  16018224910210267587ull, 3506100381843433288ull}},
{{1097715669762169318ull, 5027322888760567702ull,
  1576037064053282868ull, 4382625477304291611ull}},
{{14521130348883519536ull, 12365448842330130621ull,
  17125924229529159456ull, 2739140923315182256ull}},
{{4316354880822235708ull, 15456811052912663277ull,
  2960661213201897704ull, 3423926154143977821ull}},
{{10007129619455182538ull, 874269742431277480ull,
  8312512534929760035ull, 4279907692679972276ull}},
{{6254456012159489087ull, 16687319653515406089ull,
  14418692371185875829ull, 2674942307924982672ull}},
{{12429756033626749262ull, 7024091511612093899ull,
  18023365463982344787ull, 3343677884906228340ull}},
{{10925509023606048674ull, 4168428371087729470ull,
  4082462756268379368ull, 4179597356132785426ull}},
{{2216757121326392517ull, 2605267731929830919ull,
  7163225241095125009ull, 2612248347582990891ull}},
{{16606004456940154358ull, 7868270683339676552ull,
  4342345532941518357ull, 3265310434478738614ull}},
{{2310761497465641332ull, 14447024372601983595ull,
  14651303953031673754ull, 4081638043098423267ull}},
{{17585127000411883497ull, 13641076251303627650ull,
  6851221961431102144ull, 2551023776936514542ull}},
{{12758036713660078563ull, 17051345314129534563ull,
  17787399488643653488ull, 3188779721170643177ull}},
{{11335859873647710299ull, 2867437568952366588ull,
  8399191305522403149ull, 3985974651463303972ull}},
{{16308284457884594745ull, 4097991489808923069ull,
  14472866602806277776ull, 2491234157164564982ull}},
{{6550297517073579719ull, 5122489362261153837ull,
  8867711216653071412ull, 3114042696455706228ull}},
{{12799557914769362553ull, 6403111702826442296ull,
  11084639020816339265ull, 3892553370569632785ull}},
{{7999723696730851596ull, 15531159860334996195ull, 10370360369130184ull,
  2432845856606020491ull}},
{{5387968602486176591ull, 967205751709193628ull,
  13848021005743576443ull, 3041057320757525613ull}},
{{6734960753107720738ull, 15044065244918655747ull,
  3474968201897306841ull, 3801321650946907017ull}},
{{1903507461478631510ull, 2485011750433077986ull,
  13701070172254286536ull, 2375826031841816885ull}},
{{11602756363703065195ull, 3106264688041347482ull,
  3291279660035694458ull, 2969782539802271107ull}},
{{5280073417774055685ull, 13106202896906460161ull,
  17949157630326781784ull, 3712228174752838883ull}},
{{14829260932177254564ull, 8191376810566537600ull,
  8912380509740544663ull, 2320142609220524302ull}},
{{89832091512016588ull, 5627534994780784097ull, 1917103600320905021ull,
  2900178261525655378ull}},
{{4723976132817408639ull, 11646104761903368025ull,
  11619751537255907084ull, 3625222826907069222ull}},
{{10516656184449148703ull, 14557630952379210031ull,
  5301317384715108047ull, 4531528533633836528ull}},
{{13490439142921799796ull, 16016048372878088125ull,
  3313323365446942529ull, 2832205333521147830ull}},
{{3027990873370086032ull, 6185002410815446445ull,
  13365026243663453970ull, 3540256666901434787ull}},
{{8396674610139995444ull, 16954625050374083864ull,
  12094596786151929558ull, 4425320833626793484ull}},
{{5247921631337497153ull, 5984954638056414511ull,
  16782495028199731782ull, 2765825521016745927ull}},
{{1948216020744483537ull, 16704565334425293947ull,
  16366432766822276823ull, 3457281901270932409ull}},
{{16270328081212768133ull, 16269020649604229529ull,
  6622982903245682317ull, 4321602376588665512ull}},
{{3251426023116898227ull, 12473980915216337408ull,
  4139364314528551448ull, 2701001485367915945ull}},
{{4064282528896122784ull, 15592476144020421760ull,
  9785891411588077214ull, 3376251856709894931ull}},
{{5080353161120153480ull, 10267223143170751392ull,
  7620678246057708614ull, 4220314820887368664ull}},
{{3175220725700095925ull, 1805328446054331716ull,
  4762923903786067884ull, 2637696763054605415ull}},
{{3969025907125119906ull, 2256660557567914645ull,
  1341968861305196951ull, 3297120953818256769ull}},
{{9572968402333787787ull, 16655883752242057018ull,
  6289147095058884092ull, 4121401192272820961ull}},
{{10594791269886005271ull, 1186555308296509828ull,
  15459931980480272318ull, 2575875745170513100ull}},
{{13243489087357506588ull, 10706566172225413093ull,
  878170901890788781ull, 3219844681463141376ull}},
{{2719303303914719523ull, 17994893733709154271ull,
  1097713627363485976ull, 4024805851828926720ull}},
{{8617093592587781558ull, 11246808583568221419ull,
  686071017102178735ull, 2515503657393079200ull}},
{{6159680972307339044ull, 9446824711032888870ull, 857588771377723419ull,
  3144379571741349000ull}},
{{16922973252238949613ull, 7196844870363723183ull,
  1071985964222154274ull, 3930474464676686250ull}},
{{17494387310290425364ull, 9109714062404714893ull,
  5281677246066234325ull, 2456546540422928906ull}},
{{8032926082580867993ull, 15998828596433281521ull,
  15825468594437568714ull, 3070683175528661132ull}},
{{14652843621653472895ull, 10775163708686826093ull,
  1335091669337409277ull, 3838353969410826416ull}},
{{11463870272747114512ull, 9040320327142960260ull,
  834432293335880798ull, 2398971230881766510ull}},
{{14329837840933893139ull, 2077028372073924517ull,
  10266412403524626806ull, 2998714038602208137ull}},
{{4077239245885202712ull, 11819657501947181455ull,
  17444701522833171411ull, 3748392548252760171ull}},
{{9465803556319333551ull, 5081442929503294457ull,
  8597095442557038180ull, 2342745342657975107ull}},
{{16443940463826554843ull, 6351803661879118071ull,
  6134683284768909821ull, 2928431678322468884ull}},
{{15943239561355805650ull, 12551440595776285493ull,
  7668354105961137276ull, 3660539597903086105ull}},
{{6093991396412593350ull, 15689300744720356867ull,
  14197128650878809499ull, 4575674497378857631ull}},
{{1502901613544176892ull, 7499969956236529090ull,
  15790734434440337793ull, 2859796560861786019ull}},
{{11101999053784996923ull, 13986648463723049266ull,
  15126732024623034337ull, 3574745701077232524ull}},
{{4654126780376470345ull, 3648252524371647871ull, 461670957069241306ull,
  4468432126346540656ull}},
{{9826358265376375822ull, 6891843846159667823ull, 288544348168275816ull,
  2792770078966587910ull}},
{{7671261813293081873ull, 8614804807699584779ull,
  9584052472065120578ull, 3490962598708234887ull}},
{{4977391248188964438ull, 1545133972769705166ull,
  7368379571654012819ull, 4363703248385293609ull}},
{{16945927585400266486ull, 17106609797476923392ull,
  16134452278352227771ull, 2727314530240808505ull}},
{{2735665408040781491ull, 16771576228418766337ull,
  6333007292658121002ull, 3409143162801010632ull}},
{{8031267778478364768ull, 11741098248668682113ull,
  7916259115822651253ull, 4261428953501263290ull}},
{{16548757407617447740ull, 9644029414631620272ull,
  9559347965816544937ull, 2663393095938289556ull}},
{{2239202685812258059ull, 16666722786716913245ull,
  11949184957270681171ull, 3329241369922861945ull}},
{{7410689375692710477ull, 16221717464968753652ull,
  1101423141306187752ull, 4161551712403577432ull}},
{{13855052896662719857ull, 10138573415605471032ull,
  688389463316367345ull, 2600969820252235895ull}},
{{17318816120828399821ull, 17284902787934226694ull,
  14695544884427622893ull, 3251212275315294868ull}},
{{12425148114180723968ull, 7771070429635619656ull,
  18369431105534528617ull, 4064015344144118585ull}},
{{7765717571362952480ull, 16386134064590732045ull,
  4563365413317998529ull, 2540009590090074116ull}},
{{14318832982631078504ull, 6647609525456251344ull,
  5704206766647498162ull, 3175011987612592645ull}},
{{17898541228288848130ull, 17532883943675089988ull,
  11741944476736760606ull, 3968764984515740806ull}},
{{1963216230825754273ull, 6346366446369543339ull,
  2727029279533087475ull, 2480478115322338004ull}},
{{16289078343814356553ull, 3321272039534541269ull,
  3408786599416359344ull, 3100597644152922505ull}},
{{6526289874485781980ull, 4151590049418176587ull,
  8872669267697837084ull, 3875747055191153131ull}},
{{1773088162339919785ull, 11818115817741136175ull,
  3239575283097454225ull, 2422341909494470707ull}},
{{16051418258207063444ull, 937586716894256506ull,
  17884527159153981494ull, 3027927386868088383ull}},
{{10840900785904053496ull, 10395355432972596441ull,
  17743972930515088963ull, 3784909233585110479ull}},
{{18304778037258503195ull, 4191254136394178823ull,
  18007512109213012458ull, 2365568270990694049ull}},
{{18269286528145741090ull, 14462439707347499337ull,
  8674332081234101860ull, 2956960338738367562ull}},
{{9001550104900012651ull, 18078049634184374172ull,
  1619543064687851517ull, 3696200423422959453ull}},
{{14849340852417283715ull, 13604624030578927809ull,
  3318057424643601150ull, 2310125264639349658ull}},
{{4726618010239440931ull, 7782408001368883954ull,
  13370943817659277246ull, 2887656580799187072ull}},
{{15131644549654076972ull, 504637964856329134ull,
  16713679772074096558ull, 3609570725998983840ull}},
{{9691183650212820407ull, 9854169492925187226ull,
  2445355641383069081ull, 4511963407498729801ull}},
{{10668675799810400659ull, 17688070979146711776ull,
  13057562321932887935ull, 2819977129686706125ull}},
{{13335844749763000823ull, 17498402705506001816ull,
  2486894847133946207ull, 3524971412108382657ull}},
{{16669805937203751029ull, 17261317363455114366ull,
  7720304577344820663ull, 4406214265135478321ull}},
{{5806942692324956489ull, 17705852379800528335ull,
  16354405406908982674ull, 2753883915709673950ull}},
{{2646992346978807707ull, 12908943437895884611ull,
  11219634721781452535ull, 3442354894637092438ull}},
{{17143798489005673346ull, 11524493278942467859ull,
  4801171365372039861ull, 4302943618296365548ull}},
{{8409031046414851889ull, 9508651308552736364ull,
  12224104140212300721ull, 2689339761435228467ull}},
{{10511288808018564862ull, 16497500154118308359ull,
  10668444156837987997ull, 3361674701794035584ull}},
{{8527424991595818173ull, 6786817137365721737ull,
  13335555196047484997ull, 4202093377242544480ull}},
{{16858855665815856118ull, 6547603720067270037ull,
  8334721997529678123ull, 2626308360776590300ull}},
{{7238511526987656436ull, 3572818631656699643ull,
  10418402496912097654ull, 3282885450970737875ull}},
{{4436453390307182641ull, 13689395326425650362ull,
  8411317102712734163ull, 4103606813713422344ull}},
{{7384469387369377055ull, 6250029069802337524ull,
  5257073189195458852ull, 2564754258570888965ull}},
{{9230586734211721318ull, 7812536337252921905ull,
  11183027504921711469ull, 3205942823213611206ull}},
{{16149919436192039551ull, 14377356439993540285ull,
  4755412344297363528ull, 4007428529017014008ull}},
{{12399542656833718672ull, 8985847774995962678ull,
  2972132715185852205ull, 2504642830635633755ull}},
{{6276056284187372532ull, 15843995737172341252ull,
  17550223949264478968ull, 3130803538294542193ull}},
{{7845070355234215664ull, 1358250597755874949ull,
  8102721881298434999ull, 3913504422868177742ull}},
{{7209011981235078742ull, 7766435651238503699ull, 452515157384133970ull,
  2445940264292611089ull}},
{{4399578958116460524ull, 484672527193353816ull, 5177329965157555367ull,
  3057425330365763861ull}},
{{5499473697645575655ull, 14440898714273855982ull,
  11083348474874332112ull, 3821781662957204826ull}},
{{17272229116310648496ull, 9025561696421159988ull,
  11538778815223845474ull, 2388613539348253016ull}},
{{3143542321678759004ull, 2058580083671674178ull,
  14423473519029806843ull, 2985766924185316270ull}},
{{13152799938953224563ull, 16408283159871756434ull,
  8805969861932482745ull, 3732208655231645338ull}},
{{12832185980273153256ull, 3337647947278765915ull,
  10115417182135189620ull, 2332630409519778336ull}},
{{11428546456914053666ull, 4172059934098457394ull,
  12644271477668987025ull, 2915788011899722920ull}},
{{5062311034287791275ull, 9826760936050459647ull,
  15805339347086233781ull, 3644735014874653650ull}},
{{1716202774432351189ull, 16895137188490462463ull,
  10533302147003016418ull, 4555918768593317063ull}},
{{7990155761661301349ull, 15171146761233926943ull,
  13500842869517967117ull, 2847449230370823164ull}},
{{5376008683649238783ull, 5128875396260244967ull,
  16876053586897458897ull, 3559311537963528955ull}},
{{2108324836134160574ull, 11022780263752694113ull,
  16483380965194435717ull, 4449139422454411194ull}},
{{12846918068652320119ull, 9195080674059127772ull,
  14913799121673910227ull, 2780712139034006996ull}},
{{16058647585815400149ull, 6882164824146521811ull,
  195504828382836168ull, 3475890173792508746ull}},
{{15461623463841862282ull, 8602706030183152264ull,
  9467753072333321018ull, 4344862717240635932ull}},
{{9663514664901163926ull, 9988377287291858069ull,
  15140717707063101444ull, 2715539198275397457ull}},
{{16691079349553842812ull, 12485471609114822586ull,
  5090839078546713093ull, 3394423997844246822ull}},
{{11640477150087527707ull, 1771781456111364521ull,
  15586920885038167175ull, 4243029997305308527ull}},
{{357769191163622961ull, 8024892437710684682ull,
  16659354580789936340ull, 2651893748315817829ull}},
{{9670583525809304509ull, 10031115547138355852ull,
  6989135170705256713ull, 3314867185394772287ull}},
{{12088229407261630636ull, 17150580452350332719ull,
  4124732944954182987ull, 4143583981743465359ull}},
{{14472672407179601004ull, 8413269773505263997ull,
  9495487118237446223ull, 2589739988589665849ull}},
{{4255782453692337542ull, 5904901198454192093ull,
  16481044916224195683ull, 3237174985737082311ull}},
{{9931414085542809832ull, 2769440479640352212ull,
  15989620126852856700ull, 4046468732171352889ull}},
{{15430505840319031953ull, 10954272336629995940ull,
  3075983551641953581ull, 2529042957607095556ull}},
{{841388226689238325ull, 18304526439214882830ull,
  3844979439552441976ull, 3161303697008869445ull}},
{{10275107320216323715ull, 4433913975309051921ull,
  9417910317867940375ull, 3951629621261086806ull}},
{{17951157121203672082ull, 9688725262209239306ull,
  1274507930240074830ull, 2469768513288179254ull}},
{{13215574364649814294ull, 2887534540906773325ull,
  10816506949654869346ull, 3087210641610224067ull}},
{{2684409900530104156ull, 12832790212988242465ull,
  8908947668641198778ull, 3859013302012780084ull}},
{{13206971233899784857ull, 12632179901545039444ull,
  14791464329755525044ull, 2411883313757987552ull}},
{{16508714042374731072ull, 15790224876931299305ull,
  42586338484854689ull, 3014854142197484441ull}},
{{6800834497686250127ull, 5902723040881960420ull,
  4664918941533456266ull, 3768567677746855551ull}},
{{13473893597908682138ull, 8300887918978613166ull,
  9833103366099492022ull, 2355354798591784719ull}},
{{7618994960531076864ull, 1152737861868490650ull,
  7679693189196977124ull, 2944193498239730899ull}},
{{300371663809070272ull, 1440922327335613313ull, 4987930468068833501ull,
  3680241872799663624ull}},
{{4987150598188725744ull, 6412838927596904545ull,
  6234913085086041876ull, 4600302340999579530ull}},
{{14646184169936423350ull, 13231396366602841148ull,
  8508506696606164076ull, 2875188963124737206ull}},
{{18307730212420529188ull, 16539245458253551435ull,
  1412261333902929287ull, 3593986203905921508ull}},
{{18272976747098273580ull, 16062370804389551390ull,
  1765326667378661609ull, 4492482754882401885ull}},
{{6808924448509033084ull, 3121452725102387763ull,
  3409172176325357458ull, 2807801721801501178ull}},
{{3899469542208903451ull, 13125187943232760512ull,
  13484837257261472630ull, 3509752152251876472ull}},
{{4874336927761129313ull, 7183112892186174832ull,
  16856046571576840788ull, 4387190190314845590ull}},
{{3046460579850705821ull, 13712817594471135078ull,
  5923343088808137588ull, 2741993868946778494ull}},
{{13031447761668158084ull, 17141021993088918847ull,
  16627550897864947793ull, 3427492336183473117ull}},
{{11677623683657809701ull, 7591219436078984847ull,
  6949380567049021030ull, 4284365420229341397ull}},
{{14216043829927212919ull, 132826129121977625ull,
  6649205863619332096ull, 2677728387643338373ull}},
{{3934996732126852437ull, 166032661402472032ull,
  12923193347951553024ull, 3347160484554172966ull}},
{{4918745915158565546ull, 207540826753090040ull, 6930619648084665472ull,
  4183950605692716208ull}},
{{3074216196974103467ull, 129713016720681275ull, 4331637280052915920ull,
  2614969128557947630ull}},
{{17677828301499793045ull, 162141270900851593ull,
  14637918636920920708ull, 3268711410697434537ull}},
{{8262227321592577594ull, 202676588626064492ull, 4462340240868987173ull,
  4085889263371793172ull}},
{{14387264112850136805ull, 2432515877104984259ull,
  12012334687397892791ull, 2553680789607370732ull}},
{{13372394122635283102ull, 16875702901663394036ull,
  15015418359247365988ull, 3192100987009213415ull}},
{{16715492653294103877ull, 2647884553369690929ull,
  14157586930631819582ull, 3990126233761516769ull}},
{{3529653880667733067ull, 15489985901138220543ull,
  1930962804003805382ull, 2493828896100947981ull}},
{{18247125406116830046ull, 10139110339567999870ull,
  7025389523432144632ull, 3117286120126184976ull}},
{{13585534720791261749ull, 12673887924459999838ull,
  8781736904290180790ull, 3896607650157731220ull}},
{{3879273182067150689ull, 3309493934360111995ull,
  14711957602036138802ull, 2435379781348582012ull}},
{{237405459156550458ull, 13360239454804915802ull,
  18389947002545173502ull, 3044224726685727515ull}},
{{9520128860800463880ull, 7476927281651368944ull,
  18375747734754078974ull, 3805280908357159394ull}},
{{5950080538000289925ull, 61393532604717686ull, 16096528352648687263ull,
  2378300567723224621ull}},
{{16660972709355138214ull, 13911799971038060819ull,
  6285602385528695366ull, 2972875709654030777ull}},
{{16214529868266534864ull, 8166377926942800216ull,
  12468689000338257112ull, 3716094637067538471ull}},
{{10134081167666584290ull, 5103986204339250135ull,
  14710459652852492551ull, 2322559148167211544ull}},
{{8055915441155842458ull, 1768296736996674765ull,
  18388074566065615689ull, 2903198935209014430ull}},
{{14681580319872190977ull, 6822056939673231360ull,
  13761721170727243803ull, 3628998669011268038ull}},
{{18351975399840238721ull, 3915885156164151296ull,
  7978779426554278946ull, 4536248336264085048ull}},
{{11469984624900149201ull, 7059114241029982464ull,
  4986737141596424341ull, 2835155210165053155ull}},
{{14337480781125186501ull, 13435578819714865984ull,
  1621735408568142522ull, 3543944012706316444ull}},
{{17921850976406483126ull, 7571101487788806672ull,
  2027169260710178153ull, 4429930015882895555ull}},
{{11201156860254051954ull, 16261153475936473930ull,
  17407881852439719009ull, 2768706259926809721ull}},
{{4778074038462789134ull, 6491383789638428701ull,
  7924794260267485050ull, 3460882824908512152ull}},
{{10584278566505874322ull, 17337601773902811684ull,
  9905992825334356312ull, 4326103531135640190ull}},
{{15838546140920947259ull, 10836001108689257302ull,
  1579559497406584791ull, 2703814706959775119ull}},
{{10574810639296408266ull, 8933315367434183724ull,
  15809507427040394701ull, 3379768383699718898ull}},
{{13218513299120510332ull, 15778330227720117559ull,
  10538512246945717568ull, 4224710479624648623ull}},
{{15179099839591400814ull, 9861456392325073474ull,
  13504099181982155336ull, 2640444049765405389ull}},
{{9750502762634475209ull, 12326820490406341843ull,
  3045065922195530458ull, 3300555062206756737ull}},
{{7576442434865706107ull, 6185153576153151496ull,
  8418018421171800977ull, 4125693827758445921ull}},
{{4735276521791066317ull, 15394936031164189445ull,
  16790476559300845370ull, 2578558642349028700ull}},
{{10530781670666220801ull, 10020298002100460998ull,
  2541351625416505097ull, 3223198302936285876ull}},
{{3940105051478000193ull, 17137058521052964152ull,
  3176689531770631371ull, 4028997878670357345ull}},
{{2462565657173750121ull, 8404818566444408643ull,
  13514646003425114367ull, 2518123674168973340ull}},
{{16913265126749351363ull, 5894337189628122899ull,
  16893307504281392959ull, 3147654592711216675ull}},
{{16529895390009301299ull, 2756235468607765720ull,
  16504948361924353295ull, 3934568240889020844ull}},
{{10331184618755813312ull, 8640176195520935431ull,
  1092220689347945001ull, 2459105150555638028ull}},
{{8302294755017378736ull, 15411906262828557193ull,
  1365275861684931251ull, 3073881438194547535ull}},
{{14989554462199111324ull, 14653196810108308587ull,
  15541652882388327776ull, 3842351797743184418ull}},
{{7062628529660750626ull, 9158248006317692867ull,
  14325219069920092764ull, 2401469873589490261ull}},
{{4216599643648550378ull, 11447810007897116084ull,
  4071465782117952243ull, 3001837341986862827ull}},
{{5270749554560687972ull, 9698076491444007201ull, 477646209220052400ull,
  3752296677483578534ull}},
{{14823433517668899743ull, 6061297807152504500ull,
  14133586936044696462ull, 2345185423427236583ull}},
{{82547823376573062ull, 16799994295795406434ull,
  13055297651628482673ull, 2931481779284045729ull}},
{{9326556816075492136ull, 7164934814462094330ull,
  2484064009253439630ull, 3664352224105057162ull}},
{{2434823983239589362ull, 18179540554932393721ull,
  12328452048421575345ull, 4580440280131321452ull}},
{{13050980035593213111ull, 4444683819191664219ull,
  16928654567118260399ull, 2862775175082075907ull}},
{{11702039026064128485ull, 944168755562192370ull,
  16549132190470437595ull, 3578468968852594884ull}},
{{5404176745725384798ull, 15015268999734904175ull,
  2239671164378495377ull, 4473086211065743606ull}},
{{10295139493719447355ull, 2467014097193233253ull,
  15234852533018723323ull, 2795678881916089753ull}},
{{17480610385576697098ull, 16918825676773705278ull,
  5208507610991240441ull, 3494598602395112192ull}},
{{12627390945116095564ull, 7313474040684967886ull,
  6510634513739050552ull, 4368248252993890240ull}},
{{3280433322270171824ull, 4570921275428104929ull,
  4069146571086906595ull, 2730155158121181400ull}},
{{8712227671265102683ull, 1101965575857743257ull,
  5086433213858633244ull, 3412693947651476750ull}},
{{15501970607508766258ull, 1377456969822179071ull,
  15581413554178067363ull, 4265867434564345937ull}},
{{16606260657334060768ull, 17001811670634719583ull,
  2820854443720210245ull, 2666167146602716211ull}},
{{16146139803240188055ull, 7417206533011235767ull,
  17361126109932426519ull, 3332708933253395263ull}},
{{15570988735622847165ull, 4659822147836656805ull,
  17089721618988145245ull, 4165886166566744079ull}},
{{12037710968977973430ull, 5218231851611604455ull,
  17598605039508672634ull, 2603678854104215049ull}},
{{10435452692795078884ull, 15746161851369281377ull,
  8163198244103677080ull, 3254598567630268812ull}},
{{17656001884421236509ull, 1235958240502050105ull,
  10203997805129596351ull, 4068248209537836015ull}},
{{4117472150122190962ull, 7690002927954863172ull,
  13295027655847079575ull, 2542655130961147509ull}},
{{5146840187652738702ull, 5000817641516191061ull,
  2783726514526685757ull, 3178318913701434387ull}},
{{11045236252993311282ull, 10862708070322626730ull,
  17314716198440520908ull, 3972898642126792983ull}},
{{11514958676548207455ull, 16012564580806417514ull,
  17739226651666407423ull, 2483061651329245614ull}},
{{5170326308830483511ull, 15404019707580633989ull,
  12950661277728233471ull, 3103827064161557018ull}},
{{11074593904465492293ull, 14643338616048404582ull,
  6964954560305516031ull, 3879783830201946273ull}},
{{2309935171863544779ull, 16069615662671334720ull,
  15882311646259417279ull, 2424864893876216420ull}},
{{2887418964829430974ull, 15475333559911780496ull,
  1406145484114719983ull, 3031081117345270526ull}},
{{3609273706036788717ull, 14732480931462337716ull,
  10981053891998175787ull, 3788851396681588157ull}},
{{11479168103127768756ull, 6901957572950267120ull,
  9169001691712553819ull, 2368032122925992598ull}},
{{14348960128909710945ull, 4015760947760445996ull,
  2237880077785916466ull, 2960040153657490748ull}},
{{17936200161137138682ull, 14243073221555333303ull,
  2797350097232395582ull, 3700050192071863435ull}},
{{18127654128351793532ull, 4290234745044695410ull,
  17889244875266104903ull, 2312531370044914646ull}},
{{13436195623584966107ull, 751107412878481359ull,
  13138184057227855321ull, 2890664212556143308ull}},
{{12183558511053819730ull, 5550570284525489603ull,
  16422730071534819151ull, 3613330265695179135ull}},
{{10617762120389886758ull, 2326526837229474100ull,
  15916726570991136035ull, 4516662832118973919ull}},
{{15859473362098455032ull, 17594980337764278976ull,
  16865483134510541877ull, 2822914270074358699ull}},
{{1377597628913517174ull, 8158667366923185009ull,
  16470167899710789443ull, 3528642837592948374ull}},
{{6333683054569284371ull, 5586648190226593357ull,
  11364337837783710996ull, 4410803546991185468ull}},
{{6264394918319496684ull, 12715027155746396656ull,
  16326083185469595180ull, 2756752216869490917ull}},
{{7830493647899370855ull, 15893783944682995820ull,
  6572545926554830263ull, 3445940271086863647ull}},
{{9788117059874213569ull, 15255543912426356871ull,
  3603996389766149925ull, 4307425338858579559ull}},
{{13035102190062465337ull, 11840557954480166996ull,
  9170026771244925559ull, 2692140836786612224ull}},
{{16293877737578081671ull, 10189011424672820841ull,
  11462533464056156949ull, 3365176045983265280ull}},
{{6532289116690438376ull, 17347950299268413956ull,
  14328166830070196186ull, 4206470057479081600ull}},
{{13306052734786299793ull, 15454154955470146626ull,
  8955104268793872616ull, 2629043785924426000ull}},
{{7409193881628098934ull, 870949620628131667ull,
  11193880335992340771ull, 3286304732405532500ull}},
{{4649806333607735763ull, 14923745081067328296ull,
  13992350419990425963ull, 4107880915506915625ull}},
{{2906128958504834852ull, 7021497666453386233ull,
  1827689984852934371ull, 2567425572191822266ull}},
{{8244347216558431469ull, 4165186064639344887ull,
  11507984517920943772ull, 3209281965239777832ull}},
{{5693748002270651432ull, 5206482580799181109ull,
  14384980647401179715ull, 4011602456549722290ull}},
{{5864435510632851097ull, 948208603785794241ull,
  13602298923053125226ull, 2507251535343576431ull}},
{{11942230406718451775ull, 10408632791587018609ull,
  12391187635389018628ull, 3134064419179470539ull}},
{{1092729953115901007ull, 13010790989483773262ull,
  10877298525808885381ull, 3917580523974338174ull}},
{{14518014275979601842ull, 10437587377641052240ull,
  2186625560203165459ull, 2448487827483961359ull}},
{{18147517844974502302ull, 8435298203623927396ull,
  16568340005536120536ull, 3060609784354951698ull}},
{{4237653232508576261ull, 10544122754529909246ull,
  11487052970065374862ull, 3825762230443689623ull}},
{{16483591325600023875ull, 1978390703153805374ull,
  14096937133931941145ull, 2391101394027306014ull}},
{{11381117120145254036ull, 7084674397369644622ull,
  8397799380560150623ull, 2988876742534132518ull}},
{{5003024363326791737ull, 4244156978284667874ull,
  1273877188845412471ull, 3736095928167665648ull}},
{{7738576245506632740ull, 9570127139068999277ull, 796173243028382794ull,
  2335059955104791030ull}},
{{14284906325310678829ull, 2739286886981473288ull,
  10218588590640254301ull, 2918824943880988787ull}},
{{17856132906638348536ull, 8035794627154229514ull,
  8161549719872929972ull, 3648531179851235984ull}},
{{13096794096443159862ull, 10044743283942786893ull,
  10201937149841162465ull, 4560663974814044980ull}},
{{10491339319490668866ull, 17807179598532711568ull,
  15599582755505502348ull, 2850414984258778112ull}},
{{13114174149363336082ull, 3812230424456337844ull,
  1052734370672326320ull, 3563018730323472641ull}},
{{16392717686704170102ull, 4765288030570422305ull,
  5927603981767795804ull, 4453773412904340801ull}},
{{3327919526549024458ull, 12201677055961289749ull,
  15233967534673342137ull, 2783608383065213000ull}},
{{8771585426613668477ull, 1417038264669448474ull, 595715344632126056ull,
  3479510478831516251ull}},
{{1741109746412309788ull, 1771297830836810593ull,
  14579702236072321282ull, 4349388098539395313ull}},
{{12617408637576163377ull, 5718747162700394524ull,
  2194784869904118945ull, 2718367561587122071ull}},
{{15771760796970204222ull, 11760119971802881059ull,
  16578539142662312393ull, 3397959451983902588ull}},
{{15103014977785367373ull, 865091909471437612ull,
  2276429854618338876ull, 4247449314979878236ull}},
{{216012324261078800ull, 9764054480274424316ull,
  10646140695991237605ull, 2654655821862423897ull}},
{{270015405326348500ull, 16816754118770418299ull,
  17919361888416434910ull, 3318319777328029871ull}},
{{14172577311940099337ull, 11797570611608247065ull,
  17787516342093155734ull, 4147899721660037339ull}},
{{1940331792321480230ull, 2761795613827766512ull,
  8811354704594528382ull, 2592437326037523337ull}},
{{2425414740401850287ull, 12675616554139483948ull,
  15625879399170548381ull, 3240546657546904171ull}},
{{3031768425502312859ull, 2009462637392191223ull,
  14920663230535797573ull, 4050683321933630214ull}},
{{8812384293580027393ull, 3561757157583813466ull,
  4713728500657485579ull, 2531677076208518884ull}},
{{1792108330120258433ull, 18287254502261930545ull,
  5892160625821856973ull, 3164596345260648605ull}},
{{6851821431077710945ull, 9024010072545249469ull,
  11976886800704709121ull, 3955745431575810756ull}},
{{6588231403637263293ull, 17169221341409250678ull,
  16708926287295219008ull, 2472340894734881722ull}},
{{17458661291401354924ull, 3014782603052011731ull,
  11662785822264247953ull, 3090426118418602153ull}},
{{17211640595824305751ull, 8380164272242402568ull,
  743424222548146229ull, 3863032648023252692ull}},
{{10757275372390191095ull, 7543445679365195557ull,
  9688012175947367201ull, 2414395405014532932ull}},
{{18058280233915126772ull, 14040993117633882350ull,
  12110015219934209001ull, 3017994256268166165ull}},
{{13349478255539132657ull, 3716183341760189226ull,
  1302460969635597540ull, 3772492820335207707ull}},
{{12955109928139345815ull, 11545986625454894074ull,
  16954939170518106126ull, 2357808012709504816ull}},
{{6970515373319406460ull, 5209111244963841785ull,
  2746929889438081042ull, 2947260015886881021ull}},
{{13324830235076645979ull, 15734761093059578039ull,
  8045348380224989206ull, 3684075019858601276ull}},
{{12044351775418419570ull, 10445079329469696741ull,
  10056685475281236508ull, 4605093774823251595ull}},
{{9833562868850206183ull, 15751546617773336271ull,
  3979585412837078865ull, 2878183609264532247ull}},
{{7680267567635369825ull, 5854375216934506627ull, 362795747618960678ull,
  3597729511580665309ull}},
{{4988648441116824377ull, 16541341058022909092ull,
  5065180702951088751ull, 4497161889475831636ull}},
{{12341277312552791044ull, 17255867188905400038ull,
  12389109976199206277ull, 2810726180922394772ull}},
{{6203224603836212997ull, 7734775930849586336ull,
  15486387470249007847ull, 3513407726152993465ull}},
{{7754030754795266246ull, 5056783895134595016ull,
  5522926282529096097ull, 4391759657691241832ull}},
{{4846269221747041404ull, 14689704980527591645ull,
  3451828926580685060ull, 2744849786057026145ull}},
{{10669522545611189659ull, 18362131225659489556ull,
  8926472176653244229ull, 3431062232571282681ull}},
{{13336903182013987073ull, 9117605976792198233ull,
  15769776239243943191ull, 4288827790714103351ull}},
{{1418035461117660065ull, 12616032763136205752ull,
  16773639177168546350ull, 2680517369196314594ull}},
{{1772544326397075081ull, 6546668917065481382ull,
  11743676934605907130ull, 3350646711495393243ull}},
{{11439052444851119659ull, 17406708183186627535ull,
  10067910149829996008ull, 4188308389369241554ull}},
{{14066936805673031643ull, 10879192614491642209ull,
  10904129862071135409ull, 2617692743355775971ull}},
{{3748612951809125842ull, 18210676786541940666ull,
  9018476309161531357ull, 3272115929194719964ull}},
{{13909138226616183110ull, 8928287927895262120ull,
  11273095386451914197ull, 4090144911493399955ull}},
{{8693211391635114444ull, 7886022964148232777ull,
  4739841607318752421ull, 2556340569683374972ull}},
{{15478200257971280959ull, 14469214723612678875ull,
  5924802009148440526ull, 3195425712104218715ull}},
{{14736064304036713295ull, 8863146367661072786ull,
  2794316493008162754ull, 3994282140130273394ull}},
{{13821726208450333713ull, 10151152498215558395ull,
  6358133826557489625ull, 2496426337581420871ull}},
{{12665471742135529238ull, 17300626641196835898ull,
  3335981264769474127ull, 3120532921976776089ull}},
{{6608467640814635739ull, 17014097283068656969ull,
  8781662599389230563ull, 3900666152470970111ull}},
{{15659507321577617097ull, 8327967792704216653ull,
  12406068152259350958ull, 2437916345294356319ull}},
{{5739326096689857659ull, 1186587704025495009ull,
  10895899171896800794ull, 3047395431617945399ull}},
{{11785843639289709978ull, 10706606666886644569ull,
  9008187946443613088ull, 3809244289522431749ull}},
{{448623246914986880ull, 6691629166804152856ull, 7935960475740952132ull,
  2380777680951519843ull}},
{{560779058643733600ull, 8364536458505191070ull, 5308264576248802261ull,
  2975972101189399804ull}},
{{9924345860159442808ull, 15067356591558876741ull,
  6635330720311002826ull, 3719965126486749755ull}},
{{8508559171813345707ull, 14028783888151685867ull,
  1841238690980682814ull, 2324978204054218597ull}},
{{6024012946339294230ull, 8312607823334831526ull,
  6913234382153241422ull, 2906222755067773246ull}},
{{16753388219778893595ull, 1167387742313763599ull,
  17864915014546327586ull, 3632778443834716557ull}},
{{16330049256296229090ull, 10682606714746980307ull,
  8496085712900745770ull, 4540973054793395697ull}},
{{7900437775971449230ull, 11288315215144250596ull,
  16839268616631435866ull, 2838108159245872310ull}},
{{9875547219964311537ull, 4887021982075537437ull,
  11825713733934519025ull, 3547635199057340388ull}},
{{16956120043382777325ull, 10720463496021809700ull,
  14782142167418148781ull, 4434543998821675485ull}},
{{1374202990259460020ull, 9006132694227325015ull,
  11544681863850036940ull, 2771589999263547178ull}},
{{15552811793106488737ull, 11257665867784156268ull,
  5207480292957770367ull, 3464487499079433973ull}},
{{994270667673559305ull, 9460396316302807432ull,
  11121036384624600863ull, 4330609373849292466ull}},
{{621419167295974566ull, 12830276725330336501ull,
  11562333758817763443ull, 2706630858655807791ull}},
{{5388459977547356111ull, 11426159888235532722ull,
  9841231180094816400ull, 3383288573319759739ull}},
{{15958947008788970947ull, 14282699860294415902ull,
  7689852956691132596ull, 4229110716649699674ull}},
{{5362655862065718938ull, 18150059449538785747ull,
  9417844116359345776ull, 2643194197906062296ull}},
{{2091633809154760769ull, 4240830238213930568ull,
  11772305145449182221ull, 3303992747382577870ull}},
{{2614542261443450961ull, 9912723816194801114ull,
  5492009394956701968ull, 4129990934228222338ull}},
{{6245774931829544755ull, 6195452385121750696ull,
  8044191890275326634ull, 2581244333892638961ull}},
{{7807218664786930943ull, 16967687518256964178ull,
  14666925881271546196ull, 3226555417365798701ull}},
{{535651294128887871ull, 2762865324111653607ull, 4498599296307269034ull,
  4033194271707248377ull}},
{{7252311086471636775ull, 6338476845997171408ull,
  14340839606260512906ull, 2520746419817030235ull}},
{{9065388858089545969ull, 17146468094351240068ull,
  13314363489398253228ull, 3150933024771287794ull}},
{{11331736072611932461ull, 2986341044229498469ull,
  7419582324893040728ull, 3938666280964109743ull}},
{{9388178054596151740ull, 1866463152643436543ull,
  11554767980699232311ull, 2461666425602568589ull}},
{{7123536549817801771ull, 16168136996086459391ull,
  608401920591876676ull, 3077083032003210737ull}},
{{4292734668844864310ull, 1763427171398522623ull,
  5372188419167233750ull, 3846353790004013421ull}},
{{9600488195669122050ull, 14937200037406240351ull,
  5663460771193215045ull, 2403971118752508388ull}},
{{7388924226159014658ull, 4836441991475636727ull,
  7079325963991518807ull, 3004963898440635485ull}},
{{4624469264271380419ull, 1433866470917158005ull,
  13460843473416786413ull, 3756204873050794356ull}},
{{5196136299383306714ull, 3202009553536917705ull,
  17636399207740267316ull, 2347628045656746472ull}},
{{11106856392656521296ull, 4002511941921147131ull,
  3598754935965782529ull, 2934535057070933091ull}},
{{9271884472393263716ull, 9614825945828821818ull,
  18333501725239391873ull, 3668168821338666363ull}},
{{2366483553636803837ull, 16630218450713415177ull,
  18305191138121851937ull, 4585211026673332954ull}},
{{13008267267091472159ull, 3476357504054802629ull,
  16052430479753545365ull, 2865756891670833096ull}},
{{2425276028582176486ull, 8957132898495891191ull,
  1618794025982380090ull, 3582196114588541371ull}},
{{16866653091009884319ull, 1973044086265088180ull,
  15858550587760138825ull, 4477745143235676713ull}},
{{1318286145026401892ull, 12762367599984149873ull,
  2994065089709004909ull, 2798590714522297946ull}},
{{6259543699710390269ull, 2117901444698023629ull,
  12965953398991031945ull, 3498238393152872432ull}},
{{12436115643065375740ull, 7259062824299917440ull,
  16207441748738789931ull, 4372797991441090540ull}},
{{7772572276915859837ull, 2231071255973754448ull, 906279056106967899ull,
  2732998744650681588ull}},
{{9715715346144824797ull, 16623897125249356772ull,
  1132848820133709873ull, 3416248430813351985ull}},
{{12144644182681030996ull, 6944813351279532253ull,
  6027747043594525246ull, 4270310538516689981ull}},
{{9896245623389338325ull, 18175566399831871370ull,
  6073184911460272230ull, 2668944086572931238ull}},
{{3146934992381897098ull, 13496085962935063405ull,
  16814853176180116096ull, 3336180108216164047ull}},
{{8545354758904759276ull, 16870107453668829256ull,
  16406880451797757216ull, 4170225135270205059ull}},
{{5340846724315474548ull, 10543817158543018285ull,
  7948457273159904308ull, 2606390709543878162ull}},
{{11287744423821731088ull, 13179771448178772856ull,
  712199554595104577ull, 3257988386929847703ull}},
{{14109680529777163860ull, 2639656254941302358ull,
  14725307498526044434ull, 4072485483662309628ull}},
{{4206864312683339509ull, 6261471177765701878ull,
  18426689223433553579ull, 2545303427288943517ull}},
{{14481952427708950194ull, 3215152953779739443ull,
  9198303474009778262ull, 3181629284111179397ull}},
{{13490754516208799838ull, 13242313229079450112ull,
  16109565360939610731ull, 3977036605138974246ull}},
{{8431721572630499899ull, 5970602758960962368ull,
  5456792332159868803ull, 2485647878211858904ull}},
{{10539651965788124874ull, 2851567430273815056ull,
  6820990415199836004ull, 3107059847764823630ull}},
{{13174564957235156092ull, 3564459287842268820ull,
  17749610055854570813ull, 3883824809706029537ull}},
{{17457475135126748366ull, 4533630064115111964ull,
  4175977257268024902ull, 2427390506066268461ull}},
{{3375099845198883841ull, 14890409616998665764ull,
  9831657590012419031ull, 3034238132582835576ull}},
{{4218874806498604801ull, 14001326002820944301ull,
  12289571987515523789ull, 3792797665728544470ull}},
{{4942639763275321953ull, 11056671760976784140ull,
  3069296473769814464ull, 2370498541080340294ull}},
{{6178299704094152441ull, 13820839701220980175ull,
  13059992629067043888ull, 2963123176350425367ull}},
{{3111188611690302647ull, 17276049626526225219ull,
  11713304767906416956ull, 3703903970438031709ull}},
{{18085393946802296819ull, 1574158979724114953ull,
  9626658489155204550ull, 2314939981523769818ull}},
{{8771684378220707311ull, 11191070761509919500ull,
  2809951074589229879ull, 2893674976904712273ull}},
{{10964605472775884139ull, 9377152433460011471ull,
  8124124861663925253ull, 3617093721130890341ull}},
{{9094070822542467270ull, 16333126560252402243ull,
  14766842095507294470ull, 4521367151413612926ull}},
{{3377951254875348092ull, 5596518081730363498ull,
  4617590291264671140ull, 2825854469633508079ull}},
{{13445811105448960922ull, 6995647602162954372ull,
  1160301845653451021ull, 3532318087041885099ull}},
{{16807263881811201153ull, 13356245521131080869ull,
  15285435362348977488ull, 4415397608802356373ull}},
{{12810382935345694673ull, 8347653450706925543ull,
  11859240110681804882ull, 2759623505501472733ull}},
{{11401292650754730437ull, 1211194776528881121ull,
  988992083070092391ull, 3449529381876840917ull}},
{{416557758161249334ull, 15349051525943265114ull,
  5847926122265003392ull, 4311911727346051146ull}},
{{4872034617278168738ull, 9593157203714540696ull,
  8266639844843015024ull, 2694944829591281966ull}},
{{6090043271597710922ull, 11991446504643175870ull,
  1109927769198992972ull, 3368681036989102458ull}},
{{16835926126351914461ull, 14989308130803969837ull,
  10610781748353517023ull, 4210851296236378072ull}},
{{12828296838183640490ull, 16285846609393563004ull,
  6631738592720948139ull, 2631782060147736295ull}},
{{16035371047729550613ull, 15745622243314565851ull,
  3677987222473797270ull, 3289727575184670369ull}},
{{15432527791234550362ull, 10458655767288431506ull,
  9209170046519634492ull, 4112159468980837961ull}},
{{14257015887948981880ull, 15760031891410045499ull,
  17284946325143241317ull, 2570099668113023725ull}},
{{13209583841508839446ull, 5864981808980393162ull,
  7771124851146887935ull, 3212624585141279657ull}},
{{7288607765031273499ull, 2719541242798103549ull,
  14325592082360997823ull, 4015780731426599571ull}},
{{6861222862358239889ull, 8617242304389896574ull,
  6647652042261929687ull, 2509862957141624732ull}},
{{17799900614802575670ull, 6159866862059982813ull,
  8309565052827412109ull, 3137328696427030915ull}},
{{8414817713221055875ull, 12311519596002366421ull,
  5775270297606877232ull, 3921660870533788644ull}},
{{7565104079976853874ull, 7694699747501479013ull,
  12832915972859074078ull, 2451038044083617902ull}},
{{14068066118398455246ull, 395002647522072958ull,
  6817772929219066790ull, 3063797555104522378ull}},
{{8361710611143293250ull, 9717125346257367006ull,
  17745588198378609295ull, 3829746943880652972ull}},
{{614383113537170377ull, 12990732369051936235ull,
  1867620587131855001ull, 2393591839925408108ull}},
{{14603036947203626683ull, 2403357406032756581ull,
  2334525733914818752ull, 2991989799906760135ull}},
{{4418738128722369642ull, 3004196757540945727ull,
  16753215222675687152ull, 3739987249883450168ull}},
{{9679240358092562883ull, 1877622973463091079ull,
  10470759514172304470ull, 2337492031177156355ull}},
{{7487364429188315699ull, 11570400753683639657ull,
  8476763374287992683ull, 2921865038971445444ull}},
{{13970891554912782528ull, 9851314923677161667ull,
  10595954217859990854ull, 3652331298714306805ull}},
{{12851928425213590256ull, 3090771617741676276ull,
  17856628790752376472ull, 4565414123392883506ull}},
{{17255827302613269718ull, 1931732261088547672ull,
  15772079012647623199ull, 2853383827120552191ull}},
{{3123040054557035531ull, 16249723381642848303ull,
  15103412747382141094ull, 3566729783900690239ull}},
{{17738858123478458126ull, 11088782190198784570ull,
  14267579915800288464ull, 4458412229875862799ull}},
{{15698472345601424233ull, 6930488868874240356ull,
  15834766475016262146ull, 2786507643672414249ull}},
{{1176346358292228675ull, 17886483122947576254ull,
  5958400038488163970ull, 3483134554590517812ull}},
{{10693804984720061652ull, 13134731866829694509ull,
  7448000048110204963ull, 4353918193238147265ull}},
{{8989471124663732484ull, 5903364407554865116ull,
  16184215076137347862ull, 2721198870773842040ull}},
{{11236838905829665605ull, 16602577546298357203ull,
  1783524771462133211ull, 3401498588467302551ull}},
{{9434362613859694103ull, 16141535914445558600ull,
  16064464019609830226ull, 4251873235584128188ull}},
{{5896476633662308814ull, 14700145964955862029ull,
  816917975401368083ull, 2657420772240080118ull}},
{{11982281810505273922ull, 13763496437767439632ull,
  10244519506106485912ull, 3321775965300100147ull}},
{{14977852263131592402ull, 17204370547209299540ull,
  8193963364205719486ull, 4152219956625125184ull}},
{{137785627602469444ull, 6141045573578424309ull, 5121227102628574679ull,
  2595137472890703240ull}},
{{4783918052930474708ull, 3064620948545642482ull,
  6401533878285718349ull, 3243921841113379050ull}},
{{15203269603017869193ull, 8442462204109441006ull,
  17225289384711923744ull, 4054902301391723812ull}},
{{4890357483458780342ull, 5276538877568400629ull,
  1542433828590176532ull, 2534313938369827383ull}},
{{10724632872750863331ull, 6595673596960500786ull,
  15763100341019884377ull, 3167892422962284228ull}},
{{4182419054083803356ull, 12856278014628013887ull,
  1257131352565303855ull, 3959865528702855286ull}},
{{9531540936443458954ull, 14952702786783590535ull,
  14620765150635478621ull, 2474915955439284553ull}},
{{7302740152126935788ull, 4855820428197324457ull,
  4440898383012184565ull, 3093644944299105692ull}},
{{13740111208586057639ull, 10681461553674043475ull,
  5551122978765230706ull, 3867056180373882115ull}},
{{6281726496152592073ull, 11287599489473665076ull,
  1163608852514575239ull, 2416910112733676322ull}},
{{7852158120190740091ull, 9497813343414693441ull,
  10677883102497994857ull, 3021137640917095402ull}},
{{14426883668665813017ull, 16483952697695754705ull,
  4123981841267717763ull, 3776422051146369253ull}},
{{2099273265275051280ull, 7996627426846152739ull,
  4883331660006017554ull, 2360263781966480783ull}},
{{16459149636875977812ull, 772412246702915115ull,
  1492478556580134039ull, 2950329727458100979ull}},
{{15962251027667584360ull, 14800573363660807606ull,
  15700656251007331260ull, 3687912159322626223ull}},
{{10729441747729704642ull, 53972630866457892ull,
  15014134295331776172ull, 4609890199153282779ull}},
{{15929273129185841210ull, 9257104931146311990ull,
  7077990925368666155ull, 2881181374470801737ull}},
{{10688219374627525704ull, 6959695145505502084ull,
  13459174675138220598ull, 3601476718088502171ull}},
{{13360274218284407130ull, 17922990968736653413ull,
  12212282325495387843ull, 4501845897610627714ull}},
{{10656014395641448408ull, 8896026346246714431ull,
  12244362471862005306ull, 2813653686006642321ull}},
{{8708331976124422606ull, 1896660895953617231ull,
  1470395034545342921ull, 3517067107508302902ull}},
{{6273728951728140354ull, 6982512138369409443ull,
  11061365830036454459ull, 4396333884385378627ull}},
{{1615237585616393769ull, 2058227077267186950ull,
  4607510634559090085ull, 2747708677740861642ull}},
{{11242419018875268019ull, 7184469865011371591ull,
  14982760330053638414ull, 3434635847176077052ull}},
{{9441337755166697120ull, 18203959368118990297ull,
  281706338857496401ull, 4293294808970096316ull}},
{{17430051143047655460ull, 4459945577433287079ull,
  9399438498640711059ull, 2683309255606310197ull}},
{{17175877910382181421ull, 963245953364220945ull,
  16360984141728276728ull, 3354136569507887746ull}},
{{7634789332695563064ull, 1204057441705276182ull,
  11227858140305570102ull, 4192670711884859683ull}},
{{160057314507339011ull, 14587593956347961326ull,
  4711568328477287361ull, 2620419194928037302ull}},
{{9423443679988949572ull, 4399434390152787945ull,
  15112832447451385010ull, 3275523993660046627ull}},
{{16390990618413574869ull, 14722665024545760739ull,
  14279354540886843358ull, 4094404992075058284ull}},
{{7938526127294790341ull, 4589979621913712558ull,
  18147968624909052907ull, 2559003120046911427ull}},
{{699785622263712119ull, 1125788508964752794ull,
  18073274762708928230ull, 3198753900058639284ull}},
{{10098104064684415956ull, 10630607673060716800ull,
  4144849379676608671ull, 3998442375073299106ull}},
{{6311315040427759973ull, 13561658823304029856ull,
  7202216880725268323ull, 2499026484420811941ull}},
{{7889143800534699966ull, 12340387510702649416ull,
  13614457119333973308ull, 3123783105526014926ull}},
{{9861429750668374957ull, 15425484388378311770ull,
  7794699362312690827ull, 3904728881907518658ull}},
{{10775079612595122252ull, 7335084733522750904ull,
  9483373119872819671ull, 2440455551192199161ull}},
{{13468849515743902815ull, 4557169898476050726ull,
  16465902418268412493ull, 3050569438990248951ull}},
{{7612689857825102711ull, 10308148391522451312ull,
  15970692004408127712ull, 3813211798737811189ull}},
{{4757931161140689195ull, 6442592744701532070ull,
  12287525511968773772ull, 2383257374211131993ull}},
{{15170785988280637301ull, 8053240930876915087ull,
  1524348834678803503ull, 2979071717763914992ull}},
{{14351796466923408722ull, 5454865145168755955ull,
  1905436043348504379ull, 3723839647204893740ull}},
{{6664029782613436500ull, 1103447706516778520ull,
  10414269563947591045ull, 2327399779503058587ull}},
{{8330037228266795624ull, 5990995651573361054ull,
  8406150936507100902ull, 2909249724378823234ull}},
{{1189174498478718722ull, 16712116601321477126ull,
  1284316633779100319ull, 3636562155473529043ull}},
{{10709840159953174211ull, 16278459733224458503ull,
  15440453847506039111ull, 4545702694341911303ull}},
{{13611179127611815738ull, 17091566360906368420ull,
  16567812682332356300ull, 2841064183963694564ull}},
{{17013973909514769672ull, 2917713877423408909ull,
  2263021779205893760ull, 3551330229954618206ull}},
{{7432409331611298378ull, 3647142346779261137ull,
  12052149260862143008ull, 4439162787443272757ull}},
{{16174470878325531247ull, 2279463966737038210ull,
  9838436297252533332ull, 2774476742152045473ull}},
{{10994716561052138250ull, 2849329958421297763ull,
  16909731389993054569ull, 3468095927690056841ull}},
{{9131709682887784909ull, 8173348466454010108ull,
  7302106182209154499ull, 4335119909612571052ull}},
{{14930690588659641376ull, 2802499782320062365ull,
  13787188400735497370ull, 2709449943507856907ull}},
{{4828305180542388008ull, 12726496764754853765ull,
  12622299482491983808ull, 3386812429384821134ull}},
{{10647067494105372914ull, 15908120955943567206ull,
  6554502316260203952ull, 4233515536731026418ull}},
{{2042731165388470167ull, 9942575597464729504ull,
  8708249966090015374ull, 2645947210456891511ull}},
{{2553413956735587709ull, 3204847459976136072ull,
  6273626439185131314ull, 3307434013071114389ull}},
{{3191767445919484636ull, 13229431361824945898ull,
  12453719067408802046ull, 4134292516338892986ull}},
{{6606540672127065802ull, 3656708582713203282ull,
  12395260435557889183ull, 2583932822711808116ull}},
{{17481547877013608060ull, 18405943783673667814ull,
  15494075544447361478ull, 3229916028389760145ull}},
{{12628562809412234267ull, 13784057692737308960ull,
  5532536375277038136ull, 4037395035487200182ull}},
{{7892851755882646417ull, 8615036057960818100ull,
  17292893289830312547ull, 2523371897179500113ull}},
{{9866064694853308021ull, 6157109054023634721ull,
  7781058557005726972ull, 3154214871474375142ull}},
{{16944266886994022930ull, 7696386317529543401ull,
  502951159402382907ull, 3942768589342968928ull}},
{{3672637776730182476ull, 2504398439242270674ull, 314344474626489317ull,
  2464230368339355580ull}},
{{13814169257767503903ull, 7742184067480226246ull,
  392930593283111646ull, 3080287960424194475ull}},
{{8044339535354604070ull, 454358047495507000ull,
  14326221296886053270ull, 3850359950530243093ull}},
{{5027712209596627544ull, 14119031834966855587ull,
  11259731319767477245ull, 2406474969081401933ull}},
{{1672954243568396526ull, 3813731738426405772ull, 239606094427182845ull,
  3008093711351752417ull}},
{{2091192804460495657ull, 9378850691460395119ull,
  4911193636461366460ull, 3760117139189690521ull}},
{{8224524530428891642ull, 15085153719017522757ull,
  14598711068856823797ull, 2350073211993556575ull}},
{{14892341681463502456ull, 5021384093489739734ull,
  13636702817643641843ull, 2937591514991945719ull}},
{{9392055064974602262ull, 1665044098434786764ull,
  12434192503627164400ull, 3671989393739932149ull}},
{{11740068831218252828ull, 2081305123043483455ull,
  1707682574251791788ull, 4589986742174915187ull}},
{{14255072047152489873ull, 10524187738756952967ull,
  17208202673403227531ull, 2868741713859321991ull}},
{{13207154040513224438ull, 8543548655018803305ull,
  16898567323326646510ull, 3585927142324152489ull}},
{{2673884495359366835ull, 1456063781918728324ull,
  7288151098876144426ull, 4482408927905190612ull}},
{{10894549846454380080ull, 5521725882126593106ull,
  13778466473652366074ull, 2801505579940744132ull}},
{{4394815271213199292ull, 16125529389513017191ull,
  17223083092065457592ull, 3501881974925930165ull}},
{{881833070589111211ull, 1710167663181719873ull, 7693795809799658279ull,
  4377352468657412707ull}},
{{12080360715186664267ull, 7986383817129656776ull,
  2502779371911092472ull, 2735845292910882942ull}},
{{15100450893983330334ull, 9982979771412070970ull,
  12351846251743641398ull, 3419806616138603677ull}},
{{9652191580624387109ull, 3255352677410312905ull,
  1604749759397388036ull, 4274758270173254597ull}},
{{17561834783958711703ull, 11257967460236221373ull,
  3308811608837061474ull, 2671723918858284123ull}},
{{8117235424666225917ull, 4849087288440500909ull,
  17971072566328490555ull, 3339654898572855153ull}},
{{14758230299260170300ull, 1449673092123238232ull,
  8628782652628449482ull, 4174568623216068942ull}},
{{9223893937037606438ull, 5517731701004411799ull, 781303139465393022ull,
  2609105389510043089ull}},
{{6918181402869620143ull, 16120536663110290557ull,
  5588314942759129181ull, 3261381736887553861ull}},
{{13259412772014413083ull, 6315612773605699484ull,
  11597079696876299381ull, 4076727171109442326ull}},
{{17510505019363783985ull, 6253100992717256129ull,
  2636488792120299209ull, 2547954481943401454ull}},
{{8053073218922566269ull, 12428062259323958066ull,
  12518983027005149819ull, 3184943102429251817ull}},
{{842969486798432028ull, 10923391805727559679ull,
  1813670728474273562ull, 3981178878036564772ull}},
{{7444384956890101874ull, 11438805897007112703ull,
  10356916242151196784ull, 2488236798772852982ull}},
{{4693795177685239438ull, 14298507371258890879ull,
  3722773265834220172ull, 3110295998466066228ull}},
{{1255557953679161393ull, 17873134214073613599ull,
  4653466582292775215ull, 3887869998082582785ull}},
{{7702252748690557727ull, 18088237911437090355ull,
  14437631660001454269ull, 2429918748801614240ull}},
{{5016129917435809255ull, 8775239334014199232ull,
  18047039575001817837ull, 3037398436002017800ull}},
{{6270162396794761568ull, 15580735185945136944ull,
  4112055395042720680ull, 3796748045002522251ull}},
{{3918851497996725980ull, 9737959491215710590ull, 264191612688006473ull,
  2372967528126576407ull}},
{{14121936409350683283ull, 16784135382447026141ull,
  14165297571142171803ull, 2966209410158220508ull}},
{{3817362456406190392ull, 16368483209631394773ull,
  17706621963927714754ull, 3707761762697775635ull}},
{{4691694544467562947ull, 14841988024447009637ull,
  8760795718241127769ull, 2317351101686109772ull}},
{{10476304199011841588ull, 4717426975276598334ull,
  10950994647801409712ull, 2896688877107637215ull}},
{{3872008211910026177ull, 5896783719095747918ull,
  9077057291324374236ull, 3620861096384546519ull}},
{{14063382301742308529ull, 7370979648869684897ull,
  6734635595728079891ull, 4526076370480683149ull}},
{{1872084910947860975ull, 2301019271329859109ull,
  6514990256543743884ull, 2828797731550426968ull}},
{{6951792157112214122ull, 2876274089162323886ull,
  8143737820679679855ull, 3535997164438033710ull}},
{{17913112233245043461ull, 17430400666735068569ull,
  956300238994824010ull, 4419996455547542138ull}},
{{4278166118137070307ull, 15505686435136805760ull,
  5209373667799152910ull, 2762497784717213836ull}},
{{5347707647671337884ull, 10158736007066231392ull,
  6511717084748941138ull, 3453122230896517295ull}},
{{6684634559589172354ull, 3475047971978013432ull,
  3527960337508788519ull, 4316402788620646619ull}},
{{4177896599743232722ull, 9089434010127340251ull,
  18345876275438850488ull, 2697751742887904136ull}},
{{610684731251652998ull, 11361792512659175314ull,
  4485601270589011494ull, 3372189678609880171ull}},
{{9986727950919342055ull, 4978868603969193334ull, 995315569808876464ull,
  4215237098262350214ull}},
{{1630018950897200881ull, 3111792877480745834ull,
  14457130286412711502ull, 2634523186413968883ull}},
{{11260895725476276909ull, 13113113133705708100ull,
  13459726839588501473ull, 3293153983017461104ull}},
{{14076119656845346136ull, 2556333361849971413ull,
  16824658549485626842ull, 4116442478771826380ull}},
{{11103417794742035287ull, 6209394369583620037ull,
  1292039556573740968ull, 2572776549232391488ull}},
{{44214188145380397ull, 7761742961979525047ull, 1615049445717176210ull,
  3215970686540489360ull}},
{{13890325790463889208ull, 478806665619630500ull,
  2018811807146470263ull, 4019963358175611700ull}},
{{17904825655894706563ull, 7216783193653350918ull,
  10485129416321319722ull, 2512477098859757312ull}},
{{13157660033013607396ull, 18244351028921464456ull,
  13106411770401649652ull, 3140596373574696640ull}},
{{16447075041267009245ull, 4358694712442278954ull,
  16383014713002062066ull, 3925745466968370800ull}},
{{14891107919219268682ull, 7335870213703812250ull,
  10239384195626288791ull, 2453590916855231750ull}},
{{9390512862169310044ull, 4558151748702377409ull,
  3575858207678085181ull, 3066988646069039688ull}},
{{16349827096139025459ull, 10309375704305359665ull,
  4469822759597606476ull, 3833735807586299610ull}},
{{3301112907445809056ull, 15666731852045625599ull,
  7405325243175891951ull, 2396084879741437256ull}},
{{17961449189589425032ull, 14971728796629644094ull,
  9256656553969864939ull, 2995106099676796570ull}},
{{13228439450132005482ull, 14102974977359667214ull,
  2347448655607555366ull, 3743882624595995713ull}},
{{3656088637905115523ull, 4202673342422404105ull,
  12996370455823191864ull, 2339926640372497320ull}},
{{9181796815808782307ull, 5253341678028005131ull,
  16245463069778989830ull, 2924908300465621650ull}},
{{6865560001333589980ull, 15790049134389782222ull,
  11083456800368961479ull, 3656135375582027063ull}},
{{17805322038521763283ull, 15125875399559839873ull,
  9242634982033813945ull, 4570169219477533829ull}},
{{4210797246435020196ull, 2536143097083818065ull,
  8082489872984827668ull, 2856355762173458643ull}},
{{9875182576471163149ull, 3170178871354772581ull,
  5491426322803646681ull, 3570444702716823304ull}},
{{16955664239016341840ull, 8574409607620853630ull,
  6864282903504558351ull, 4463055878396029130ull}},
{{5985604130957825746ull, 12276535032404115375ull,
  8901862833117736873ull, 2789409923997518206ull}},
{{2870319145269894278ull, 1510610735222980507ull,
  1903956504542395284ull, 3486762404996897758ull}},
{{17422956986869531560ull, 1888263419028725633ull,
  11603317667532769913ull, 4358453006246122197ull}},
{{3971819089152375369ull, 12709379682961423281ull,
  9557916551421675147ull, 2724033128903826373ull}},
{{9576459879867857115ull, 11275038585274391197ull,
  16559081707704481838ull, 3405041411129782966ull}},
{{16582260868262209298ull, 4870426194738213188ull,
  11475480097775826490ull, 4256301763912228708ull}},
{{1140541005809105003ull, 7655702390138771147ull,
  16395547097964667364ull, 2660188602445142942ull}},
{{15260734312543544966ull, 9569627987673463933ull,
  11271061835601058397ull, 3325235753056428678ull}},
{{5240859835397267496ull, 16573721003019217821ull,
  4865455257646547188ull, 4156544691320535848ull}},
{{5581380406336986137ull, 1135203590032235330ull,
  3040909536029091993ull, 2597840432075334905ull}},
{{16200097544776008479ull, 6030690505967682066ull,
  8412822938463752895ull, 3247300540094168631ull}},
{{11026749894115234791ull, 2926677114032214679ull,
  5904342654652303215ull, 4059125675117710789ull}},
{{13809247711463103600ull, 8746702223911216030ull,
  5996057168371383461ull, 2536953546948569243ull}},
{{8038187602474103692ull, 15545063798316407942ull,
  2883385442036841422ull, 3171191933685711554ull}},
{{824362466237853807ull, 10207957711040734120ull,
  12827603839400827586ull, 3963989917107139442ull}},
{{515226541398658630ull, 10991659587827846729ull,
  12628938418052905145ull, 2477493698191962151ull}},
{{5255719195175711191ull, 18351260503212196315ull,
  11174487004138743527ull, 3096867122739952689ull}},
{{1957962975542251085ull, 18327389610587857490ull,
  133050699891265697ull, 3871083903424940862ull}},
{{5835412878141294832ull, 4537089478976329075ull,
  13918214742714204773ull, 2419427439640588038ull}},
{{2682580079249230636ull, 10283047867147799248ull,
  8174396391537980158ull, 3024284299550735048ull}},
{{3353225099061538295ull, 3630437797079973252ull,
  10217995489422475198ull, 3780355374438418810ull}},
{{11319137723768237242ull, 16104081678457146994ull,
  10997933199316434902ull, 2362722109024011756ull}},
{{4925550117855520745ull, 10906730061216657935ull,
  13747416499145543628ull, 2953402636280014695ull}},
{{1545251628892013027ull, 13633412576520822419ull,
  12572584605504541631ull, 3691753295350018369ull}},
{{17106683332553365806ull, 15438411887966595867ull,
  940336350799256663ull, 2307345809593761481ull}},
{{16771668147264319354ull, 14686328841530856930ull,
  5787106456926458733ull, 2884182261992201851ull}},
{{11741213147225623384ull, 4522852996631407451ull,
  2622197052730685513ull, 3605227827490252314ull}},
{{10064830415604641326ull, 10265252264216647218ull,
  12501118352768132699ull, 4506534784362815392ull}},
{{10902205028180288733ull, 4109939655921710559ull,
  7813198970480082937ull, 2816584240226759620ull}},
{{9016070266797973012ull, 9749110588329526103ull,
  9766498713100103671ull, 3520730300283449525ull}},
{{6658401815070078361ull, 7574702216984519725ull,
  16819809409802517493ull, 4400912875354311906ull}},
{{6467344143632492928ull, 7040031894829018780ull,
  15124066899553961337ull, 2750570547096444941ull}},
{{8084180179540616159ull, 13411725886963661379ull,
  5070025569160287959ull, 3438213183870556177ull}},
{{5493539205998382295ull, 12152971340277188820ull,
  10949217979877747853ull, 4297766479838195221ull}},
{{12656834040603764743ull, 9901450096886936964ull,
  9149104246637286360ull, 2686104049898872013ull}},
{{15821042550754705928ull, 12376812621108671205ull,
  16048066326723995854ull, 3357630062373590016ull}},
{{5941245133161218698ull, 6247643739531063199ull,
  1613338834695443202ull, 4197037577966987521ull}},
{{10630807235866843542ull, 8516463355634302403ull,
  12537551817753121761ull, 2623148486229367200ull}},
{{8676823026406166524ull, 15257265212970265908ull,
  15671939772191402201ull, 3278935607786709000ull}},
{{10846028783007708155ull, 5236523460930668673ull,
  1143180641529701136ull, 4098669509733386251ull}},
{{18307983035448287357ull, 3272827163081667920ull,
  16855388965451920874ull, 2561668443583366406ull}},
{{4438234720600807580ull, 13314405990706860709ull,
  11845864169960125284ull, 3202085554479208008ull}},
{{10159479419178397379ull, 16643007488383575886ull,
  14807330212450156605ull, 4002606943099010010ull}},
{{1737988618559110458ull, 12707722689453428881ull,
  13866267401208735782ull, 2501629339436881256ull}},
{{6784171791626275976ull, 6661281324962010293ull,
  17332834251510919728ull, 3127036674296101570ull}},
{{13091900757960232874ull, 8326601656202512866ull,
  12442670777533873852ull, 3908795842870126963ull}},
{{12794123992152533451ull, 14427498071981346349ull,
  5470826226744977205ull, 2442997401793829352ull}},
{{2157596934908503101ull, 4199314534694519225ull,
  6838532783431221507ull, 3053746752242286690ull}},
{{7308682187063016780ull, 637457149940761127ull,
  17771538016143802692ull, 3817183440302858362ull}},
{{11485455394555467344ull, 9621782755567751512ull,
  15718897278517264586ull, 2385739650189286476ull}},
{{14356819243194334180ull, 2803856407604913582ull,
  1201877524437029117ull, 2982174562736608096ull}},
{{8722652017138141917ull, 8116506527933529882ull,
  1502346905546286396ull, 3727718203420760120ull}},
{{10063343529138726602ull, 14296188616813231984ull,
  938966815966428997ull, 2329823877137975075ull}},
{{12579179411423408252ull, 4035177715734376268ull,
  15008766575240199959ull, 2912279846422468843ull}},
{{15723974264279260315ull, 432286126240582431ull,
  14149272200622862045ull, 3640349808028086054ull}},
{{15043281811921687490ull, 5152043676228115943ull,
  8463218213923801748ull, 4550437260035107568ull}},
{{16319580160092136537ull, 12443399334497348272ull,
  5289511383702376092ull, 2844023287521942230ull}},
{{1952731126405619056ull, 15554249168121685341ull,
  15835261266482745923ull, 3555029109402427787ull}},
{{7052599926434411724ull, 14831125441724718772ull,
  15182390564676044500ull, 4443786386753034734ull}},
{{13631246990876283135ull, 46081364223173424ull, 4877308084495139909ull,
  2777366491720646709ull}},
{{17039058738595353919ull, 4669287723706354684ull,
  10708321124046312790ull, 3471708114650808386ull}},
{{2852079349534640783ull, 15059981691487719164ull,
  4162029368203115179ull, 4339635143313510483ull}},
{{11005921630313926297ull, 7106645547966130525ull,
  295425345913253035ull, 2712271964570944052ull}},
{{18369088056319795776ull, 4271620916530275252ull,
  369281682391566294ull, 3390339955713680065ull}},
{{4514615996690193103ull, 14562898182517619874ull,
  5073288121416845771ull, 4237924944642100081ull}},
{{7433321016358758594ull, 6795968354859818469ull,
  14700020121953998367ull, 2648703090401312550ull}},
{{13903337288875836146ull, 3883274425147385182ull,
  9151653115587722151ull, 3310878863001640688ull}},
{{8155799574240019375ull, 242407013006843574ull,
  11439566394484652689ull, 4138598578752050860ull}},
{{485688715472624205ull, 11680719429197746994ull,
  16373101033407683738ull, 2586624111720031787ull}},
{{9830482931195556065ull, 5377527249642407934ull,
  15854690273332216769ull, 3233280139650039734ull}},
{{3064731627139669273ull, 11333595080480397822ull,
  10594990804810495153ull, 4041600174562549668ull}},
{{15750515322244457008ull, 165967897659166782ull,
  15845241289861335279ull, 2526000109101593542ull}},
{{10464772115950795451ull, 14042517927356122190ull,
  10583179575471893290ull, 3157500136376991928ull}},
{{3857593108083718506ull, 8329775372340376930ull,
  13228974469339866613ull, 3946875170471239910ull}},
{{7022681710979711970ull, 7511952616926429533ull,
  3656423024910028729ull, 2466796981544524944ull}},
{{13390038157152027867ull, 14001626789585424820ull,
  4570528781137535911ull, 3083496226930656180ull}},
{{16737547696440034834ull, 12890347468554393121ull,
  5713160976421919889ull, 3854370283663320225ull}},
{{3543438282633939915ull, 1138938140205413845ull,
  15099940656332169691ull, 2408981427289575140ull}},
{{9040983871719812798ull, 15258730730538931018ull,
  428181746705660497ull, 3011226784111968926ull}},
{{2077857802794990189ull, 5238355357891500061ull,
  9758599220236851430ull, 3764033480139961157ull}},
{{3604504135960562820ull, 17109030153964351250ull,
  8404967521861726095ull, 2352520925087475723ull}},
{{13729002206805479333ull, 16774601674028051158ull,
  5894523383899769715ull, 2940651156359344654ull}},
{{7937880721652073359ull, 16356566074107676044ull,
  16591526266729487952ull, 3675813945449180817ull}},
{{9922350902065091698ull, 1998963518925043439ull,
  6904349778129696229ull, 4594767431811476022ull}},
{{13118998341431764167ull, 3555195208541846101ull,
  18150276666613223855ull, 2871729644882172513ull}},
{{2563689871507541497ull, 18279052065959471339ull,
  8852787777984366106ull, 3589662056102715642ull}},
{{17039670394666590583ull, 13625443045594563365ull,
  1842612685625681825ull, 4487077570128394553ull}},
{{12955637005880313067ull, 1598372875855520247ull,
  12680847974584520901ull, 2804423481330246595ull}},
{{11582860238923003429ull, 6609652113246788213ull,
  11239373949803263222ull, 3505529351662808244ull}},
{{643517243371590575ull, 17485437178413261075ull,
  14049217437254079027ull, 4381911689578510305ull}},
{{16543099341603101773ull, 8622555227294594219ull,
  1863231870642717536ull, 2738694805986568941ull}},
{{16067188158576489313ull, 10778194034118242774ull,
  6940725856730784824ull, 3423368507483211176ull}},
{{10860613161365835833ull, 13472742542647803468ull,
  8675907320913481030ull, 4279210634354013970ull}},
{{16011255262708423204ull, 3808778070727489263ull,
  10034128093998313548ull, 2674506646471258731ull}},
{{15402383059958141100ull, 4760972588409361579ull,
  7930974099070504031ull, 3343133308089073414ull}},
{{14641292806520288471ull, 1339529717084314070ull,
  690345586983354231ull, 4178916635111341768ull}},
{{4539121985647792391ull, 7754735100818778150ull, 431465991864596394ull,
  2611822896944588605ull}},
{{14897274518914516296ull, 470046839168696879ull,
  5151018508258133397ull, 3264778621180735756ull}},
{{14009907130215757466ull, 5199244567388259003ull,
  6438773135322666746ull, 4080973276475919695ull}},
{{6450348947171154465ull, 7861213873045049781ull,
  10941762237217748572ull, 2550608297797449809ull}},
{{12674622202391330985ull, 9826517341306312226ull,
  18288888814949573619ull, 3188260372246812261ull}},
{{6619905716134387923ull, 7671460658205502379ull,
  9026052963404803312ull, 3985325465308515327ull}},
{{1831598063370298500ull, 4794662911378438987ull,
  12558812129769083926ull, 2490828415817822079ull}},
{{16124555634495036837ull, 15216700676077824541ull,
  11086829143783967003ull, 3113535519772277599ull}},
{{6320636487836632334ull, 14409189826669892773ull,
  9246850411302570850ull, 3891919399715346999ull}},
{{6256240814111589161ull, 13617429660096070887ull,
  12696810534705188637ull, 2432449624822091874ull}},
{{3208614999212098547ull, 3186729019837924897ull,
  6647641131526709989ull, 3040562031027614843ull}},
{{8622454767442511087ull, 8595097293224794025ull,
  3697865395980999582ull, 3800702538784518554ull}},
{{16918249275720039190ull, 760249789838108361ull,
  6922851890915512643ull, 2375439086740324096ull}},
{{7312753539367885275ull, 14785370292579799164ull,
  8653564863644390803ull, 2969298858425405120ull}},
{{9140941924209856594ull, 13870026847297361051ull,
  10816956079555488504ull, 3711623573031756400ull}},
{{3407245693417466419ull, 8668766779560850657ull,
  6760597549722180315ull, 2319764733144847750ull}},
{{8870743135199220928ull, 6224272456023675417ull,
  17674118974007501202ull, 2899705916431059687ull}},
{{15700114937426414064ull, 17003712606884370079ull,
  17480962699081988598ull, 3624632395538824609ull}},
{{15013457653355629676ull, 12031268721750686791ull,
  8016145318570322036ull, 4530790494423530762ull}},
{{16300940060988350403ull, 16742914987948955052ull,
  9621776842533839176ull, 2831744059014706726ull}},
{{1929431002525886388ull, 2481899661226642200ull,
  2803849016312523163ull, 3539680073768383408ull}},
{{2411788753157357985ull, 16937432631815466462ull,
  3504811270390653953ull, 4424600092210479260ull}},
{{15342426026005512453ull, 3668366367243584682ull,
  11413879080848934529ull, 2765375057631549537ull}},
{{9954660495652114758ull, 9197143977481868757ull, 432290795779004449ull,
  3456718822039436922ull}},
{{17055011637992531351ull, 16108115990279723850ull,
  9763735531578531369ull, 4320898527549296152ull}},
{{15271068292172719999ull, 3150043466283745550ull,
  6102334707236582106ull, 2700561579718310095ull}},
{{9865463328361124190ull, 13160926369709457746ull,
  3016232365618339728ull, 3375701974647887619ull}},
{{3108457123596629430ull, 16451157962136822183ull,
  17605348512305088372ull, 4219627468309859523ull}},
{{8860314729888975250ull, 1058601689480738056ull,
  8697499810976986281ull, 2637267167693662202ull}},
{{11075393412361219062ull, 5934938130278310474ull,
  1648502726866457043ull, 3296583959617077753ull}},
{{4620869728596748020ull, 2806986644420500189ull,
  6672314427010459208ull, 4120729949521347191ull}},
{{5193886589586661464ull, 1754366652762812618ull,
  11087725544522618861ull, 2575456218450841994ull}},
{{15715730273838102638ull, 6804644334380903676ull,
  4636284893798497768ull, 3219320273063552493ull}},
{{1197918768588076682ull, 8505805417976129596ull,
  10407042135675510114ull, 4024150341329440616ull}},
{{9972071267222323734ull, 9927814404662468901ull,
  6504401334797193821ull, 2515093963330900385ull}},
{{17076775102455292572ull, 17021454024255474030ull,
  12742187686923880180ull, 3143867454163625481ull}},
{{12122596841214339907ull, 2830073456609790922ull,
  2092676553372686514ull, 3929834317704531852ull}},
{{12188309044186350346ull, 6380481928808507230ull,
  10531294882712704879ull, 2456146448565332407ull}},
{{6012014268378162124ull, 3363916392583246134ull,
  8552432584963493195ull, 3070183060706665509ull}},
{{16738389872327478463ull, 18039953546011221379ull,
  15302226749631754397ull, 3837728825883331886ull}},
{{8155650660990980088ull, 13580813975470707314ull,
  4952205700092458594ull, 2398580516177082429ull}},
{{971191289383949301ull, 7752645432483608335ull,
  10801943143542961147ull, 2998225645221353036ull}},
{{15049047167012100339ull, 5079120772177122514ull,
  13502428929428701434ull, 3747782056526691295ull}},
{{14017340497809950616ull, 7786136501038089475ull,
  15356547108534020252ull, 2342363785329182059ull}},
{{12909989603835050366ull, 9732670626297611844ull,
  14583997867240137411ull, 2927954731661477574ull}},
{{16137487004793812957ull, 7554152264444626901ull,
  9006625297195395956ull, 3659943414576846968ull}},
{{6336800700710102484ull, 9442690330555783627ull,
  11258281621494244945ull, 4574929268221058710ull}},
{{1654657428730120101ull, 17430896502665834527ull,
  2424739995006515186ull, 2859330792638161694ull}},
{{15903379841194813838ull, 12565248591477517350ull,
  12254297030612919791ull, 3574163490797702117ull}},
{{10655852764638741489ull, 11094874720919508784ull,
  1482813232983986027ull, 4467704363497127647ull}},
{{6659907977899213431ull, 4628453691360999038ull,
  7844287298256073123ull, 2792315227185704779ull}},
{{17548257009228792597ull, 1173881095773860893ull,
  5193673104392703500ull, 3490394033982130974ull}},
{{8100263206253827034ull, 1467351369717326117ull,
  15715463417345655183ull, 4362992542477663717ull}},
{{7368507513122335848ull, 7834623633714410679ull,
  12128007645054728441ull, 2726870339048539823ull}},
{{4598948372975531906ull, 14404965560570401253ull,
  10548323537891022647ull, 3408587923810674779ull}},
{{10360371484646802786ull, 13394520932285613662ull,
  8573718403936390405ull, 4260734904763343474ull}},
{{1863546159476863838ull, 10677418591892202491ull,
  9970260020887631907ull, 2662959315477089671ull}},
{{16164490754628243509ull, 8735087221437865209ull,
  7851139007682151980ull, 3328699144346362089ull}},
{{6370555388003140674ull, 10918859026797331512ull,
  14425609778030077879ull, 4160873930432952611ull}},
{{3981597117501962922ull, 13741815919389414051ull,
  6710163102055104722ull, 2600546206520595382ull}},
{{365310378450065748ull, 7953897862381991756ull,
  17611075914423656711ull, 3250682758150744227ull}},
{{456637973062582185ull, 5330686309550101791ull,
  17402158874602182985ull, 4063353447688430284ull}},
{{7202927760805195722ull, 14860893989537283379ull,
  1652977259771588557ull, 2539595904805268928ull}},
{{4391973682579106748ull, 4741059431639440512ull,
  2066221574714485697ull, 3174494881006586160ull}},
{{5489967103223883435ull, 10538010307976688544ull,
  2582776968393107121ull, 3968118601258232700ull}},
{{3431229439514927147ull, 18115471488553900100ull,
  10837607642100467758ull, 2480074125786395437ull}},
{{4289036799393658933ull, 13420967323837599317ull,
  18158695571052972602ull, 3100092657232994296ull}},
{{9972982017669461571ull, 7552837117942223338ull,
  4251625390106664137ull, 3875115821541242871ull}},
{{10844799779470801386ull, 16249738244782359346ull,
  9574794896457746941ull, 2421947388463276794ull}},
{{4332627687483725924ull, 6477114750695785471ull,
  2745121583717407869ull, 3027434235579095993ull}},
{{804098590927269501ull, 12708079456797119743ull,
  8043087998074147740ull, 3784292794473869991ull}},
{{7420090646970625294ull, 17165921697352975647ull,
  11944459026437424193ull, 2365182996546168744ull}},
{{4663427290285893714ull, 7622344066409055847ull,
  14930573783046780242ull, 2956478745682710930ull}},
{{1217598094429979238ull, 304558046156544001ull, 9439845191953699495ull,
  3695598432103388663ull}},
{{12290213855087206784ull, 7107877806488921856ull,
  12817432272612144040ull, 2309749020064617914ull}},
{{15362767318859008480ull, 8884847258111152320ull,
  6798418303910404242ull, 2887186275080772393ull}},
{{756715074864208984ull, 1882687035784164593ull,
  13109708898315393207ull, 3608982843850965491ull}},
{{5557579862007649134ull, 16188416850012369453ull,
  11775450104466853604ull, 4511228554813706864ull}},
{{5779330422968474661ull, 894388494402955100ull, 7359656315291783503ull,
  2819517846758566790ull}},
{{7224163028710593326ull, 14953043673285857587ull,
  18422942430969505186ull, 3524397308448208487ull}},
{{4418517767460853753ull, 9467932554752546176ull,
  18416992020284493579ull, 4405496635560260609ull}},
{{2761573604663033596ull, 3611614837506647408ull,
  4593090985036726631ull, 2753435397225162881ull}},
{{3451967005828791995ull, 18349576602165472972ull,
  10353049749723296192ull, 3441794246531453601ull}},
{{4314958757285989993ull, 4490226678997289599ull,
  17552998205581508145ull, 4302242808164317001ull}},
{{9614378250944825602ull, 14335606720441775759ull,
  4053094850847360734ull, 2688901755102698126ull}},
{{7406286795253644098ull, 8696136363697443891ull,
  14289740600413976726ull, 3361127193878372657ull}},
{{4646172475639667219ull, 1646798417767029056ull,
  4027117695235307196ull, 4201408992347965822ull}},
{{2903857797274792012ull, 10252621047959168968ull,
  16352006614804230709ull, 2625880620217478638ull}},
{{3629822246593490015ull, 17427462328376349114ull,
  11216636231650512578ull, 3282350775271848298ull}},
{{13760649845096638326ull, 12560955873615660584ull,
  4797423252708364915ull, 4102938469089810373ull}},
{{8600406153185398954ull, 5544754411796093913ull,
  5304232542156422024ull, 2564336543181131483ull}},
{{15362193709909136597ull, 6930943014745117391ull,
  2018604659268139626ull, 3205420678976414354ull}},
{{14591056118959032842ull, 17887050805286172547ull,
  11746627860939950340ull, 4006775848720517942ull}},
{{6813567065135701574ull, 1956034716449082034ull,
  2729956394660081059ull, 2504234905450323714ull}},
{{17740330868274402776ull, 16280101450843516254ull,
  12635817530179877131ull, 3130293631812904642ull}},
{{12952041548488227661ull, 15738440795127007414ull,
  6571399875870070606ull, 3912867039766130803ull}},
{{3483339949377754385ull, 5224839478526991730ull,
  1801281913205100177ull, 2445541899853831752ull}},
{{13577546973576968789ull, 11142735366586127566ull,
  2251602391506375221ull, 3056927374817289690ull}},
{{7748561680116435178ull, 93361152950495746ull, 12037875026237744835ull,
  3821159218521612112ull}},
{{9454537068500159890ull, 16199251785089917505ull,
  7523671891398590521ull, 2388224511576007570ull}},
{{16429857354052587767ull, 6414006676080233169ull,
  181217827393462344ull, 2985280639470009463ull}},
{{6702263637283570996ull, 8017508345100291462ull,
  14061580339523991642ull, 3731600799337511828ull}},
{{18023972828584395585ull, 9622628734115070067ull,
  18011859749057270584ull, 2332250499585944892ull}},
{{17918280017303106577ull, 12028285917643837584ull,
  4068080612612036614ull, 2915313124482431116ull}},
{{3951105947919331605ull, 5811985360200021173ull,
  5085100765765045768ull, 3644141405603038895ull}},
{{9550568453326552410ull, 7264981700250026466ull,
  1744689938778919306ull, 4555176757003798619ull}},
{{10580791301756483160ull, 9152299581083654445ull,
  17231332276232682230ull, 2846985473127374136ull}},
{{17837675145622991854ull, 2217002439499792248ull,
  3092421271581301172ull, 3558731841409217671ull}},
{{3850349858319188202ull, 2771253049374740311ull,
  17700584644758790177ull, 4448414801761522088ull}},
{{9323997689090574482ull, 13261248201927682454ull,
  11062865402974243860ull, 2780259251100951305ull}},
{{2431625074508442295ull, 16576560252409603068ull,
  18440267772145192729ull, 3475324063876189131ull}},
{{3039531343135552868ull, 6885642260229840123ull,
  18438648696754103008ull, 4344155079845236414ull}},
{{18040608153955578207ull, 4303526412643650076ull,
  6912469417043926476ull, 2715096924903272759ull}},
{{4104016118734921143ull, 5379408015804562596ull,
  4028900752877520191ull, 3393871156129090949ull}},
{{5130020148418651428ull, 2112574001328315341ull,
  9647811959524288143ull, 4242338945161363686ull}},
{{5512105601975351095ull, 8237887778471278944ull,
  1418196456275292185ull, 2651461840725852304ull}},
{{6890132002469188868ull, 14909045741516486584ull,
  1772745570344115231ull, 3314327300907315380ull}},
{{8612665003086486085ull, 14024621158468220326ull,
  2215931962930144039ull, 4142909126134144225ull}},
{{771229608501665900ull, 15682917251683719560ull,
  12914172522899809784ull, 2589318203833840140ull}},
{{964037010627082374ull, 1156902490895097834ull,
  16142715653624762231ull, 3236647754792300175ull}},
{{10428418300138628776ull, 15281186168901036004ull,
  15566708548603564884ull, 4045809693490375219ull}},
{{15741133474441418793ull, 327369318708371694ull,
  7423349833663534101ull, 2528631058431484512ull}},
{{10453044806196997683ull, 5020897666812852522ull,
  9279187292079417626ull, 3160788823039355640ull}},
{{3842933970891471296ull, 15499494120370841461ull,
  11598984115099272032ull, 3950986028799194550ull}},
{{4707676741020863512ull, 9687183825231775913ull,
  2637679053509657116ull, 2469366267999496594ull}},
{{10496281944703467294ull, 12108979781539719891ull,
  12520470853741847203ull, 3086707834999370742ull}},
{{8508666412451946213ull, 10524538708497261960ull,
  6427216530322533196ull, 3858384793749213428ull}},
{{5317916507782466383ull, 15801208729665564533ull,
  13240382368306359055ull, 2411490496093258392ull}},
{{11259081653155470883ull, 15139824893654567762ull,
  16550477960382948819ull, 3014363120116572990ull}},
{{4850480029589562796ull, 14313095098640821799ull,
  11464725413623910216ull, 3767953900145716238ull}},
{{9949079046134558604ull, 8945684436650513624ull,
  2553767365087555981ull, 2354971187591072649ull}},
{{12436348807668198254ull, 15793791564240529934ull,
  7803895224786832880ull, 2943713984488840811ull}},
{{6322063972730472010ull, 1295495381591110802ull,
  5143183012556153197ull, 3679642480611051014ull}},
{{17125952002767865820ull, 6231055245416276406ull,
  15652350802549967304ull, 4599553100763813767ull}},
{{6092033983302528234ull, 3894409528385172754ull,
  16700248279234811421ull, 2874720687977383604ull}},
{{16838414515982936100ull, 9479697928908853846ull,
  2428566275333962660ull, 3593400859971729506ull}},
{{11824646108123894317ull, 11849622411136067308ull,
  12259079881022229133ull, 4491751074964661882ull}},
{{16613775854432209756ull, 9711857016173736019ull,
  12273610944066281112ull, 2807344421852913676ull}},
{{16155533799612874291ull, 12139821270217170024ull,
  15342013680082851390ull, 3509180527316142095ull}},
{{1747673175806541248ull, 5951404550916686723ull,
  14565831081676176334ull, 4386475659145177619ull}},
{{17233196799374945944ull, 17554685899605092913ull,
  6797801416833916256ull, 2741547286965736012ull}},
{{7706437943936518718ull, 3496613300796814526ull,
  8497251771042395321ull, 3426934108707170015ull}},
{{409675393065872590ull, 8982452644423406062ull, 6009878695375606247ull,
  4283667635883962519ull}},
{{14091105175948334081ull, 12531561930405710644ull,
  10673703212250835760ull, 2677292272427476574ull}},
{{17613881469935417601ull, 15664452413007138305ull,
  4118756978458768892ull, 3346615340534345718ull}},
{{8182293782137108289ull, 1133821442549371266ull,
  14371818259928236924ull, 4183269175667932147ull}},
{{9725619632263080585ull, 9932010438448132849ull,
  6676543403241454125ull, 2614543234792457592ull}},
{{16768710558756238635ull, 17026699066487553965ull,
  8345679254051817656ull, 3268179043490571990ull}},
{{7125830143163134581ull, 2836629759399890841ull,
  1208727030709996263ull, 4085223804363214988ull}},
{{15982858885545428873ull, 8690422627266013631ull,
  9978826431048523472ull, 2553264877727009367ull}},
{{15366887588504398188ull, 10863028284082517039ull,
  7861847020383266436ull, 3191581097158761709ull}},
{{14596923467203109831ull, 13578785355103146299ull,
  14438994793906470949ull, 3989476371448452136ull}},
{{6817234157788249692ull, 10792583856153160389ull,
  9024371746191544343ull, 2493422732155282585ull}},
{{13133228715662700019ull, 8879043801764062582ull,
  15892150701166818333ull, 3116778415194103231ull}},
{{7193163857723599216ull, 15710490770632466132ull,
  15253502358031135012ull, 3895973018992629039ull}},
{{13719099447932025318ull, 595684694790515524ull,
  16450968001410541239ull, 2434983136870393149ull}},
{{17148874309915031648ull, 14579663923770308117ull,
  6728651946481012836ull, 3043728921087991437ull}},
{{7601034832111625847ull, 18224579904712885147ull,
  13022500951528653949ull, 3804661151359989296ull}},
{{2444803760856072203ull, 13696205449659247169ull,
  8139063094705408718ull, 2377913219599993310ull}},
{{7667690719497478157ull, 7896884775219283153ull, 950456831526985090ull,
  2972391524499991638ull}},
{{14196299417799235600ull, 647733932169328133ull,
  10411443076263507171ull, 3715489405624989547ull}},
{{11178530145338216202ull, 16545734772101687747ull,
  4201308913450998029ull, 2322180878515618467ull}},
{{9361476663245382349ull, 6847110409844945972ull, 639950123386359633ull,
  2902726098144523084ull}},
{{11701845829056727936ull, 13170574030733570369ull,
  799937654232949541ull, 3628407622680653855ull}},
{{792249231038746208ull, 2628159483134799250ull,
  14834980123073350639ull, 4535509528350817318ull}},
{{5106841787826604284ull, 8560128704600331387ull,
  4660176558493456245ull, 2834693455219260824ull}},
{{1771866216355867451ull, 15311846899177802138ull,
  5825220698116820306ull, 3543366819024076030ull}},
{{11438204807299610122ull, 9916436587117476864ull,
  16504897909500801191ull, 4429208523780095037ull}},
{{7148878004562256326ull, 13115301894589504896ull,
  12621404202651694696ull, 2768255327362559398ull}},
{{8936097505702820408ull, 16394127368236881120ull,
  6553383216459842562ull, 3460319159203199248ull}},
{{11170121882128525510ull, 11269287173441325592ull,
  8191729020574803203ull, 4325398949003999060ull}},
{{6981326176330328444ull, 4737461474187134543ull,
  14343202674714027810ull, 2703374343127499412ull}},
{{4114971701985522650ull, 15145198879588693987ull,
  17929003343392534762ull, 3379217928909374265ull}},
{{532028609054515409ull, 9708126562631091676ull, 8576196123958504741ull,
  4224022411136717832ull}},
{{9555889917513847939ull, 8373422110858126249ull,
  5360122577474065463ull, 2640014006960448645ull}},
{{16556548415319697827ull, 5855091620145269907ull,
  11311839240269969733ull, 3300017508700560806ull}},
{{16083999500722234380ull, 11930550543608975288ull,
  4916427013482686358ull, 4125021885875701008ull}},
{{10052499687951396488ull, 2844908071328221651ull,
  3072766883426678974ull, 2578138678672313130ull}},
{{7953938591511857706ull, 12779507126015052872ull,
  13064330641138124525ull, 3222673348340391412ull}},
{{9942423239389822132ull, 2139325852236652378ull,
  16330413301422655657ull, 4028341685425489265ull}},
{{10825700543046026737ull, 12866293703716377496ull,
  3288979285748077929ull, 2517713553390930791ull}},
{{13532125678807533421ull, 2247809074363308158ull,
  17946282162467261124ull, 3147141941738663488ull}},
{{7691785061654640968ull, 2809761342954135198ull,
  3986108629374524789ull, 3933927427173329361ull}},
{{195679645106762701ull, 4061943848560028451ull,
  14020532939427547753ull, 2458704641983330850ull}},
{{14079657611665617088ull, 9689115829127423467ull,
  8302294137429658883ull, 3073380802479163563ull}},
{{12987885996154633456ull, 7499708767981891430ull,
  5766181653359685700ull, 3841726003098954454ull}},
{{3505742729169258006ull, 13910690016843457952ull,
  17438921588631967274ull, 2401078751936846533ull}},
{{4382178411461572508ull, 8164990484199546632ull,
  7963593930507795381ull, 3001348439921058167ull}},
{{5477723014326965634ull, 14817924123676821194ull,
  5342806394707356322ull, 3751685549901322709ull}},
{{8035262902381741426ull, 13872888595725401150ull,
  5645097005905791653ull, 2344803468688326693ull}},
{{820706591122400974ull, 3506052689374587726ull,
  11668057275809627471ull, 2931004335860408366ull}},
{{10249255275757777025ull, 18217623917000398369ull,
  5361699557907258530ull, 3663755419825510458ull}},
{{17423255113124609185ull, 13548657859395722153ull,
  15925496484238848971ull, 4579694274781888072ull}},
{{3972005418061798885ull, 6162068152908632394ull,
  9953435302649280607ull, 2862308921738680045ull}},
{{14188378809432024414ull, 3090899172708402588ull,
  17053480146738988663ull, 3577886152173350056ull}},
{{17735473511790030518ull, 17698682021167666947ull,
  2870106109714184212ull, 4472357690216687571ull}},
{{8778827935655075122ull, 1838304226375016034ull,
  17934717383067222797ull, 2795223556385429731ull}},
{{1750162882714068094ull, 6909566301396157947ull,
  17806710710406640592ull, 3494029445481787164ull}},
{{16022761658674748829ull, 8636957876745197433ull,
  3811644314298749124ull, 4367536806852233956ull}},
{{3096697009030636163ull, 14621470709820524204ull,
  11605649733291494010ull, 2729710504282646222ull}},
{{3870871261288295203ull, 9053466350420879447ull,
  5283690129759591705ull, 3412138130353307778ull}},
{{226903058182981100ull, 15928518956453487213ull,
  15827984699054265439ull, 4265172662941634722ull}},
{{2447657420578057140ull, 16872853375424511364ull,
  14504176455336303803ull, 2665732914338521701ull}},
{{3059571775722571424ull, 16479380700853251301ull,
  4295162513888216042ull, 3332166142923152127ull}},
{{8436150738080602184ull, 11375853839211788318ull,
  757267123932882149ull, 4165207678653940159ull}},
{{660908192872988461ull, 9415751658721061651ull, 7390820980099133199ull,
  2603254799158712599ull}},
{{14661193296373399289ull, 7158003554973939159ull,
  4626840206696528595ull, 3254068498948390749ull}},
{{13714805602039361207ull, 4335818425290036045ull,
  10395236276798048648ull, 4067585623685488436ull}},
{{10877596510488294706ull, 2709886515806272528ull,
  15720394709853556213ull, 2542241014803430272ull}},
{{13596995638110368383ull, 7999044163185228564ull,
  1203749313607393650ull, 3177801268504287841ull}},
{{16996244547637960478ull, 775433167126759897ull,
  6116372660436629967ull, 3972251585630359801ull}},
{{3705123814632643443ull, 7402174757095306792ull,
  15351947958841363489ull, 2482657241018974875ull}},
{{4631404768290804304ull, 13864404464796521394ull,
  14578248930124316457ull, 3103321551273718594ull}},
{{15012627997218281188ull, 3495447525713488030ull,
  8999439125800619764ull, 3879151939092148243ull}},
{{4771206479834037838ull, 11408026740425705827ull,
  3318806444411693400ull, 2424469961932592652ull}},
{{1352322081365159394ull, 14260033425532132284ull,
  4148508055514616750ull, 3030587452415740815ull}},
{{1690402601706449242ull, 8601669745060389547ull, 573949050965883034ull,
  3788234315519676019ull}},
{{17197402690562388441ull, 9987729609090131370ull,
  16499619221349534560ull, 2367646447199797511ull}},
{{12273381326348209743ull, 12484662011362664213ull,
  16012838008259530296ull, 2959558058999746889ull}},
{{1506668602653098466ull, 15605827514203330267ull,
  6180989455042249158ull, 3699447573749683612ull}},
{{17082568941154044206ull, 5141956177949693512ull,
  13086490446256181532ull, 2312154733593552257ull}},
{{2906467102733003641ull, 6427445222437116891ull,
  2523055002538063203ull, 2890193416991940322ull}},
{{17468141933698418263ull, 3422620509619008209ull,
  12377190790027354812ull, 3612741771239925402ull}},
{{8000119361840859116ull, 4278275637023760262ull,
  6248116450679417707ull, 4515927214049906753ull}},
{{388388582723149044ull, 368079263926156212ull, 15434287827743105827ull,
  2822454508781191720ull}},
{{485485728403936305ull, 14295157135189858977ull, 846115710969330667ull,
  3528068135976489651ull}},
{{5218543178932308285ull, 13257260400559935817ull,
  14892702693993827046ull, 4410085169970612063ull}},
{{14790804532901162438ull, 3674101731922571981ull,
  16225468211387223760ull, 2756303231231632539ull}},
{{4653447610844289336ull, 4592627164903214977ull,
  15670149245806641796ull, 3445379039039540674ull}},
{{10428495531982749574ull, 5740783956129018721ull,
  10364314520403526437ull, 4306723798799425843ull}},
{{18047024753557688244ull, 5893832981794330652ull,
  4171853566038510071ull, 2691702374249641152ull}},
{{4112036868237558688ull, 2755605208815525412ull,
  5214816957548137589ull, 3364627967812051440ull}},
{{5140046085296948360ull, 8056192529446794669ull,
  6518521196935171986ull, 4205784959765064300ull}},
{{5518371812524286677ull, 9646806349331634572ull,
  13297447784939258299ull, 2628615599853165187ull}},
{{6897964765655358347ull, 7446821918237155311ull,
  12010123712746684970ull, 3285769499816456484ull}},
{{4010769938641810029ull, 85155360941668331ull, 15012654640933356213ull,
  4107211874770570605ull}},
{{200888202437437316ull, 2359065109802236659ull,
  11688752159797041585ull, 2567007421731606628ull}},
{{14086168308328960357ull, 7560517405680183727ull,
  14610940199746301981ull, 3208759277164508285ull}},
{{12996024366983812543ull, 14062332775527617563ull,
  4428617194400713764ull, 4010949096455635357ull}},
{{5816672220151188887ull, 18012330021559536785ull,
  5073728755714140054ull, 2506843185284772098ull}},
{{11882526293616374013ull, 13292040490094645173ull,
  15565532981497450876ull, 3133553981605965122ull}},
{{1018099811738303804ull, 16615050612618306467ull,
  10233544190017037787ull, 3916942477007456403ull}},
{{16777213446832297542ull, 8078563623672747589ull,
  4090122109546954665ull, 2448089048129660252ull}},
{{7136458753258208215ull, 14709890548018322391ull,
  5112652636933693331ull, 3060111310162075315ull}},
{{4308887423145372365ull, 13775677166595515085ull,
  1779129777739728760ull, 3825139137702594144ull}},
{{4998897648679551680ull, 8609798229122196928ull,
  1111956111087330475ull, 2390711961064121340ull}},
{{6248622060849439600ull, 6150561767975358256ull,
  1389945138859163094ull, 2988389951330151675ull}},
{{7810777576061799500ull, 16911574246823973628ull,
  15572489478856117579ull, 3735487439162689593ull}},
{{14105108021893400496ull, 8263890895051289565ull,
  2815276896643991631ull, 2334679649476680996ull}},
{{3796326972084586908ull, 5718177600386724053ull,
  3519096120804989539ull, 2918349561845851245ull}},
{{9357094733533121538ull, 2536035982056017162ull,
  9010556169433624828ull, 3647936952307314056ull}},
{{2472996380061626115ull, 3170044977570021453ull,
  11263195211792031035ull, 4559921190384142570ull}},
{{3851465746752210274ull, 18122179175477121072ull,
  11651183025797407300ull, 2849950743990089106ull}},
{{4814332183440262842ull, 4205979895636849724ull,
  5340606745391983318ull, 3562438429987611383ull}},
{{6017915229300328553ull, 14480846906400837963ull,
  2064072413312591243ull, 4453048037484514229ull}},
{{1455354009099011394ull, 6744686307286829775ull,
  3595888267534063479ull, 2783155023427821393ull}},
{{15654250566655927954ull, 3819171865681149314ull,
  9106546352844967253ull, 3478943779284776741ull}},
{{10344441171465134134ull, 9385650850528824547ull,
  15994868959483596970ull, 4348679724105970926ull}},
{{4159432722952014882ull, 10477717800007903246ull,
  5385107081249860202ull, 2717924827566231829ull}},
{{14422662940544794410ull, 3873775213155103249ull,
  11343069869989713157ull, 3397406034457789786ull}},
{{4193270620398829301ull, 9453905034871266966ull,
  4955465300632365638ull, 4246757543072237233ull}},
{{16455852193031432025ull, 1297004628367153949ull,
  14626380858963698284ull, 2654223464420148270ull}},
{{6734757186007126319ull, 1621255785458942437ull,
  9059604036849847047ull, 3317779330525185338ull}},
{{13030132500936295803ull, 15861627787105841758ull,
  2101133009207533000ull, 4147224163156481673ull}},
{{3532146794657796973ull, 9913517366941151099ull,
  12842423176823177885ull, 2592015101972801045ull}},
{{18250241548604409928ull, 17003582727103826777ull,
  2217970915746808644ull, 3240018877466001307ull}},
{{8977743880473348698ull, 2807734335170231856ull,
  16607521699965674518ull, 4050023596832501633ull}},
{{5611089925295842937ull, 15589892014763558622ull,
  3462172034837464717ull, 2531264748020313521ull}},
{{16237234443474579479ull, 5652306963172284565ull,
  8939401061974218801ull, 3164080935025391901ull}},
{{6461484999061060636ull, 11677069722392743611ull,
  15785937345895161405ull, 3955101168781739876ull}},
{{1732585115199468946ull, 9604011585709158709ull, 642838804329700070ull,
  2471938230488587423ull}},
{{6777417412426724086ull, 2781642445281672578ull,
  14638606560694288800ull, 3089922788110734278ull}},
{{17695143802388180916ull, 3477053056602090722ull,
  9074886164013085192ull, 3862403485138417848ull}},
{{15671150894920000976ull, 2173158160376306701ull,
  5671803852508178245ull, 2414002178211511155ull}},
{{5753880563367837508ull, 7328133718897771281ull,
  2478068797207834902ull, 3017502722764388944ull}},
{{11804036722637184789ull, 18383539185476989909ull,
  3097585996509793627ull, 3771878403455486180ull}},
{{9683365960861934446ull, 9183868981709424741ull,
  11159363284673396825ull, 2357424002159678862ull}},
{{16715893469504805961ull, 16091522245564168830ull,
  4725832068986970223ull, 2946780002699598578ull}},
{{11671494800026231643ull, 15502716788527823134ull,
  15130662123088488587ull, 3683475003374498222ull}},
{{5365996463178013746ull, 14766709967232391014ull,
  9689955617005834926ull, 4604343754218122778ull}},
{{17188805844768422303ull, 4617507711092856479ull,
  10667908279056034733ull, 2877714846386326736ull}},
{{16874321287533139975ull, 10383570657293458503ull,
  13334885348820043416ull, 3597143557982908420ull}},
{{16481215590989037064ull, 12979463321616823129ull,
  16668606686025054270ull, 4496429447478635525ull}},
{{3383230716727066309ull, 3500478557583126552ull,
  12723722187979352871ull, 2810268404674147203ull}},
{{4229038395908832887ull, 18210656252261071902ull,
  11292966716546803184ull, 3512835505842684004ull}},
{{14509670031740816916ull, 4316576241616788261ull,
  14116208395683503981ull, 4391044382303355005ull}},
{{11374386779051704525ull, 5003703160224186615ull,
  11128473256515883940ull, 2744402738939596878ull}},
{{9606297455387242752ull, 6254628950280233269ull,
  4687219533790079117ull, 3430503423674496098ull}},
{{16619557837661441344ull, 12429972206277679490ull,
  15082396454092374704ull, 4288129279593120122ull}},
{{14998909666965788744ull, 7768732628923549681ull,
  14038183802235122094ull, 2680080799745700076ull}},
{{4913579028425072218ull, 487543749299661294ull,
  17547729752793902618ull, 3350100999682125095ull}},
{{15365345822386116080ull, 9832801723479352425ull,
  17322976172564990368ull, 4187626249602656369ull}},
{{2685812111350240694ull, 6145501077174595266ull,
  3909331080212037124ull, 2617266406001660231ull}},
{{12580637176042576676ull, 7681876346468244082ull,
  274977831837658501ull, 3271583007502075289ull}},
{{6502424433198445037ull, 14214031451512693007ull,
  4955408308224461030ull, 4089478759377594111ull}},
{{10981544298390110004ull, 4272083638768045225ull,
  10014659220281370000ull, 2555924224610996319ull}},
{{18338616391415025409ull, 5340104548460056531ull,
  7906638006924324596ull, 3194905280763745399ull}},
{{18311584470841393857ull, 6675130685575070664ull,
  5271611490228017841ull, 3993631600954681749ull}},
{{11444740294275871161ull, 15701171724552888925ull,
  5600600190606205102ull, 2496019750596676093ull}},
{{470867312562675239ull, 10403092618836335349ull,
  11612436256685144282ull, 3120024688245845116ull}},
{{5200270159130731953ull, 3780493736690643378ull,
  14515545320856430353ull, 3900030860307306395ull}},
{{7861854867884095375ull, 13892023631500121871ull,
  6766372816321575018ull, 2437519287692066497ull}},
{{5215632566427731314ull, 8141657502520376531ull,
  13069652038829356677ull, 3046899109615083121ull}},
{{1907854689607276238ull, 14788757896577858568ull,
  2502006993254532134ull, 3808623887018853902ull}},
{{1192409181004547649ull, 4631287666933773701ull,
  15398812426066246296ull, 2380389929386783688ull}},
{{6102197494683072465ull, 5789109583667217126ull, 801771458873256254ull,
  2975487411733479611ull}},
{{16851118905208616390ull, 16459759016438797215ull,
  14837272378873734029ull, 3719359264666849513ull}},
{{17449478343396467100ull, 12593192394487942211ull,
  2355766209155001912ull, 2324599540416780946ull}},
{{17200161910818195970ull, 15741490493109927764ull,
  12168079798298528198ull, 2905749425520976182ull}},
{{3053458314813193347ull, 10453491079532633898ull,
  5986727711018384440ull, 3632186781901220228ull}},
{{13040194930371267492ull, 13066863849415792372ull,
  7483409638772980550ull, 4540233477376525285ull}},
{{17373493868336817990ull, 3555103887457482328ull,
  6982974033446806796ull, 2837645923360328303ull}},
{{3270123261711470872ull, 4443879859321852911ull,
  4117031523381120591ull, 3547057404200410379ull}},
{{17922712132421502302ull, 943163805724928234ull, 534603385799012835ull,
  4433821755250512974ull}},
{{15813381101190826843ull, 16730378443073937810ull,
  14169185171406546733ull, 2771138597031570608ull}},
{{10543354339633757745ull, 7077914998560258551ull,
  17711481464258183417ull, 3463923246289463260ull}},
{{8567506906114809278ull, 13459079766627711093ull,
  3692607756613177655ull, 4329904057861829076ull}},
{{7660534825535449751ull, 15329453881783401289ull,
  11531251884738011842ull, 2706190036163643172ull}},
{{14187354550346700092ull, 9938445315374475803ull,
  14414064855922514803ull, 3382737545204553965ull}},
{{13122507169505987211ull, 7811370625790706850ull,
  4182523014620979792ull, 4228421931505692457ull}},
{{12813252999368629911ull, 4882106641119191781ull,
  14143291930206582130ull, 2642763707191057785ull}},
{{2181508193928623677ull, 15326005338253765535ull,
  3844056857476063950ull, 3303454633988822232ull}},
{{16561943297692943308ull, 9934134635962431110ull,
  4805071071845079938ull, 4129318292486027790ull}},
{{5739528542630701664ull, 10820520165903907348ull,
  16838227475185338673ull, 2580823932803767368ull}},
{{7174410678288377079ull, 18137336225807272089ull,
  2601040270272121725ull, 3226029916004709211ull}},
{{13579699366287859253ull, 8836612226976926399ull,
  17086358393122315869ull, 4032537395005886513ull}},
{{15404841131570993889ull, 7828725651074272951ull,
  3761444968060365562ull, 2520335871878679071ull}},
{{14644365396036354458ull, 562535026988065381ull, 90120191648069049ull,
  3150419839848348839ull}},
{{4470398689763279360ull, 5314854802162469631ull,
  13947708294842250023ull, 3938024799810436048ull}},
{{9711528208743131456ull, 10239313278992625375ull,
  8717317684276406264ull, 2461265499881522530ull}},
{{7527724242501526416ull, 12799141598740781719ull,
  1673275068490732022ull, 3076581874851903163ull}},
{{4797969284699520116ull, 6775554961571201341ull,
  15926651890895578740ull, 3845727343564878953ull}},
{{5304573812150894025ull, 13458093887836776646ull,
  3036628404168654856ull, 2403579589728049346ull}},
{{15854089302043393339ull, 16822617359795970807ull,
  13019157542065594378ull, 3004474487160061682ull}},
{{15205925609126853769ull, 11804899662890187701ull,
  7050574890727217165ull, 3755593108950077103ull}},
{{11809546514917977558ull, 9683905298520061265ull,
  11324138334345592584ull, 2347245693093798189ull}},
{{926875088365308235ull, 12104881623150076582ull, 320114862649827018ull,
  2934057116367247737ull}},
{{10381965897311411102ull, 5907729992082819919ull,
  5011829596739671677ull, 3667571395459059671ull}},
{{8365771353211875973ull, 11996348508530912803ull,
  1653100977497201692ull, 4584464244323824589ull}},
{{2922764086543728532ull, 16721089854686596310ull,
  3339031120149445009ull, 2865290152702390368ull}},
{{12876827145034436472ull, 7066304263076081675ull,
  4173788900186806262ull, 3581612690877987960ull}},
{{11484347912865657686ull, 18056252365699877902ull,
  5217236125233507827ull, 4477015863597484950ull}},
{{2566031427113648150ull, 8979314719348729737ull,
  17095830633553106104ull, 2798134914748428093ull}},
{{7819225302319448092ull, 11224143399185912171ull,
  7534730236659218918ull, 3497668643435535117ull}},
{{5162345609471922210ull, 4806807212127614406ull,
  14030098814251411552ull, 4372085804294418896ull}},
{{17061524061202115094ull, 3004254507579759003ull,
  8768811758907132220ull, 2732553627684011810ull}},
{{16715219058075255963ull, 3755318134474698754ull,
  1737642661779139467ull, 3415692034605014763ull}},
{{11670651785739294145ull, 82461649665985539ull,
  16007111382506088046ull, 4269615043256268453ull}},
{{4988314356873364889ull, 13886596586323404674ull,
  12310287623279998980ull, 2668509402035167783ull}},
{{15458764982946481919ull, 17358245732904255842ull,
  10776173510672610821ull, 3335636752543959729ull}},
{{10100084191828326591ull, 7862749110848156091ull,
  18081902906768151431ull, 4169545940679949661ull}},
{{4006709610679010168ull, 11831747221921179413ull,
  13607032325943788596ull, 2605966212924968538ull}},
{{9620073031776150613ull, 14789684027401474266ull,
  7785418370574959937ull, 3257457766156210673ull}},
{{2801719252865412459ull, 4652046978969679121ull,
  14343458981646087826ull, 4071822207695263341ull}},
{{13280289579109352547ull, 7519215380283437354ull,
  11270504872742498843ull, 2544888879809539588ull}},
{{7376989937031914875ull, 4787333206926908789ull,
  14088131090928123554ull, 3181111099761924485ull}},
{{13832923439717281498ull, 15207538545513411794ull,
  3775105808377990730ull, 3976388874702405607ull}},
{{13257263168250688840ull, 14116397609373270275ull,
  9276970157877326062ull, 2485243046689003504ull}},
{{11959892941885973146ull, 8422124974861812036ull,
  11596212697346657578ull, 3106553808361254380ull}},
{{14949866177357466433ull, 1304284181722489237ull,
  14495265871683321973ull, 3883192260451567975ull}},
{{11649509370062110473ull, 3121020622790249725ull,
  15977070197443158089ull, 2426995162782229984ull}},
{{726828657295474379ull, 8512961796915200061ull, 1524593673094395995ull,
  3033743953477787481ull}},
{{5520221840046730877ull, 6029516227716612172ull,
  6517428109795382898ull, 3792179941847234351ull}},
{{12673510686883982607ull, 8380133660750270511ull,
  10990921596263196167ull, 2370112463654521469ull}},
{{11230202340177590354ull, 5863481057510450235ull,
  18350338013756383113ull, 2962640579568151836ull}},
{{9426066906794600038ull, 11941037340315450698ull,
  4491178443485927275ull, 3703300724460189796ull}},
{{10502977835174012928ull, 5157305328483462734ull,
  12030358564033480355ull, 2314562952787618622ull}},
{{3905350257112740352ull, 1834945642176940514ull,
  5814576168187074636ull, 2893203690984523278ull}},
{{14105059858245701248ull, 2293682052721175642ull,
  16491592247088619103ull, 3616504613730654097ull}},
{{8407952785952350752ull, 16702160621183633265ull,
  6779432253578610166ull, 4520630767163317622ull}},
{{16784185537288688980ull, 5827164369812382886ull,
  18072203213768795066ull, 2825394229477073513ull}},
{{11756859884756085417ull, 16507327499120254416ull,
  8755195961928830120ull, 3531742786846341892ull}},
{{14696074855945106771ull, 2187415300190766404ull,
  10943994952411037651ull, 4414678483557927365ull}},
{{18408418821820467540ull, 17508035627115086666ull,
  9145839854470592483ull, 2759174052223704603ull}},
{{13787151490420808617ull, 17273358515466470429ull,
  6820613799660852700ull, 3448967565279630754ull}},
{{3398881307743847059ull, 3144954070623536421ull,
  17749139286430841684ull, 4311209456599538442ull}},
{{4430143826553598364ull, 11188968330994486071ull,
  15704898072446663956ull, 2694505910374711526ull}},
{{925993764764610051ull, 13986210413743107589ull,
  10407750553703554137ull, 3368132387968389408ull}},
{{5769178224383150468ull, 3647704961896720774ull,
  13009688192129442672ull, 4210165484960486760ull}},
{{17440794445521632755ull, 2279815601185450483ull,
  8131055120080901670ull, 2631353428100304225ull}},
{{17189307038474653039ull, 12073141538336588912ull,
  14775504918528514991ull, 3289191785125380281ull}},
{{3039889724383764683ull, 10479740904493348237ull,
  4634323092878480027ull, 4111489731406725352ull}},
{{4205774086953546879ull, 4243995056094648696ull,
  2896451933049050017ull, 2569681082129203345ull}},
{{5257217608691933599ull, 9916679838545698774ull,
  8232250934738700425ull, 3212101352661504181ull}},
{{15794894047719692806ull, 17007535816609511371ull,
  14901999686850763435ull, 4015126690826880226ull}},
{{7565965770611114052ull, 8323866876167250655ull,
  13925435822709115051ull, 2509454181766800141ull}},
{{4845771194836504661ull, 5793147576781675415ull,
  3571736723104230102ull, 3136817727208500177ull}},
{{1445527975118242922ull, 16464806507831870077ull,
  9076356922307675531ull, 3921022159010625221ull}},
{{3209297993662595778ull, 7984661058181224846ull,
  7978566085655991159ull, 2450638849381640763ull}},
{{13234994528933020531ull, 5369140304299143153ull,
  5361521588642601045ull, 3063298561727050954ull}},
{{2708685105884111951ull, 11323111398801316846ull,
  15925274022658027114ull, 3829123202158813692ull}},
{{15527986246459733682ull, 11688630642678210932ull,
  729924227306491138ull, 2393202001349258558ull}},
{{963238734365115486ull, 5387416266492987858ull,
  10135777320987889731ull, 2991502501686573197ull}},
{{10427420454811170166ull, 2122584314688846918ull,
  17281407669662250068ull, 3739378127108216496ull}},
{{1905451765829593450ull, 10549987233535305132ull,
  10800879793538906292ull, 2337111329442635310ull}},
{{2381814707286991812ull, 13187484041919131415ull,
  4277727705068857057ull, 2921389161803294138ull}},
{{16812326439390903477ull, 2649296997116750556ull,
  14570531668190847130ull, 3651736452254117672ull}},
{{2568663975529077730ull, 12534993283250714004ull,
  18213164585238558912ull, 4564670565317647090ull}},
{{10828787021560449389ull, 7834370802031696252ull,
  15994913884201487224ull, 2852919103323529431ull}},
{{13535983776950561737ull, 9792963502539620315ull,
  15381956336824471126ull, 3566148879154411789ull}},
{{12308293702760814267ull, 3017832341319749586ull,
  5392387365748425196ull, 4457686098943014737ull}},
{{12304369582652896821ull, 11109517250179619299ull,
  14899457149661235507ull, 2786053811839384210ull}},
{{10768775959888733122ull, 9275210544297136220ull,
  9400949400221768576ull, 3482567264799230263ull}},
{{13460969949860916402ull, 11594013180371420275ull,
  7139500731849822816ull, 4353209080999037829ull}},
{{6107263209449378800ull, 7246258237732137672ull,
  6768030966619833212ull, 2720755675624398643ull}},
{{7634079011811723499ull, 9057822797165172090ull,
  3848352689847403611ull, 3400944594530498304ull}},
{{319226727909878566ull, 6710592478029077209ull, 4810440862309254514ull,
  4251180743163122880ull}},
{{11728731751012143864ull, 8805806317195561159ull,
  3006525538943284071ull, 2656987964476951800ull}},
{{10049228670337791926ull, 6395571878067063545ull,
  3758156923679105089ull, 3321234955596189750ull}},
{{17173221856349627811ull, 12606150866011217335ull,
  13921068191453657169ull, 4151543694495237187ull}},
{{17650792687859599238ull, 961315263615928978ull,
  6394824610444841779ull, 2594714809059523242ull}},
{{12840118822969723240ull, 15036702134802074935ull,
  17216902799910828031ull, 3243393511324404052ull}},
{{11438462510284766145ull, 14184191650075205765ull,
  3074384426178983423ull, 4054241889155505066ull}},
{{9454882078141672793ull, 15782648808938085459ull,
  6533176284789252543ull, 2533901180722190666ull}},
{{7206916579249703087ull, 15116624992745218920ull,
  17389842392841341487ull, 3167376475902738332ull}},
{{9008645724062128859ull, 14284095222504135746ull,
  3290558917342125243ull, 3959220594878422916ull}},
{{10242089595966218441ull, 6621716504851390889ull,
  11279971360193604085ull, 2474512871799014322ull}},
{{17414298013385160955ull, 12888831649491626515ull,
  4876592163387229298ull, 3093141089748767903ull}},
{{17156186498304063290ull, 6887667525009757336ull,
  1484054185806648719ull, 3866426362185959879ull}},
{{10722616561440039556ull, 11222321230772180191ull,
  7845062893770237305ull, 2416516476366224924ull}},
{{8791584683372661541ull, 192843483183061527ull, 9806328617212796632ull,
  3020645595457781155ull}},
{{6377794835788439022ull, 241054353978826909ull, 7646224753088607886ull,
  3775806994322226444ull}},
{{6291964781581468341ull, 13985717026518930530ull,
  14002262507535155736ull, 2359879371451391527ull}},
{{17088328013831611234ull, 17482146283148663162ull,
  12891142115991556766ull, 2949849214314239409ull}},
{{12137037980434738235ull, 12629310817081053145ull,
  2278869589707282246ull, 3687311517892799262ull}},
{{1336239420261259081ull, 6563266484496540624ull,
  12071959023988878616ull, 4609139397365999077ull}},
{{835149637663286926ull, 4102041552810337890ull, 9850817399206743087ull,
  2880712123353749423ull}},
{{10267309083933884466ull, 515865922585534458ull,
  7701835730581040955ull, 3600890154192186779ull}},
{{3610764318062579774ull, 14479890458514081785ull,
  5015608644798913289ull, 4501112692740233474ull}},
{{13785942744857582119ull, 2132402508930219259ull,
  7746441421426708710ull, 2813195432962645921ull}},
{{12620742412644589744ull, 11888875173017549882ull,
  14294737795210773791ull, 3516494291203307401ull}},
{{6552555978950961372ull, 10249407947844549449ull,
  4033364188731303527ull, 4395617864004134252ull}},
{{15624562532912820618ull, 13323408995043925261ull,
  11744224654811840512ull, 2747261165002583907ull}},
{{5695645110858862060ull, 16654261243804906577ull,
  10068594800087412736ull, 3434076456253229884ull}},
{{11731242407000965479ull, 2371082481046581605ull,
  12585743500109265921ull, 4292595570316537355ull}},
{{9637869513589297377ull, 13011141596722583263ull,
  5560246678354597248ull, 2682872231447835847ull}},
{{7435650873559233817ull, 16263926995903229079ull,
  2338622329515858656ull, 3353590289309794809ull}},
{{4682877573521654367ull, 1883164671169484733ull,
  7534963930322211225ull, 4191987861637243511ull}},
{{5232641492664727931ull, 12706192965549397718ull,
  11626881484092463871ull, 2619992413523277194ull}},
{{15764173902685685722ull, 11271055188509359243ull,
  5310229818260804031ull, 3274990516904096493ull}},
{{15093531359929719249ull, 9477132967209311150ull,
  11249473291253392943ull, 4093738146130120616ull}},
{{4821771081528686627ull, 12840737132146901325ull,
  7030920807033370589ull, 2558586341331325385ull}},
{{10638899870338246187ull, 2215863359901462944ull,
  13400337027219101141ull, 3198232926664156731ull}},
{{13298624837922807734ull, 7381515218304216584ull,
  12138735265596488522ull, 3997791158330195914ull}},
{{8311640523701754834ull, 9225133029867523269ull,
  12198395559425193230ull, 2498619473956372446ull}},
{{15001236673054581446ull, 2308044250479628278ull,
  6024622412426715730ull, 3123274342445465558ull}},
{{9528173804463450999ull, 12108427349954311156ull,
  16754150052388170470ull, 3904092928056831947ull}},
{{15178480664644432683ull, 2956081075294056568ull,
  8165500773528912592ull, 2440058080035519967ull}},
{{526356757095989237ull, 3695101344117570711ull, 5595189948483752836ull,
  3050072600044399959ull}},
{{14493004001652150259ull, 4618876680146963388ull,
  2382301417177303141ull, 3812590750055499949ull}},
{{18281499537887369720ull, 5192640934305546069ull,
  3794781394949508415ull, 2382869218784687468ull}},
{{9016816367077048438ull, 1879115149454544683ull,
  4743476743686885519ull, 2978586523480859335ull}},
{{6659334440418922643ull, 16183951992100344566ull,
  1317659911181218994ull, 3723233154351074169ull}},
{{17997142080543990364ull, 14726656013490103257ull,
  12352752490556731631ull, 2327020721469421355ull}},
{{8661369545397824243ull, 13796633998435241168ull,
  10829254594768526635ull, 2908775901836776694ull}},
{{10826711931747280304ull, 12634106479616663556ull,
  4313196206605882486ull, 3635969877295970868ull}},
{{13533389914684100379ull, 6569261062666053637ull,
  5391495258257353108ull, 4544962346619963585ull}},
{{10764211705891256689ull, 13329160201021059331ull,
  14898899582479315452ull, 2840601466637477240ull}},
{{8843578613936682957ull, 16661450251276324164ull,
  176880404389592699ull, 3550751833296846551ull}},
{{11054473267420853697ull, 16215126795668017301ull,
  14056158560769154586ull, 4438439791621058188ull}},
{{9214888801351727513ull, 14746140265719898717ull,
  18008471137335497424ull, 2774024869763161367ull}},
{{16130297020117047295ull, 18432675332149873396ull,
  17898902903241983876ull, 3467531087203951709ull}},
{{1716127201436757502ull, 4594100091477790130ull,
  8538570573770316134ull, 4334413859004939637ull}},
{{5684265519325361343ull, 16706370612455782543ull,
  7642449617820141535ull, 2709008661878087273ull}},
{{2493645880729313775ull, 16271277247142340275ull,
  14164748040702564823ull, 3386260827347609091ull}},
{{16952115406193805930ull, 15727410540500537439ull,
  13094249032450818125ull, 4232826034184511364ull}},
{{17512601156512210563ull, 12135474597026529851ull,
  17407277682136537136ull, 2645516271365319602ull}},
{{17279065427212875299ull, 15169343246283162314ull,
  12535725065815895612ull, 3306895339206649503ull}},
{{12375459747161318316ull, 514934984144401277ull,
  11057970313842481612ull, 4133619174008311879ull}},
{{10040505351189517900ull, 9545206401945026606ull,
  13828760473792632863ull, 2583511983755194924ull}},
{{3327259652132121566ull, 7319821984003895354ull,
  17285950592240791079ull, 3229389979693993655ull}},
{{13382446602019927766ull, 4538091461577481288ull,
  16995752221873600945ull, 4036737474617492069ull}},
{{8364029126262454854ull, 14365522209554395565ull,
  12928188147884694542ull, 2522960921635932543ull}},
{{15066722426255456471ull, 8733530725088218648ull,
  11548549166428480274ull, 3153701152044915679ull}},
{{386658959109768973ull, 1693541369505497503ull, 9824000439608212439ull,
  3942126440056144599ull}},
{{7159190877084687464ull, 7975992383582017795ull,
  13057529302396214630ull, 2463829025035090374ull}},
{{4337302577928471426ull, 746618442622746436ull, 7098539591140492480ull,
  3079786281293862968ull}},
{{5421628222410589282ull, 933273053278433045ull, 8873174488925615600ull,
  3849732851617328710ull}},
{{5694360648220312254ull, 583295658299020653ull, 934048037151121846ull,
  2406083032260830444ull}},
{{11729636828702778221ull, 9952491609728551624ull,
  1167560046438902307ull, 3007603790326038055ull}},
{{14662046035878472776ull, 7828928493733301626ull,
  15294508113330791596ull, 3759504737907547568ull}},
{{13775464790851433389ull, 14116452345438089324ull,
  9559067570831744747ull, 2349690461192217230ull}},
{{17219330988564291736ull, 13033879413370223751ull,
  2725462426684905126ull, 2937113076490271538ull}},
{{16912477717277976766ull, 7068977229858003881ull,
  12630200070210907216ull, 3671391345612839422ull}},
{{7305539091315307246ull, 8836221537322504852ull,
  6564378050908858212ull, 4589239182016049278ull}},
{{13789333968926842837ull, 14746010497681341340ull,
  17937794337100200094ull, 2868274488760030798ull}},
{{17236667461158553546ull, 9209141085246900867ull,
  13198870884520474310ull, 3585343110950038498ull}},
{{16934148308020804028ull, 2288054319703850276ull,
  7275216568795817080ull, 4481678888687548123ull}},
{{1360470655658226710ull, 1430033949814906423ull,
  2241167346283691723ull, 2801049305429717577ull}},
{{15535646374854947099ull, 15622600492550796740ull,
  7413145201282002557ull, 3501311631787146971ull}},
{{972813894859132258ull, 5693192560406332214ull, 4654745483175115293ull,
  4376639539733933714ull}},
{{14443066739569121373ull, 5864088359467651585ull,
  7520901945411834962ull, 2735399712333708571ull}},
{{4218775369179238005ull, 16553482486189340290ull,
  4789441413337405798ull, 3419249640417135714ull}},
{{14496841248328823314ull, 11468481070881899554ull,
  15210173803526533056ull, 4274062050521419642ull}},
{{13672211798632902475ull, 7167800669301187221ull,
  14118044645631471064ull, 2671288781575887276ull}},
{{3255206693008964382ull, 8959750836626484027ull,
  17647555807039338830ull, 3339110976969859095ull}},
{{17904066421543369189ull, 1976316508928329225ull,
  17447758740371785634ull, 4173888721212323869ull}},
{{4272512485823523887ull, 5846883836507593670ull,
  13210692221946059973ull, 2608680450757702418ull}},
{{14564012644134180667ull, 11920290814061879991ull,
  7289993240577799158ull, 3260850563447128023ull}},
{{13593329786740337930ull, 5676991480722574181ull,
  4500805532294861044ull, 4076063204308910029ull}},
{{10801674125926405158ull, 12771491712306384671ull,
  5118846466897982104ull, 2547539502693068768ull}},
{{8890406638980618544ull, 15964364640382980839ull,
  6398558083622477630ull, 3184424378366335960ull}},
{{6501322280298385276ull, 10732083763623950241ull,
  7998197604528097038ull, 3980530472957919950ull}},
{{15592541471254960558ull, 2095866333837580996ull,
  387187484402672745ull, 2487831545598699969ull}},
{{1043932765359149081ull, 7231518935724364150ull,
  5095670373930728835ull, 3109789431998374961ull}},
{{10528287993553712159ull, 4427712651228067283ull,
  10981273985840798948ull, 3887236789997968701ull}},
{{4274336986757376147ull, 11990692443872317860ull,
  9169139250364193294ull, 2429522993748730438ull}},
{{5342921233446720184ull, 5764993517985621517ull,
  2238052026100465810ull, 3036903742185913048ull}},
{{11290337560235788134ull, 16429613934336802704ull,
  2797565032625582262ull, 3796129677732391310ull}},
{{7056460975147367584ull, 5656822690533113786ull,
  15583536200673152626ull, 2372581048582744568ull}},
{{18043948255788985288ull, 16294400400021168040ull,
  1032676177131889166ull, 2965726310728430711ull}},
{{4108191246026679994ull, 11144628463171684243ull,
  15125903276697025170ull, 3707157888410538388ull}},
{{261776519552981044ull, 11577078807909690556ull, 230317511080864923ull,
  2316973680256586493ull}},
{{327220649441226305ull, 9859662491459725291ull, 4899582907278469058ull,
  2896217100320733116ull}},
{{14244083867083696593ull, 3101206077469880805ull,
  6124478634098086323ull, 3620271375400916395ull}},
{{3970046778572457030ull, 17711565652119514719ull,
  3043912274195219999ull, 4525339219251145494ull}},
{{9398808264248867500ull, 17987257560215778555ull,
  15737503226654176211ull, 2828337012031965933ull}},
{{7136824311883696470ull, 17872385931842335290ull,
  5836820978035556552ull, 3535421265039957417ull}},
{{18144402426709396396ull, 3893738341093367496ull,
  11907712240971833595ull, 4419276581299946771ull}},
{{11340251516693372748ull, 127743453969660733ull,
  5136477141393702045ull, 2762047863312466732ull}},
{{340256340584552222ull, 4771365335889463821ull, 6420596426742127556ull,
  3452559829140583415ull}},
{{5037006444158078182ull, 5964206669861829776ull,
  3414059515000271541ull, 4315699786425729269ull}},
{{3148129027598798864ull, 6033472177877337562ull,
  4439630206088863665ull, 2697312366516080793ull}},
{{13158533321353274388ull, 12153526240774059856ull,
  10161223776038467485ull, 3371640458145100991ull}},
{{16448166651691592985ull, 1356849745685411108ull,
  8089843701620696453ull, 4214550572681376239ull}},
{{1056732120452469808ull, 3153874100267075895ull,
  11973681341154017139ull, 2634094107925860149ull}},
{{15155973205847750971ull, 17777400680616008580ull,
  1132043621160357711ull, 3292617634907325187ull}},
{{498222433600137098ull, 17610064832342622822ull,
  15250112581732610851ull, 4115772043634156483ull}},
{{14146447076282249398ull, 8700447511000445311ull,
  7225477354369187830ull, 2572357527271347802ull}},
{{13071372826925423844ull, 1652187351895780831ull,
  18255218729816260596ull, 3215446909089184752ull}},
{{11727530015229391901ull, 2065234189869726039ull,
  4372279338560774129ull, 4019308636361480941ull}},
{{14247235287159451794ull, 12819986414737048534ull,
  5038517595814177782ull, 2512067897725925588ull}},
{{8585672072094538935ull, 6801610981566534860ull,
  6298146994767722228ull, 3140084872157406985ull}},
{{10732090090118173668ull, 8502013726958168575ull,
  12484369761887040689ull, 3925106090196758731ull}},
{{13625085333964940399ull, 16842973625417325119ull,
  5496888091965706478ull, 2453191306372974207ull}},
{{12419670649028787594ull, 11830344994916880591ull,
  2259424096529745194ull, 3066489132966217759ull}},
{{10912902292858596589ull, 5564559206791324931ull,
  16659338175944345205ull, 3833111416207772198ull}},
{{4514720923822928916ull, 5783692513458272034ull,
  5800400341537827849ull, 2395694635129857624ull}},
{{14866773191633436953ull, 11841301660250227946ull,
  7250500426922284811ull, 2994618293912322030ull}},
{{9360094452687020383ull, 10189941056885397029ull,
  18286497570507631822ull, 3743272867390402537ull}},
{{8155902042143081692ull, 1757027142125985239ull,
  4511531953926188033ull, 2339545542119001586ull}},
{{5583191534251464211ull, 6807969946084869453ull,
  14862786979262510849ull, 2924431927648751982ull}},
{{11590675436241718167ull, 13121648451033474720ull,
  9355111687223362753ull, 3655539909560939978ull}},
{{14488344295302147709ull, 2567002508509679688ull,
  2470517572174427634ull, 4569424886951174973ull}},
{{9055215184563842318ull, 6216062586245937709ull,
  3849916491822711223ull, 2855890554344484358ull}},
{{15930704999132190802ull, 3158392214380034232ull,
  14035767651633164837ull, 3569863192930605447ull}},
{{1466637175205686886ull, 8559676286402430695ull,
  12933023546114068142ull, 4462328991163256809ull}},
{{7834177262144636160ull, 738111660574131280ull, 1165610688680210733ull,
  2788955619477035506ull}},
{{9792721577680795200ull, 5534325594145052004ull,
  10680385397705039224ull, 3486194524346294382ull}},
{{12240901972100993999ull, 6917906992681315005ull,
  4127109710276523222ull, 4357743155432867978ull}},
{{9956406741776815202ull, 18158749925707985590ull,
  7191129587350214917ull, 2723589472145542486ull}},
{{3222136390366243194ull, 8863379351852818276ull,
  18212284021042544455ull, 3404486840181928107ull}},
{{4027670487957803993ull, 6467538171388634941ull,
  18153669007875792665ull, 4255608550227410134ull}},
{{4823137064187321448ull, 15571426403186366598ull,
  6734357111494982511ull, 2659755343892131334ull}},
{{15252293367088927617ull, 14852596985555570343ull,
  17641318426223503947ull, 3324694179865164167ull}},
{{14453680690433771617ull, 13954060213517075025ull,
  17439962014351992030ull, 4155867724831455209ull}},
{{2116021403880025405ull, 4109601615020783987ull,
  3982447231328913163ull, 2597417328019659506ull}},
{{16480084810132195468ull, 525316000348592079ull,
  14201431076015917262ull, 3246771660024574382ull}},
{{15988419994237856431ull, 9880017037290515907ull,
  8528416808165120769ull, 4058464575030717978ull}},
{{7686919487184966318ull, 17704225694375042202ull,
  9941946523530588384ull, 2536540359394198736ull}},
{{385277322126432089ull, 3683538044259251137ull,
  12427433154413235481ull, 3170675449242748420ull}},
{{5093282671085428015ull, 9216108573751451825ull,
  15534291443016544351ull, 3963344311553435525ull}},
{{14712516715496862270ull, 12677596886235739246ull,
  12014775161099034171ull, 2477090194720897203ull}},
{{9167273857516302029ull, 11235310089367286154ull,
  10406782932946404810ull, 3096362743401121504ull}},
{{2235720285040601728ull, 4820765574854331885ull,
  13008478666183006013ull, 3870453429251401880ull}},
{{3703168187364070032ull, 5318821493497651380ull,
  8130299166364378758ull, 2419033393282126175ull}},
{{4628960234205087540ull, 15871898903726840033ull,
  5551187939528085543ull, 3023791741602657719ull}},
{{10397886311183747329ull, 15228187611231162137ull,
  2327298905982719025ull, 3779739677003322149ull}},
{{18027893990558311841ull, 2600088229378394479ull,
  3760404825452893343ull, 2362337298127076343ull}},
{{17923181469770501897ull, 17085168342005156811ull,
  88820013388728774ull, 2952921622658845429ull}},
{{17792290818785739467ull, 12133088390651670206ull,
  4722711035163298872ull, 3691152028323556786ull}},
{{6508495743313699263ull, 7583180244157293879ull,
  7563380415404449699ull, 2306970017702222991ull}},
{{3523933660714736175ull, 4867289286769229445ull,
  4842539500828174220ull, 2883712522127778739ull}},
{{9016603094320808122ull, 6084111608461536806ull,
  1441488357607829871ull, 3604640652659723424ull}},
{{2047381831046234345ull, 2993453492149533104ull,
  1801860447009787339ull, 4505800815824654280ull}},
{{1279613644403896466ull, 18011809497089315854ull,
  1126162779381117086ull, 2816125509890408925ull}},
{{10822889092359646390ull, 13291389834506869009ull,
  6019389492653784262ull, 3520156887363011156ull}},
{{18140297383876945891ull, 7390865256278810453ull,
  7524236865817230328ull, 4400196109203763945ull}},
{{13643528874136785134ull, 4619290785174256533ull,
  16231863087204238715ull, 2750122568252352465ull}},
{{3219353037388817706ull, 1162427463040432763ull,
  6454770803723134682ull, 3437653210315440582ull}},
{{17859249352018185844ull, 10676406365655316761ull,
  17291835541508694160ull, 4297066512894300727ull}},
{{4244501817370284297ull, 6672753978534572976ull,
  17724926241084015706ull, 2685666570558937954ull}},
{{5305627271712855371ull, 17564314510022992028ull,
  12932785764500243824ull, 3357083213198672443ull}},
{{6632034089641069213ull, 3508649063819188419ull,
  11554296187197916877ull, 4196354016498340554ull}},
{{1839178296811974306ull, 4498748674100686714ull,
  11833121135426085952ull, 2622721260311462846ull}},
{{11522344907869743691ull, 5623435842625858392ull,
  5568029382427831632ull, 3278401575389328558ull}},
{{14402931134837179614ull, 7029294803282322990ull,
  16183408764889565348ull, 4098001969236660697ull}},
{{4390145940845849355ull, 13616681288906227677ull,
  3197101450414896486ull, 2561251230772912936ull}},
{{10099368444484699597ull, 7797479574278008788ull,
  3996376813018620608ull, 3201564038466141170ull}},
{{12624210555605874496ull, 9746849467847510985ull,
  14218843053128051568ull, 4001955048082676462ull}},
{{972602569612589704ull, 6091780917404694366ull, 4275090889777644326ull,
  2501221905051672789ull}},
{{10439125248870512938ull, 16838098183610643765ull,
  9955549630649443311ull, 3126527381314590986ull}},
{{17660592579515529077ull, 16435936711085916802ull,
  3221065001457028331ull, 3908159226643238733ull}},
{{15649556380624593577ull, 7966617435215004049ull,
  4319008635124336659ull, 2442599516652024208ull}},
{{5726887420498578259ull, 5346585775591367158ull,
  5398760793905420824ull, 3053249395815030260ull}},
{{16381981312477998632ull, 6683232219489208947ull,
  6748450992381776030ull, 3816561744768787825ull}},
{{7932895311085055193ull, 18012078192462919304ull,
  15746996916307079778ull, 2385351090480492390ull}},
{{9916119138856318992ull, 13291725703723873322ull,
  10460374108529073915ull, 2981688863100615488ull}},
{{3171776886715622931ull, 12002971111227453749ull,
  13075467635661342394ull, 3727111078875769360ull}},
{{4288203563410958284ull, 12113542962944546497ull,
  8172167272288338996ull, 2329444424297355850ull}},
{{9971940472691085759ull, 15141928703680683121ull,
  991837053505647937ull, 2911805530371694813ull}},
{{17076611609291245103ull, 5092352824318690189ull,
  5851482335309447826ull, 3639756912964618516ull}},
{{7510706456331892666ull, 15588813067253138545ull,
  7314352919136809782ull, 4549696141205773145ull}},
{{16223406581275902677ull, 5131322148605823686ull,
  16100685620528975874ull, 2843560088253608215ull}},
{{11055886189740102538ull, 15637524722612055416ull,
  15514171007233831938ull, 3554450110317010269ull}},
{{13819857737175128172ull, 10323533866410293462ull,
  5557655703760126211ull, 4443062637896262837ull}},
{{4025725067307067204ull, 4146365657292739462ull,
  5779377824063772834ull, 2776914148685164273ull}},
{{14255528370988609813ull, 14406329108470700135ull,
  11835908298507103946ull, 3471142685856455341ull}},
{{13207724445308374362ull, 8784539348733599361ull,
  959827317851716221ull, 4338928357320569177ull}},
{{1337298750676652120ull, 7796180102172193553ull,
  12129107119725792398ull, 2711830223325355735ull}},
{{6283309456773203054ull, 521853090860466133ull,
  10549697881229852594ull, 3389787779156694669ull}},
{{12465822839393891721ull, 9875688400430358474ull,
  17798808369964703646ull, 4237234723945868336ull}},
{{12402825293048570230ull, 1560619231841586142ull,
  11124255231227939779ull, 2648271702466167710ull}},
{{6280159579455936979ull, 15785832095084146390ull,
  4681947002180148915ull, 3310339628082709638ull}},
{{17073571511174697032ull, 15120604100427795083ull,
  15075805789579961952ull, 4137924535103387047ull}},
{{8365139185270491693ull, 9450377562767371927ull,
  16339907646128558076ull, 2586202834439616904ull}},
{{5844737963160726713ull, 11812971953459214909ull,
  1978140483951145979ull, 3232753543049521131ull}},
{{11917608472378296295ull, 10154528923396630732ull,
  16307733660221096186ull, 4040941928811901413ull}},
{{16671877332091210992ull, 10958266595550282111ull,
  12498176546851879068ull, 2525588705507438383ull}},
{{16228160646686625836ull, 13697833244437852639ull,
  11011034665137460931ull, 3156985881884297979ull}},
{{15673514789930894391ull, 12510605537119927895ull,
  9152107312994438260ull, 3946232352355372474ull}},
{{16713475771347890851ull, 17042500497554730742ull,
  10331753089048911816ull, 2466395220222107796ull}},
{{11668472677330087755ull, 2856381548233861812ull,
  12914691361311139771ull, 3082994025277634745ull}},
{{14585590846662609694ull, 17405534990574490977ull,
  2308306146356761001ull, 3853742531597043432ull}},
{{2198465251523049203ull, 3960930341467975005ull,
  1442691341472975626ull, 2408589082248152145ull}},
{{7359767582831199407ull, 14174534963689744564ull,
  6415050195268607436ull, 3010736352810190181ull}},
{{9199709478538999259ull, 17718168704612180705ull,
  12630498762513147199ull, 3763420441012737726ull}},
{{17279033470155344297ull, 17991384468023694796ull,
  3282375708143329095ull, 2352137775632961079ull}},
{{3152047763984628755ull, 17877544566602230592ull,
  17938027690461325081ull, 2940172219541201348ull}},
{{3940059704980785944ull, 8511872652970624528ull,
  3975790539367104736ull, 3675215274426501686ull}},
{{4925074631225982430ull, 10639840816213280660ull,
  14193110211063656728ull, 4594019093033127107ull}},
{{12301543681371014827ull, 6649900510133300412ull,
  6564850872701091503ull, 2871261933145704442ull}},
{{15376929601713768534ull, 3700689619239237611ull,
  17429435627731140187ull, 3589077416432130552ull}},
{{14609475983714822763ull, 14176005621659110ull, 3340050460954373618ull,
  4486346770540163191ull}},
{{4519236471394376323ull, 4620546021940924848ull,
  9005060565737565367ull, 2803966731587601994ull}},
{{5649045589242970404ull, 1163996508998768156ull,
  2032953670317180901ull, 3504958414484502493ull}},
{{7061306986553713004ull, 6066681654675848099ull,
  7152878106323864030ull, 4381198018105628116ull}},
{{2107473857382376676ull, 17626734089454568774ull,
  13693920853307190826ull, 2738248761316017572ull}},
{{11857714358582746653ull, 12810045574963435159ull,
  17117401066633988533ull, 3422810951645021965ull}},
{{10210456929801045412ull, 2177498913422130237ull,
  7561693278010321955ull, 4278513689556277457ull}},
{{8687378590339347335ull, 17501837885384689062ull,
  16255273344824920981ull, 2674071055972673410ull}},
{{1635851201069408360ull, 8042239301448697616ull,
  11095719644176375419ull, 3342588819965841763ull}},
{{2044814001336760450ull, 5441113108383484116ull,
  9257963536793081370ull, 4178236024957302204ull}},
{{10501380787690251089ull, 8012381711167065476ull,
  15009599247350451664ull, 2611397515598313877ull}},
{{13126725984612813862ull, 10015477138958831845ull,
  4926941003905900868ull, 3264246894497892347ull}},
{{2573349425483853615ull, 12519346423698539807ull,
  1546990236454988181ull, 4080308618122365434ull}},
{{8525872418568490365ull, 10130434524025281331ull,
  5578554916211755517ull, 2550192886326478396ull}},
{{6045654504783225053ull, 17274729173458989568ull,
  6973193645264694396ull, 3187741107908097995ull}},
{{7557068130979031316ull, 3146667393114185344ull,
  4104806038153480092ull, 3984676384885122494ull}},
{{4723167581861894573ull, 11190039157551141648ull,
  16400561829128088769ull, 2490422740553201558ul